/** @packageDocumentation
 * @module Common
 */
import { I18N } from "@bentley/imodeljs-i18n";
/**
 * Manages the I18N service for the ui-components package.
 * @public
 */
export declare class UiComponents {
    private static _initialized;
    private static _i18n?;
    /**
     * Registers the I18N service namespace for UiComponents. Also initializes UiCore.
     * @param i18n The internationalization service created by the application. Defaults to IModelApp.i18n.
     */
    static initialize(i18n?: I18N): Promise<void>;
    /** Unregisters the UiComponents I18N namespace */
    static terminate(): void;
    /** Determines if UiComponents has been initialized */
    static get initialized(): boolean;
    /** The internationalization service created by the application. */
    static get i18n(): I18N;
    /** The internationalization service namespace. */
    static get i18nNamespace(): string;
    /** @internal */
    static get packageName(): string;
    /** Calls i18n.translateWithNamespace with the "UiComponents" namespace. Do NOT include the namespace in the key.
     * @internal
     */
    static translate(key: string | string[]): string;
    /** @internal */
    static loggerCategory(obj: any): string;
}
//# sourceMappingURL=UiComponents.d.ts.map