/** @packageDocumentation
 * @module Breadcrumb
 */
import * as React from "react";
import { CommonProps } from "@bentley/ui-core";
import { TableProps } from "../../table/component/Table";
import { ColumnDescription, TableDataProvider } from "../../table/TableDataProvider";
import { TreeNodeItem } from "../../tree/TreeDataProvider";
import { BreadcrumbPath } from "../BreadcrumbPath";
/** Properties for the [[BreadcrumbDetails]] component
 * @beta
 */
export interface BreadcrumbDetailsProps extends CommonProps {
    /** Path data object shared by Breadcrumb component */
    path: BreadcrumbPath;
    columns?: ColumnDescription[];
    renderTable?: (props: TableProps, node: TreeNodeItem | undefined, children: TreeNodeItem[]) => React.ReactNode;
    /** Callback triggered when child node is loaded with an asynchronous dataProvider. */
    onChildrenLoaded?: (parent: TreeNodeItem, children: TreeNodeItem[]) => void;
    /** Callback triggered when root nodes are loaded with an asynchronous dataProvider. */
    onRootNodesLoaded?: (nodes: TreeNodeItem[]) => void;
    /** @internal */
    onRender?: () => void;
}
/** @internal */
interface BreadcrumbDetailsState {
    table?: TableDataProvider;
    childNodes?: TreeNodeItem[];
    modelReady: boolean;
}
/**
 * A Table containing all children of tree node specified in path.
 * Used in conjunction with [[Breadcrumb]] to see children of current path.
 * @beta
 */
export declare class BreadcrumbDetails extends React.Component<BreadcrumbDetailsProps, BreadcrumbDetailsState> {
    private _tree;
    private _mounted;
    readonly state: BreadcrumbDetailsState;
    /** @internal */
    constructor(props: BreadcrumbDetailsProps);
    /** @internal */
    componentDidMount(): void;
    /** @internal */
    componentWillUnmount(): void;
    /** @internal */
    componentDidUpdate(prevProps: BreadcrumbDetailsProps): void;
    private _recreateTree;
    /** @internal */
    shouldComponentUpdate(nextProps: BreadcrumbDetailsProps, nextState: BreadcrumbDetailsState): boolean;
    private _onModelLoaded;
    private _onChildrenLoaded;
    private _onModelReady;
    private _onTreeNodeChanged;
    private static inspireNodeFromTreeNodeItem;
    private _treeChange;
    private _pathChange;
    private _updateTree;
    /** @internal */
    render(): React.ReactNode;
    private renderTable;
}
export {};
//# sourceMappingURL=BreadcrumbDetails.d.ts.map