"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Breadcrumb
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BreadcrumbDetails = void 0;
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const getPropertyRecordAsString_1 = require("../../common/getPropertyRecordAsString");
const Table_1 = require("../../table/component/Table");
const BeInspireTree_1 = require("../../tree/deprecated/component/BeInspireTree");
const TreeDataProvider_1 = require("../../tree/TreeDataProvider");
const UiComponents_1 = require("../../UiComponents");
const BreadcrumbTreeUtils_1 = require("../BreadcrumbTreeUtils");
/**
 * A Table containing all children of tree node specified in path.
 * Used in conjunction with [[Breadcrumb]] to see children of current path.
 * @beta
 */
class BreadcrumbDetails extends React.Component {
    /** @internal */
    constructor(props) {
        super(props);
        this._mounted = false;
        this._onModelLoaded = (rootNodes) => {
            const node = this.props.path.getCurrentNode();
            if (node === undefined)
                this._updateTree(undefined);
            if (this.props.onRootNodesLoaded)
                this.props.onRootNodesLoaded(rootNodes.map((n) => n.payload));
        };
        this._onChildrenLoaded = (parentNode) => {
            const node = this.props.path.getCurrentNode();
            if (node !== undefined) {
                const iNode = this._tree.node(node.id);
                this._updateTree(iNode);
            }
            const children = parentNode.getChildren();
            if (this.props.onChildrenLoaded)
                this.props.onChildrenLoaded(parentNode.payload, BeInspireTree_1.toNodes(children).map((c) => c.payload));
        };
        this._onModelReady = () => {
            // istanbul ignore else
            if (this._mounted)
                this.setState({ modelReady: true });
        };
        this._onTreeNodeChanged = (_items) => {
            bentleyjs_core_1.using(this._tree.pauseRendering(), async () => {
                await this._tree.reload();
            });
        };
        this._treeChange = () => {
            const currentNode = this.props.path.getCurrentNode();
            this._updateTree(currentNode ? this._tree.node(currentNode.id) : undefined);
        };
        this._pathChange = (args) => {
            this._updateTree(args.currentNode ? this._tree.node(args.currentNode.id) : undefined);
            if (TreeDataProvider_1.isTreeDataProviderInterface(args.oldDataProvider) && args.oldDataProvider.onTreeNodeChanged) {
                // unsubscribe from previous data provider `onTreeNodeChanged` events
                args.oldDataProvider.onTreeNodeChanged.removeListener(this._onTreeNodeChanged);
            }
            if (TreeDataProvider_1.isTreeDataProviderInterface(args.dataProvider) && args.dataProvider.onTreeNodeChanged) {
                // subscribe for new data provider `onTreeNodeChanged` events
                args.dataProvider.onTreeNodeChanged.addListener(this._onTreeNodeChanged);
            }
            if (args.dataProvider !== args.oldDataProvider) {
                // istanbul ignore else
                if (this._mounted)
                    this.setState({ modelReady: false }, () => {
                        this._recreateTree();
                    });
            }
        };
        this._updateTree = (node) => {
            const childNodes = (node ? BeInspireTree_1.toNodes(node.getChildren()) : this._tree.nodes()).map((child) => child.payload);
            if (childNodes.length === 0) {
                const parents = node ? BeInspireTree_1.toNodes(node.getParents()).map((child) => child.payload) : [];
                parents.reverse();
                if (parents.length > 1)
                    this.props.path.setCurrentNode(parents[parents.length - 2]);
                else if (parents.length === 1)
                    this.props.path.setCurrentNode(undefined);
            }
            const table = BreadcrumbTreeUtils_1.BreadcrumbTreeUtils.aliasNodeListToTableDataProvider(childNodes, this.props.columns || [
                { key: "icon", label: UiComponents_1.UiComponents.translate("breadcrumb.icon"), icon: true },
                { key: "label", label: UiComponents_1.UiComponents.translate("breadcrumb.name") },
                { key: "description", label: UiComponents_1.UiComponents.translate("breadcrumb.description") },
            ], this.props.path.getDataProvider());
            // istanbul ignore else hard to control whether mounted or not
            if (this._mounted)
                this.setState({ table, childNodes });
        };
        // eslint-disable-next-line @typescript-eslint/naming-convention
        this.renderTable = (props, _node, _children) => {
            return React.createElement(Table_1.Table, Object.assign({}, props, { onRender: this.props.onRender }));
        };
        this.state = {
            modelReady: TreeDataProvider_1.isTreeDataProviderInterface(props.path.getDataProvider()) ? false : true,
        };
        this._recreateTree();
    }
    /** @internal */
    componentDidMount() {
        this._mounted = true;
        /* istanbul ignore next */
        if (this.props.onRender)
            this.props.onRender();
        const dataProvider = this.props.path.getDataProvider();
        const node = this.props.path.getCurrentNode();
        this._updateTree(node ? this._tree.node(node.id) : undefined);
        if (TreeDataProvider_1.isTreeDataProviderInterface(dataProvider) && dataProvider.onTreeNodeChanged)
            dataProvider.onTreeNodeChanged.addListener(this._treeChange);
        this.props.path.BreadcrumbUpdateEvent.addListener(this._pathChange);
    }
    /** @internal */
    componentWillUnmount() {
        this._mounted = false;
        this._tree.removeAllListeners();
        const dataProvider = this.props.path.getDataProvider();
        if (TreeDataProvider_1.isTreeDataProviderInterface(dataProvider) && dataProvider.onTreeNodeChanged)
            dataProvider.onTreeNodeChanged.removeListener(this._treeChange);
        this.props.path.BreadcrumbUpdateEvent.removeListener(this._pathChange);
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        /* istanbul ignore next */
        if (this.props.onRender)
            this.props.onRender();
        if (!this.props.path.BreadcrumbUpdateEvent.has(this._pathChange)) {
            this.props.path.BreadcrumbUpdateEvent.addListener(this._pathChange);
            prevProps.path.BreadcrumbUpdateEvent.removeListener(this._pathChange);
        }
    }
    _recreateTree() {
        this._tree = new BeInspireTree_1.BeInspireTree({
            dataProvider: this.props.path.getDataProvider(),
            mapPayloadToInspireNodeConfig: BreadcrumbDetails.inspireNodeFromTreeNodeItem,
        });
        this._tree.on(BeInspireTree_1.BeInspireTreeEvent.ModelLoaded, this._onModelLoaded);
        this._tree.on(BeInspireTree_1.BeInspireTreeEvent.ChildrenLoaded, this._onChildrenLoaded);
        this._tree.ready.then(this._onModelReady); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    shouldComponentUpdate(nextProps, nextState) {
        if (this.state.modelReady !== nextState.modelReady) {
            // always render when state.modelReady changes
            return true;
        }
        // istanbul ignore if
        if (!nextState.modelReady) {
            // if we got here and model is not ready - don't render
            return false;
        }
        const cNode = nextProps.path.getCurrentNode();
        const current = cNode ? this._tree.node(cNode.id) : undefined;
        // otherwise, render when any of the following props / state change
        return this.props.renderTable !== nextProps.renderTable
            || this.props.path !== nextProps.path
            || this.state.table !== nextState.table
            || (current !== undefined && /* istanbul ignore next */ current.isDirty());
    }
    static inspireNodeFromTreeNodeItem(item, remapper) {
        const node = {
            id: item.id,
            text: getPropertyRecordAsString_1.getPropertyRecordAsString(item.label),
            itree: {
                state: { collapsed: false },
            },
        };
        if (item.icon)
            node.itree.icon = item.icon;
        if (item.hasChildren)
            node.children = true;
        else if (item.children)
            node.children = item.children.map((p) => remapper(p, remapper));
        return node;
    }
    /** @internal */
    render() {
        const node = this.props.path.getCurrentNode();
        if (node) {
            const iNode = this._tree.node(node.id);
            if (iNode) {
                iNode.setDirty(false);
            }
        }
        const { childNodes } = this.state;
        const renderTable = this.props.renderTable ? this.props.renderTable : this.renderTable;
        return (React.createElement("div", { className: classnames_1.default("components-breadcrumb-details", this.props.className), style: this.props.style }, this.state.table && childNodes &&
            renderTable({
                dataProvider: this.state.table,
                onRowsSelected: async (rowIterator, replace) => {
                    const iteratorResult = await rowIterator.next();
                    // istanbul ignore else should always be false
                    if (!iteratorResult.done) {
                        const row = iteratorResult.value;
                        this.props.path.setCurrentNode(row._node);
                    }
                    return replace;
                },
            }, node, childNodes)));
    }
}
exports.BreadcrumbDetails = BreadcrumbDetails;
//# sourceMappingURL=BreadcrumbDetails.js.map