"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Breadcrumb
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withBreadcrumbDetailsDragDrop = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const Table_1 = require("../../../table/component/Table");
const withDragDrop_1 = require("../../../table/hocs/withDragDrop");
/**
 * A HOC component that adds drag and drop functionality to the supplied
 * breadcrumb component.
 * @beta
 * @deprecated
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
function withBreadcrumbDetailsDragDrop(BreadcrumbComponent) {
    // eslint-disable-next-line @typescript-eslint/naming-convention
    return class WithDragAndDrop extends React.Component {
        constructor() {
            super(...arguments);
            // eslint-disable-next-line @typescript-eslint/naming-convention
            this.renderTable = (props, node, children) => {
                const DDTable = withDragDrop_1.withTableDragDrop(Table_1.Table); // eslint-disable-line @typescript-eslint/naming-convention
                return (React.createElement(DDTable, Object.assign({}, props, { dragProps: this.createDragProps(node), dropProps: this.createDropProps(node, children) })));
            };
        }
        static get displayName() { return `WithDragDrop(${ui_core_1.getDisplayName(BreadcrumbComponent)})`; }
        createDragProps(_item) {
            if (!this.props.dragProps)
                return {};
            const { onDragSourceBegin, onDragSourceEnd, objectType } = this.props.dragProps;
            const dragProps = {
                onDragSourceBegin: (args) => {
                    const dataProvider = this.props.path.getDataProvider();
                    const current = this.props.path.getCurrentNode();
                    if (args.dataObject) {
                        args.dataObject.parentId = current ? current.id : dataProvider;
                    }
                    args.parentObject = current || dataProvider;
                    return onDragSourceBegin ? onDragSourceBegin(args) : args;
                }, onDragSourceEnd: (args) => {
                    // istanbul ignore else
                    if (onDragSourceEnd) {
                        const dataProvider = this.props.path.getDataProvider();
                        const current = this.props.path.getCurrentNode();
                        args.parentObject = current || dataProvider;
                        onDragSourceEnd(args);
                    }
                }, objectType: (data) => {
                    // istanbul ignore else
                    if (objectType) {
                        if (typeof objectType === "function") {
                            if (data && typeof data === "object") {
                                const dataProvider = this.props.path.getDataProvider();
                                const current = this.props.path.getCurrentNode();
                                data.parentId = current ? current.id : dataProvider;
                            }
                            return objectType(data);
                        }
                        else
                            return objectType;
                    }
                    else
                        return "";
                },
            };
            return dragProps;
        }
        createDropProps(_item, children) {
            if (!this.props.dropProps)
                return {};
            const { onDropTargetOver, onDropTargetDrop, canDropTargetDrop, objectTypes } = this.props.dropProps;
            const dropProps = {
                canDropOn: true,
                onDropTargetOver: (args) => {
                    // istanbul ignore else
                    if (onDropTargetOver) {
                        const dataProvider = this.props.path.getDataProvider();
                        const current = this.props.path.getCurrentNode();
                        args.dropLocation = current || dataProvider;
                        if (children && args.dropRect && args.row !== undefined) {
                            const relativeY = (args.clientOffset.y - args.dropRect.top) / args.dropRect.height;
                            if (relativeY >= 1 / 3 && relativeY < 2 / 3) {
                                const rowNum = args.row;
                                args.row = undefined;
                                args.dropLocation = children[rowNum];
                            }
                        }
                        onDropTargetOver(args);
                    }
                }, onDropTargetDrop: (args) => {
                    const dataProvider = this.props.path.getDataProvider();
                    const current = this.props.path.getCurrentNode();
                    args.dropLocation = current || dataProvider;
                    if (children && args.dropRect && args.row !== undefined) {
                        const relativeY = (args.clientOffset.y - args.dropRect.top) / args.dropRect.height;
                        if (relativeY >= 1 / 3 && relativeY < 2 / 3) {
                            const rowNum = args.row;
                            args.row = undefined;
                            args.dropLocation = children[rowNum];
                        }
                    }
                    return onDropTargetDrop ? onDropTargetDrop(args) : args;
                }, canDropTargetDrop: (args) => {
                    const dataProvider = this.props.path.getDataProvider();
                    const current = this.props.path.getCurrentNode();
                    args.dropLocation = current || dataProvider;
                    return canDropTargetDrop ? canDropTargetDrop(args) : true;
                }, objectTypes,
            };
            return dropProps;
        }
        render() {
            const _a = this.props, { dragProps, dropProps, renderContent } = _a, breadcrumbProps = __rest(_a, ["dragProps", "dropProps", "renderContent"]); // eslint-disable-line @typescript-eslint/no-unused-vars
            return (React.createElement(BreadcrumbComponent, Object.assign({}, breadcrumbProps, { renderTable: this.renderTable })));
        }
    };
}
exports.withBreadcrumbDetailsDragDrop = withBreadcrumbDetailsDragDrop;
//# sourceMappingURL=withDragDrop.js.map