"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Breadcrumb
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withBreadcrumbDragDrop = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const Breadcrumb_1 = require("../Breadcrumb");
const DragDropBreadcrumbNode_1 = require("./DragDropBreadcrumbNode");
/**
 * A HOC component that adds drag and drop functionality to the supplied breadcrumb component.
 * @beta
 * @deprecated
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
function withBreadcrumbDragDrop(BreadcrumbComponent) {
    // eslint-disable-next-line @typescript-eslint/naming-convention
    return class WithDragAndDrop extends React.Component {
        constructor() {
            super(...arguments);
            // eslint-disable-next-line @typescript-eslint/naming-convention
            this.renderNode = (props, node, parent) => {
                const baseNode = this.props.renderNode ? /* istanbul ignore next */ this.props.renderNode(props, node) : React.createElement(Breadcrumb_1.BreadcrumbNode, Object.assign({}, props));
                const DDBreadcrumbNode = DragDropBreadcrumbNode_1.DragDropBreadcrumbNode(); // eslint-disable-line @typescript-eslint/naming-convention
                return (React.createElement(DDBreadcrumbNode, { key: (node && /* istanbul ignore next */ node.id) || "root", dragProps: this.createNodeDragProps(node, parent), dropProps: this.createNodeDropProps(node) }, baseNode));
            };
        }
        static get displayName() { return `WithDragDrop(${ui_core_1.getDisplayName(BreadcrumbComponent)})`; }
        createNodeDragProps(item, parent) {
            if (!item || !this.props.dragProps)
                return {};
            const { onDragSourceBegin, onDragSourceEnd, objectType } = this.props.dragProps;
            const dragProps = {
                onDragSourceBegin: (args) => {
                    args.dataObject = item.extendedData;
                    args.parentObject = (parent || this.props.dataProvider);
                    return onDragSourceBegin ? onDragSourceBegin(args) : args;
                },
                onDragSourceEnd: (args) => {
                    // istanbul ignore else
                    if (onDragSourceEnd) {
                        args.parentObject = (parent || this.props.dataProvider);
                        onDragSourceEnd(args);
                    }
                },
                objectType: () => {
                    if (typeof objectType === "function")
                        return objectType(item.extendedData);
                    else
                        return objectType;
                },
            };
            return dragProps;
        }
        createNodeDropProps(item) {
            if (!this.props.dropProps)
                return {};
            const { onDropTargetDrop, onDropTargetOver, canDropTargetDrop, objectTypes } = this.props.dropProps;
            const dropProps = {
                onDropTargetDrop: (args) => {
                    args.dropLocation = (item || this.props.dataProvider);
                    return onDropTargetDrop ? onDropTargetDrop(args) : args;
                },
                onDropTargetOver: (args) => {
                    // istanbul ignore else
                    if (onDropTargetOver) {
                        args.dropLocation = (item || this.props.dataProvider);
                        onDropTargetOver(args);
                    }
                },
                canDropTargetDrop: (args) => {
                    args.dropLocation = (item || this.props.dataProvider);
                    return canDropTargetDrop ? canDropTargetDrop(args) : true;
                },
                objectTypes,
            };
            return dropProps;
        }
        render() {
            const _a = this.props, { dragProps, dropProps, renderNode } = _a, treeProps = __rest(_a, ["dragProps", "dropProps", "renderNode"]); // eslint-disable-line @typescript-eslint/no-unused-vars
            return (React.createElement(BreadcrumbComponent, Object.assign({}, treeProps, { renderNode: this.renderNode })));
        }
    };
}
exports.withBreadcrumbDragDrop = withBreadcrumbDragDrop;
//# sourceMappingURL=withDragDrop.js.map