"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Color
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlphaSlider = void 0;
require("./AlphaSlider.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const UiComponents_1 = require("../UiComponents");
const ui_abstract_1 = require("@bentley/ui-abstract");
/** AlphaSlider component used to set the alpha value.
 * @beta
 */
class AlphaSlider extends React.PureComponent {
    /** @internal */
    constructor(props) {
        super(props);
        this._container = null;
        this._transparencyLabel = UiComponents_1.UiComponents.translate("color.transparency");
        this._calculateChange = (e, isHorizontal, alpha, container) => {
            e.preventDefault();
            const { width: containerWidth, height: containerHeight } = container.getBoundingClientRect();
            let x = 0;
            if ("pageX" in e) {
                x = e.pageX;
            }
            else {
                // istanbul ignore if
                if (undefined === e.touches)
                    return undefined;
                x = e.touches[0].pageX;
            }
            // istanbul ignore if
            if (undefined === x)
                return undefined;
            let y = 0;
            if ("pageY" in e) {
                y = e.pageY;
            }
            else {
                // istanbul ignore if
                if (undefined === e.touches)
                    return;
                y = e.touches[0].pageY;
            }
            // istanbul ignore if
            if (undefined === y)
                return undefined;
            const left = x - (container.getBoundingClientRect().left + window.pageXOffset);
            const top = y - (container.getBoundingClientRect().top + window.pageYOffset);
            let t = 0;
            if (!isHorizontal) {
                // istanbul ignore next
                if (top < 0) {
                    t = 1;
                }
                else if (top > containerHeight) {
                    t = 0;
                }
                else {
                    t = 1 - (top / containerHeight);
                }
            }
            else { // horizontal
                // istanbul ignore next
                if (left < 0) {
                    t = 0;
                }
                else if (left > containerWidth) {
                    t = 1;
                }
                else {
                    t = left / containerWidth;
                }
            }
            // istanbul ignore if
            if (t < 0)
                t = 0;
            // istanbul ignore if
            if (t > 1)
                t = 1;
            // istanbul ignore next
            return (alpha !== t) ? t : undefined;
        };
        this._onChange = (e) => {
            // istanbul ignore else
            if (this._container && this.props.onAlphaChange) {
                const change = this._calculateChange(e, this.props.isHorizontal ? this.props.isHorizontal : false, this.props.alpha, this._container);
                undefined !== change && typeof this.props.onAlphaChange === "function" && this.props.onAlphaChange(change);
            }
        };
        this._onMouseDown = (e) => {
            this._onChange(e);
            // istanbul ignore else
            if (this._container)
                this._container.focus();
            window.addEventListener("mousemove", this._onChange);
            window.addEventListener("mouseup", this._onMouseUp);
        };
        this._onKeyDown = (evt) => {
            let newTransparency;
            if (evt.key === ui_abstract_1.SpecialKey.ArrowLeft || evt.key === ui_abstract_1.SpecialKey.ArrowDown) {
                newTransparency = this.props.alpha - (evt.ctrlKey ? .1 : .05);
            }
            else if (evt.key === ui_abstract_1.SpecialKey.ArrowRight || evt.key === ui_abstract_1.SpecialKey.ArrowUp) {
                newTransparency = this.props.alpha + (evt.ctrlKey ? .1 : .05);
            }
            else if (evt.key === ui_abstract_1.SpecialKey.PageDown) {
                newTransparency = this.props.alpha - (evt.ctrlKey ? .5 : .25);
            }
            else if (evt.key === ui_abstract_1.SpecialKey.PageUp) {
                newTransparency = this.props.alpha + (evt.ctrlKey ? .5 : .25);
            }
            else if (evt.key === ui_abstract_1.SpecialKey.Home) {
                newTransparency = 0;
            }
            else {
                // istanbul ignore else
                if (evt.key === ui_abstract_1.SpecialKey.End) {
                    newTransparency = 1;
                }
            }
            // istanbul ignore else
            if (undefined !== newTransparency) {
                // istanbul ignore if
                if (newTransparency > 1)
                    newTransparency = 1;
                // istanbul ignore if
                if (newTransparency < 0)
                    newTransparency = 0;
                // istanbul ignore else
                if (this.props.onAlphaChange)
                    this.props.onAlphaChange(newTransparency);
            }
        };
        this._onMouseUp = () => {
            this._unbindEventListeners();
        };
    }
    /** @internal */
    componentWillUnmount() {
        this._unbindEventListeners();
    }
    _unbindEventListeners() {
        window.removeEventListener("mousemove", this._onChange);
        window.removeEventListener("mouseup", this._onMouseUp);
    }
    /** @internal */
    render() {
        const containerClasses = classnames_1.default(this.props.isHorizontal ? "components-alpha-container-horizontal" : "components-alpha-container-vertical", this.props.className);
        const pointerStyle = this.props.isHorizontal ?
            { left: `${(this.props.alpha * 100)}%` } :
            { left: `0px`, top: `${-(this.props.alpha * 100) + 100}%` };
        return (React.createElement("div", { className: containerClasses, style: this.props.style, "data-testid": "alpha-container" },
            React.createElement("div", { "data-testid": "alpha-slider", role: "slider", "aria-label": this._transparencyLabel, "aria-valuemin": 0, "aria-valuemax": 1, "aria-valuenow": this.props.alpha, className: "components-alpha-slider", ref: (container) => this._container = container, onMouseDown: this._onMouseDown, onTouchMove: this._onChange, onTouchStart: this._onChange, tabIndex: 0, onKeyDown: this._onKeyDown },
                React.createElement("div", { style: pointerStyle, className: "components-alpha-pointer", "data-testid": "alpha-pointer" }))));
    }
}
exports.AlphaSlider = AlphaSlider;
//# sourceMappingURL=AlphaSlider.js.map