/** @packageDocumentation
 * @module Color
 */
import "./ColorPickerButton.scss";
import * as React from "react";
import { ColorDef } from "@bentley/imodeljs-common";
import { CommonProps } from "@bentley/ui-core";
/** Properties for the [[ColorPickerButton]] React component
 * @beta
 */
export interface ColorPickerProps extends React.ButtonHTMLAttributes<HTMLButtonElement>, CommonProps {
    /** Active color */
    initialColor: ColorDef;
    /** Available colors */
    colorDefs?: ColorDef[];
    /** Function to run when user selects color swatch */
    onColorPick?: ((color: ColorDef) => void) | undefined;
    /** Show swatches as squares unless round is set to true */
    round?: boolean;
    /** Disabled or not */
    disabled?: boolean;
    /** Readonly or not */
    readonly?: boolean;
    /** Title to show at top of DropDown */
    dropDownTitle?: string;
    /** Number of columns */
    numColumns?: number;
    /** Provides ability to return reference to HTMLButtonElement */
    ref?: React.Ref<HTMLButtonElement>;
    /** If true show up/down caret next to color  */
    showCaret?: boolean;
}
/** ColorPickerButton component
 * @note Using forwardRef so the ColorEditor (Type Editor) can access the ref of the button element inside this component.
 * @beta
 */
export declare const ColorPickerButton: (props: ColorPickerProps) => JSX.Element | null;
//# sourceMappingURL=ColorPickerButton.d.ts.map