"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Color
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorPickerButton = void 0;
require("./ColorPickerButton.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const imodeljs_common_1 = require("@bentley/imodeljs-common");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const Swatch_1 = require("./Swatch");
const getCSSColorFromDef_1 = require("./getCSSColorFromDef");
// cSpell:ignore colorpicker
function ColorOptions({ handleColorPicked, options, numColumns, round, title }) {
    const containerStyle = { gridTemplateColumns: `repeat(${numColumns}, 1fr)` };
    return (React.createElement("div", { className: "components-colorpicker-popup-container" },
        title && React.createElement("h4", null, title),
        React.createElement("div", { "data-testid": "components-colorpicker-popup-colors", className: "components-colorpicker-popup-colors", style: containerStyle }, options.map((color, index) => React.createElement(Swatch_1.ColorSwatch, { className: "components-colorpicker-swatch", key: index, colorDef: color, onColorPick: handleColorPicked, round: round })))));
}
// Defined using following pattern (const ColorPickerButton at bottom) to ensure useful API documentation is extracted
const ForwardRefColorPickerButton = React.forwardRef(function ForwardRefColorPickerButton({ className, colorDefs, disabled, dropDownTitle, initialColor, numColumns, onColorPick, readonly, round, showCaret, style }, ref) {
    const target = React.useRef();
    const refs = ui_core_1.useRefs(target, ref); // combine ref needed for target with the forwardRef needed by the Parent when parent is a Type Editor.
    const [showPopup, setShowPopup] = React.useState(false);
    const [colorDef, setColorDef] = React.useState(initialColor);
    // See if new initialColor props have changed since component mounted
    React.useEffect(() => {
        setColorDef(initialColor);
    }, [initialColor]);
    const defaultColors = React.useRef([
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.red),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.orange),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.yellow),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.green),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.blue),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.indigo),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.violet),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.black),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.white),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.cyan),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.fuchsia),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.tan),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.gray),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.brown),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.purple),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.olive),
    ]);
    const closePopup = React.useCallback(() => {
        setShowPopup(false);
    }, []);
    const togglePopup = React.useCallback(() => {
        setShowPopup(!showPopup);
    }, [showPopup]);
    const handleColorPicked = React.useCallback((color) => {
        closePopup();
        // istanbul ignore else
        if (!color.equals(colorDef)) {
            setColorDef(color);
            onColorPick && onColorPick(color);
        }
    }, [closePopup, colorDef, onColorPick]);
    const rgbaString = getCSSColorFromDef_1.getCSSColorFromDef(colorDef);
    const buttonStyle = Object.assign({}, style);
    const swatchStyle = { backgroundColor: rgbaString };
    const buttonClassNames = classnames_1.default("components-colorpicker-button", round && "round", readonly && "readonly", className);
    const colorOptions = colorDefs && colorDefs.length ? colorDefs : defaultColors.current;
    return (React.createElement(React.Fragment, null,
        React.createElement("button", { "data-testid": "components-colorpicker-button", "data-value": rgbaString, onClick: togglePopup, className: buttonClassNames, style: buttonStyle, disabled: disabled, ref: refs },
            React.createElement("div", { className: "components-colorpicker-button-container" },
                React.createElement("div", { className: "components-colorpicker-button-color-swatch", style: swatchStyle }),
                showCaret && React.createElement(ui_core_1.WebFontIcon, { className: "components-caret", iconName: showPopup ? "icon-caret-up" : "icon-caret-down", iconSize: "x-small" }))),
        React.createElement(ui_core_1.Popup, { className: "components-colorpicker-popup", isOpen: showPopup, position: ui_abstract_1.RelativePosition.BottomLeft, onClose: closePopup, target: target.current, closeOnNestedPopupOutsideClick: true },
            React.createElement(ColorOptions, { handleColorPicked: handleColorPicked, options: colorOptions, numColumns: numColumns !== null && numColumns !== void 0 ? numColumns : 4, round: !!round, title: dropDownTitle }))));
});
/** ColorPickerButton component
 * @note Using forwardRef so the ColorEditor (Type Editor) can access the ref of the button element inside this component.
 * @beta
 */
exports.ColorPickerButton = ForwardRefColorPickerButton;
//# sourceMappingURL=ColorPickerButton.js.map