"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Color
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorPickerDialog = void 0;
// cSpell:ignore colorpicker
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const ColorPickerPanel_1 = require("./ColorPickerPanel");
/**
 * Color Picker Dialog to use as modal dialog.
 * @beta
 */
function ColorPickerDialog({ dialogTitle, color, onOkResult, onCancelResult, colorPresets }) {
    const [activeColor, setActiveColor] = React.useState(color);
    const dialogContainer = React.useRef(null);
    const handleOk = React.useCallback(() => {
        onOkResult(activeColor);
    }, [onOkResult, activeColor]);
    const handleCancel = React.useCallback(() => {
        // istanbul ignore else
        if (onCancelResult)
            onCancelResult();
    }, [onCancelResult]);
    const handleColorChange = React.useCallback((newColorDef) => {
        setActiveColor(newColorDef);
    }, []);
    const buttonCluster = React.useMemo(() => [
        { type: ui_core_1.DialogButtonType.OK, onClick: handleOk },
        { type: ui_core_1.DialogButtonType.Cancel, onClick: handleCancel },
    ], [handleCancel, handleOk]);
    return (React.createElement("div", { ref: dialogContainer },
        React.createElement(ui_core_1.Dialog, { title: dialogTitle, opened: true, resizable: true, movable: true, modal: true, buttonCluster: buttonCluster, onClose: handleCancel, onEscape: handleCancel, minHeight: 340, maxWidth: 400 },
            React.createElement(ColorPickerPanel_1.ColorPickerPanel, { activeColor: activeColor, colorPresets: colorPresets, onColorChange: handleColorChange }))));
}
exports.ColorPickerDialog = ColorPickerDialog;
//# sourceMappingURL=ColorPickerDialog.js.map