"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Color
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorPickerPanel = void 0;
// cSpell:ignore colorpicker
const React = __importStar(require("react"));
const Swatch_1 = require("./Swatch");
const HueSlider_1 = require("./HueSlider");
const SaturationPicker_1 = require("./SaturationPicker");
require("./ColorPickerPanel.scss");
/**
 * Color Picker Dialog to use as modal dialog.
 * @beta
 */
// istanbul ignore next
function ColorPickerPanel({ activeColor, onColorChange, colorPresets }) {
    const handlePresetColorPick = React.useCallback((newColor, e) => {
        e.preventDefault();
        if (onColorChange) {
            onColorChange(newColor);
        }
    }, [onColorChange]);
    const handleHueChange = React.useCallback((newHsvColor) => {
        // for a ColorDef to be created from hsv s can't be 0
        if (newHsvColor.s === 0) {
            newHsvColor = newHsvColor.clone(undefined, 0.5);
        }
        const newColorDef = newHsvColor.toColorDef();
        if (onColorChange) {
            onColorChange(newColorDef);
        }
    }, [onColorChange]);
    const handleSaturationChange = React.useCallback((newHsvColor) => {
        const newColorDef = newHsvColor.toColorDef();
        if (onColorChange) {
            onColorChange(newColorDef);
        }
    }, [onColorChange]);
    const currentHsv = React.useMemo(() => activeColor.toHSV(), [activeColor]);
    return (React.createElement("div", { "data-testid": "components-colorpicker-panel", className: "components-colorpicker-panel" },
        React.createElement("div", { className: "components-colorpicker-panel-color" },
            React.createElement("div", { className: "components-colorpicker-saturation" },
                React.createElement(SaturationPicker_1.SaturationPicker, { hsv: currentHsv, onSaturationChange: handleSaturationChange })),
            React.createElement("div", { className: "components-colorpicker-hue" },
                React.createElement(HueSlider_1.HueSlider, { hsv: currentHsv, onHueChange: handleHueChange, isHorizontal: false }))),
        colorPresets && colorPresets.length &&
            React.createElement("div", { className: "components-colorpicker-panel-presets" }, colorPresets.map((preset, index) => React.createElement(Swatch_1.ColorSwatch, { className: "components-colorpicker-panel-swatch", key: index, colorDef: preset, round: false, onColorPick: handlePresetColorPick })))));
}
exports.ColorPickerPanel = ColorPickerPanel;
//# sourceMappingURL=ColorPickerPanel.js.map