/** @packageDocumentation
 * @module Color
 */
import * as React from "react";
import { ColorDef } from "@bentley/imodeljs-common";
import { RelativePosition } from "@bentley/ui-abstract";
import { CommonProps } from "@bentley/ui-core";
import "./ColorPickerPopup.scss";
/** Properties for the [[ColorPickerPopup]] React component
 * @beta
 */
export interface ColorPickerPopupProps extends React.ButtonHTMLAttributes<HTMLButtonElement>, CommonProps {
    /** Current color */
    initialColor: ColorDef;
    /** Preset colors. Pass undefined to show default preset colors. Pass empty array to show no presets. */
    colorDefs?: ColorDef[];
    /** Function to call when the color value is changed */
    onColorChange?: ((newColor: ColorDef) => void) | undefined;
    /** Function to call when the popup is closed */
    onClose?: ((colorValue: ColorDef) => void) | undefined;
    /** Disabled or not */
    disabled?: boolean;
    /** Readonly or not, color displayed on button but button will not trigger pop-up */
    readonly?: boolean;
    /** popup position. If not set RelativePosition.BottomLeft is used */
    popupPosition?: RelativePosition;
    /** Provides ability to return reference to HTMLButtonElement */
    ref?: React.Ref<HTMLButtonElement>;
    /** If true show up/down caret next to color  */
    showCaret?: boolean;
    /** If true, don't propagate clicks out of the ColorPicker */
    captureClicks?: boolean;
}
/** ColorPickerButton component
 * @note Using forwardRef so the ColorEditor (Type Editor) can access the ref of the button element inside this component.
 * @beta
 */
export declare const ColorPickerPopup: (props: ColorPickerPopupProps) => JSX.Element | null;
//# sourceMappingURL=ColorPickerPopup.d.ts.map