"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Color
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorPickerPopup = void 0;
// cSpell:ignore colorpicker
const React = __importStar(require("react"));
const classnames_1 = __importDefault(require("classnames"));
const imodeljs_common_1 = require("@bentley/imodeljs-common");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const ColorPickerPanel_1 = require("./ColorPickerPanel");
require("./ColorPickerPopup.scss");
const getCSSColorFromDef_1 = require("./getCSSColorFromDef");
// Defined using following pattern (const ColorPickerPopup at bottom) to ensure useful API documentation is extracted
const ForwardRefColorPickerPopup = React.forwardRef(function ForwardRefColorPickerPopup(props, ref) {
    const target = React.useRef();
    const refs = ui_core_1.useRefs(target, ref); // combine ref needed for target with the forwardRef needed by the Parent when parent is a Type Editor.
    const [showPopup, setShowPopup] = React.useState(false);
    const [colorDef, setColorDef] = React.useState(props.initialColor);
    const defaultColors = React.useRef([
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.red),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.orange),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.yellow),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.green),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.blue),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.indigo),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.violet),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.black),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.white),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.cyan),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.fuchsia),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.tan),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.gray),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.brown),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.purple),
        imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.olive),
    ]);
    // istanbul ignore next
    const closePopup = React.useCallback(() => {
        props.onClose && props.onClose(colorDef);
        setShowPopup(false);
    }, [colorDef, props]);
    const togglePopup = React.useCallback(() => {
        setShowPopup(!showPopup);
    }, [showPopup]);
    const handleColorChanged = React.useCallback((newColor) => {
        // istanbul ignore else
        if (!newColor.equals(colorDef)) {
            setColorDef(newColor);
            // istanbul ignore else
            props.onColorChange && props.onColorChange(newColor);
        }
    }, [colorDef, props]);
    const rgbaString = getCSSColorFromDef_1.getCSSColorFromDef(colorDef);
    const buttonStyle = Object.assign({}, props.style);
    const swatchStyle = { backgroundColor: rgbaString };
    const buttonClassNames = classnames_1.default("components-colorpicker-popup-button", props.readonly && "readonly", props.className);
    const clickHandler = (event) => {
        // istanbul ignore else
        if (props.captureClicks)
            event.stopPropagation();
    };
    const colorOptions = props.colorDefs && props.colorDefs.length ? props.colorDefs : defaultColors.current;
    const popupPosition = undefined !== props.popupPosition ? props.popupPosition : ui_abstract_1.RelativePosition.BottomLeft;
    return (
    /* eslint-disable-next-line jsx-a11y/no-static-element-interactions, jsx-a11y/click-events-have-key-events */
    React.createElement("div", { onClick: clickHandler },
        React.createElement("button", { "data-testid": "components-colorpicker-popup-button", onClick: togglePopup, className: buttonClassNames, style: buttonStyle, disabled: props.disabled, ref: refs },
            React.createElement("div", { className: "components-colorpicker-button-container" },
                React.createElement("div", { className: "components-colorpicker-button-color-swatch", style: swatchStyle }),
                props.showCaret && React.createElement(ui_core_1.WebFontIcon, { className: "components-caret", iconName: showPopup ? "icon-caret-up" : "icon-caret-down", iconSize: "x-small" }))),
        React.createElement(ui_core_1.Popup, { className: "components-colorpicker-popup", isOpen: showPopup, position: popupPosition, onClose: closePopup, target: target.current, closeOnNestedPopupOutsideClick: true },
            React.createElement("div", { className: "components-colorpicker-popup-panel-padding" },
                React.createElement(ColorPickerPanel_1.ColorPickerPanel, { activeColor: colorDef, colorPresets: colorOptions, onColorChange: handleColorChanged })))));
});
/** ColorPickerButton component
 * @note Using forwardRef so the ColorEditor (Type Editor) can access the ref of the button element inside this component.
 * @beta
 */
exports.ColorPickerPopup = ForwardRefColorPickerPopup;
//# sourceMappingURL=ColorPickerPopup.js.map