"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Color
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HueSlider = void 0;
require("./HueSlider.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const UiComponents_1 = require("../UiComponents");
const ui_abstract_1 = require("@bentley/ui-abstract");
// hue is a value from 0 to 360
function calculateHue(currentPos, high, isVertical) {
    // istanbul ignore next
    if (currentPos <= 0) {
        return isVertical ? 359 : 0;
    }
    else if (currentPos >= high) {
        return isVertical ? 0 : 359;
    }
    else {
        let percent = ((currentPos * 100) / high);
        if (isVertical)
            percent = 100 - percent;
        return Math.round(((359 * percent) / 100));
    }
}
function calculateChange(currentHue, e, isHorizontal, container) {
    const { width: containerWidth, height: containerHeight, top: containerTop, left: containerLeft } = container.getBoundingClientRect();
    let x;
    if ("pageX" in e) {
        x = e.pageX;
    }
    else {
        // istanbul ignore if
        if (undefined === e.touches || 0 === e.touches.length)
            return currentHue;
        x = e.touches[0].pageX;
    }
    // istanbul ignore if
    if (undefined === x)
        return currentHue;
    let y;
    if ("pageY" in e) {
        y = e.pageY;
    }
    else {
        // istanbul ignore if
        if (undefined === e.touches || 0 === e.touches.length)
            return currentHue;
        y = e.touches[0].pageY;
    }
    // istanbul ignore if
    if (undefined === y)
        return currentHue;
    const pointerX = x - (containerLeft + window.pageXOffset);
    const pointerY = y - (containerTop + window.pageYOffset);
    if (!isHorizontal) { // vertical
        return calculateHue(pointerY, containerHeight, true);
    }
    else { // horizontal
        return calculateHue(pointerX, containerWidth, false);
    }
}
/** HueSlider component used to set the hue value.
 * @beta
 */
function HueSlider({ isHorizontal, onHueChange, hsv, className, style }) {
    const container = React.useRef(null);
    const [hueLabel] = React.useState(() => UiComponents_1.UiComponents.translate("color.hue"));
    const isDragging = React.useRef(false);
    const onChange = React.useCallback((e) => {
        // istanbul ignore else
        if (container.current) {
            const newHue = calculateChange(hsv.h, e, !!isHorizontal, container.current);
            // istanbul ignore else
            const newColor = hsv.clone(newHue);
            // istanbul ignore else
            if (onHueChange)
                onHueChange(newColor);
        }
    }, [isHorizontal, hsv, onHueChange]);
    const onDragging = React.useCallback((e) => {
        // istanbul ignore else
        if (isDragging.current) {
            onChange(e);
        }
    }, [onChange]);
    const onMouseUp = React.useCallback(() => {
        // istanbul ignore else
        if (isDragging.current) {
            isDragging.current = false;
        }
    }, []);
    const onTouchEnd = React.useCallback((event) => {
        event.preventDefault();
        // istanbul ignore else
        if (isDragging.current) {
            onChange(event);
            isDragging.current = false;
        }
    }, [onChange]);
    const onMouseDown = React.useCallback((e) => {
        e.preventDefault();
        // istanbul ignore else
        if (e.target !== e.currentTarget) {
            // istanbul ignore else
            if (!isDragging.current) {
                document.addEventListener("mouseup", onMouseUp, { capture: true, once: true });
                isDragging.current = true;
            }
        }
        onChange(e);
        // istanbul ignore else
        if (container.current)
            container.current.focus();
    }, [onChange, onMouseUp]);
    const onTouchStart = React.useCallback((e) => {
        // istanbul ignore else
        if (e.target !== e.currentTarget)
            isDragging.current = true;
        onChange(e);
        // istanbul ignore else
        if (container.current)
            container.current.focus();
    }, [onChange]);
    const onKeyDown = React.useCallback((evt) => {
        let newHue;
        const hueValue = hsv.h;
        if (evt.key === ui_abstract_1.SpecialKey.ArrowLeft || evt.key === ui_abstract_1.SpecialKey.ArrowDown) {
            newHue = hueValue - (evt.ctrlKey ? 10 : 1);
        }
        else if (evt.key === ui_abstract_1.SpecialKey.ArrowRight || evt.key === ui_abstract_1.SpecialKey.ArrowUp) {
            newHue = hueValue + (evt.ctrlKey ? 10 : 1);
        }
        else if (evt.key === ui_abstract_1.SpecialKey.PageDown) {
            newHue = hueValue - (evt.ctrlKey ? 180 : 60);
        }
        else if (evt.key === ui_abstract_1.SpecialKey.PageUp) {
            newHue = hueValue + (evt.ctrlKey ? 180 : 60);
        }
        else if (evt.key === ui_abstract_1.SpecialKey.Home) {
            newHue = 0;
        }
        else {
            // istanbul ignore else
            if (evt.key === ui_abstract_1.SpecialKey.End) {
                newHue = 359;
            }
        }
        // istanbul ignore else
        if (undefined !== newHue) {
            // istanbul ignore if
            if (newHue > 359)
                newHue = 359; // 360 is same as zero
            // istanbul ignore if
            if (newHue < 0)
                newHue = 0;
            const newColor = hsv.clone(newHue);
            // istanbul ignore else
            if (onHueChange)
                onHueChange(newColor);
            evt.preventDefault();
        }
    }, [hsv, onHueChange]);
    const containerClasses = classnames_1.default(isHorizontal ? "components-hue-container-horizontal" : "components-hue-container-vertical", className);
    const pointerStyle = isHorizontal ? { left: `${(hsv.h * 100) / 360}%`, backgroundColor: `hsl(${hsv.h} ,100%, 50%)` } :
        { left: `0px`, top: `${-((hsv.h * 100) / 360) + 100}%`, backgroundColor: `hsl(${hsv.h} ,100%, 50%)` };
    return (React.createElement("div", { className: containerClasses, style: style, "data-testid": "hue-container" },
        React.createElement("div", { "data-testid": "hue-slider", role: "slider", "aria-label": hueLabel, "aria-valuemin": 0, "aria-valuemax": 360, "aria-valuenow": hsv.h, className: "components-hue-slider", ref: container, onMouseDown: onMouseDown, onMouseMove: onDragging, onTouchMove: onDragging, onMouseUp: onMouseUp, onTouchStart: onTouchStart, onTouchEnd: onTouchEnd, tabIndex: 0, onKeyDown: onKeyDown },
            React.createElement("div", { style: pointerStyle, className: "components-hue-pointer", "data-testid": "hue-pointer" }))));
}
exports.HueSlider = HueSlider;
//# sourceMappingURL=HueSlider.js.map