"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Color
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SaturationPicker = void 0;
require("./SaturationPicker.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const imodeljs_common_1 = require("@bentley/imodeljs-common");
const UiComponents_1 = require("../UiComponents");
const ui_abstract_1 = require("@bentley/ui-abstract");
function calculateChange(e, hsv, container) {
    const { width: containerWidth, height: containerHeight, top: containerTop, left: containerLeft } = container.getBoundingClientRect();
    let x;
    if ("pageX" in e) {
        x = e.pageX;
    }
    else {
        // istanbul ignore next
        if (undefined !== e.touches && e.touches.length)
            x = e.touches[0].pageX;
    }
    // istanbul ignore if
    if (undefined === x)
        return hsv;
    let y = 0;
    if ("pageY" in e) {
        y = e.pageY;
    }
    else {
        // istanbul ignore next
        if (undefined !== e.touches && e.touches.length)
            y = e.touches[0].pageY;
    }
    // istanbul ignore if
    if (undefined === y)
        return hsv;
    let left = x - (containerLeft + window.pageXOffset);
    let top = y - (containerTop + window.pageYOffset);
    // istanbul ignore next
    if (left < 0) {
        left = 0;
    }
    else if (left > containerWidth) {
        left = containerWidth;
    }
    else if (top < 0) {
        top = 0;
    }
    else if (top > containerHeight) {
        top = containerHeight;
    }
    let saturation = Math.round((left * 100) / containerWidth);
    let value = Math.round(-((top * 100) / containerHeight) + 100);
    // istanbul ignore if
    if (saturation < 0)
        saturation = 0;
    // istanbul ignore if
    if (saturation > 100)
        saturation = 100;
    // istanbul ignore if
    if (value < 0)
        value = 0;
    // istanbul ignore if
    if (value > 100)
        value = 100;
    return hsv.clone(hsv.h, saturation, value);
}
/** SaturationPicker component used to set the saturation value.
 * @beta
 */
function SaturationPicker({ onSaturationChange, hsv, className, style }) {
    const container = React.useRef(null);
    const [saturationLabel] = React.useState(() => UiComponents_1.UiComponents.translate("color.saturation"));
    const isDragging = React.useRef(false);
    const onChange = React.useCallback((e) => {
        // istanbul ignore else
        if (container.current) {
            const newHsvColor = calculateChange(e, hsv, container.current);
            // istanbul ignore else
            if (newHsvColor) {
                // istanbul ignore else
                if (onSaturationChange)
                    onSaturationChange(newHsvColor);
            }
        }
    }, [hsv, onSaturationChange]);
    const onDragging = React.useCallback((e) => {
        // istanbul ignore else
        if (isDragging.current) {
            onChange(e);
        }
    }, [onChange]);
    const onMouseUp = React.useCallback(() => {
        // istanbul ignore else
        if (isDragging.current) {
            isDragging.current = false;
        }
    }, []);
    const onTouchEnd = React.useCallback((event) => {
        // istanbul ignore else
        if (isDragging.current) {
            onChange(event);
            isDragging.current = false;
        }
    }, [onChange]);
    const onMouseDown = React.useCallback((e) => {
        // istanbul ignore else
        if (e.target !== e.currentTarget) {
            isDragging.current = true;
            document.addEventListener("mouseup", onMouseUp, { capture: true, once: true });
        }
        onChange(e);
        // istanbul ignore else
        if (container.current)
            container.current.focus();
        e.preventDefault();
    }, [onChange, onMouseUp]);
    const onTouchStart = React.useCallback((e) => {
        // istanbul ignore else
        if (e.target !== e.currentTarget)
            isDragging.current = true;
        onChange(e);
        // istanbul ignore else
        if (container.current)
            container.current.focus();
    }, [onChange]);
    const onKeyDown = React.useCallback((evt) => {
        const h = hsv.h;
        let { s, v } = Object.assign({}, hsv);
        if (evt.key === ui_abstract_1.SpecialKey.ArrowLeft) {
            s -= (evt.ctrlKey ? 10 : 1);
        }
        else if (evt.key === ui_abstract_1.SpecialKey.ArrowDown) {
            v -= (evt.ctrlKey ? 10 : 1);
        }
        else if (evt.key === ui_abstract_1.SpecialKey.ArrowRight) {
            s += (evt.ctrlKey ? 10 : 1);
        }
        else if (evt.key === ui_abstract_1.SpecialKey.ArrowUp) {
            v += (evt.ctrlKey ? 10 : 1);
        }
        else if (evt.key === ui_abstract_1.SpecialKey.PageDown) {
            v = 0;
        }
        else if (evt.key === ui_abstract_1.SpecialKey.PageUp) {
            v = 100;
        }
        else if (evt.key === ui_abstract_1.SpecialKey.Home) {
            s = 0;
        }
        else {
            // istanbul ignore else
            if (evt.key === ui_abstract_1.SpecialKey.End) {
                s = 100;
            }
        }
        // istanbul ignore if
        if (s < 0)
            s = 0;
        // istanbul ignore if
        if (s > 100)
            s = 100;
        // istanbul ignore if
        if (v < 0)
            v = 0;
        // istanbul ignore if
        if (v > 100)
            v = 100;
        const newColor = new imodeljs_common_1.HSVColor(h, s, v);
        // istanbul ignore else
        if (onSaturationChange)
            onSaturationChange(newColor);
        evt.preventDefault();
    }, [hsv, onSaturationChange]);
    const pointerStyle = React.useMemo(() => ({
        left: `${hsv.s}%`,
        top: `${-(hsv.v) + 100}%`,
        backgroundColor: `${imodeljs_common_1.ColorDef.fromHSV(hsv).toRgbString()}`,
    }), [hsv]);
    const colorStyle = React.useMemo(() => ({ backgroundColor: `hsl(${hsv.h} ,100%, 50%)` }), [hsv]);
    return (React.createElement("div", { className: classnames_1.default("components-saturation-container", className), style: style, "data-testid": "saturation-container" },
        React.createElement("div", { "data-testid": "saturation-region", role: "slider", "aria-label": saturationLabel, "aria-valuenow": hsv.s, style: colorStyle, className: "components-saturation-region", ref: container, onMouseDown: onMouseDown, onMouseMove: onDragging, onTouchMove: onDragging, onTouchStart: onTouchStart, onTouchEnd: onTouchEnd, tabIndex: 0, onKeyDown: onKeyDown },
            React.createElement("div", { style: pointerStyle, className: "components-saturation-pointer", "data-testid": "saturation-pointer" }))));
}
exports.SaturationPicker = SaturationPicker;
//# sourceMappingURL=SaturationPicker.js.map