"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HighlightedText = void 0;
const react_1 = __importDefault(require("react"));
const react_highlight_words_1 = __importDefault(require("react-highlight-words"));
const HighlightingEngine_1 = require("../tree/HighlightingEngine");
/**
 * Highlighted text
 * Used for highlighting parts in the 'text' which match with 'searchText'
 * Also actively highlights one matched part which is selected with 'activeMatchIndex'
 * @beta
 */
function HighlightedText(props) {
    const { searchText, activeMatchIndex, text, caseSensitive } = props;
    return (react_1.default.createElement(react_highlight_words_1.default, { searchWords: [searchText], findChunks: findChunksNoRegex, activeIndex: activeMatchIndex, activeClassName: HighlightingEngine_1.HighlightingEngine.ACTIVE_CLASS_NAME, autoEscape: true, textToHighlight: text, caseSensitive: caseSensitive }));
}
exports.HighlightedText = HighlightedText;
const findChunksNoRegex = (args) => {
    const text = args.caseSensitive ? args.textToHighlight : args.textToHighlight.toUpperCase();
    const term = args.caseSensitive ? args.searchWords[0] : args.searchWords[0].toUpperCase();
    const chunks = [];
    let index = text.indexOf(term);
    while (index !== -1) {
        chunks.push({ start: index, end: index + term.length, highlight: true });
        index = text.indexOf(term, index + 1);
    }
    return chunks;
};
//# sourceMappingURL=HighlightedText.js.map