"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageRenderer = void 0;
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../UiComponents");
/** A class that renders images from data provided by an image loader
 * @internal
 */
class ImageRenderer {
    hexToBase64(hexstring) {
        const match = hexstring.match(/\w{2}/g);
        // istanbul ignore next
        if (!match)
            return "";
        return btoa(match.map((a) => {
            return String.fromCharCode(parseInt(a, 16));
        }).join(""));
    }
    /** Render raw binary image */
    renderBinary(data, format) {
        // Convert binary to base64
        const dataAsBase64 = this.hexToBase64(data);
        return (React.createElement("img", { src: `data:image/${format};base64,${dataAsBase64}`, alt: "" }));
    }
    /** Render svg string into JSX */
    renderSvg(svg) {
        return (React.createElement("div", null,
            React.createElement(ui_core_1.SvgSprite, { src: svg })));
    }
    /** Render image from an url */
    renderUrl(url) {
        return (React.createElement("img", { src: url, alt: "" }));
    }
    /** Render image as ui-core icon */
    renderCoreIcon(iconName) {
        return (React.createElement(ui_core_1.WebFontIcon, { iconName: iconName }));
    }
    /** Replaces the escaped instances of "\:" with ":" */
    normalizeEscapedIconString(escapedIconString) {
        return escapedIconString.replace(/\\:/g, ":");
    }
    /**
     * Extract class and name from icon name, if the name follows format "{className}:{fontName}".
     * className and fontName can be escaped using \ if : is needed.
     */
    extractIconClassAndName(iconName) {
        const matches = iconName.match(/(\\.|[^:])+/g);
        if (!matches || matches.length !== 2)
            return {
                iconClassName: undefined,
                iconName,
            };
        return {
            iconClassName: this.normalizeEscapedIconString(matches[0]),
            iconName: this.normalizeEscapedIconString(matches[1]),
        };
    }
    /**
     * Render image as provided webfont icon.
     * Defaults to ui-core icon if iconName does not contain className.
     */
    renderWebfontIcon(iconName) {
        const iconInfo = this.extractIconClassAndName(iconName);
        return (React.createElement(ui_core_1.WebFontIcon, Object.assign({}, iconInfo)));
    }
    /** Render image from data provided by an image loader */
    render(loadedImage) {
        switch (loadedImage.sourceType) {
            case "binary":
                const image = loadedImage;
                return this.renderBinary(image.value, image.fileFormat);
            case "url":
                return this.renderUrl(loadedImage.value);
            case "svg":
                return this.renderSvg(loadedImage.value);
            case "core-icon":
                return this.renderCoreIcon(loadedImage.value);
            case "webfont-icon":
                return this.renderWebfontIcon(loadedImage.value);
            default:
                const unhandledSourceType = loadedImage.sourceType; // Compile time check that all cases are handled
                throw new ui_abstract_1.UiError(UiComponents_1.UiComponents.loggerCategory(this), `Can't handle sourceType: "${unhandledSourceType}"`);
        }
    }
}
exports.ImageRenderer = ImageRenderer;
//# sourceMappingURL=ImageRenderer.js.map