/** @packageDocumentation
 * @module Common
 */
import { Observable } from "rxjs/internal/Observable";
/**
 * Controls observable subscription order and timing.
 *
 * Scheduled observables are placed at the end of a queue. The scheduler always
 * subscribes to at most one observable from the queue and waits until observables
 * either complete or get unscheduled before removing them from the queue.
 *
 * To schedule an observable, subscribe to the result of `scheduleSubscription()` call.
 * @internal
 */
export declare class SubscriptionScheduler<T> {
    private _scheduledObservables;
    private _scheduler;
    constructor();
    /**
     * Schedules `source` for subscription in the current scheduler.
     *
     * The actual scheduling is performed when the returned observable is subscribed to.
     * To cancel, simply remove all subscribers from the returned observable.
     *
     * @param source Input observable for which to schedule a subscription.
     * @returns Multicast observable which mirrors `source`.
     */
    scheduleSubscription(source: Observable<T>): Observable<T>;
}
/**
 * Helper function for use as a `pipe()` argument with `rxjs` observables.
 * @internal
 */
export declare function scheduleSubscription<T>(scheduler: SubscriptionScheduler<T>): (source: Observable<T>) => Observable<T>;
//# sourceMappingURL=SubscriptionScheduler.d.ts.map