"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAsyncValue = void 0;
const React = __importStar(require("react"));
const from_1 = require("rxjs/internal/observable/from");
const takeUntil_1 = require("rxjs/internal/operators/takeUntil");
const Subject_1 = require("rxjs/internal/Subject");
const ui_core_1 = require("@bentley/ui-core");
/**
 * Custom hook for working with possibly async values.
 * @beta
 */
const useAsyncValue = (value) => {
    const cancelled = React.useMemo(() => new Subject_1.Subject(), []);
    // cancel any pending promises on unmount
    React.useEffect(() => () => cancelled.next(), [cancelled]);
    const [result, setResult] = React.useState(() => {
        if (ui_core_1.isPromiseLike(value)) {
            from_1.from(value).pipe(takeUntil_1.takeUntil(cancelled)).subscribe({ next: (resolvedValue) => setResult(resolvedValue) });
            return undefined;
        }
        return value;
    });
    ui_core_1.useEffectSkipFirst(() => {
        const updateValue = (newValue) => {
            cancelled.next();
            setResult(newValue);
        };
        if (ui_core_1.isPromiseLike(value)) {
            const subscription = from_1.from(value).pipe(takeUntil_1.takeUntil(cancelled)).subscribe({ next: (resolvedValue) => updateValue(resolvedValue) });
            return () => subscription.unsubscribe();
        }
        updateValue(value);
        return undefined;
    }, [value, cancelled]);
    return result;
};
exports.useAsyncValue = useAsyncValue;
//# sourceMappingURL=UseAsyncValue.js.map