"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createContextWithMandatoryProvider = void 0;
const ui_abstract_1 = require("@bentley/ui-abstract");
const UiComponents_1 = require("../UiComponents");
const react_1 = __importDefault(require("react"));
/** @internal */
function createContextWithMandatoryProvider(contextName) {
    const context = react_1.default.createContext(undefined);
    function useContextWithoutDefaultValue(ConsumingComponent) {
        const value = react_1.default.useContext(context);
        /* istanbul ignore if */
        if (value === undefined) {
            throw new ui_abstract_1.UiError(UiComponents_1.UiComponents.loggerCategory(ConsumingComponent), `'${ui_abstract_1.getClassName(ConsumingComponent)}' expects to be wrapped by a '${contextName}' provider.`);
        }
        return value;
    }
    return [context.Provider, context.Consumer, useContextWithoutDefaultValue];
}
exports.createContextWithMandatoryProvider = createContextWithMandatoryProvider;
//# sourceMappingURL=UseContextWithMandatoryProvider.js.map