"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRerender = void 0;
const react_1 = require("react");
/** @internal */
function useRerender(initialContext) {
    const data = react_1.useRef({ numRerenders: 0, rerenderRequested: false, context: initialContext }).current;
    if (data.rerenderRequested) {
        data.numRerenders += 1;
        data.rerenderRequested = false;
    }
    else {
        data.context = initialContext;
        data.numRerenders = 0;
    }
    const [_, setState] = react_1.useState({});
    return {
        rerenderContext: data.context,
        numRerenders: data.numRerenders,
        rerender: (newContext) => {
            data.rerenderRequested = true;
            data.context = newContext;
            setState({});
        },
    };
}
exports.useRerender = useRerender;
//# sourceMappingURL=UseRerender.js.map