/** @packageDocumentation
 * @module Common
 */
/** Selection mode flags for Table and Tree row selection
 * @public
 */
export declare enum SelectionModeFlags {
    SelectionLimitOne = 1,
    DragEnabled = 2,
    ToggleEnabled = 4,
    KeysEnabled = 8,
    None = 16
}
/** Selection modes for Table and Tree row selection
 * @public
 */
export declare enum SelectionMode {
    /** Only one item selected at a time. */
    Single = 1,
    /** Toggles items; drag only applies to desktop. */
    Multiple = 6,
    /** Allows the use of Ctrl & Shift Keys in a desktop environment. */
    Extended = 12,
    /** Only one item selected at a time; also allows deselecting. */
    SingleAllowDeselect = 5,
    /** Do not allow (disable) selection */
    None = 16
}
/** Determines if a SelectionMode is active
 * @public
 */
export declare const hasSelectionModeFlag: (selectionMode: SelectionMode, flag: SelectionModeFlags) => boolean;
/** Determines if a SelectionMode is active
 * @public
 * @deprecated Use [[hasSelectionModeFlag]] instead
 */
export declare const hasFlag: (selectionMode: SelectionMode, flag: SelectionModeFlags) => boolean;
//# sourceMappingURL=SelectionModes.d.ts.map