"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasFlag = exports.hasSelectionModeFlag = exports.SelectionMode = exports.SelectionModeFlags = void 0;
/** Selection mode flags for Table and Tree row selection
 * @public
 */
var SelectionModeFlags;
(function (SelectionModeFlags) {
    SelectionModeFlags[SelectionModeFlags["SelectionLimitOne"] = 1] = "SelectionLimitOne";
    SelectionModeFlags[SelectionModeFlags["DragEnabled"] = 2] = "DragEnabled";
    SelectionModeFlags[SelectionModeFlags["ToggleEnabled"] = 4] = "ToggleEnabled";
    SelectionModeFlags[SelectionModeFlags["KeysEnabled"] = 8] = "KeysEnabled";
    SelectionModeFlags[SelectionModeFlags["None"] = 16] = "None";
})(SelectionModeFlags = exports.SelectionModeFlags || (exports.SelectionModeFlags = {}));
/** Selection modes for Table and Tree row selection
 * @public
 */
var SelectionMode;
(function (SelectionMode) {
    /** Only one item selected at a time. */
    SelectionMode[SelectionMode["Single"] = 1] = "Single";
    /** Toggles items; drag only applies to desktop. */
    SelectionMode[SelectionMode["Multiple"] = 6] = "Multiple";
    /** Allows the use of Ctrl & Shift Keys in a desktop environment. */
    SelectionMode[SelectionMode["Extended"] = 12] = "Extended";
    /** Only one item selected at a time; also allows deselecting. */
    SelectionMode[SelectionMode["SingleAllowDeselect"] = 5] = "SingleAllowDeselect";
    /** Do not allow (disable) selection */
    SelectionMode[SelectionMode["None"] = 16] = "None";
})(SelectionMode = exports.SelectionMode || (exports.SelectionMode = {}));
/** Determines if a SelectionMode is active
 * @public
 */
const hasSelectionModeFlag = (selectionMode, flag) => {
    return (selectionMode & flag) !== 0;
};
exports.hasSelectionModeFlag = hasSelectionModeFlag;
/** Determines if a SelectionMode is active
 * @public
 * @deprecated Use [[hasSelectionModeFlag]] instead
 */
// istanbul ignore next
const hasFlag = (selectionMode, flag) => {
    return (selectionMode & flag) !== 0;
};
exports.hasFlag = hasFlag;
//# sourceMappingURL=SelectionModes.js.map