/** @packageDocumentation
 * @module Common
 */
import * as React from "react";
import { GlobalDialogProps } from "@bentley/ui-core";
import { ShowHideID, ShowHideItem } from "./ShowHideItem";
/** Properties for the [[ShowHideDialog]] component
 * @public
 */
export interface ShowHideDialogProps<T extends ShowHideID> extends GlobalDialogProps {
    /** key-label pair list for id's to be shown/hidden, and an accompanying label. */
    items: Array<ShowHideItem<T>>;
    /** Hidden list to start with */
    initialHidden?: T[];
    /** Called when item is shown/hidden */
    onShowHideChange?: (cols: T[]) => boolean | undefined;
}
/** @internal */
interface ShowHideDialogState<T extends ShowHideID> {
    hiddenColumns: T[];
}
/**
 * [Dialog]($ui-core) Component used to toggle show/hide items, given through items prop, through a list of checkboxes.
 * @public
 */
export declare class ShowHideDialog<T extends ShowHideID> extends React.PureComponent<ShowHideDialogProps<T>, ShowHideDialogState<T>> {
    /** @internal */
    readonly state: ShowHideDialogState<T>;
    constructor(props: ShowHideDialogProps<T>);
    /** @internal */
    componentDidUpdate(oldProps: ShowHideDialogProps<T>): void;
    private _toggleItem;
    private _hide;
    private _show;
    /** @internal */
    render(): React.ReactNode;
}
export {};
//# sourceMappingURL=ShowHideDialog.d.ts.map