"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShowHideDialog = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../../UiComponents");
/**
 * [Dialog]($ui-core) Component used to toggle show/hide items, given through items prop, through a list of checkboxes.
 * @public
 */
class ShowHideDialog extends React.PureComponent {
    constructor(props) {
        super(props);
        this._toggleItem = (item) => {
            if (this.state.hiddenColumns.indexOf(item.id) !== -1)
                this._show(item);
            else
                this._hide(item);
        };
        this._hide = (item) => {
            this.setState((prevState) => ({ hiddenColumns: [...prevState.hiddenColumns, item.id] }), () => {
                if (this.props.onShowHideChange)
                    this.props.onShowHideChange(this.state.hiddenColumns);
            });
        };
        this._show = (item) => {
            const hiddenColumns = this.state.hiddenColumns.filter((value) => {
                return value !== item.id;
            });
            this.setState({ hiddenColumns }, () => {
                if (this.props.onShowHideChange)
                    this.props.onShowHideChange(this.state.hiddenColumns);
            });
        };
        this.state = {
            hiddenColumns: props.initialHidden || [],
        };
    }
    /** @internal */
    componentDidUpdate(oldProps) {
        if (this.props.initialHidden && oldProps.initialHidden !== this.props.initialHidden) {
            this.setState((_, props) => ({ hiddenColumns: props.initialHidden || /* istanbul ignore next */ [] }));
        }
    }
    /** @internal */
    render() {
        const _a = this.props, { opened, items, initialHidden, onClose, onShowHideChange } = _a, props = __rest(_a, ["opened", "items", "initialHidden", "onClose", "onShowHideChange"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        return (React.createElement(ui_core_1.GlobalDialog, Object.assign({ opened: opened, resizable: true, movable: true, modal: false, minWidth: 300, minHeight: 250, width: 300, onClose: onClose, onEscape: onClose, onOutsideClick: onClose, buttonCluster: onClose && [{ onClick: onClose, type: ui_core_1.DialogButtonType.Close }] }, props), this.props.items.map((item, index) => {
            const visible = this.state.hiddenColumns.indexOf(item.id) === -1;
            const sel = () => {
                this._toggleItem(item);
            };
            const label = item.label || UiComponents_1.UiComponents.translate("showhide.noLabel");
            const id = `show-hide-dialog-input-${index}`;
            return (React.createElement("div", { key: index },
                React.createElement("input", { "data-testid": id, id: id, type: "checkbox", checked: visible, onChange: () => undefined, onClick: sel }),
                React.createElement("label", { htmlFor: id }, label)));
        })));
    }
}
exports.ShowHideDialog = ShowHideDialog;
//# sourceMappingURL=ShowHideDialog.js.map