/** @packageDocumentation
 * @module Common
 */
import * as React from "react";
import { GlobalContextMenuProps } from "@bentley/ui-core";
import { ShowHideID, ShowHideItem } from "./ShowHideItem";
/** Properties for the [[ShowHideMenu]] component
 * @public
 */
export interface ShowHideMenuProps<T extends ShowHideID> extends GlobalContextMenuProps {
    /** key-label pair list for id's to be shown/hidden, and an accompanying label. */
    items: Array<ShowHideItem<T>>;
    /** X position to place menu */
    x: number;
    /** Y position to place menu */
    y: number;
    /** Whether dialog is opened or closed */
    opened: boolean;
    /** Hidden list to start with */
    initialHidden?: T[];
    /** Called when close button is clicked */
    onClose?: () => void;
    /** Called when item is shown/hidden */
    onShowHideChange?: (cols: T[]) => boolean | undefined;
}
/** @internal */
interface ShowHideMenuState<T extends ShowHideID> {
    hiddenColumns: T[];
    dialogOpened: boolean;
}
/**
 * [ContextMenu]($ui-core) Component used to toggle show/hide items, given through items prop, through a list of checkboxes.
 * Component includes a "list" button that displays a dialog with the same checkboxes.
 * @public
 */
export declare class ShowHideMenu<T extends ShowHideID> extends React.PureComponent<ShowHideMenuProps<T>, ShowHideMenuState<T>> {
    /** @internal */
    readonly state: ShowHideMenuState<T>;
    /** @internal */
    constructor(props: ShowHideMenuProps<T>);
    /** @internal */
    componentDidUpdate(oldProps: ShowHideMenuProps<T>): void;
    private _toggleItem;
    private _hide;
    private _show;
    private _showAll;
    private _showDialog;
    private _closeDialog;
    private _defaultContextMenu;
    /** @internal */
    render(): React.ReactNode;
}
export {};
//# sourceMappingURL=ShowHideMenu.d.ts.map