"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Common
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShowHideMenu = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../../UiComponents");
const ShowHideDialog_1 = require("./ShowHideDialog");
/**
 * [ContextMenu]($ui-core) Component used to toggle show/hide items, given through items prop, through a list of checkboxes.
 * Component includes a "list" button that displays a dialog with the same checkboxes.
 * @public
 */
class ShowHideMenu extends React.PureComponent {
    /** @internal */
    constructor(props) {
        super(props);
        this._toggleItem = (item) => {
            if (this.state.hiddenColumns.indexOf(item.id) !== -1)
                this._show(item);
            else
                this._hide(item);
            if (this.props.onClose)
                this.props.onClose();
        };
        this._hide = (item) => {
            this.setState((prevState) => ({ hiddenColumns: [...prevState.hiddenColumns, item.id] }), () => {
                if (this.props.onShowHideChange)
                    this.props.onShowHideChange(this.state.hiddenColumns);
            });
        };
        this._show = (item) => {
            const hiddenColumns = this.state.hiddenColumns.filter((value) => {
                return value !== item.id;
            });
            this.setState({ hiddenColumns }, () => {
                if (this.props.onShowHideChange)
                    this.props.onShowHideChange(this.state.hiddenColumns);
            });
        };
        this._showAll = () => {
            this.setState({ hiddenColumns: [] }, () => {
                // istanbul ignore next
                if (this.props.onShowHideChange)
                    this.props.onShowHideChange(this.state.hiddenColumns);
            });
            if (this.props.onClose)
                this.props.onClose();
        };
        this._showDialog = () => {
            if (this.props.onClose)
                this.props.onClose();
            this.setState({
                dialogOpened: true,
            });
        };
        this._closeDialog = () => {
            this.setState({
                dialogOpened: false,
            });
        };
        this._defaultContextMenu = (event) => {
            event.stopPropagation();
        };
        this.state = {
            hiddenColumns: props.initialHidden || [],
            dialogOpened: false,
        };
    }
    /** @internal */
    componentDidUpdate(oldProps) {
        if (this.props.initialHidden && oldProps.initialHidden !== this.props.initialHidden) {
            this.setState((_, props) => ({ hiddenColumns: props.initialHidden || /* istanbul ignore next */ [] }));
        }
    }
    /** @internal */
    render() {
        const _a = this.props, { items, x, y, opened, initialHidden, onClose, onShowHideChange } = _a, props = __rest(_a, ["items", "x", "y", "opened", "initialHidden", "onClose", "onShowHideChange"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        return (React.createElement(ui_core_1.GlobalContextMenu, Object.assign({ x: x, y: y, opened: opened, onEsc: onClose, onOutsideClick: onClose, edgeLimit: false, autoflip: true }, props),
            this.props.items.map((item, index) => {
                const visible = this.state.hiddenColumns.indexOf(item.id) === -1;
                const sel = () => this._toggleItem(item);
                const label = item.label || UiComponents_1.UiComponents.translate("showhide.noLabel");
                const id = `show-hide-menu-input-${index}`;
                return (React.createElement(ui_core_1.ContextMenuItem, { key: index, onSelect: sel, icon: React.createElement("input", { type: "checkbox", "data-testid": id, id: id, checked: visible, onChange: () => undefined }) }, label));
            }),
            React.createElement(ui_core_1.ContextMenuDivider, null),
            React.createElement(ui_core_1.ContextMenuItem, { onSelect: this._showAll },
                React.createElement("span", { "data-testid": "show-hide-showall" }, UiComponents_1.UiComponents.translate("showhide.showAll"))),
            React.createElement(ui_core_1.ContextMenuItem, { onSelect: this._showDialog },
                React.createElement("span", { "data-testid": "show-hide-list" }, UiComponents_1.UiComponents.translate("showhide.list"))),
            React.createElement(ShowHideDialog_1.ShowHideDialog, { items: items, title: UiComponents_1.UiComponents.translate("showhide.title"), opened: this.state.dialogOpened, onClose: this._closeDialog, initialHidden: this.state.hiddenColumns, onContextMenu: this._defaultContextMenu, onShowHideChange: onShowHideChange })));
    }
}
exports.ShowHideMenu = ShowHideMenu;
// cspell:ignore showall
//# sourceMappingURL=ShowHideMenu.js.map