"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module TypeConverters
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BooleanTypeConverter = void 0;
const ui_abstract_1 = require("@bentley/ui-abstract");
const UiComponents_1 = require("../UiComponents");
const TypeConverter_1 = require("./TypeConverter");
const TypeConverterManager_1 = require("./TypeConverterManager");
/** Boolean Type Converter.
 * @public
 */
class BooleanTypeConverter extends TypeConverter_1.TypeConverter {
    /** @internal */
    static getLocalizedTrueFalse() {
        if (!BooleanTypeConverter.sl10nTrue)
            BooleanTypeConverter.sl10nTrue = UiComponents_1.UiComponents.translate("general.true");
        if (!BooleanTypeConverter.sl10nFalse)
            BooleanTypeConverter.sl10nFalse = UiComponents_1.UiComponents.translate("general.false");
    }
    convertToString(value) {
        if (value === undefined)
            return "";
        BooleanTypeConverter.getLocalizedTrueFalse();
        if (value === BooleanTypeConverter.sl10nTrue || value === BooleanTypeConverter.sl10nFalse)
            return value;
        return value ? BooleanTypeConverter.sl10nTrue : BooleanTypeConverter.sl10nFalse;
    }
    convertFromString(value) {
        BooleanTypeConverter.getLocalizedTrueFalse();
        const booleanValue = (0 === value.toLocaleLowerCase().localeCompare(BooleanTypeConverter.sl10nTrue.toLocaleLowerCase()));
        return booleanValue;
    }
    sortCompare(a, b, _ignoreCase) {
        if (!!a === !!b)
            return 0;
        if (!!a && !b)
            return 1;
        return -1;
    }
    get isBooleanType() { return true; }
}
exports.BooleanTypeConverter = BooleanTypeConverter;
/** @internal */
BooleanTypeConverter.sl10nTrue = "";
/** @internal */
BooleanTypeConverter.sl10nFalse = "";
TypeConverterManager_1.TypeConverterManager.registerConverter(ui_abstract_1.StandardTypeNames.Boolean, BooleanTypeConverter);
TypeConverterManager_1.TypeConverterManager.registerConverter(ui_abstract_1.StandardTypeNames.Bool, BooleanTypeConverter);
//# sourceMappingURL=BooleanTypeConverter.js.map