"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module TypeConverters
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CompositeTypeConverter = void 0;
const ui_abstract_1 = require("@bentley/ui-abstract");
const TypeConverter_1 = require("./TypeConverter");
const TypeConverterManager_1 = require("./TypeConverterManager");
/**
 * Composite type converter
 * @public
 */
class CompositeTypeConverter extends TypeConverter_1.TypeConverter {
    convertToString(value) {
        if (value === undefined)
            return "";
        return createDisplayValue(value);
    }
    sortCompare(valueA, valueB, ignoreCase) {
        const length = Math.min(valueA.parts.length, valueB.parts.length);
        const separatorComparison = compareStrings(valueA.separator, valueB.separator, ignoreCase);
        for (let i = 0; i < length; i++) {
            const lhs = valueA.parts[i];
            const rhs = valueB.parts[i];
            const compareResult = lhs.typeName !== rhs.typeName ? compareStrings(lhs.displayValue, rhs.displayValue, ignoreCase)
                : TypeConverterManager_1.TypeConverterManager.getConverter(lhs.typeName).sortCompare(lhs.rawValue, rhs.rawValue, ignoreCase);
            if (compareResult !== 0)
                return compareResult;
            if (i === 0 && separatorComparison !== 0)
                return separatorComparison;
        }
        if (valueA.parts.length !== valueB.parts.length)
            return valueA.parts.length - valueB.parts.length;
        return 0;
    }
}
exports.CompositeTypeConverter = CompositeTypeConverter;
TypeConverterManager_1.TypeConverterManager.registerConverter(ui_abstract_1.StandardTypeNames.Composite, CompositeTypeConverter);
const compareStrings = (lhs, rhs, ignoreCase) => {
    if (ignoreCase)
        return lhs.toLocaleLowerCase().localeCompare(rhs.toLocaleLowerCase());
    else
        return lhs.localeCompare(rhs);
};
const createDisplayValue = async (compositeValue) => {
    const parts = [];
    for (const part of compositeValue.parts) {
        let valueString;
        if (part.typeName === "composite") {
            valueString = await createDisplayValue(part.rawValue);
        }
        else {
            valueString = await TypeConverterManager_1.TypeConverterManager.getConverter(part.typeName).convertToString(part.rawValue);
        }
        parts.push(valueString);
    }
    return parts.join(compositeValue.separator);
};
//# sourceMappingURL=CompositeTypeConverter.js.map