/** @packageDocumentation
 * @module TypeConverters
 */
import { AlternateDateFormats, Primitives, TimeDisplay } from "@bentley/ui-abstract";
import { TimeFormat } from "@bentley/ui-core";
import { LessGreaterOperatorProcessor, TypeConverter } from "./TypeConverter";
import { ConvertedPrimitives } from "./valuetypes/ConvertedTypes";
/**
 * DateTime Type Converter.
 * @public
 */
export declare abstract class DateTimeTypeConverterBase extends TypeConverter implements LessGreaterOperatorProcessor {
    convertToString(value?: Primitives.Value): string;
    static isValidTimeDisplay(type: TimeDisplay): boolean;
    static isAlternateDateFormats(type: AlternateDateFormats): boolean;
    convertToStringWithOptions(value?: Primitives.Value, options?: {
        [key: string]: any;
    }): string | Promise<string>;
    /** Default implementation just calls convertFromString with no options */
    convertFromStringWithOptions(value: string, options?: {
        [key: string]: any;
    }): ConvertedPrimitives.Value | undefined | Promise<ConvertedPrimitives.Value | undefined>;
    private isDateValid;
    convertFromString(value: string): Date | undefined;
    protected abstract getTimeFormat(): TimeFormat;
    get isLessGreaterType(): boolean;
    sortCompare(valueA: Date, valueB: Date, _ignoreCase?: boolean): number;
    isEqualTo(valueA: Date, valueB: Date): boolean;
    isNotEqualTo(valueA: Date, valueB: Date): boolean;
    isLessThan(a: Date, b: Date): boolean;
    isLessThanOrEqualTo(a: Date, b: Date): boolean;
    isGreaterThan(a: Date, b: Date): boolean;
    isGreaterThanOrEqualTo(a: Date, b: Date): boolean;
}
/**
 * Short Date Type Converter.
 * @public
 */
export declare class ShortDateTypeConverter extends DateTimeTypeConverterBase {
    protected getTimeFormat(): TimeFormat;
}
/**
 * Date Time Type Converter.
 * @public
 */
export declare class DateTimeTypeConverter extends DateTimeTypeConverterBase {
    protected getTimeFormat(): TimeFormat;
}
//# sourceMappingURL=DateTimeTypeConverter.d.ts.map