"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module TypeConverters
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnumTypeConverter = void 0;
const ui_abstract_1 = require("@bentley/ui-abstract");
const TypeConverter_1 = require("./TypeConverter");
const TypeConverterManager_1 = require("./TypeConverterManager");
/**
 * Enum Type Converter.
 * @public
 */
class EnumTypeConverter extends TypeConverter_1.TypeConverter {
    convertPropertyToString(propertyDescription, value) {
        if (value === undefined)
            return "";
        if (propertyDescription.enum) {
            return this.getMatchingStringValue(propertyDescription.enum, value);
        }
        return super.convertToString(value);
    }
    async getMatchingStringValue(enumVal, value) {
        let choices = [];
        if (enumVal.choices instanceof Promise) {
            choices = await enumVal.choices;
        }
        else {
            choices = enumVal.choices;
        }
        const pos = this.getPosition(choices, value);
        if (-1 !== pos)
            return choices[pos].label;
        return this.convertToString(value);
    }
    getPosition(choices, value) {
        for (let i = 0; i < choices.length; ++i) {
            if (choices[i].value === value)
                return i;
        }
        return -1;
    }
    sortCompare(a, b, ignoreCase) {
        if (isNaN(+a) || isNaN(+b)) {
            return TypeConverterManager_1.TypeConverterManager.getConverter("string").sortCompare(a, b, ignoreCase);
        }
        return (+a) - (+b);
    }
}
exports.EnumTypeConverter = EnumTypeConverter;
TypeConverterManager_1.TypeConverterManager.registerConverter(ui_abstract_1.StandardTypeNames.Enum, EnumTypeConverter);
//# sourceMappingURL=EnumTypeConverter.js.map