"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module TypeConverters
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.HexadecimalTypeConverter = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const ui_abstract_1 = require("@bentley/ui-abstract");
const TypeConverter_1 = require("./TypeConverter");
const TypeConverterManager_1 = require("./TypeConverterManager");
/** Hexadecimal Type Converter.
 * @public
 */
class HexadecimalTypeConverter extends TypeConverter_1.TypeConverter {
    convertToString(value) {
        if (value === undefined)
            return "";
        // Need to Uppercase without changing 0x part
        const hexString = value.toString();
        return `0x${hexString.substring(2, hexString.length).toUpperCase()}`;
    }
    convertFromString(value) {
        if (value.substr(0, 2) !== "0x")
            value = `0x${value}`;
        value = bentleyjs_core_1.Id64.fromString(value);
        if (bentleyjs_core_1.Id64.isValidId64(value))
            return value;
        return undefined;
    }
    sortCompare(a, b) {
        // Normalize the strings
        a = bentleyjs_core_1.Id64.fromString(a);
        b = bentleyjs_core_1.Id64.fromString(b);
        if (a === b)
            return 0;
        if (a > b)
            return 1;
        return -1;
    }
}
exports.HexadecimalTypeConverter = HexadecimalTypeConverter;
TypeConverterManager_1.TypeConverterManager.registerConverter(ui_abstract_1.StandardTypeNames.Hex, HexadecimalTypeConverter);
TypeConverterManager_1.TypeConverterManager.registerConverter(ui_abstract_1.StandardTypeNames.Hexadecimal, HexadecimalTypeConverter);
//# sourceMappingURL=HexadecimalTypeConverter.js.map