/** @packageDocumentation
 * @module TypeConverters
 */
import { Primitives } from "@bentley/ui-abstract";
import { LessGreaterOperatorProcessor, TypeConverter } from "./TypeConverter";
/**
 * Base Numeric Type Converter.
 * @public
 */
export declare abstract class NumericTypeConverterBase extends TypeConverter implements LessGreaterOperatorProcessor {
    get isLessGreaterType(): boolean;
    isLessThan(a: Primitives.Numeric, b: Primitives.Numeric): boolean;
    isLessThanOrEqualTo(a: Primitives.Numeric, b: Primitives.Numeric): boolean;
    isGreaterThan(a: Primitives.Numeric, b: Primitives.Numeric): boolean;
    isGreaterThanOrEqualTo(a: Primitives.Numeric, b: Primitives.Numeric): boolean;
    sortCompare(a: Primitives.Numeric, b: Primitives.Numeric, _ignoreCase?: boolean): number;
}
/**
 * Float Type Converter.
 * @public
 */
export declare class FloatTypeConverter extends NumericTypeConverterBase {
    convertToString(value?: Primitives.Float): string;
    convertFromString(value: string): number;
}
/**
 * Int Type Converter.
 * @public
 */
export declare class IntTypeConverter extends NumericTypeConverterBase {
    convertToString(value?: Primitives.Int): string;
    convertFromString(value: string): number;
}
//# sourceMappingURL=NumericTypeConverter.d.ts.map