/** @packageDocumentation
 * @module TypeConverters
 */
import { Primitives } from "@bentley/ui-abstract";
import { TypeConverter } from "./TypeConverter";
import { ConvertedPrimitives } from "./valuetypes/ConvertedTypes";
/**
 * Point type converter.
 * @public
 */
export declare abstract class BasePointTypeConverter extends TypeConverter {
    componentConverterName: string;
    constructor(componentConverterName?: string);
    private formatValue;
    convertToString(value?: Primitives.Point): string | Promise<string>;
    convertFromString(value: string): ConvertedPrimitives.Point | undefined;
    protected abstract constructPoint(_values: Primitives.Point): ConvertedPrimitives.Point | undefined;
    protected abstract getVectorLength(point: Primitives.Point): number | undefined;
    sortCompare(a: Primitives.Point, b: Primitives.Point, _ignoreCase?: boolean): number;
}
/**
 * Point2d type converter.
 * @public
 */
export declare class Point2dTypeConverter extends BasePointTypeConverter {
    constructor(componentConverterName?: string);
    protected getVectorLength(point: Primitives.Point): number | undefined;
    protected constructPoint(values: Primitives.Point): ConvertedPrimitives.Point2d | undefined;
}
/**
 * Point3d type converter.
 * @public
 */
export declare class Point3dTypeConverter extends BasePointTypeConverter {
    constructor(componentConverterName?: string);
    protected getVectorLength(point: Primitives.Point): number | undefined;
    protected constructPoint(values: Primitives.Point): ConvertedPrimitives.Point3d | undefined;
}
//# sourceMappingURL=PointTypeConverter.d.ts.map