/** @packageDocumentation
 * @module TypeConverters
 */
import { Primitives } from "@bentley/ui-abstract";
import { TypeConverter } from "./TypeConverter";
/** Operators for string types
 * @public
 */
export interface StringOperatorProcessor {
    /** Determines if one string starts with another string */
    startsWith(a: string, b: string, caseSensitive: boolean): boolean;
    /** Determines if one string ends with another string */
    endsWith(a: string, b: string, caseSensitive: boolean): boolean;
    /** Determines if one string contains another string */
    contains(a: string, b: string, caseSensitive: boolean): boolean;
    /** Determines if one string does not contain another string */
    doesNotContain(a: string, b: string, caseSensitive: boolean): boolean;
    /** Determines if one string is contained within another string */
    isContainedIn(a: string, b: string, caseSensitive: boolean): boolean;
    /** Determines if one string is not contained within another string */
    isNotContainedIn(a: string, b: string, caseSensitive: boolean): boolean;
    /** Determines if a string is empty */
    isEmpty(a: string): boolean;
    /** Determines if a string is not empty */
    isNotEmpty(a: string): boolean;
}
/**
 * String Type Converter.
 * @public
 */
export declare class StringTypeConverter extends TypeConverter implements StringOperatorProcessor {
    convertToString(value?: Primitives.String): string;
    convertFromString(value: string): string;
    sortCompare(valueA: Primitives.String, valueB: Primitives.String, ignoreCase?: boolean): number;
    get isStringType(): boolean;
    startsWith(valueA: string, valueB: string, caseSensitive: boolean): boolean;
    endsWith(valueA: string, valueB: string, caseSensitive: boolean): boolean;
    contains(valueA: string, valueB: string, caseSensitive: boolean): boolean;
    doesNotContain(valueA: string, valueB: string, caseSensitive: boolean): boolean;
    isContainedIn(valueA: string, valueB: string, caseSensitive: boolean): boolean;
    isNotContainedIn(valueA: string, valueB: string, caseSensitive: boolean): boolean;
    isEmpty(valueA: string): boolean;
    isNotEmpty(valueA: string): boolean;
    private checkArgTypes;
}
//# sourceMappingURL=StringTypeConverter.d.ts.map