"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module TypeConverters
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeConverterManager = void 0;
/**
 * Manages Type Converters. Type Converters are registered with and obtained from the manager.
 * @public
 */
class TypeConverterManager {
    static getFullConverterName(typename, converterName) {
        let fullConverterName = typename;
        if (converterName)
            fullConverterName += `:${converterName}`;
        return fullConverterName;
    }
    static registerConverter(typename, converter, converterName) {
        const fullConverterName = TypeConverterManager.getFullConverterName(typename, converterName);
        if (TypeConverterManager._converters.hasOwnProperty(fullConverterName)) {
            const nameOfConverter = TypeConverterManager._converters[fullConverterName].constructor.name;
            throw Error(`TypeConverterManager.registerConverter error: type '${typename}' already registered to '${nameOfConverter}'`);
        }
        const instance = new converter();
        TypeConverterManager._converters[fullConverterName] = instance;
    }
    static unregisterConverter(typename, converterName) {
        const fullConverterName = TypeConverterManager.getFullConverterName(typename, converterName);
        // istanbul ignore else
        if (TypeConverterManager._converters.hasOwnProperty(fullConverterName)) {
            delete TypeConverterManager._converters[fullConverterName];
        }
    }
    static getConverter(typename, converterName) {
        const fullConverterName = TypeConverterManager.getFullConverterName(typename, converterName);
        if (TypeConverterManager._converters.hasOwnProperty(fullConverterName))
            return TypeConverterManager._converters[fullConverterName];
        if (!TypeConverterManager._defaultTypeConverter) {
            const { StringTypeConverter } = require("../converters/StringTypeConverter"); // eslint-disable-line @typescript-eslint/no-var-requires
            TypeConverterManager._defaultTypeConverter = new StringTypeConverter();
        }
        return TypeConverterManager._defaultTypeConverter;
    }
}
exports.TypeConverterManager = TypeConverterManager;
TypeConverterManager._converters = {};
//# sourceMappingURL=TypeConverterManager.js.map