/** @packageDocumentation
 * @module Date
 */
import { AlternateDateFormats, DateFormatter, TimeDisplay } from "@bentley/ui-abstract";
import { CommonProps } from "@bentley/ui-core";
import "./DateField.scss";
/** Props for [[DateField]] Component.
 * @internal
 */
export interface DateFieldProps extends CommonProps {
    /** Defines initial date and time for component. */
    initialDate: Date;
    /** Function to call when the date or time is changed. */
    onDateChange?: (day: Date) => void;
    /** Optional value to define if edit field allows editing. If a DateFormatter is provided
     * it must provide a parseData function or the field will be read only no matter the setting of this value. */
    readOnly?: boolean;
    /** Optional date formatter that produces an explicit date display */
    dateFormatter?: DateFormatter;
    /** This property has two purposes, the first is specify that the display of time is desired and the second is to define the format of the time display. */
    timeDisplay?: TimeDisplay;
}
/** Function to format a Date object that is used in control, type editor, and type converter
 * to produce a consistent formatted Date string.
 * @internal
 */
export declare function formatInputDate(inputDate: Date, timeDisplay?: TimeDisplay, customFormatter?: DateFormatter, alternateDateFormat?: AlternateDateFormats): string | undefined;
/** Date input component. This component is typically used by the [[DatePickerPopupButton]] to display and edit date and time.
 * @internal
 */
export declare function DateField({ initialDate, onDateChange, readOnly, dateFormatter, timeDisplay, style, className }: DateFieldProps): JSX.Element;
//# sourceMappingURL=DateField.d.ts.map