"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Date
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatePicker = void 0;
const React = __importStar(require("react"));
const classnames_1 = __importDefault(require("classnames"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../UiComponents");
require("./DatePicker.scss");
function isSameDay(a, b) {
    return (a &&
        b &&
        a.getFullYear() === b.getFullYear() &&
        a.getMonth() === b.getMonth() &&
        a.getDate() === b.getDate());
}
/** DatePicker component. Show a month selector and a day calendar to select a specific date.
 * @alpha
 */
function DatePicker(props) {
    const previousMonthLabel = React.useRef(UiComponents_1.UiComponents.i18n.translate("UiComponents:datepicker.previousMonth"));
    const nextMonthLabel = React.useRef(UiComponents_1.UiComponents.i18n.translate("UiComponents:datepicker.nextMonth"));
    const monthsLong = React.useRef([
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.january"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.february"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.march"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.april"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.may"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.june"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.july"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.august"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.september"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.october"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.november"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:month.long.december"),
    ]);
    const daysLong = React.useRef([
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.long.sunday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.long.monday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.long.tuesday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.long.wednesday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.long.thursday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.long.friday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.long.saturday"),
    ]);
    const daysShort = React.useRef([
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.short.sunday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.short.monday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.short.tuesday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.short.wednesday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.short.thursday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.short.friday"),
        UiComponents_1.UiComponents.i18n.translate("UiComponents:days.short.saturday"),
    ]);
    const [selectedDay, setSelectedDay] = React.useState(new Date(props.selected.getTime()));
    const [displayedMonthIndex, setDisplayedMonthIndex] = React.useState(selectedDay.getMonth());
    const [displayedYear, setDisplayedYear] = React.useState(selectedDay.getFullYear());
    const [focusedDay, setFocusedDay] = React.useState(selectedDay);
    const days = React.useMemo(() => {
        const msFirstDayOfMonth = new Date(displayedYear, displayedMonthIndex, 1).getTime();
        let offsetToFirst = new Date(msFirstDayOfMonth).getDay();
        if (0 === offsetToFirst)
            offsetToFirst = 7;
        const daysInMonth = [];
        // generate 6 weeks of dates
        for (let i = 0; i < 42; i++) {
            const adjustedDay = 1 + i - offsetToFirst;
            daysInMonth.push(new Date(displayedYear, displayedMonthIndex, adjustedDay));
        }
        return daysInMonth;
    }, [displayedMonthIndex, displayedYear]);
    const weeks = React.useMemo(() => {
        const weeksInMonth = [];
        const weekCount = Math.ceil(days.length / 7);
        for (let i = 0; i < weekCount; i++) {
            weeksInMonth.push(days.slice(i * 7, (i + 1) * 7));
        }
        return weeksInMonth;
    }, [days]);
    const setMonthAndYear = React.useCallback((newMonth, newYear) => {
        setDisplayedMonthIndex(newMonth);
        setDisplayedYear(newYear);
        if (selectedDay.getFullYear() === newYear && selectedDay.getMonth() === newMonth) {
            setFocusedDay(new Date(selectedDay.getTime()));
        }
        else {
            const newFocusDay = new Date(focusedDay.getTime());
            newFocusDay.setFullYear(newYear, newMonth, 1);
            setFocusedDay(newFocusDay);
        }
    }, [focusedDay, selectedDay]);
    const handleMoveToPreviousMonth = React.useCallback(() => {
        const newMonth = displayedMonthIndex !== 0 ? displayedMonthIndex - 1 : 11;
        const newYear = displayedMonthIndex !== 0 ? displayedYear : displayedYear - 1;
        setMonthAndYear(newMonth, newYear);
    }, [displayedMonthIndex, displayedYear, setMonthAndYear]);
    const handleMoveToNextMonth = React.useCallback(() => {
        const newMonth = displayedMonthIndex !== 11 ? displayedMonthIndex + 1 : 0;
        const newYear = displayedMonthIndex !== 11 ? displayedYear : displayedYear + 1;
        setMonthAndYear(newMonth, newYear);
    }, [displayedMonthIndex, displayedYear, setMonthAndYear]);
    // when invoked, it will return another function which can be used for the onClick React listener.
    const handleOnDayChange = React.useCallback((day) => () => {
        setSelectedDay(day);
        setFocusedDay(day);
        props.onDateChange && props.onDateChange(day);
    }, [props]);
    const handleCalendarKeyDown = React.useCallback((event) => {
        if (event.key === ui_abstract_1.SpecialKey.ArrowDown) {
            const focusedDayIndex = days.findIndex((day) => isSameDay(day, focusedDay));
            if ((focusedDayIndex + 7) > 41)
                setFocusedDay(days[focusedDayIndex % 7]);
            else
                setFocusedDay(days[focusedDayIndex + 7]);
            event.preventDefault();
        }
        if (event.key === ui_abstract_1.SpecialKey.ArrowUp) {
            const focusedDayIndex = days.findIndex((day) => isSameDay(day, focusedDay));
            if ((focusedDayIndex - 7) < 0)
                setFocusedDay(days[(focusedDayIndex % 7) + 35]);
            else
                setFocusedDay(days[focusedDayIndex - 7]);
            event.preventDefault();
        }
        if (event.key === ui_abstract_1.SpecialKey.ArrowLeft) {
            const focusedDayIndex = days.findIndex((day) => isSameDay(day, focusedDay));
            // istanbul ignore else
            if ((focusedDayIndex - 1) >= 0)
                setFocusedDay(days[focusedDayIndex - 1]);
            event.preventDefault();
        }
        if (event.key === ui_abstract_1.SpecialKey.ArrowRight) {
            const focusedDayIndex = days.findIndex((day) => isSameDay(day, focusedDay));
            // istanbul ignore else
            if ((focusedDayIndex + 1) <= 41)
                setFocusedDay(days[focusedDayIndex + 1]);
            event.preventDefault();
        }
        if (event.key === ui_abstract_1.SpecialKey.Enter || event.key === ui_abstract_1.SpecialKey.Space) {
            handleOnDayChange(focusedDay)(); // NB: immediately call returned handler function
            event.preventDefault();
        }
    }, [days, focusedDay, handleOnDayChange]);
    const previousButtonClass = classnames_1.default("components-previous-month", props.showFocusOutline && "showFocusOutline");
    const nextButtonClass = classnames_1.default("components-next-month", props.showFocusOutline && "showFocusOutline");
    const calendarClass = classnames_1.default("components-date-picker-calendar-month", props.showFocusOutline && "showFocusOutline");
    return (React.createElement("div", { className: "components-date-picker-calendar" },
        React.createElement("div", { className: "components-date-picker-calendar-header-months" },
            React.createElement("button", { className: previousButtonClass, title: previousMonthLabel.current, onClick: handleMoveToPreviousMonth },
                React.createElement(ui_core_1.WebFontIcon, { iconName: "icon-chevron-left" })),
            React.createElement("span", { className: "components-month-year" },
                monthsLong.current[displayedMonthIndex],
                " ",
                displayedYear),
            React.createElement("button", { className: nextButtonClass, title: nextMonthLabel.current, onClick: handleMoveToNextMonth },
                React.createElement(ui_core_1.WebFontIcon, { iconName: "icon-chevron-right" }))),
        React.createElement("div", { className: "components-date-picker-calendar-header-weekdays" }, [0, 1, 2, 3, 4, 5, 6].map((dayOfWeek) => React.createElement("div", { key: `day-${dayOfWeek}`, className: "components-date-picker-calendar-header-day-short", title: daysLong.current[dayOfWeek] },
            React.createElement("span", null, daysShort.current[dayOfWeek])))),
        React.createElement("ul", { tabIndex: 0, onKeyDown: handleCalendarKeyDown, "data-testid": "components-date-picker-calendar-list", className: calendarClass, role: "listbox" }, weeks.map((weekdays, weekIndex) => (React.createElement(React.Fragment, { key: `week-${weekIndex}` }, weekdays.map((day, dayIndex) => {
            const isActive = selectedDay && day && isSameDay(selectedDay, day);
            const isFocused = focusedDay && day && isSameDay(focusedDay, day) && props.showFocusOutline;
            const isCurrentMonth = day.getMonth() === displayedMonthIndex;
            const classNames = classnames_1.default("components-date-picker-calendar-day", isActive && "selected", !isCurrentMonth && "notCurrentMonth", isFocused && "focused");
            const dateValue = day.getDate();
            return (
            /* eslint-disable-next-line jsx-a11y/click-events-have-key-events */
            React.createElement("li", { className: classNames, key: `${displayedYear}.${displayedMonthIndex}.day.${dayIndex}`, onClick: handleOnDayChange(day), role: "option", "aria-selected": isActive, "data-value": day.getTime() },
                React.createElement("span", null, dateValue)));
        })))))));
}
exports.DatePicker = DatePicker;
//# sourceMappingURL=DatePicker.js.map