"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Date
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatePickerPopupButton = void 0;
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../UiComponents");
const DatePicker_1 = require("./DatePicker");
const DateField_1 = require("./DateField");
const TimeField_1 = require("./TimeField");
require("./DatePickerPopupButton.scss");
/** Component that displays a button used to pick a date and optionally a time.
 * @alpha
 * */
function DatePickerPopupButton({ displayEditField, timeDisplay, selected, onDateChange, dateFormatter, buttonToolTip, fieldStyle, fieldClassName, style }) {
    const [workingDate, setWorkingDate] = React.useState(new Date(selected.getTime()));
    const [isSettingsOpen, setIsSettingsOpen] = React.useState(false);
    const timeLabelRef = React.useRef(UiComponents_1.UiComponents.translate("datepicker.time"));
    const toolTipLabelRef = React.useRef(UiComponents_1.UiComponents.translate("datepicker.selectDate"));
    const toolTipLabel = React.useMemo(() => buttonToolTip ? buttonToolTip : toolTipLabelRef.current, [buttonToolTip]);
    // See if props have changed since component mounted
    React.useEffect(() => {
        const newWorkingDate = new Date(selected.getTime());
        setWorkingDate(newWorkingDate);
    }, [selected]);
    const buttonRef = React.useRef(null);
    const togglePopupDisplay = React.useCallback((event) => {
        event.preventDefault();
        setShowFocusOutline(false);
        setIsSettingsOpen((prev) => !prev);
    }, [setIsSettingsOpen]);
    const handleCloseSetting = React.useCallback(() => {
        setIsSettingsOpen(false);
    }, [setIsSettingsOpen]);
    const handleOnDateChanged = (day) => {
        // combine current time into selected Date
        const newWorkingDate = new Date(day.getTime());
        newWorkingDate.setHours(workingDate.getHours(), workingDate.getMinutes(), workingDate.getSeconds());
        onDateChange && onDateChange(newWorkingDate);
        !timeDisplay && setIsSettingsOpen(false);
    };
    const handleOnTimeChanged = (time) => {
        // Combine new time into selected Date
        const newWorkingDate = new Date(workingDate.getTime());
        newWorkingDate.setHours(time.hours, time.minutes, time.seconds);
        setWorkingDate(newWorkingDate);
        onDateChange && onDateChange(newWorkingDate);
    };
    const [showFocusOutline, setShowFocusOutline] = React.useState(false);
    const handlePopupKeyDown = React.useCallback((event) => {
        // istanbul ignore else
        if (event.key === ui_abstract_1.SpecialKey.Space) {
            setShowFocusOutline(true);
            setIsSettingsOpen(true);
        }
    }, []);
    const timeSpec = { hours: workingDate.getHours(), minutes: workingDate.getMinutes(), seconds: workingDate.getSeconds() };
    return (React.createElement(React.Fragment, null,
        React.createElement("button", { title: toolTipLabel, style: style, className: "components-date-picker-calendar-popup-button", onKeyDown: handlePopupKeyDown, "data-testid": "components-date-picker-calendar-popup-button", onPointerDown: togglePopupDisplay, ref: buttonRef },
            React.createElement("div", { className: "datepicker-button" },
                React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 16 16" },
                    React.createElement("path", { d: "M13,13H9V10h4ZM16,3V15a1,1,0,0,1-1,1H1a1,1,0,0,1-1-1V3A1,1,0,0,1,1,2H3V0H4V2h8V0h1V2h2A1,1,0,0,1,16,3ZM15,6H1v9H15Z" })))),
        React.createElement(ui_core_1.Popup, { isOpen: isSettingsOpen, position: ui_abstract_1.RelativePosition.BottomLeft, onClose: handleCloseSetting, target: buttonRef.current, closeOnEnter: false, moveFocus: showFocusOutline, closeOnNestedPopupOutsideClick: true },
            React.createElement("div", { className: "components-date-picker-calendar-popup-panel", "data-testid": "components-date-picker-calendar-popup-panel" },
                React.createElement(DatePicker_1.DatePicker, { selected: workingDate, onDateChange: handleOnDateChanged, showFocusOutline: showFocusOutline }),
                timeDisplay &&
                    React.createElement("div", { className: "time-container" },
                        React.createElement(ui_core_1.BodyText, { className: "time-label" }, timeLabelRef.current),
                        React.createElement(TimeField_1.TimeField, { time: timeSpec, timeDisplay: timeDisplay, onTimeChange: handleOnTimeChanged })))),
        !!displayEditField && React.createElement(DateField_1.DateField, { style: fieldStyle, className: fieldClassName, initialDate: workingDate, timeDisplay: timeDisplay, dateFormatter: dateFormatter, onDateChange: handleOnDateChanged })));
}
exports.DatePickerPopupButton = DatePickerPopupButton;
//# sourceMappingURL=DatePickerPopupButton.js.map