"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Date
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntlFormatter = void 0;
/**
 * A basic class that allows user to provide an Intl.DateTimeFormat
 * that can be used to format the date and time display. If no format is
 * specified a default format will be used. This default implementation does not
 * support parsing, so when used by [[DatePickerPopup]] the edit field will be readonly. If
 * a parseData function is implemented then the edit field will be editable.
 * @alpha
 */
class IntlFormatter {
    constructor(_intlFormatter) {
        this._intlFormatter = _intlFormatter;
    }
    get formatter() {
        if (!this._intlFormatter) {
            // https://tc39.es/ecma402/#sec-intl-datetimeformat-constructor
            this._intlFormatter = new Intl.DateTimeFormat(undefined, {
                weekday: "short",
                year: "numeric",
                month: "2-digit",
                day: "2-digit",
                hour: "numeric",
                hour12: true,
                minute: "numeric",
                second: "numeric", /* "2-digit", "numeric" */
                /* timeZoneName:	"short", */ /* "short", "long" */
            });
        }
        return this._intlFormatter;
    }
    formateDate(day) {
        return this.formatter.format(day);
    }
}
exports.IntlFormatter = IntlFormatter;
//# sourceMappingURL=IntlFormatter.js.map