"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withDragSource = void 0;
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module DragDrop
 */
const React = __importStar(require("react"));
const react_dnd_1 = require("react-dnd");
const DragDropDef_1 = require("./DragDropDef");
let emptyImage;
function getEmptyImage() {
    if (!emptyImage) {
        emptyImage = new Image();
        emptyImage.src =
            "data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==";
    }
    return emptyImage;
}
/**
 * HOC (Higher-Order Component) that transforms wrapped component into a DragSource.
 * @param Component component to wrap.
 * @beta
 * @deprecated
 */
// istanbul ignore next
const withDragSource = (
// eslint-disable-next-line @typescript-eslint/naming-convention
Component) => {
    var _a;
    return react_dnd_1.DragSource((props) => {
        if (props.dragProps.objectType) {
            if (typeof props.dragProps.objectType === "function")
                return props.dragProps.objectType();
            else
                return props.dragProps.objectType;
        }
        return "";
    }, {
        beginDrag(props, _monitor, component) {
            let dropEffect = props.defaultDropEffect || DragDropDef_1.DropEffects.Move; // eslint-disable-line deprecation/deprecation
            if (component.state.ctrlKey) {
                dropEffect = props.ctrlDropEffect || DragDropDef_1.DropEffects.Copy; // eslint-disable-line deprecation/deprecation
            }
            else if (component.state.altKey) {
                dropEffect = props.altDropEffect || DragDropDef_1.DropEffects.Link; // eslint-disable-line deprecation/deprecation
            }
            let dragRect = { left: 0, top: 0 };
            const componentElement = component.rootElement;
            if (componentElement) {
                dragRect = componentElement.getBoundingClientRect();
            }
            const obj = {
                dataObject: {},
                dropEffect,
                dropStatus: DragDropDef_1.DropStatus.None,
                dragRect,
                defaultDragLayer: props.dragProps.defaultDragLayer,
                clientOffset: { x: dragRect.left || 0, y: dragRect.top || 0 },
                initialClientOffset: { x: dragRect.left || 0, y: dragRect.top || 0 },
            };
            if (props.dragProps.onDragSourceBegin)
                return props.dragProps.onDragSourceBegin(obj);
            return obj;
        },
        endDrag(props, monitor, component) {
            let dragRect = { left: 0, top: 0 };
            const componentElement = component && component.rootElement;
            if (componentElement) {
                dragRect = componentElement.getBoundingClientRect();
            }
            // eslint-disable-next-line deprecation/deprecation
            const obj = monitor.getDropResult() || // if onDropTargetDrop returns a value
                // eslint-disable-next-line deprecation/deprecation
                monitor.getItem() || // otherwise, get current drag item.
                {
                    dataObject: {},
                    dropEffect: DragDropDef_1.DropEffects.None,
                    dropStatus: DragDropDef_1.DropStatus.None,
                    dragRect,
                    clientOffset: { x: 0, y: 0 },
                    initialClientOffset: { x: 0, y: 0 },
                    sourceClientOffset: { x: 0, y: 0 },
                    initialSourceClientOffset: { x: 0, y: 0 },
                };
            const { dataObject, dropEffect, dropStatus, dropRect, initialClientOffset, initialSourceClientOffset, local, row, col } = obj;
            const clientOffset = monitor.getClientOffset() || obj.clientOffset;
            const sourceClientOffset = monitor.getSourceClientOffset() || obj.sourceClientOffset;
            const dragObj = {
                dataObject,
                dropEffect, dropStatus, dropRect, dragRect,
                clientOffset, initialClientOffset, sourceClientOffset, initialSourceClientOffset,
                local, row, col,
            };
            if (props.dragProps.onDragSourceEnd)
                props.dragProps.onDragSourceEnd(dragObj);
        },
    }, (connect, monitor) => {
        return {
            connectDragSource: connect.dragSource(),
            connectDragPreview: connect.dragPreview(),
            isDragging: monitor.isDragging(),
            canDrag: monitor.canDrag(),
            item: monitor.getItem(),
            type: monitor.getItemType(),
        };
    })((_a = class DragSourceWrapper extends React.Component {
            constructor() {
                super(...arguments);
                this.rootElement = null;
                this.state = {
                    ctrlKey: false,
                    altKey: false,
                };
                this.handleKeyChange = (event) => {
                    const { ctrlKey, altKey } = event;
                    if (this.state.ctrlKey !== ctrlKey) {
                        this.setState({ ctrlKey });
                    }
                    if (this.state.altKey !== altKey) {
                        this.setState({ altKey });
                    }
                };
            }
            render() {
                const _a = this.props, { dragProps, connectDragSource, connectDragPreview, // eslint-disable-line @typescript-eslint/no-unused-vars
                isDragging, canDrag, item, type, defaultDropEffect, ctrlDropEffect, altDropEffect, dragStyle } = _a, // eslint-disable-line @typescript-eslint/no-unused-vars
                props = __rest(_a, ["dragProps", "connectDragSource", "connectDragPreview", "isDragging", "canDrag", "item", "type", "defaultDropEffect", "ctrlDropEffect", "altDropEffect", "dragStyle"]); // eslint-disable-line deprecation/deprecation
                const p = {
                    item,
                    type,
                    isDragging,
                    canDrag,
                };
                const effectMap = {
                    [DragDropDef_1.DropEffects.Move]: "move",
                    [DragDropDef_1.DropEffects.Copy]: "copy",
                    [DragDropDef_1.DropEffects.Link]: "link", // eslint-disable-line deprecation/deprecation
                };
                const defaultEffect = effectMap[defaultDropEffect];
                const ctrlEffect = effectMap[ctrlDropEffect];
                const altEffect = effectMap[altDropEffect];
                const dropEffect = this.state.ctrlKey ? ctrlEffect || "copy" : this.state.altKey ? altEffect || "link" : defaultEffect || "move";
                return connectDragSource(React.createElement("div", { className: "drag-source-wrapper", "data-testid": "drag-source-wrapper", ref: (el) => { this.rootElement = el; }, style: this.props.dragStyle },
                    React.createElement(Component, Object.assign({}, props, p))), { dropEffect });
            }
            componentDidMount() {
                if (this.props.connectDragPreview) {
                    this.props.connectDragPreview(getEmptyImage(), { captureDraggingState: true });
                }
                window.addEventListener("keydown", this.handleKeyChange);
                window.addEventListener("keyup", this.handleKeyChange);
            }
            componentWillUnmount() {
                window.removeEventListener("keydown", this.handleKeyChange);
                window.removeEventListener("keyup", this.handleKeyChange);
            }
        },
        _a.defaultProps = {
            defaultDropEffect: DragDropDef_1.DropEffects.Move,
            ctrlDropEffect: DragDropDef_1.DropEffects.Copy,
            altDropEffect: DragDropDef_1.DropEffects.Link, // eslint-disable-line deprecation/deprecation
        },
        _a));
};
exports.withDragSource = withDragSource;
//# sourceMappingURL=withDragSource.js.map