"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BooleanPropertyEditor = exports.BooleanEditor = void 0;
require("./BooleanEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
/** BooleanEditor React component that is a property editor with checkbox input
 * @beta
 */
class BooleanEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._inputElement = React.createRef();
        /** @internal */
        this.state = {
            checkboxValue: false,
            isDisabled: false,
        };
        this._updateCheckboxValue = (e) => {
            // istanbul ignore else
            if (this._isMounted) {
                let checkboxValue = false;
                // istanbul ignore if
                if (e.target.checked !== undefined) // Needed for unit test environment
                    checkboxValue = e.target.checked;
                else {
                    // istanbul ignore else
                    if (e.target.value !== undefined && typeof e.target.value === "boolean")
                        checkboxValue = e.target.value;
                }
                this.setState({
                    checkboxValue,
                }, async () => {
                    // istanbul ignore else
                    if (this.props.propertyRecord && this.props.onCommit) {
                        const propertyValue = await this.getPropertyValue();
                        // istanbul ignore else
                        if (propertyValue !== undefined) {
                            this.props.onCommit({ propertyRecord: this.props.propertyRecord, newValue: propertyValue });
                        }
                    }
                });
            }
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.checkboxValue,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._inputElement.current;
    }
    get hasFocus() {
        return document.activeElement === this._inputElement.current;
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const { propertyRecord } = this.props;
        let checkboxValue = false;
        let isDisabled = false;
        // istanbul ignore else
        if (propertyRecord && propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const primitiveValue = propertyRecord.value.value;
            checkboxValue = primitiveValue;
        }
        // istanbul ignore else
        if (propertyRecord && propertyRecord.isDisabled)
            isDisabled = propertyRecord.isDisabled;
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ checkboxValue, isDisabled });
    }
    /** @internal */
    render() {
        const className = classnames_1.default("components-cell-editor", "components-boolean-editor", this.props.className);
        const checked = this.state.checkboxValue;
        const isDisabled = !!this.state.isDisabled;
        return (React.createElement(ui_core_1.Checkbox, { inputRef: this._inputElement, onBlur: this.props.onBlur, className: className, style: this.props.style, checked: checked, onChange: this._updateCheckboxValue, setFocus: this.props.setFocus, disabled: isDisabled, "data-testid": "components-checkbox-editor" }));
    }
}
exports.BooleanEditor = BooleanEditor;
/** Boolean Property Editor registered for the "bool" and "boolean" type names.
 * It uses the [[BooleanEditor]] React component.
 * @beta
 */
class BooleanPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    get reactNode() {
        return React.createElement(BooleanEditor, null);
    }
}
exports.BooleanPropertyEditor = BooleanPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Bool, BooleanPropertyEditor);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Boolean, BooleanPropertyEditor);
//# sourceMappingURL=BooleanEditor.js.map