"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorPropertyEditor = exports.ColorEditor = void 0;
require("./ColorEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const imodeljs_common_1 = require("@bentley/imodeljs-common");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ColorPickerButton_1 = require("../color/ColorPickerButton");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
/** ColorEditor React component that is a property editor with text input
 * @beta
 */
class ColorEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._buttonElement = React.createRef();
        /** @internal */
        this.state = {
            colorValue: 0,
            readonly: false,
            numColumns: 4,
            availableColors: [],
        };
        this._onColorPick = (color) => {
            const propertyRecord = this.props.propertyRecord;
            this.setState({
                colorValue: color.tbgr,
            }, async () => {
                // istanbul ignore else
                if (propertyRecord && this.props.onCommit) {
                    const propertyValue = await this.getPropertyValue();
                    // istanbul ignore else
                    if (propertyValue !== undefined) {
                        this.props.onCommit({ propertyRecord, newValue: propertyValue });
                    }
                }
            });
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.colorValue,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._buttonElement.current;
    }
    get hasFocus() {
        return document.activeElement === this._buttonElement.current;
    }
    setFocus() {
        // istanbul ignore else
        if (this._buttonElement && this._buttonElement.current && !this.state.isDisabled) {
            this._buttonElement.current.focus();
        }
    }
    /** @internal */
    componentDidMount() {
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const record = this.props.propertyRecord;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const colorValue = record.value.value;
            let numColumns = 4;
            const availableColors = new Array();
            const readonly = record && undefined !== record.isReadonly ? record.isReadonly : /* istanbul ignore next */ false;
            const isDisabled = record ? record.isDisabled : /* istanbul ignore next */ undefined;
            if (record.property.editor && record.property.editor.params) {
                const colorParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.ColorData);
                // istanbul ignore else
                if (colorParams) {
                    colorParams.colorValues.forEach((colorNumber) => {
                        availableColors.push(imodeljs_common_1.ColorDef.create(colorNumber));
                    });
                    // istanbul ignore else
                    if (colorParams.numColumns)
                        numColumns = colorParams.numColumns;
                }
            }
            this.setState({ colorValue, readonly, isDisabled, numColumns, availableColors }, () => {
                if (this.props.setFocus) {
                    this.setFocus();
                }
            });
        }
    }
    /** @internal */
    render() {
        const colorDef = imodeljs_common_1.ColorDef.create(this.state.colorValue);
        return (React.createElement("div", { className: classnames_1.default("components-color-editor", this.props.className), style: this.props.style },
            React.createElement(ColorPickerButton_1.ColorPickerButton, { ref: this._buttonElement, initialColor: colorDef, colorDefs: this.state.availableColors.length > 0 ? this.state.availableColors : [colorDef], numColumns: this.state.numColumns, disabled: this.state.isDisabled ? true : false, readonly: this.state.readonly, onColorPick: this._onColorPick, "data-testid": "components-color-editor" })));
    }
}
exports.ColorEditor = ColorEditor;
/** Color Property Editor registered for the "number" type name and "color-picker" editor name.
 * It uses the [[ColorEditor]] React component.
 * @beta
 */
class ColorPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    get reactNode() {
        return React.createElement(ColorEditor, null);
    }
}
exports.ColorPropertyEditor = ColorPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Number, ColorPropertyEditor, ui_abstract_1.StandardEditorNames.ColorPicker);
//# sourceMappingURL=ColorEditor.js.map