/** @packageDocumentation
 * @module PropertyEditors
 */
import "./CustomNumberEditor.scss";
import * as React from "react";
import { PropertyValue } from "@bentley/ui-abstract";
import { PropertyEditorProps, TypeEditor } from "./EditorContainer";
import { PropertyEditorBase } from "./PropertyEditorManager";
/** @internal */
interface CustomNumberEditorState {
    inputValue: string;
    size?: number;
    maxLength?: number;
    iconSpec?: string;
}
/** CustomNumberEditor is a React component that is a property editor for numbers that specify custom formatting and parsing functions.
 * @alpha
 */
export declare class CustomNumberEditor extends React.PureComponent<PropertyEditorProps, CustomNumberEditorState> implements TypeEditor {
    private _isMounted;
    private _formatParams;
    private _inputElement;
    /** @internal */
    readonly state: Readonly<CustomNumberEditorState>;
    getPropertyValue(): Promise<PropertyValue | undefined>;
    get htmlElement(): HTMLElement | null;
    get hasFocus(): boolean;
    private shouldSetFocus;
    private _applyUpdatedValue;
    private _updateInputValue;
    /** @internal */
    componentDidMount(): void;
    /** @internal */
    componentWillUnmount(): void;
    /** @internal */
    componentDidUpdate(prevProps: PropertyEditorProps): void;
    private _getInitialDisplayValue;
    private setStateFromProps;
    private _resetToOriginalValue;
    private _onKeyPress;
    private _onFocus;
    /** @internal */
    render(): React.ReactNode;
}
/** Custom Property Editor registered for the "number" type name and the "number-custom" editor name.
 * It uses the [[CustomNumberEditor]] React component.
 * @alpha
 */
export declare class CustomNumberPropertyEditor extends PropertyEditorBase {
    get reactNode(): React.ReactNode;
    get containerHandlesEscape(): boolean;
}
export {};
//# sourceMappingURL=CustomNumberEditor.d.ts.map