"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomNumberPropertyEditor = exports.CustomNumberEditor = void 0;
// cSpell:ignore customnumber testid
require("./CustomNumberEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../UiComponents");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
/** CustomNumberEditor is a React component that is a property editor for numbers that specify custom formatting and parsing functions.
 * @alpha
 */
class CustomNumberEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._inputElement = React.createRef();
        /** @internal */
        this.state = {
            inputValue: "",
        };
        this._updateInputValue = (e) => {
            this._applyUpdatedValue(e.target.value);
        };
        this._onKeyPress = (e) => {
            // istanbul ignore else
            if (e.key === ui_abstract_1.SpecialKey.Escape) {
                const initialDisplayValue = this._getInitialDisplayValue();
                if (initialDisplayValue !== this.state.inputValue) {
                    e.preventDefault();
                    e.stopPropagation();
                    this._resetToOriginalValue();
                }
                else {
                    // istanbul ignore else
                    if (this.props.onCancel)
                        this.props.onCancel();
                }
            }
            // istanbul ignore else
            if (e.key !== ui_abstract_1.SpecialKey.Enter) {
                // istanbul ignore next
                if (imodeljs_frontend_1.IModelApp.notifications)
                    imodeljs_frontend_1.IModelApp.notifications.closeInputFieldMessage();
            }
        };
        // istanbul ignore next
        this._onFocus = (e) => {
            e.target.select();
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        if (record.isReadonly) {
            return {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: record.value.value,
                displayValue: record.value.displayValue,
            };
        }
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const parseResults = this._formatParams.parseFunction(this.state.inputValue);
            if (!parseResults.parseError && undefined !== parseResults.value) {
                const newDisplayValue = this._formatParams.formatFunction(parseResults.value);
                propertyValue = {
                    valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                    value: parseResults.value,
                    displayValue: newDisplayValue,
                };
                // make sure the text in the input item matches the latest formatted text... this could get out if the input string say 1.5 === the display string of 1'-6"
                // istanbul ignore else
                if (newDisplayValue !== this.state.inputValue) {
                    this.setState({ inputValue: newDisplayValue });
                }
            }
            else {
                const msg = new imodeljs_frontend_1.NotifyMessageDetails(imodeljs_frontend_1.OutputMessagePriority.Error, parseResults.parseError ? parseResults.parseError : /* istanbul ignore next */ UiComponents_1.UiComponents.translate("errors.unable-to-parse-quantity"));
                this.htmlElement && msg.setInputFieldTypeDetails(this.htmlElement);
                // istanbul ignore next
                if (imodeljs_frontend_1.IModelApp.notifications)
                    imodeljs_frontend_1.IModelApp.notifications.outputMessage(msg);
                const displayValue = (record.value.displayValue && record.value.displayValue.length > 0) ? record.value.displayValue : /* istanbul ignore next */ this._formatParams.formatFunction(record.value.value);
                propertyValue = {
                    valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                    value: record.value.value,
                    displayValue,
                };
            }
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._inputElement.current;
    }
    get hasFocus() {
        return document.activeElement === this._inputElement.current;
    }
    shouldSetFocus() {
        if (!this.props.setFocus)
            return false;
        const record = this.props.propertyRecord;
        const disabled = (record && !record.isDisabled) ? false : true;
        const readonly = (record && !record.isReadonly) ? false : true;
        return (!disabled && !readonly);
    }
    _applyUpdatedValue(userInput) {
        const record = this.props.propertyRecord;
        const readonly = (record && !record.isReadonly) ? false : true;
        const disabled = (record && !record.isDisabled) ? false : true;
        if (readonly || disabled)
            return;
        // istanbul ignore else
        if (this._isMounted)
            this.setState({
                inputValue: userInput,
            });
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    _getInitialDisplayValue() {
        const record = this.props.propertyRecord;
        let initialDisplayValue = "";
        let numberValue = 0;
        // istanbul ignore else
        if (record) {
            // istanbul ignore else
            if (record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
                const primitiveValue = record.value;
                numberValue = (undefined !== primitiveValue.value) ? primitiveValue.value : /* istanbul ignore next */ 0;
                // istanbul ignore else
                if (primitiveValue.displayValue)
                    initialDisplayValue = primitiveValue.displayValue;
                else
                    initialDisplayValue = this._formatParams.formatFunction(numberValue);
            }
        }
        return initialDisplayValue;
    }
    async setStateFromProps() {
        const record = this.props.propertyRecord;
        // istanbul ignore next
        if (!record || !record.property) {
            bentleyjs_core_1.Logger.logError(UiComponents_1.UiComponents.loggerCategory(this), "PropertyRecord must be defined to use CustomNumberPropertyEditor");
            // eslint-disable-next-line no-console
            // console.log("PropertyRecord must be defined to use CustomNumberPropertyEditor");
            return;
        }
        // istanbul ignore else
        if (record.property && record.property.editor && record.property.editor.params) {
            this._formatParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.CustomFormattedNumber);
        }
        if (!this._formatParams) {
            bentleyjs_core_1.Logger.logError(UiComponents_1.UiComponents.loggerCategory(this), `CustomFormattedNumberParams must be defined for property ${record.property.name}`);
            // eslint-disable-next-line no-console
            // console.log(`CustomFormattedNumberParams must be defined for property ${record!.property!.name}`);
            return;
        }
        const initialDisplayValue = this._getInitialDisplayValue();
        let size;
        let maxLength;
        let iconSpec;
        // istanbul ignore else
        if (record.property && record.property.editor && record.property.editor.params) {
            const editorSizeParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.InputEditorSize);
            // istanbul ignore else
            if (editorSizeParams) {
                // istanbul ignore else
                if (editorSizeParams.size)
                    size = editorSizeParams.size;
                // istanbul ignore else
                if (editorSizeParams.maxLength)
                    maxLength = editorSizeParams.maxLength;
            }
            const iconParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.Icon);
            if (iconParams) {
                iconSpec = iconParams.definition.iconSpec;
            }
        }
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ inputValue: initialDisplayValue, size, maxLength, iconSpec });
    }
    _resetToOriginalValue() {
        const initialDisplayValue = this._getInitialDisplayValue();
        this.setState({ inputValue: initialDisplayValue });
    }
    /** @internal */
    render() {
        const minSize = this.state.size ? this.state.size : 8;
        const minWidthStyle = {
            minWidth: `${minSize * 0.75}em`,
        };
        const record = this.props.propertyRecord;
        if (!record || !this._formatParams)
            return null;
        const readOnly = !record.isReadonly ? false : true;
        const disabled = !record.isDisabled ? false : true;
        const className = classnames_1.default("components-cell-editor", "components-customnumber-editor", this.props.className);
        const inputProps = {
            className,
            style: this.props.style ? this.props.style : minWidthStyle,
            readOnly,
            disabled,
            size: this.state.size,
            maxLength: this.state.maxLength,
            value: this.state.inputValue,
            onChange: this._updateInputValue,
            onBlur: this.props.onBlur,
            onFocus: this._onFocus,
            setFocus: this.shouldSetFocus(),
            nativeKeyHandler: this._onKeyPress,
            ref: this._inputElement,
        };
        let reactNode;
        if (this.state.iconSpec) {
            const icon = React.createElement(ui_core_1.Icon, { iconSpec: this.state.iconSpec });
            reactNode = (React.createElement(ui_core_1.IconInput, Object.assign({}, inputProps, { icon: icon, "data-testid": "components-customnumber-editor" })));
        }
        else {
            reactNode = (React.createElement(ui_core_1.Input, Object.assign({}, inputProps, { "data-testid": "components-customnumber-editor" })));
        }
        return reactNode;
    }
}
exports.CustomNumberEditor = CustomNumberEditor;
/** Custom Property Editor registered for the "number" type name and the "number-custom" editor name.
 * It uses the [[CustomNumberEditor]] React component.
 * @alpha
 */
class CustomNumberPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    get reactNode() {
        return React.createElement(CustomNumberEditor, null);
    }
    get containerHandlesEscape() {
        return false;
    }
}
exports.CustomNumberPropertyEditor = CustomNumberPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Number, CustomNumberPropertyEditor, ui_abstract_1.StandardEditorNames.NumberCustom);
//# sourceMappingURL=CustomNumberEditor.js.map