/** @packageDocumentation
 * @module PropertyEditors
 */
import "./DateTimeEditor.scss";
import * as React from "react";
import { PropertyValue, TimeDisplay } from "@bentley/ui-abstract";
import { PropertyEditorProps, TypeEditor } from "./EditorContainer";
import { PropertyEditorBase } from "./PropertyEditorManager";
import { TypeConverter } from "../converters/TypeConverter";
/** @internal */
interface DateTimeEditorState {
    value: Date;
    displayValue?: string;
    timeDisplay?: TimeDisplay;
    isDisabled?: boolean;
    typeConverter?: TypeConverter;
    editInUtc: boolean;
}
/** @internal */
interface DateTimeEditorProps extends PropertyEditorProps {
    showTime?: boolean;
}
/** DateTimeEditor React component that is a property editor for selection of date and time.
 * @internal
 */
export declare class DateTimeEditor extends React.PureComponent<DateTimeEditorProps, DateTimeEditorState> implements TypeEditor {
    private _isMounted;
    private _enterKey;
    private _divElement;
    /** @internal */
    readonly state: Readonly<DateTimeEditorState>;
    getPropertyValue(): Promise<PropertyValue | undefined>;
    get htmlElement(): HTMLElement | null;
    get hasFocus(): boolean;
    processDateChange(typeConverter: TypeConverter, newValue: Date): Promise<void>;
    private _handleChange;
    private _handleTimeChange;
    /** @internal */
    componentDidMount(): void;
    /** @internal */
    componentWillUnmount(): void;
    /** @internal */
    componentDidUpdate(prevProps: PropertyEditorProps): void;
    private setStateFromProps;
    private _handleEnter;
    private _handleClose;
    private _handleOk;
    private _handleCancel;
    private _handleCommit;
    /** @internal */
    render(): React.ReactNode;
}
/** DateTime Property Editor registered for the "number" type name and "DateTime" editor name.
  * It uses the [[DateTimeEditor]] React component.
  * @internal
  */
export declare class ShortDateTimePropertyEditor extends PropertyEditorBase {
    get reactNode(): React.ReactNode;
    get containerHandlesTab(): boolean;
}
/** DateTime Property Editor registered for the "number" type name and "DateTime" editor name.
  * It uses the [[DateTimeEditor]] React component.
  * @internal
  */
export declare class DateTimePropertyEditor extends PropertyEditorBase {
    get reactNode(): React.ReactNode;
    get containerHandlesTab(): boolean;
}
export {};
//# sourceMappingURL=DateTimeEditor.d.ts.map