"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnumPropertyButtonGroupEditor = exports.EnumButtonGroupEditor = void 0;
require("./EnumButtonGroupEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
/** EnumButtonGroupEditor React component that is a property editor with select input
 * @beta
 */
class EnumButtonGroupEditor extends React.Component {
    constructor() {
        super(...arguments);
        this._btnRefs = new Map();
        this._divElement = React.createRef();
        /** @internal */
        this.state = {
            selectValue: "",
            enumIcons: [],
            choices: [],
        };
        this._handleButtonClick = (index) => {
            const propertyRecord = this.props.propertyRecord;
            // istanbul ignore else
            if (this.state.choices && this.state.choices.length > index) {
                const selectValue = this.state.choices[index].value;
                this.setState({
                    selectValue,
                }, async () => {
                    // istanbul ignore else
                    if (propertyRecord && this.props.onCommit) {
                        const propertyValue = await this.getPropertyValue();
                        // istanbul ignore else
                        if (propertyValue !== undefined) {
                            this.props.onCommit({ propertyRecord, newValue: propertyValue });
                        }
                    }
                });
            }
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.selectValue,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._divElement.current;
    }
    get hasFocus() {
        let containsFocus = false;
        // istanbul ignore else
        if (this._divElement.current)
            containsFocus = this._divElement.current.contains(document.activeElement);
        return containsFocus;
    }
    /** @internal */
    componentDidMount() {
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const { propertyRecord } = this.props;
        // istanbul ignore else
        if (propertyRecord && propertyRecord.property.enum && propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const primitiveValue = propertyRecord.value.value;
            let selectValue;
            if (typeof primitiveValue === "string") {
                selectValue = primitiveValue;
            }
            else {
                selectValue = primitiveValue;
            }
            let choices = [];
            // istanbul ignore else
            if (propertyRecord && propertyRecord.property.enum) {
                if (propertyRecord.property.enum.choices instanceof Promise) {
                    choices = await propertyRecord.property.enum.choices;
                }
                else {
                    choices = propertyRecord.property.enum.choices;
                }
            }
            const numChoices = choices.length;
            const enumIcons = new Array(numChoices);
            enumIcons.fill({ iconSpec: "icon icon-placeholder" });
            // istanbul ignore else
            if (propertyRecord.property.editor && propertyRecord.property.editor.params) {
                // istanbul ignore else
                if (propertyRecord.property.editor && propertyRecord.property.editor.params) {
                    const bgParams = propertyRecord.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.ButtonGroupData);
                    // istanbul ignore else
                    if (bgParams) {
                        bgParams.buttons.forEach((iconDef, index) => {
                            // istanbul ignore else
                            if (index < numChoices) {
                                enumIcons[index] = iconDef;
                            }
                        });
                    }
                }
            }
            this.setState({ selectValue, enumIcons, choices });
        }
    }
    getButton(choice, index) {
        const choiceValue = this.state.choices ? this.state.choices[index].value : /* istanbul ignore next */ 0;
        const isActive = (choiceValue === this.state.selectValue) ? true : false;
        let isDisabled = false;
        const isEnabledFunction = this.state.enumIcons[index].isEnabledFunction;
        // istanbul ignore else
        if (isEnabledFunction) {
            isDisabled = !isEnabledFunction();
        }
        const className = classnames_1.default("components-enumbuttongroup-button", isDisabled && "nz-is-disabled", isActive && "nz-is-active");
        return (React.createElement("button", { ref: (ref) => this._btnRefs.set(choiceValue, ref), "data-testid": choice.label, className: className, title: choice.label, key: choice.label, onClick: () => this._handleButtonClick(index) },
            React.createElement(ui_core_1.Icon, { iconSpec: this.state.enumIcons[index].iconSpec })));
    }
    /** @internal */
    render() {
        return (React.createElement("div", { className: classnames_1.default("components-enumbuttongroup-editor", this.props.className), style: this.props.style, ref: this._divElement }, this.state.choices && this.state.enumIcons.length && this.state.choices.map((choice, index) => this.getButton(choice, index))));
    }
}
exports.EnumButtonGroupEditor = EnumButtonGroupEditor;
/** Enum Property Button Group Editor registered for the "enum" type name and the "enum-buttongroup" editor name.
 * It uses the [[EnumButtonGroupEditor]] React component.
 * @beta
 */
class EnumPropertyButtonGroupEditor extends PropertyEditorManager_1.PropertyEditorBase {
    get reactNode() {
        return React.createElement(EnumButtonGroupEditor, null);
    }
}
exports.EnumPropertyButtonGroupEditor = EnumPropertyButtonGroupEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Enum, EnumPropertyButtonGroupEditor, ui_abstract_1.StandardEditorNames.EnumButtonGroup);
//# sourceMappingURL=EnumButtonGroupEditor.js.map