"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnumPropertyEditor = exports.EnumEditor = void 0;
require("./EnumEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
const UiComponents_1 = require("../UiComponents");
/** EnumEditor React component that is a property editor with select input
 * @beta
 */
class EnumEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._ariaLabel = UiComponents_1.UiComponents.translate("editor.enum");
        this._selectElement = React.createRef();
        /** @internal */
        this.state = {
            selectValue: "",
            valueIsNumber: false,
            options: {},
        };
        this._updateSelectValue = (e) => {
            // istanbul ignore else
            if (this._isMounted) {
                let selectValue;
                // istanbul ignore if
                if (this.state.valueIsNumber)
                    selectValue = parseInt(e.target.value, 10);
                else
                    selectValue = e.target.value;
                this.setState({
                    selectValue,
                }, async () => {
                    // istanbul ignore else
                    if (this.props.propertyRecord && this.props.onCommit) {
                        const propertyValue = await this.getPropertyValue();
                        // istanbul ignore else
                        if (propertyValue) {
                            this.props.onCommit({ propertyRecord: this.props.propertyRecord, newValue: propertyValue });
                        }
                    }
                });
            }
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.selectValue,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._selectElement.current;
    }
    // istanbul ignore next
    get hasFocus() {
        return document.activeElement === this._selectElement.current;
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const { propertyRecord } = this.props;
        let initialValue = "";
        let valueIsNumber = false;
        // istanbul ignore else
        if (propertyRecord && propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const primitiveValue = propertyRecord.value.value;
            if (typeof primitiveValue === "string") {
                initialValue = primitiveValue;
                valueIsNumber = false;
            }
            else {
                initialValue = primitiveValue;
                valueIsNumber = true;
            }
        }
        let choices;
        if (propertyRecord && propertyRecord.property.enum) {
            // istanbul ignore else
            if (propertyRecord.property.enum.choices instanceof Promise) {
                choices = await propertyRecord.property.enum.choices;
            }
            else {
                choices = propertyRecord.property.enum.choices;
            }
        }
        const options = {};
        if (choices) {
            choices.forEach((choice) => {
                options[choice.value.toString()] = choice.label;
            });
        }
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ selectValue: initialValue, valueIsNumber, options });
    }
    /** @internal */
    render() {
        const className = classnames_1.default("components-cell-editor", "components-enum-editor", this.props.className);
        const selectValue = this.state.selectValue ? this.state.selectValue.toString() : undefined;
        // set min-width to show about 4 characters + down arrow
        const minWidthStyle = {
            minWidth: `${6 * 0.75}em`,
        };
        return (React.createElement(ui_core_1.Select, { ref: this._selectElement, onBlur: this.props.onBlur, className: className, style: this.props.style ? this.props.style : minWidthStyle, value: selectValue, onChange: this._updateSelectValue, "data-testid": "components-select-editor", options: this.state.options, setFocus: this.props.setFocus, "aria-label": this._ariaLabel }));
    }
}
exports.EnumEditor = EnumEditor;
/** Enum Property Button Group Editor registered for the "enum" type name.
 * It uses the [[EnumEditor]] React component.
 * @beta
 */
class EnumPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    // istanbul ignore next
    get containerHandlesEnter() {
        return false;
    }
    get reactNode() {
        return React.createElement(EnumEditor, null);
    }
}
exports.EnumPropertyEditor = EnumPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Enum, EnumPropertyEditor);
//# sourceMappingURL=EnumEditor.js.map