"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IconPropertyEditor = exports.IconEditor = void 0;
require("./IconEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const IconPickerButton_1 = require("../iconpicker/IconPickerButton");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
/** IconEditor React component that is a property editor with button and popup
 * @alpha
 */
// istanbul ignore next
class IconEditor extends React.PureComponent {
    constructor(props) {
        super(props);
        this._control = null;
        this._isMounted = false;
        this._divElement = React.createRef();
        this._onIconChange = (icon) => {
            const propertyRecord = this.props.propertyRecord;
            this.setState({
                icon,
            }, async () => {
                // istanbul ignore else
                if (propertyRecord && this.props.onCommit) {
                    const propertyValue = await this.getPropertyValue();
                    // istanbul ignore else
                    if (propertyValue) {
                        this.props.onCommit({ propertyRecord, newValue: propertyValue });
                    }
                }
            });
        };
        let icon = "";
        let numColumns = 4;
        const icons = [];
        const readonly = false;
        // TODO: add support for following if we need to specify set of weights to display
        const record = props.propertyRecord;
        if (record && record.property && record.property.editor && record.property.editor.params) {
            const iconParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.IconListData);
            // istanbul ignore else
            if (iconParams) {
                if (iconParams.iconValue)
                    icon = iconParams.iconValue;
                if (iconParams.numColumns)
                    numColumns = iconParams.numColumns;
                if (iconParams.iconValues)
                    iconParams.iconValues.forEach((i) => icons.push(i));
            }
        }
        this.state = { icon, icons, numColumns, readonly };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.icon,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._divElement.current;
    }
    get hasFocus() {
        let containsFocus = false;
        if (this._divElement.current)
            containsFocus = this._divElement.current.contains(document.activeElement);
        return containsFocus;
    }
    setFocus() {
        // istanbul ignore else
        if (this._control && !this.state.isDisabled) {
            this._control.setFocus();
        }
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const record = this.props.propertyRecord;
        let initialValue = "";
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            initialValue = record.value.value;
        }
        const readonly = record && undefined !== record.isReadonly ? record.isReadonly : false;
        const isDisabled = record ? record.isDisabled : undefined;
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ icon: initialValue, readonly, isDisabled }, () => {
                if (this.props.setFocus) {
                    this.setFocus();
                }
            });
    }
    /** @internal */
    render() {
        const { icon, icons, numColumns } = this.state;
        return (React.createElement("div", { className: classnames_1.default("components-icon-editor", this.props.className), style: this.props.style, ref: this._divElement },
            React.createElement(IconPickerButton_1.IconPickerButton, { ref: (control) => this._control = control, icon: icon, icons: icons, numColumns: numColumns, disabled: this.state.isDisabled, readonly: this.state.readonly, onIconChange: this._onIconChange, "data-testid": "components-icon-editor" })));
    }
}
exports.IconEditor = IconEditor;
/** Icon Property Editor registered for the "text" and "string" type names and the "icon-picker" editor name.
 * It uses the [[IconEditor]] React component.
 * @alpha
 */
// istanbul ignore next
class IconPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    get reactNode() {
        return React.createElement(IconEditor, null);
    }
}
exports.IconPropertyEditor = IconPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Text, IconPropertyEditor, ui_abstract_1.StandardEditorNames.IconPicker);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.String, IconPropertyEditor, ui_abstract_1.StandardEditorNames.IconPicker);
//# sourceMappingURL=IconEditor.js.map