"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageCheckBoxPropertyEditor = exports.ImageCheckBoxEditor = void 0;
require("./ImageCheckBoxEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
const ui_core_1 = require("@bentley/ui-core");
/** [[ImageCheckBoxEditor]]
 * Boolean editor that renders with an image instead of checkbox
 * @beta
 */
class ImageCheckBoxEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._inputElement = React.createRef();
        /** @internal */
        this.state = {
            imageOff: "",
            imageOn: "",
            checkboxValue: false,
            isDisabled: false,
        };
        this._handleClick = (checked) => {
            this.setState({
                checkboxValue: checked,
            }, async () => {
                // istanbul ignore else
                if (this.props.propertyRecord && this.props.onCommit) {
                    const propertyValue = await this.getPropertyValue();
                    // istanbul ignore else
                    if (this._isMounted && propertyValue !== undefined) {
                        this.props.onCommit({ propertyRecord: this.props.propertyRecord, newValue: propertyValue });
                    }
                }
            });
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.checkboxValue,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._inputElement.current;
    }
    get hasFocus() {
        return document.activeElement === this._inputElement.current;
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps();
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps();
        }
    }
    setStateFromProps() {
        const { propertyRecord } = this.props;
        let checkboxValue = false;
        let imageOn = "";
        let imageOff = "";
        let isDisabled = false;
        // istanbul ignore else
        if (propertyRecord && propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const primitiveValue = propertyRecord.value.value;
            checkboxValue = primitiveValue;
        }
        // istanbul ignore else
        if (propertyRecord && propertyRecord.isDisabled)
            isDisabled = propertyRecord.isDisabled;
        if (propertyRecord && propertyRecord.property && propertyRecord.property.editor && propertyRecord.property.editor.params) {
            const imageCheckBoxParams = propertyRecord.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.CheckBoxImages);
            // istanbul ignore else
            if (imageCheckBoxParams) {
                imageOn = imageCheckBoxParams.imageOn;
                imageOff = imageCheckBoxParams.imageOff;
            }
        }
        this.setState({ imageOn, imageOff, checkboxValue, isDisabled });
    }
    render() {
        const className = classnames_1.default("components-cell-editor", "components-imagecheckbox-editor", this.props.className);
        const checked = this.state.checkboxValue;
        const isDisabled = !!this.state.isDisabled;
        return (React.createElement(ui_core_1.ImageCheckBox, { inputRef: this._inputElement, imageOff: this.state.imageOff, imageOn: this.state.imageOn, className: className, border: true, style: this.props.style, checked: checked, disabled: isDisabled, onClick: this._handleClick, "data-testid": "components-imagecheckbox-editor" }));
    }
}
exports.ImageCheckBoxEditor = ImageCheckBoxEditor;
/** ImageCheckBox Property Editor registered for the "bool" and "boolean" type names.
 * It uses the [[ImageCheckBoxEditor]] React component.
 * @beta
 */
class ImageCheckBoxPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    get reactNode() {
        return React.createElement(ImageCheckBoxEditor, null);
    }
}
exports.ImageCheckBoxPropertyEditor = ImageCheckBoxPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Boolean, ImageCheckBoxPropertyEditor, ui_abstract_1.StandardEditorNames.ImageCheckBox);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Bool, ImageCheckBoxPropertyEditor, ui_abstract_1.StandardEditorNames.ImageCheckBox);
//# sourceMappingURL=ImageCheckBoxEditor.js.map