"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumericInputPropertyEditor = exports.NumericInputEditor = void 0;
require("./NumericInputEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
/** NumericInputEditor React component that is a property editor with numeric input & up/down buttons
 * @beta
 */
class NumericInputEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._inputElement = React.createRef();
        this.hasFocus = false; // hot used since containerHandlesEnter is false
        /** @internal */
        this.state = {
            value: 0,
            readonly: false,
        };
        this._handleCommit = async () => {
            // istanbul ignore else
            if (this.props.propertyRecord && this.props.onCommit) {
                const propertyValue = await this.getPropertyValue();
                // istanbul ignore else
                if (propertyValue !== undefined) {
                    this.props.onCommit({ propertyRecord: this.props.propertyRecord, newValue: propertyValue });
                }
            }
        };
        this._updateValue = (value, _stringValue) => {
            const newValue = value !== undefined ? value : /* istanbul ignore next */ 0;
            // istanbul ignore else
            if (this._isMounted)
                this.setState({
                    value: newValue,
                }, async () => {
                    await this._handleCommit();
                });
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.value,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._inputElement.current;
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const record = this.props.propertyRecord;
        let initialValue = 0;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            initialValue = record.value.value;
        }
        const readonly = record && undefined !== record.isReadonly ? record.isReadonly : false;
        let size;
        let maxLength;
        let min;
        let max;
        let step;
        let precision;
        const isDisabled = record ? record.isDisabled : undefined;
        if (record && record.property && record.property.editor && record.property.editor.params) {
            const editorSizeParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.InputEditorSize);
            if (editorSizeParams) {
                // istanbul ignore else
                if (editorSizeParams.size)
                    size = editorSizeParams.size;
                // istanbul ignore else
                if (editorSizeParams.maxLength)
                    maxLength = editorSizeParams.maxLength;
            }
            const rangeParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.Range);
            if (rangeParams) {
                min = rangeParams.minimum;
                max = rangeParams.maximum;
                step = rangeParams.step;
                precision = rangeParams.precision;
            }
        }
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ value: initialValue, readonly, size, maxLength, isDisabled, min, max, step, precision });
    }
    /** @internal */
    render() {
        const className = classnames_1.default("components-cell-editor", "components-numeric-input-editor", this.props.className);
        const minSize = this.state.size ? this.state.size : 8;
        const style = Object.assign(Object.assign({}, this.props.style), { minWidth: `${minSize * 0.75}em` });
        return (React.createElement(ui_core_1.NumberInput, { ref: this._inputElement, className: className, style: style, value: this.state.value, min: this.state.min, max: this.state.max, step: this.state.step, precision: this.state.precision, readOnly: this.state.readonly, size: this.state.size, maxLength: this.state.maxLength, onBlur: this.props.onBlur, onChange: this._updateValue, setFocus: this.props.setFocus && !this.state.isDisabled }));
    }
}
exports.NumericInputEditor = NumericInputEditor;
/** Numeric Input Property Editor registered for the "number" type name and "numeric-input" editor name.
 * It uses the [[NumericInputEditor]] React component.
 * @beta
 */
class NumericInputPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    get reactNode() {
        return React.createElement(NumericInputEditor, null);
    }
    // istanbul ignore next
    get containerHandlesEnter() {
        return false;
    }
}
exports.NumericInputPropertyEditor = NumericInputPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Number, NumericInputPropertyEditor, ui_abstract_1.StandardEditorNames.NumericInput);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Int, NumericInputPropertyEditor, ui_abstract_1.StandardEditorNames.NumericInput);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Float, NumericInputPropertyEditor, ui_abstract_1.StandardEditorNames.NumericInput);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Double, NumericInputPropertyEditor, ui_abstract_1.StandardEditorNames.NumericInput);
//# sourceMappingURL=NumericInputEditor.js.map