"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PopupOkCancelButtons = exports.PopupContent = exports.PopupButton = void 0;
require("./PopupButton.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
/** PopupButton React component that is a button and property editor popup host
 * @alpha
 */
class PopupButton extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._buttonRef = React.createRef();
        /** @internal */
        this.state = {
            showPopup: false,
        };
        this._togglePopup = (event) => {
            this.setState((prevState) => ({ showPopup: !prevState.showPopup }), () => this.props.onClick && this.props.onClick(event));
        };
        this._closePopup = () => {
            this.setState({ showPopup: false }, () => {
                this.props.onClose && this.props.onClose();
                // istanbul ignore else
                if (this._buttonRef.current)
                    this._buttonRef.current.focus();
            });
        };
        this._emptyKeyDown = (_event) => {
        };
        this._handleKeyDown = (event) => {
            // istanbul ignore else
            if ((event.key === ui_abstract_1.SpecialKey.ArrowDown || event.key === ui_abstract_1.SpecialKey.Space || event.key === ui_abstract_1.SpecialKey.Enter) && !this.state.showPopup) {
                event.preventDefault();
                event.stopPropagation();
                this.setState({ showPopup: true });
            }
        };
    }
    /** @internal */
    componentDidMount() {
        var _a;
        if (this.props.setFocus && this._buttonRef.current)
            this._buttonRef.current.focus();
        (_a = this._buttonRef.current) === null || _a === void 0 ? void 0 : _a.addEventListener("keydown", this._handleKeyDown);
    }
    /** @internal */
    componentWillUnmount() {
        // istanbul ignore next
        if (this._buttonRef.current)
            this._buttonRef.current.removeEventListener("keydown", this._handleKeyDown);
    }
    closePopup() {
        this._closePopup();
    }
    /** @internal */
    render() {
        var _a, _b, _c;
        const showArrow = (_a = this.props.showArrow) !== null && _a !== void 0 ? _a : false;
        const showShadow = (_b = this.props.showShadow) !== null && _b !== void 0 ? _b : false;
        const moveFocus = (_c = this.props.moveFocus) !== null && _c !== void 0 ? _c : true;
        const showPlaceholder = this.props.label === undefined && this.props.placeholder !== undefined;
        const classNames = classnames_1.default("components-popup-button", this.state.showPopup && "components-popup-expanded");
        const valueClassNames = classnames_1.default("components-popup-button-value", showPlaceholder && "components-popup-button-placeholder");
        return (React.createElement("div", { className: this.props.className },
            React.createElement("div", { className: classNames, onClick: this._togglePopup, onKeyDown: this._emptyKeyDown, "data-testid": "components-popup-button", tabIndex: 0, ref: this._buttonRef, title: this.props.title, role: "button" },
                React.createElement("div", { className: valueClassNames }, this.props.label || this.props.placeholder),
                React.createElement("div", { className: "components-popup-button-arrow" },
                    React.createElement("div", { className: classnames_1.default("components-popup-button-arrow-icon", "icon", "icon-chevron-down") }))),
            React.createElement(ui_core_1.Popup, { className: "components-popup-button-popup", isOpen: this.state.showPopup, position: ui_abstract_1.RelativePosition.Bottom, onClose: this._closePopup, onEnter: this.props.onEnter, closeOnEnter: this.props.closeOnEnter, target: this._buttonRef.current, showArrow: showArrow, showShadow: showShadow, moveFocus: moveFocus, focusTarget: this.props.focusTarget }, this.props.children)));
    }
}
exports.PopupButton = PopupButton;
/** Popup content with padding
 * @alpha
 */
function PopupContent(props) {
    return React.createElement(ui_core_1.Div, Object.assign({}, props, { mainClassName: "components-editor-popup-content" }));
}
exports.PopupContent = PopupContent;
/** OK/Cancel Buttons
 * @alpha
 */
function PopupOkCancelButtons(props) {
    return (React.createElement("div", { className: "components-popup-bottom-buttons" },
        React.createElement(ui_core_1.Button, { className: classnames_1.default("components-popup-large-button", "components-popup-ok-button"), "data-testid": "components-popup-ok-button", buttonType: ui_core_1.ButtonType.Primary, title: ui_core_1.UiCore.translate("dialog.ok"), onClick: props.onOk },
            React.createElement(ui_core_1.Icon, { iconSpec: "icon-checkmark" })),
        React.createElement(ui_core_1.Button, { className: classnames_1.default("components-popup-large-button", "components-popup-cancel-button"), "data-testid": "components-popup-cancel-button", title: ui_core_1.UiCore.translate("dialog.cancel"), onClick: props.onCancel },
            React.createElement(ui_core_1.Icon, { iconSpec: "icon-remove" }))));
}
exports.PopupOkCancelButtons = PopupOkCancelButtons;
//# sourceMappingURL=PopupButton.js.map