/** @packageDocumentation
 * @module PropertyEditors
 */
import "./SliderEditor.scss";
import * as React from "react";
import { PropertyValue } from "@bentley/ui-abstract";
import { PropertyEditorProps, TypeEditor } from "./EditorContainer";
import { PropertyEditorBase } from "./PropertyEditorManager";
/** @internal */
interface SliderEditorState {
    value: number;
    isDisabled?: boolean;
    min: number;
    max: number;
    size?: number;
    step?: number;
    mode?: number;
    reversed?: boolean;
    showTooltip?: boolean;
    tooltipBelow?: boolean;
    formatTooltip?: (value: number) => string;
    showMinMax?: boolean;
    minIconSpec?: string;
    maxIconSpec?: string;
    showTicks?: boolean;
    showTickLabels?: boolean;
    formatTick?: (tick: number) => string;
    getTickCount?: () => number;
    getTickValues?: () => number[];
}
/** SliderEditor React component that is a property editor with numeric input & up/down buttons
 * @beta
 */
export declare class SliderEditor extends React.PureComponent<PropertyEditorProps, SliderEditorState> implements TypeEditor {
    private _isMounted;
    private _enterKey;
    private _divElement;
    /** @internal */
    readonly state: Readonly<SliderEditorState>;
    getPropertyValue(): Promise<PropertyValue | undefined>;
    get htmlElement(): HTMLElement | null;
    get hasFocus(): boolean;
    private _handleChange;
    /** @internal */
    componentDidMount(): void;
    /** @internal */
    componentWillUnmount(): void;
    /** @internal */
    componentDidUpdate(prevProps: PropertyEditorProps): void;
    private setStateFromProps;
    private _handleEnter;
    private _handleClose;
    private _handleOk;
    private _handleCancel;
    private _handleCommit;
    /** @internal */
    render(): React.ReactNode;
}
/** Slider Property Editor registered for the "number" type name and "slider" editor name.
 * It uses the [[SliderEditor]] React component.
 * @beta
 */
export declare class SliderPropertyEditor extends PropertyEditorBase {
    get reactNode(): React.ReactNode;
}
export {};
//# sourceMappingURL=SliderEditor.d.ts.map