"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SliderPropertyEditor = exports.SliderEditor = void 0;
require("./SliderEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
const PopupButton_1 = require("./PopupButton");
/** SliderEditor React component that is a property editor with numeric input & up/down buttons
 * @beta
 */
class SliderEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._enterKey = false;
        this._divElement = React.createRef();
        /** @internal */
        this.state = {
            value: 0,
            min: 0,
            max: 100,
        };
        this._handleChange = (values) => {
            const newValue = values.length === 1 ? values[0] : /* istanbul ignore next */ 0;
            // istanbul ignore else
            if (this._isMounted)
                this.setState({
                    value: newValue,
                });
        };
        this._handleEnter = async () => {
            this._enterKey = true;
            await this._handleCommit();
        };
        this._handleClose = async () => {
            if (this._enterKey) {
                this._enterKey = false;
            }
            else {
                // istanbul ignore else
                if (this.props.onCancel)
                    this.props.onCancel();
            }
        };
        this._handleOk = async (_event) => {
            await this._handleCommit();
        };
        this._handleCancel = (_event) => {
            // istanbul ignore else
            if (this.props.onCancel) {
                this.props.onCancel();
            }
        };
        this._handleCommit = async () => {
            // istanbul ignore else
            if (this.props.propertyRecord && this.props.onCommit) {
                const propertyValue = await this.getPropertyValue();
                // istanbul ignore else
                if (propertyValue !== undefined) {
                    this.props.onCommit({ propertyRecord: this.props.propertyRecord, newValue: propertyValue });
                }
            }
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.value,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._divElement.current;
    }
    get hasFocus() {
        let containsFocus = false;
        // istanbul ignore else
        if (this._divElement.current)
            containsFocus = this._divElement.current.contains(document.activeElement);
        return containsFocus;
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const record = this.props.propertyRecord;
        let initialValue = 0;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            initialValue = record.value.value;
        }
        let size;
        let min = 0;
        let max = 100;
        let step;
        let mode;
        let reversed;
        let showTooltip;
        let tooltipBelow;
        let formatTooltip;
        let showMinMax;
        let minIconSpec;
        let maxIconSpec;
        let showTicks;
        let showTickLabels;
        let formatTick;
        let getTickCount;
        let getTickValues;
        const isDisabled = record ? record.isDisabled : undefined;
        if (record && record.property && record.property.editor && record.property.editor.params) {
            const sliderParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.Slider);
            // istanbul ignore else
            if (sliderParams) {
                min = sliderParams.minimum;
                max = sliderParams.maximum;
                size = sliderParams.size;
                step = sliderParams.step;
                mode = sliderParams.mode;
                reversed = sliderParams.reversed;
                showTooltip = sliderParams.showTooltip;
                tooltipBelow = sliderParams.tooltipBelow;
                formatTooltip = sliderParams.formatTooltip;
                showMinMax = sliderParams.showMinMax;
                minIconSpec = sliderParams.minIconSpec;
                maxIconSpec = sliderParams.maxIconSpec;
                showTicks = sliderParams.showTicks;
                showTickLabels = sliderParams.showTickLabels;
                formatTick = sliderParams.formatTick;
                getTickCount = sliderParams.getTickCount;
                getTickValues = sliderParams.getTickValues;
            }
        }
        // istanbul ignore else
        if (this._isMounted)
            this.setState({
                value: initialValue, isDisabled,
                size,
                min, max, step, mode,
                reversed, showTooltip, tooltipBelow, formatTooltip, showMinMax, minIconSpec, maxIconSpec,
                showTicks, showTickLabels, formatTick, getTickCount, getTickValues,
            });
    }
    /** @internal */
    render() {
        const className = classnames_1.default("components-cell-editor", "components-slider-editor", this.props.className);
        const minSize = this.state.size ? this.state.size : 100;
        const style = Object.assign(Object.assign({}, this.props.style), { minWidth: `${minSize}px` });
        const minImage = this.state.minIconSpec ? React.createElement(ui_core_1.Icon, { iconSpec: this.state.minIconSpec }) : undefined;
        const maxImage = this.state.maxIconSpec ? React.createElement(ui_core_1.Icon, { iconSpec: this.state.maxIconSpec }) : undefined;
        const popupContent = (React.createElement(ui_core_1.Slider, { className: "components-slider-editor-slider", style: style, values: [this.state.value], min: this.state.min, max: this.state.max, step: this.state.step, disabled: this.state.isDisabled, reversed: this.state.reversed, showTooltip: this.state.showTooltip, tooltipBelow: this.state.tooltipBelow, formatTooltip: this.state.formatTooltip, showMinMax: this.state.showMinMax, minImage: minImage, maxImage: maxImage, showTicks: this.state.showTicks, showTickLabels: this.state.showTickLabels, formatTick: this.state.formatTick, getTickCount: this.state.getTickCount, getTickValues: this.state.getTickValues, onChange: this._handleChange, includeTicksInWidth: true }));
        return (React.createElement("div", { className: className, ref: this._divElement },
            React.createElement(PopupButton_1.PopupButton, { label: this.state.value, onClose: this._handleClose, onEnter: this._handleEnter, setFocus: this.props.setFocus, focusTarget: ".core-slider-handle" },
                React.createElement(PopupButton_1.PopupContent, null,
                    popupContent,
                    React.createElement(PopupButton_1.PopupOkCancelButtons, { onOk: this._handleOk, onCancel: this._handleCancel })))));
    }
}
exports.SliderEditor = SliderEditor;
/** Slider Property Editor registered for the "number" type name and "slider" editor name.
 * It uses the [[SliderEditor]] React component.
 * @beta
 */
class SliderPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    get reactNode() {
        return React.createElement(SliderEditor, null);
    }
}
exports.SliderPropertyEditor = SliderPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Number, SliderPropertyEditor, ui_abstract_1.StandardEditorNames.Slider);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Int, SliderPropertyEditor, ui_abstract_1.StandardEditorNames.Slider);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Float, SliderPropertyEditor, ui_abstract_1.StandardEditorNames.Slider);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Double, SliderPropertyEditor, ui_abstract_1.StandardEditorNames.Slider);
//# sourceMappingURL=SliderEditor.js.map