"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextEditor = void 0;
require("./TextEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const TypeConverterManager_1 = require("../converters/TypeConverterManager");
const UiComponents_1 = require("../UiComponents");
/** TextEditor React component that is a property editor with text input
 * @beta
 */
class TextEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._ariaLabel = UiComponents_1.UiComponents.translate("editor.text");
        this._inputElement = React.createRef();
        /** @internal */
        this.state = {
            inputValue: "",
            readonly: false,
        };
        this._updateInputValue = (e) => {
            // istanbul ignore else
            if (this._isMounted)
                this.setState({
                    inputValue: e.target.value,
                });
        };
    }
    async getPropertyValue() {
        var _a;
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = await TypeConverterManager_1.TypeConverterManager.getConverter(record.property.typename, (_a = record.property.converter) === null || _a === void 0 ? void 0 : _a.name).convertFromStringToPropertyValue(this.state.inputValue, record);
            propertyValue.displayValue = this.state.inputValue;
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._inputElement.current;
    }
    get hasFocus() {
        return document.activeElement === this._inputElement.current;
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        var _a;
        const record = this.props.propertyRecord;
        let initialValue = "";
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const value = record.value.value;
            initialValue = await TypeConverterManager_1.TypeConverterManager.getConverter(record.property.typename, (_a = record.property.converter) === null || _a === void 0 ? void 0 : _a.name).convertPropertyToString(record.property, value);
        }
        const readonly = record && undefined !== record.isReadonly ? record.isReadonly : false;
        let size;
        let maxLength;
        let iconSpec;
        const isDisabled = record ? record.isDisabled : undefined;
        if (record && record.property && record.property.editor && record.property.editor.params) {
            const editorSizeParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.InputEditorSize);
            if (editorSizeParams) {
                // istanbul ignore else
                if (editorSizeParams.size)
                    size = editorSizeParams.size;
                // istanbul ignore else
                if (editorSizeParams.maxLength)
                    maxLength = editorSizeParams.maxLength;
            }
            const iconParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.Icon);
            if (iconParams) {
                iconSpec = iconParams.definition.iconSpec;
            }
        }
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ inputValue: initialValue, readonly, size, maxLength, isDisabled, iconSpec });
    }
    /** @internal */
    render() {
        const className = classnames_1.default("components-cell-editor", "components-text-editor", this.props.className);
        const minSize = this.state.size ? this.state.size : 8;
        const minWidthStyle = {
            minWidth: `${minSize * 0.75}em`,
        };
        const inputProps = {
            type: "text",
            className,
            style: this.props.style ? this.props.style : minWidthStyle,
            readOnly: this.state.readonly,
            disabled: this.state.isDisabled,
            size: this.state.size,
            maxLength: this.state.maxLength,
            value: this.state.inputValue,
            onBlur: this.props.onBlur,
            onChange: this._updateInputValue,
            setFocus: this.props.setFocus && !this.state.isDisabled,
            ref: this._inputElement,
        };
        inputProps["aria-label"] = this._ariaLabel;
        let reactNode;
        if (this.state.iconSpec) {
            const icon = React.createElement(ui_core_1.Icon, { iconSpec: this.state.iconSpec });
            reactNode = (React.createElement(ui_core_1.IconInput, Object.assign({}, inputProps, { icon: icon, "data-testid": "components-text-editor" })));
        }
        else {
            reactNode = (React.createElement(ui_core_1.Input, Object.assign({}, inputProps, { "data-testid": "components-text-editor" })));
        }
        return reactNode;
    }
}
exports.TextEditor = TextEditor;
//# sourceMappingURL=TextEditor.js.map