/** @packageDocumentation
 * @module PropertyEditors
 */
import "./TextareaEditor.scss";
import * as React from "react";
import { PropertyValue } from "@bentley/ui-abstract";
import { PropertyEditorProps, TypeEditor } from "./EditorContainer";
import { PropertyEditorBase } from "./PropertyEditorManager";
/** @internal */
interface TextareaEditorState {
    inputValue: string;
    readonly: boolean;
    isDisabled?: boolean;
    size?: number;
    maxLength?: number;
    rows: number;
}
/** TextareaEditor React component that is a property editor with text input
 * @beta
 */
export declare class TextareaEditor extends React.PureComponent<PropertyEditorProps, TextareaEditorState> implements TypeEditor {
    private _isMounted;
    private _ariaLabel;
    private _divElement;
    /** @internal */
    readonly state: Readonly<TextareaEditorState>;
    getPropertyValue(): Promise<PropertyValue | undefined>;
    get htmlElement(): HTMLElement | null;
    get hasFocus(): boolean;
    private _updateTextareaValue;
    /** @internal */
    componentDidMount(): void;
    /** @internal */
    componentWillUnmount(): void;
    /** @internal */
    componentDidUpdate(prevProps: PropertyEditorProps): void;
    private setStateFromProps;
    private _handleOk;
    private _handleCancel;
    /** @internal */
    render(): React.ReactNode;
}
/** Textarea Property Editor registered for the "text" and "string" type names and "multi-line" editor name.
 * It uses the [[Textarea]] React component.
 * @beta
 */
export declare class TextareaPropertyEditor extends PropertyEditorBase {
    get containerHandlesBlur(): boolean;
    get containerHandlesEnter(): boolean;
    get containerHandlesTab(): boolean;
    get reactNode(): React.ReactNode;
}
export {};
//# sourceMappingURL=TextareaEditor.d.ts.map