"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextareaPropertyEditor = exports.TextareaEditor = void 0;
require("./TextareaEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const TypeConverterManager_1 = require("../converters/TypeConverterManager");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
const PopupButton_1 = require("./PopupButton");
const UiComponents_1 = require("../UiComponents");
const DEFAULT_ROWS = 3;
/** TextareaEditor React component that is a property editor with text input
 * @beta
 */
class TextareaEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._ariaLabel = UiComponents_1.UiComponents.translate("editor.textarea");
        this._divElement = React.createRef();
        /** @internal */
        this.state = {
            inputValue: "",
            readonly: false,
            rows: DEFAULT_ROWS,
        };
        this._updateTextareaValue = (e) => {
            // istanbul ignore else
            if (this._isMounted)
                this.setState({
                    inputValue: e.target.value,
                });
        };
        this._handleOk = async (_event) => {
            // istanbul ignore else
            if (this.props.propertyRecord && this.props.onCommit) {
                const propertyValue = await this.getPropertyValue();
                // istanbul ignore else
                if (propertyValue !== undefined) {
                    this.props.onCommit({ propertyRecord: this.props.propertyRecord, newValue: propertyValue });
                }
            }
        };
        this._handleCancel = (_event) => {
            // istanbul ignore else
            if (this.props.onCancel) {
                this.props.onCancel();
            }
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = await TypeConverterManager_1.TypeConverterManager.getConverter(record.property.typename).convertFromStringToPropertyValue(this.state.inputValue, record);
            propertyValue.displayValue = this.state.inputValue;
        }
        return propertyValue;
    }
    // istanbul ignore next
    get htmlElement() {
        return this._divElement.current;
    }
    // istanbul ignore next
    get hasFocus() {
        let containsFocus = false;
        // istanbul ignore else
        if (this._divElement.current)
            containsFocus = this._divElement.current.contains(document.activeElement);
        return containsFocus;
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const record = this.props.propertyRecord;
        let initialValue = "";
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const value = record.value.value;
            initialValue = await TypeConverterManager_1.TypeConverterManager.getConverter(record.property.typename).convertPropertyToString(record.property, value);
        }
        const readonly = record && undefined !== record.isReadonly ? record.isReadonly : false;
        let size;
        let maxLength;
        let rows = DEFAULT_ROWS;
        const isDisabled = record ? record.isDisabled : undefined;
        if (record && record.property && record.property.editor && record.property.editor.params) {
            const editorSizeParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.InputEditorSize);
            if (editorSizeParams) {
                // istanbul ignore else
                if (editorSizeParams.size)
                    size = editorSizeParams.size;
                // istanbul ignore else
                if (editorSizeParams.maxLength)
                    maxLength = editorSizeParams.maxLength;
            }
            const multilineParams = record.property.editor.params.find((param) => param.type === ui_abstract_1.PropertyEditorParamTypes.MultilineText);
            if (multilineParams) {
                rows = multilineParams.rows;
            }
        }
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ inputValue: initialValue, readonly, size, maxLength, isDisabled, rows });
    }
    // private _handleBlur = (_event: React.FocusEvent): void => {
    //   // eslint-disable-next-line no-console
    //   console.log("_handleBlur");
    // }
    /** @internal */
    render() {
        const className = classnames_1.default("components-cell-editor", "components-textarea-editor", this.props.className);
        const minSize = this.state.size ? this.state.size : 8;
        const style = Object.assign(Object.assign({}, this.props.style), { minWidth: `${minSize * 0.75}em` });
        const textareaProps = {
            className: "components-textarea-editor-textarea",
            style,
            rows: this.state.rows,
            readOnly: this.state.readonly,
            disabled: this.state.isDisabled,
            maxLength: this.state.maxLength,
            value: this.state.inputValue,
            // onBlur: this._handleBlur,
            onChange: this._updateTextareaValue,
            setFocus: this.props.setFocus && !this.state.isDisabled,
        };
        textareaProps["aria-label"] = this._ariaLabel;
        return (React.createElement("div", { className: className, ref: this._divElement },
            React.createElement(PopupButton_1.PopupButton, { label: this.state.inputValue, closeOnEnter: false, setFocus: this.props.setFocus, focusTarget: ".uicore-inputs-textarea" },
                React.createElement(PopupButton_1.PopupContent, null,
                    React.createElement(ui_core_1.Textarea, Object.assign({}, textareaProps, { "data-testid": "components-textarea-editor" })),
                    React.createElement(PopupButton_1.PopupOkCancelButtons, { onOk: this._handleOk, onCancel: this._handleCancel })))));
    }
}
exports.TextareaEditor = TextareaEditor;
/** Textarea Property Editor registered for the "text" and "string" type names and "multi-line" editor name.
 * It uses the [[Textarea]] React component.
 * @beta
 */
class TextareaPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    // istanbul ignore next
    get containerHandlesBlur() {
        return false;
    }
    // istanbul ignore next
    get containerHandlesEnter() {
        return false;
    }
    // istanbul ignore next
    get containerHandlesTab() {
        return false;
    }
    get reactNode() {
        return React.createElement(TextareaEditor, null);
    }
}
exports.TextareaPropertyEditor = TextareaPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Text, TextareaPropertyEditor, ui_abstract_1.StandardEditorNames.MultiLine);
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.String, TextareaPropertyEditor, ui_abstract_1.StandardEditorNames.MultiLine);
//# sourceMappingURL=TextareaEditor.js.map