/** @packageDocumentation
 * @module PropertyEditors
 */
import "./ThemedEnumEditor.scss";
import * as React from "react";
import { PropertyValue } from "@bentley/ui-abstract";
import { OptionType } from "@bentley/ui-core";
import { PropertyEditorProps, TypeEditor } from "./EditorContainer";
import { PropertyEditorBase } from "./PropertyEditorManager";
/** Properties for [[EnumEditor]] component
 * @beta
 */
export interface ThemedEnumEditorProps extends PropertyEditorProps {
    /** Allow searching in enum list */
    isSearchable?: boolean;
    /** The prompt string used when no enum member has been selected */
    placeholder?: string;
    /** The function to return an error message used when the search string can't be found in the list */
    noOptionsMessage?: (obj: {
        inputValue: string;
    }) => string | null;
}
/** @internal */
interface EnumEditorState {
    selectValue: string | number;
    valueIsNumber: boolean;
    options: OptionType[] | undefined;
}
/** EnumEditor React component that is a property editor with select input
 * @beta
 */
export declare class ThemedEnumEditor extends React.PureComponent<ThemedEnumEditorProps, EnumEditorState> implements TypeEditor {
    private _isMounted;
    private _divElement;
    /** @internal */
    readonly state: Readonly<EnumEditorState>;
    getPropertyValue(): Promise<PropertyValue | undefined>;
    get htmlElement(): HTMLElement | null;
    get hasFocus(): boolean;
    private _updateSelectValue;
    /** @internal */
    componentDidMount(): void;
    /** @internal */
    componentWillUnmount(): void;
    /** @internal */
    componentDidUpdate(prevProps: PropertyEditorProps): void;
    private setStateFromProps;
    /** @internal */
    render(): JSX.Element;
}
/** Enum Property Button Group Editor registered for the "enum" type name.
 * It uses the [[EnumEditor]] React component.
 * @beta
 */
export declare class ThemedEnumPropertyEditor extends PropertyEditorBase {
    get containerHandlesBlur(): boolean;
    get containerHandlesEscape(): boolean;
    get containerHandlesEnter(): boolean;
    get containerHandlesTab(): boolean;
    get reactNode(): React.ReactNode;
}
export {};
//# sourceMappingURL=ThemedEnumEditor.d.ts.map