"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThemedEnumPropertyEditor = exports.ThemedEnumEditor = void 0;
require("./ThemedEnumEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
/** EnumEditor React component that is a property editor with select input
 * @beta
 */
class ThemedEnumEditor extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._isMounted = false;
        this._divElement = React.createRef();
        /** @internal */
        this.state = {
            selectValue: "",
            valueIsNumber: false,
            options: undefined,
        };
        this._updateSelectValue = (value, action) => {
            // istanbul ignore else
            if (this._isMounted && action.action === "select-option" && value) {
                let selectValue;
                const selectedOption = value;
                // istanbul ignore next
                if (selectedOption === undefined) // no multi-select allowed
                    return;
                if (this.state.valueIsNumber)
                    selectValue = parseInt(selectedOption.value, 10);
                else
                    selectValue = selectedOption.value;
                this.setState({
                    selectValue,
                }, async () => {
                    // istanbul ignore else
                    if (this.props.propertyRecord && this.props.onCommit) {
                        const propertyValue = await this.getPropertyValue();
                        // istanbul ignore else
                        if (propertyValue) {
                            this.props.onCommit({ propertyRecord: this.props.propertyRecord, newValue: propertyValue });
                        }
                    }
                });
            }
        };
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.selectValue,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    // istanbul ignore next
    get htmlElement() {
        return this._divElement.current;
    }
    // istanbul ignore next
    get hasFocus() {
        let containsFocus = false;
        // istanbul ignore else
        if (this._divElement.current)
            containsFocus = this._divElement.current.contains(document.activeElement);
        return containsFocus;
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const { propertyRecord } = this.props;
        let initialValue = "";
        let valueIsNumber = false;
        let choices;
        if (propertyRecord && propertyRecord.property.enum) {
            // istanbul ignore else
            if (propertyRecord.property.enum.choices instanceof Promise) {
                choices = await propertyRecord.property.enum.choices;
            }
            else {
                choices = propertyRecord.property.enum.choices;
            }
        }
        let options = [];
        if (this.state.options === undefined) {
            if (choices) {
                choices.forEach((choice) => {
                    options.push({ value: choice.value.toString(), label: choice.label });
                });
            }
        }
        else {
            options = this.state.options;
        }
        // istanbul ignore else
        if (propertyRecord && propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            const primitiveValue = propertyRecord.value.value;
            if (typeof primitiveValue === "string") {
                initialValue = primitiveValue;
                valueIsNumber = false;
            }
            else {
                initialValue = primitiveValue;
                valueIsNumber = true;
            }
        }
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ selectValue: initialValue, valueIsNumber, options });
    }
    /** @internal */
    render() {
        const className = classnames_1.default("components-cell-editor", "components-enum-editor", this.props.className);
        const selectValue = this.state.selectValue ? this.state.selectValue.toString() : undefined;
        const options = this.state.options === undefined ? [] : this.state.options;
        const selectedOption = options.find((e) => e.value === selectValue);
        const { isSearchable, placeholder, noOptionsMessage } = this.props;
        // set min-width to show about 4 characters + down arrow
        const minWidthStyle = {
            minWidth: `${6 * 0.75}em`,
        };
        return (React.createElement(ui_core_1.ThemedSelect, { divRef: this._divElement, className: className, value: selectedOption, onChange: this._updateSelectValue, "data-testid": "components-select-editor", styles: this.props.style ? this.props.style : minWidthStyle, isSearchable: isSearchable, placeholder: placeholder, noOptionsMessage: noOptionsMessage, isMulti: false, 
            // eslint-disable-next-line jsx-a11y/no-autofocus
            autoFocus: this.props.setFocus, options: options }));
    }
}
exports.ThemedEnumEditor = ThemedEnumEditor;
/** Enum Property Button Group Editor registered for the "enum" type name.
 * It uses the [[EnumEditor]] React component.
 * @beta
 */
class ThemedEnumPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    // istanbul ignore next
    get containerHandlesBlur() {
        return false;
    }
    // istanbul ignore next
    get containerHandlesEscape() {
        return false;
    }
    // istanbul ignore next
    get containerHandlesEnter() {
        return false;
    }
    // istanbul ignore next
    get containerHandlesTab() {
        return false;
    }
    // istanbul ignore next
    get reactNode() {
        return React.createElement(ThemedEnumEditor, null);
    }
}
exports.ThemedEnumPropertyEditor = ThemedEnumPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Enum, ThemedEnumPropertyEditor, ui_abstract_1.StandardEditorNames.ThemedEnum);
//# sourceMappingURL=ThemedEnumEditor.js.map