"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyEditors
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WeightPropertyEditor = exports.WeightEditor = void 0;
require("./WeightEditor.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const WeightPickerButton_1 = require("../lineweight/WeightPickerButton");
const PropertyEditorManager_1 = require("./PropertyEditorManager");
/** WeightEditor React component that is a property editor for picking a weight using a [[WeightPickerButton]] component
 * @beta
 */
class WeightEditor extends React.PureComponent {
    constructor(props) {
        super(props);
        this._control = null;
        this._isMounted = false;
        this._availableWeights = [];
        this._divElement = React.createRef();
        /** @internal */
        this.state = {
            weightValue: 0,
            readonly: false,
        };
        this._onLineWeightPick = (weight) => {
            const propertyRecord = this.props.propertyRecord;
            this.setState({
                weightValue: weight,
            }, async () => {
                // istanbul ignore else
                if (propertyRecord && this.props.onCommit) {
                    const propertyValue = await this.getPropertyValue();
                    // istanbul ignore else
                    if (propertyValue !== undefined) {
                        this.props.onCommit({ propertyRecord, newValue: propertyValue });
                    }
                }
            });
        };
        // TODO: add support for following if we need to specify set of weights to display
        //  const record = this.props.propertyRecord;
        //  if (record && record.property && record.property.editor && record.property.editor.params) {
        //    const weightParams = record.property.editor.params.find((param: PropertyEditorParams) => param.type === PropertyEditorParamTypes.ColorData) as WeightEditorParams;
        //    // istanbul ignore else
        //    if (weightParams) {
        //      weightParams.weightValues.forEach((weight: number) => {
        //        this._availableWeights.push(weight);
        //      });
        //    }
        //   }
    }
    async getPropertyValue() {
        const record = this.props.propertyRecord;
        let propertyValue;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            propertyValue = {
                valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
                value: this.state.weightValue,
                displayValue: "",
            };
        }
        return propertyValue;
    }
    get htmlElement() {
        return this._divElement.current;
    }
    get hasFocus() {
        let containsFocus = false;
        // istanbul ignore else
        if (this._divElement.current)
            containsFocus = this._divElement.current.contains(document.activeElement);
        return containsFocus;
    }
    setFocus() {
        // istanbul ignore else
        if (this._control && !this.state.isDisabled) {
            this._control.setFocus();
        }
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.propertyRecord !== prevProps.propertyRecord) {
            this.setStateFromProps(); // eslint-disable-line @typescript-eslint/no-floating-promises
        }
    }
    async setStateFromProps() {
        const record = this.props.propertyRecord;
        let initialValue = 0;
        // istanbul ignore else
        if (record && record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive) {
            initialValue = record.value.value;
        }
        const readonly = record && undefined !== record.isReadonly ? record.isReadonly : false;
        const isDisabled = record ? record.isDisabled : undefined;
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ weightValue: initialValue, readonly, isDisabled }, () => {
                if (this.props.setFocus) {
                    this.setFocus();
                }
            });
    }
    /** @internal */
    render() {
        return (React.createElement("div", { className: classnames_1.default("components-weight-editor", this.props.className), style: this.props.style, ref: this._divElement },
            React.createElement(WeightPickerButton_1.WeightPickerButton, { ref: (control) => this._control = control, activeWeight: this.state.weightValue, weights: this._availableWeights.length > 0 ? /* istanbul ignore next */ this._availableWeights : undefined, disabled: this.state.isDisabled ? true : false, readonly: this.state.readonly, onLineWeightPick: this._onLineWeightPick, "data-testid": "components-weight-editor" })));
    }
}
exports.WeightEditor = WeightEditor;
/** Weight Property Editor registered for the "number" type name and "weight-picker" editor name.
 * It uses the [[WeightEditor]] React component.
 * @beta
 */
class WeightPropertyEditor extends PropertyEditorManager_1.PropertyEditorBase {
    // istanbul ignore next
    get reactNode() {
        return React.createElement(WeightEditor, null);
    }
}
exports.WeightPropertyEditor = WeightPropertyEditor;
PropertyEditorManager_1.PropertyEditorManager.registerEditor(ui_abstract_1.StandardTypeNames.Number, WeightPropertyEditor, ui_abstract_1.StandardEditorNames.WeightPicker);
//# sourceMappingURL=WeightEditor.js.map