"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Filtering
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilteringInput = exports.FilteringInputStatus = void 0;
require("./FilteringInput.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ts_key_enum_1 = require("ts-key-enum");
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../UiComponents");
const ResultSelector_1 = require("./ResultSelector");
/**
 * Enumeration of possible component contexts
 * @beta
 */
var FilteringInputStatus;
(function (FilteringInputStatus) {
    /** Component is ready to filter */
    FilteringInputStatus[FilteringInputStatus["ReadyToFilter"] = 0] = "ReadyToFilter";
    /** Component's parent is currently filtering */
    FilteringInputStatus[FilteringInputStatus["FilteringInProgress"] = 1] = "FilteringInProgress";
    /** Component's parent has finished filtering */
    FilteringInputStatus[FilteringInputStatus["FilteringFinished"] = 2] = "FilteringFinished";
})(FilteringInputStatus = exports.FilteringInputStatus || (exports.FilteringInputStatus = {}));
/** A helper component for filtering trees and stepping through results
 * @public
 */
class FilteringInput extends React.PureComponent {
    constructor(props) {
        super(props);
        this._inputElement = React.createRef();
        this._searchLabel = ui_core_1.UiCore.translate("general.search");
        this._cancelLabel = ui_core_1.UiCore.translate("dialog.cancel");
        this._clearLabel = ui_core_1.UiCore.translate("general.search");
        this._onSearchButtonClick = () => {
            if (!this.state.searchText) {
                // Empty search string is the same as clearing the search.
                this.setState({ searchStarted: false, searchText: "" });
                this.props.onFilterClear();
                return;
            }
            this.props.onFilterStart(this.state.searchText);
            this.setState({ searchStarted: true });
        };
        this._onCancelButtonClick = () => {
            this.setState({ searchStarted: false, searchText: "" });
            this.props.onFilterCancel();
            this.focus();
        };
        this._onClearButtonClick = () => {
            this.setState({ searchStarted: false, searchText: "" });
            this.props.onFilterClear();
            this.focus();
        };
        this._onFilterKeyDown = (e) => {
            if (e.key !== ts_key_enum_1.Key.Enter)
                return;
            if (!this.state.searchText)
                return;
            this.props.onFilterStart(this.state.searchText);
            this.setState({ searchStarted: true });
            e.stopPropagation();
        };
        this._onInputChanged = (e) => {
            if (this.state.searchStarted) {
                this.props.onFilterCancel();
            }
            this.setState({ searchText: e.target.value, searchStarted: false });
        };
        this.state = {
            searchText: "",
            searchStarted: false,
            resultSelectorKey: 0,
            // eslint-disable-next-line deprecation/deprecation
            prevFilteringInProgress: FilteringInput.isDeprecatedProps(props) ? props.filteringInProgress : undefined,
        };
    }
    focus() {
        // istanbul ignore next
        if (this._inputElement.current)
            this._inputElement.current.focus();
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (FilteringInput.isDeprecatedProps(prevProps) && FilteringInput.isDeprecatedProps(this.props)) {
            // eslint-disable-next-line deprecation/deprecation
            if (prevProps.filteringInProgress !== this.props.filteringInProgress) {
                this.setState((_state, props) => (FilteringInput.isDeprecatedProps(props) ?
                    { prevFilteringInProgress: props.filteringInProgress } : // eslint-disable-line deprecation/deprecation
                    /* istanbul ignore next */ { prevFilteringInProgress: undefined }));
            }
            return;
        }
        if (this.props.resultSelectorProps !== prevProps.resultSelectorProps) {
            this.setState((state) => ({ resultSelectorKey: state.resultSelectorKey + 1 }));
        }
    }
    static getDerivedStateFromProps(nextProps, prevState) {
        // eslint-disable-next-line deprecation/deprecation
        if (FilteringInput.isDeprecatedProps(nextProps) && !nextProps.filteringInProgress && prevState.prevFilteringInProgress) {
            return { searchStarted: true };
        }
        return null;
    }
    // eslint-disable-next-line deprecation/deprecation
    static isDeprecatedProps(props) {
        // eslint-disable-next-line deprecation/deprecation
        if (props.filteringInProgress !== undefined) {
            return true;
        }
        return false;
    }
    getStatus(props) {
        if (FilteringInput.isDeprecatedProps(props)) {
            // eslint-disable-next-line deprecation/deprecation
            return (props.filteringInProgress ? FilteringInputStatus.FilteringInProgress :
                (this.state.searchStarted ? FilteringInputStatus.FilteringFinished : FilteringInputStatus.ReadyToFilter));
        }
        return props.status;
    }
    render() {
        const status = this.getStatus(this.props);
        return (
        // TODO: What is filtering-input-preload-images?
        React.createElement("div", { className: classnames_1.default("components-filtering-input", "filtering-input-preload-images", this.props.className), style: this.props.style, onKeyDown: this._onFilterKeyDown, role: "presentation" },
            React.createElement("span", { className: "components-filtering-input-input" },
                React.createElement("input", { type: "text", placeholder: UiComponents_1.UiComponents.translate("filteringInput:placeholder"), 
                    // eslint-disable-next-line jsx-a11y/no-autofocus
                    autoFocus: this.props.autoFocus, onKeyDown: this._onFilterKeyDown, value: this.state.searchText, onChange: this._onInputChanged, "aria-label": ui_core_1.UiCore.translate("general.search") }),
                React.createElement("span", { className: "components-filtering-input-input-components" },
                    status === FilteringInputStatus.FilteringFinished && this.props.resultSelectorProps ?
                        React.createElement(ResultSelector_1.ResultSelector, Object.assign({ key: this.state.resultSelectorKey }, this.props.resultSelectorProps)) : undefined,
                    status === FilteringInputStatus.ReadyToFilter ?
                        // eslint-disable-next-line jsx-a11y/click-events-have-key-events
                        React.createElement("span", { className: "icon icon-search", onClick: this._onSearchButtonClick, role: "button", tabIndex: -1, title: this._searchLabel }) : undefined,
                    status === FilteringInputStatus.FilteringInProgress ?
                        // eslint-disable-next-line jsx-a11y/click-events-have-key-events
                        React.createElement("span", { className: "icon icon-close", onClick: this._onCancelButtonClick, role: "button", tabIndex: -1, title: this._cancelLabel }) : undefined,
                    status === FilteringInputStatus.FilteringFinished ?
                        // eslint-disable-next-line jsx-a11y/click-events-have-key-events
                        React.createElement("span", { className: "components-filtering-input-clear icon icon-close", onClick: this._onClearButtonClick, role: "button", tabIndex: -1, title: this._clearLabel }) : undefined))));
    }
}
exports.FilteringInput = FilteringInput;
//# sourceMappingURL=FilteringInput.js.map