"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Filtering
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResultSelector = void 0;
require("./ResultSelector.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const UiComponents_1 = require("../UiComponents");
/** Component for stepping through results/entries
 * @public
 */
class ResultSelector extends React.PureComponent {
    /** @internal */
    constructor(props) {
        super(props);
        this._ofLabel = UiComponents_1.UiComponents.translate("general.of");
        this._onClickPrevious = () => {
            if (this.state.selectedResultInEditMode) {
                this._onSelectedResultConfirmed();
                return;
            }
            if (this.state.selectedResultId > 1) {
                this.props.onSelectedChanged(this.state.selectedResultId - 1);
                this.setState((state) => ({ selectedResultId: state.selectedResultId - 1 }));
            }
        };
        this._onClickNext = () => {
            if (this.state.selectedResultInEditMode) {
                this._onSelectedResultConfirmed();
                return;
            }
            if (this.state.selectedResultId < this.props.resultCount) {
                this.props.onSelectedChanged(this.state.selectedResultId + 1);
                this.setState((state) => ({ selectedResultId: state.selectedResultId + 1 }));
            }
        };
        this._onSelectedResultChanged = (event) => {
            if (event.target.value.length <= this._maxSelectedResultInputLength)
                this.setState({ selectedResultEdit: event.target.value });
        };
        this._onSelectedResultConfirmed = () => {
            let selectedId = +this.state.selectedResultEdit;
            if (selectedId > this.props.resultCount)
                selectedId = this.props.resultCount;
            else if (selectedId < 1)
                selectedId = 1;
            this.setState({ selectedResultInEditMode: false, selectedResultId: selectedId });
            this.props.onSelectedChanged(selectedId);
        };
        this._onSelectedResultClick = () => {
            this.setState((state) => ({
                selectedResultInEditMode: true,
                selectedResultEdit: state.selectedResultId.toString(),
            }));
        };
        this._onSelectedResultKeyDown = (event) => {
            if (event.key === ui_abstract_1.SpecialKey.Enter)
                this._onSelectedResultConfirmed();
        };
        this.state = {
            selectedResultId: props.resultCount ? 1 : 0,
            selectedResultEdit: "",
            selectedResultInEditMode: false,
        };
    }
    get _maxSelectedResultInputLength() {
        return this.props.resultCount.toString().length;
    }
    /** @internal */
    componentDidMount() {
        this.props.onSelectedChanged(this.props.resultCount ? 1 : 0);
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (this.props.resultCount !== prevProps.resultCount) {
            this.props.onSelectedChanged(this.props.resultCount ? 1 : 0);
        }
    }
    /** @internal */
    render() {
        return (React.createElement("span", { className: classnames_1.default("components-result-selector", this.props.className), style: this.props.style },
            React.createElement("button", { className: classnames_1.default("components-result-selector-button", "icon", "icon-chevron-left"), onClick: this._onClickPrevious, disabled: this.props.resultCount <= 0 }),
            React.createElement("span", { style: { pointerEvents: this.props.resultCount ? "auto" : "none" }, className: "components-result-selector-current-result", onClick: this._onSelectedResultClick, role: "presentation" },
                this.state.selectedResultInEditMode ?
                    React.createElement("input", { type: "number", style: { width: `${this.state.selectedResultEdit.length * 0.60 + 1}em` }, value: this.state.selectedResultEdit, onChange: this._onSelectedResultChanged, onBlur: this._onSelectedResultConfirmed, onKeyDown: this._onSelectedResultKeyDown }) :
                    this.state.selectedResultId,
                React.createElement("span", { style: { marginLeft: "5px", marginRight: "5px" } }, this._ofLabel),
                React.createElement("span", null, this.props.resultCount)),
            React.createElement("button", { className: "components-result-selector-button icon icon-chevron-right", onClick: this._onClickNext, disabled: this.props.resultCount <= 0 })));
    }
}
exports.ResultSelector = ResultSelector;
//# sourceMappingURL=ResultSelector.js.map