"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module IconPicker
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IconPickerButton = void 0;
require("./IconPickerButton.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
/** IconItem Functional component
 * @alpha
 */
// istanbul ignore next
class IconItem extends React.PureComponent {
    /** @internal */
    constructor(props) {
        super(props);
    }
    render() {
        const _a = this.props, { 
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        onClick, icon } = _a, // do not pass on item specific props
        otherProps = __rest(_a, ["onClick", "icon"]);
        const handleClick = (_e) => {
            if (onClick)
                onClick();
        };
        const classes = classnames_1.default("components-icon-swatch", this.props.className);
        return (React.createElement("button", Object.assign({}, otherProps, { className: classes, style: this.props.style, onClick: handleClick }),
            React.createElement(ui_core_1.SvgSprite, { src: this.props.icon })));
    }
}
/** IconPickerButton component
 * @alpha
 */
// istanbul ignore next
class IconPickerButton extends React.PureComponent {
    /** @internal */
    constructor(props) {
        super(props);
        this._target = React.createRef();
        this._togglePopup = () => {
            if (this.props.readonly)
                return;
            this.setState((prevState) => ({ showPopup: !prevState.showPopup }));
        };
        this._closePopup = () => {
            this.setState({ showPopup: false });
        };
        this._handleIconPicked = (icon) => {
            this.setState({ showPopup: false, icon }, () => {
                // istanbul ignore else
                if (this.props.onIconChange)
                    this.props.onIconChange(icon);
            });
        };
        this.state = { showPopup: false, icon: this.props.icon };
    }
    renderPopup(title) {
        const containerStyle = { gridTemplateColumns: `repeat(${this.props.numColumns}, 1fr)` };
        return (React.createElement("div", { className: "components-iconpicker-popup-container" },
            title && React.createElement("h4", null, title),
            React.createElement("div", { "data-testid": "components-iconpicker-popup-icons", className: "components-iconpicker-popup-icons", style: containerStyle }, this.props.icons.map((icon, index) => React.createElement(IconItem, { key: index, icon: icon, onClick: this._handleIconPicked.bind(this, icon) })))));
    }
    /** @internal */
    render() {
        const buttonStyle = Object.assign({}, this.props.style);
        const buttonClassNames = classnames_1.default("components-iconpicker-button", this.props.readonly && "readonly", this.props.className);
        return (React.createElement(React.Fragment, null,
            React.createElement("button", { "data-testid": "components-iconpicker-button", onClick: this._togglePopup, className: buttonClassNames, style: buttonStyle, disabled: this.props.disabled, ref: this._target },
                React.createElement(ui_core_1.SvgSprite, { className: "iconpicker-button-sprite", src: this.state.icon }),
                React.createElement("span", { className: "icon icon-chevron-down" })),
            React.createElement(ui_core_1.Popup, { className: "components-iconpicker-popup", isOpen: this.state.showPopup, position: ui_abstract_1.RelativePosition.BottomLeft, onClose: this._closePopup, target: this._target.current }, this.renderPopup(this.props.dropDownTitle))));
    }
}
exports.IconPickerButton = IconPickerButton;
/** @internal */
IconPickerButton.defaultProps = {
    numColumns: 4,
};
//# sourceMappingURL=IconPickerButton.js.map