/** @packageDocumentation
 * @module Inputs
 */
import * as React from "react";
import { CommonProps } from "@bentley/ui-core";
import { ParseResults } from "@bentley/ui-abstract";
import "./ParsedInput.scss";
/** Props for [[ParsedInput]] control
 * @beta
 */
export interface ParsedInputProps extends CommonProps {
    /** InitialValue which is used to restore input field if ESC is pressed */
    initialValue: number;
    /** Function used to format the value */
    formatValue: (value: number) => string;
    /** Function used to parse user input into a value */
    parseString: (stringValue: string) => ParseResults;
    /** Function to call when value is changed */
    onChange?: (newValue: number) => void;
    /** if readonly then only the formatValue function is used. */
    readonly?: boolean;
    /** Provides ability to return reference to HTMLInputElement */
    ref?: React.Ref<HTMLInputElement>;
}
/** Generic Input component that requires formatting and parsing functions to be passed in as props.
 * @beta
 */
export declare const ParsedInput: (props: ParsedInputProps) => JSX.Element | null;
//# sourceMappingURL=ParsedInput.d.ts.map