"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Inputs
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParsedInput = void 0;
const React = __importStar(require("react"));
const classnames_1 = __importDefault(require("classnames"));
const ui_core_1 = require("@bentley/ui-core");
const ui_abstract_1 = require("@bentley/ui-abstract");
require("./ParsedInput.scss");
const ForwardRefParsedInput = React.forwardRef(function ForwardRefParsedInput({ initialValue, formatValue, parseString, readonly, className, style, onChange }, ref) {
    const currentValueRef = React.useRef(initialValue);
    const isMountedRef = React.useRef(false);
    const lastFormattedValueRef = React.useRef(formatValue(initialValue));
    const [formattedValue, setFormattedValue] = React.useState(() => lastFormattedValueRef.current);
    const [hasBadInput, setHasBadInput] = React.useState(false);
    React.useEffect(() => {
        isMountedRef.current = true;
        return () => {
            isMountedRef.current = false;
        };
    }, []);
    // See if new initialValue props have changed since component mounted
    React.useEffect(() => {
        currentValueRef.current = initialValue;
        const currentFormattedValue = formatValue(currentValueRef.current);
        if (currentFormattedValue !== lastFormattedValueRef.current) {
            lastFormattedValueRef.current = currentFormattedValue;
            setFormattedValue(lastFormattedValueRef.current);
            setHasBadInput(false);
        }
    }, [formatValue, initialValue]);
    const handleChange = React.useCallback((event) => {
        setFormattedValue(event.currentTarget.value);
    }, []);
    const updateValueFromString = React.useCallback((strVal) => {
        if (lastFormattedValueRef.current === strVal)
            return;
        const parseResults = (parseString(strVal));
        // istanbul ignore else
        if (!parseResults.parseError) {
            // istanbul ignore else
            if (undefined !== parseResults.value && typeof parseResults.value === "number") {
                const currentValue = parseResults.value;
                // istanbul ignore else
                if (currentValue !== currentValueRef.current) {
                    currentValueRef.current = currentValue;
                    onChange && onChange(currentValueRef.current);
                }
                // istanbul ignore else
                if (isMountedRef.current) {
                    lastFormattedValueRef.current = formatValue(currentValue);
                    setFormattedValue(lastFormattedValueRef.current);
                    setHasBadInput(false);
                }
            }
        }
        else {
            setHasBadInput(true);
        }
    }, [formatValue, onChange, parseString]);
    const handleBlur = React.useCallback((event) => {
        updateValueFromString(event.target.value);
    }, [updateValueFromString]);
    const handleKeyDown = React.useCallback((event) => {
        // istanbul ignore else
        if (event.key === ui_abstract_1.SpecialKey.Enter) {
            updateValueFromString(event.currentTarget.value);
            event.preventDefault();
        }
        if (event.key === ui_abstract_1.SpecialKey.Escape) {
            setFormattedValue(formatValue(currentValueRef.current));
            setHasBadInput(false);
            event.preventDefault();
        }
    }, [formatValue, updateValueFromString]);
    const classNames = classnames_1.default(className, "components-parsed-input", hasBadInput && "components-parsed-input-has-error");
    return React.createElement(ui_core_1.Input, { "data-testid": "components-parsed-input", ref: ref, style: style, className: classNames, onKeyDown: handleKeyDown, onBlur: handleBlur, onChange: handleChange, value: formattedValue, disabled: readonly });
});
/** Generic Input component that requires formatting and parsing functions to be passed in as props.
 * @beta
 */
exports.ParsedInput = ForwardRefParsedInput;
//# sourceMappingURL=ParsedInput.js.map