/** @packageDocumentation
 * @module Inputs
 */
import * as React from "react";
import { QuantityTypeArg } from "@bentley/imodeljs-frontend";
import { CommonProps } from "@bentley/ui-core";
/** Props for [[QuantityInput]] control
 * @beta
 */
export interface QuantityProps extends CommonProps {
    /** Initial magnitude in 'persistence' units. See `getPersistenceUnitByQuantityType` in [QuantityFormatter]($imodeljs-frontend) */
    initialValue: number;
    /** Type of quantity being input. */
    quantityType: QuantityTypeArg;
    /** Function to call in the quantity value is changed. The value returned will be in 'persistence' units. */
    onQuantityChange: (newQuantityValue: number) => void;
    /** Set to `true` if value is for display only */
    readonly?: boolean;
    /** Provides ability to return reference to HTMLInputElement */
    ref?: React.Ref<HTMLInputElement>;
}
/** Input control that allows users to input a quantity and show the formatted string that represents the value.
 * @beta
 */
export declare function QuantityInput({ initialValue, quantityType, readonly, className, style, onQuantityChange, ref }: QuantityProps): JSX.Element;
//# sourceMappingURL=QuantityInput.d.ts.map