"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Inputs
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QuantityInput = void 0;
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const imodeljs_quantity_1 = require("@bentley/imodeljs-quantity");
const ParsedInput_1 = require("./ParsedInput");
const UiComponents_1 = require("../UiComponents");
/** Input control that allows users to input a quantity and show the formatted string that represents the value.
 * @beta
 */
function QuantityInput({ initialValue, quantityType, readonly, className, style, onQuantityChange, ref }) {
    const [formatterSpec, setFormatterSpec] = React.useState(() => imodeljs_frontend_1.IModelApp.quantityFormatter.findFormatterSpecByQuantityType(quantityType));
    const [parserSpec, setParserSpec] = React.useState(() => imodeljs_frontend_1.IModelApp.quantityFormatter.findParserSpecByQuantityType(quantityType));
    const formatValue = React.useCallback((value) => {
        // istanbul ignore else
        if (formatterSpec) {
            return formatterSpec.applyFormatting(value);
        }
        // istanbul ignore next
        return value.toFixed(2);
    }, [formatterSpec]);
    const parseString = React.useCallback((userInput) => {
        // istanbul ignore else
        if (parserSpec) {
            const parseResult = imodeljs_frontend_1.IModelApp.quantityFormatter.parseToQuantityValue(userInput, parserSpec);
            // istanbul ignore else
            if (imodeljs_quantity_1.Parser.isParsedQuantity(parseResult)) {
                return { value: parseResult.value };
            }
            else {
                const statusId = imodeljs_quantity_1.Parser.isParseError(parseResult) ? parseResult.error.toString() : "Unknown";
                return { parseError: `${UiComponents_1.UiComponents.translate("QuantityInput.NoParserDefined")}${statusId}` };
            }
        }
        // istanbul ignore next
        return { parseError: UiComponents_1.UiComponents.translate("QuantityInput.NoParserDefined") };
    }, [parserSpec]);
    const classNames = classnames_1.default(className, "components-quantity-input");
    React.useEffect(() => {
        const handleUnitSystemChanged = (() => {
            setFormatterSpec(imodeljs_frontend_1.IModelApp.quantityFormatter.findFormatterSpecByQuantityType(quantityType));
            setParserSpec(imodeljs_frontend_1.IModelApp.quantityFormatter.findParserSpecByQuantityType(quantityType));
        });
        imodeljs_frontend_1.IModelApp.quantityFormatter.onActiveFormattingUnitSystemChanged.addListener(handleUnitSystemChanged);
        return () => {
            imodeljs_frontend_1.IModelApp.quantityFormatter.onActiveFormattingUnitSystemChanged.removeListener(handleUnitSystemChanged);
        };
    }, [quantityType]);
    React.useEffect(() => {
        const handleUnitSystemChanged = ((args) => {
            const quantityKey = imodeljs_frontend_1.IModelApp.quantityFormatter.getQuantityTypeKey(quantityType);
            // istanbul ignore else
            if (args.quantityType === quantityKey) {
                setFormatterSpec(imodeljs_frontend_1.IModelApp.quantityFormatter.findFormatterSpecByQuantityType(quantityType));
                setParserSpec(imodeljs_frontend_1.IModelApp.quantityFormatter.findParserSpecByQuantityType(quantityType));
            }
        });
        imodeljs_frontend_1.IModelApp.quantityFormatter.onQuantityFormatsChanged.addListener(handleUnitSystemChanged);
        return () => {
            imodeljs_frontend_1.IModelApp.quantityFormatter.onQuantityFormatsChanged.removeListener(handleUnitSystemChanged);
        };
    }, [quantityType]);
    return React.createElement(ParsedInput_1.ParsedInput, { "data-testid": "components-quantity-input", ref: ref, style: style, className: classNames, onChange: onQuantityChange, initialValue: initialValue, readonly: readonly, formatValue: formatValue, parseString: parseString });
}
exports.QuantityInput = QuantityInput;
//# sourceMappingURL=QuantityInput.js.map