"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module LineWeight
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WeightPickerButton = void 0;
require("./WeightPickerButton.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const Swatch_1 = require("./Swatch");
/** WeightPickerButton component
 * @beta
 */
class WeightPickerButton extends React.PureComponent {
    /** @internal */
    constructor(props) {
        super(props);
        this._target = React.createRef();
        this._weightsContainer = null;
        this._focusTarget = React.createRef(); // weight button that should receive focus after popup is open
        this._togglePopup = () => {
            if (this.props.readonly)
                return;
            this.setState((prevState) => ({ showPopup: !prevState.showPopup }));
        };
        this._onPopupOpened = () => {
        };
        this._closePopup = () => {
            this.setState((_prevState) => ({ showPopup: false }));
        };
        this._handleWeightPicked = (weight) => {
            this._closePopup();
            this.props.onLineWeightPick && this.props.onLineWeightPick(weight);
        };
        this._handleKeyDown = (event) => {
            if (event.key === ui_abstract_1.SpecialKey.Enter) {
                event.preventDefault();
                event.stopPropagation();
                const weightButton = document.activeElement;
                // istanbul ignore else
                if (weightButton.tagName === "BUTTON") {
                    try {
                        const values = weightButton.id.split("-");
                        // istanbul ignore else
                        if (values.length) {
                            const weight = parseInt(values[values.length - 1], 10);
                            // istanbul ignore else
                            if (!isNaN(weight)) {
                                // istanbul ignore else
                                if (this.props.onLineWeightPick)
                                    this.props.onLineWeightPick(weight);
                            }
                        }
                    }
                    catch (_a) { }
                }
                this._closePopup();
            }
            else {
                switch (event.key) {
                    case ui_abstract_1.SpecialKey.ArrowDown:
                        this.moveFocusInPopup(false, event);
                        break;
                    case ui_abstract_1.SpecialKey.ArrowUp:
                        this.moveFocusInPopup(true, event);
                        break;
                }
            }
        };
        this._setWeightContainer = (el) => {
            this._weightsContainer = el;
        };
        this.state = { showPopup: false, targetElement: null };
    }
    setFocus() {
        // istanbul ignore next
        this._focusTarget.current && this._focusTarget.current.focus();
    }
    componentDidMount() {
        // eslint-disable-next-line no-console
        // console.log(`WeightPickerButton.componentDidMount focusRef=${this._focusTarget && this._focusTarget.current ? "set" : "unset"}`);
        this.setState({ targetElement: this._target.current });
    }
    buildIdForWeight(weight) {
        return `ui-core-lineweight-${weight}`;
    }
    moveFocusInPopup(moveUp, event) {
        const activeElement = document.activeElement;
        // istanbul ignore else
        if (this._weightsContainer && activeElement && activeElement.tagName === "BUTTON") {
            const values = activeElement.id.split("-");
            // istanbul ignore else
            if (values.length === 4 && values[2] === "lineweight") {
                const weight = parseInt(values[3], 10);
                const foundIndex = this.props.weights.findIndex((val) => val === weight);
                // istanbul ignore next
                if (foundIndex < 0)
                    return;
                const nextWeight = moveUp ? (foundIndex <= 0 ? this.props.weights[this.props.weights.length - 1] : this.props.weights[foundIndex - 1]) :
                    (foundIndex < this.props.weights.length - 1 ? this.props.weights[foundIndex + 1] : this.props.weights[0]);
                const focusLocation = this._weightsContainer.querySelector(`#${this.buildIdForWeight(nextWeight)}`);
                // istanbul ignore else
                if (focusLocation) {
                    focusLocation.focus();
                    event.preventDefault();
                    event.stopPropagation();
                }
            }
        }
    }
    renderPopup(title) {
        return (React.createElement("div", { className: "components-weightpicker-popup-container" },
            title && React.createElement("h4", null, title),
            React.createElement("ul", { "data-testid": "components-weightpicker-popup-lines", className: "components-weightpicker-popup-lines", onKeyDown: this._handleKeyDown, ref: this._setWeightContainer }, this.props.weights.map((weight, index) => {
                const classNames = classnames_1.default("components-weightpicker-swatch", weight === this.props.activeWeight && "active");
                return (React.createElement(Swatch_1.LineWeightSwatch, { className: classNames, key: index, colorDef: this.props.colorDef, id: this.buildIdForWeight(weight), hideLabel: this.props.hideLabel, onClick: this._handleWeightPicked.bind(this, weight), weight: weight }));
            }))));
    }
    /** @internal */
    render() {
        const buttonClassNames = classnames_1.default("components-weightpicker-button", this.props.className);
        return (React.createElement(React.Fragment, null,
            React.createElement("div", { ref: this._target, style: this.props.style },
                React.createElement(Swatch_1.LineWeightSwatch, { "data-testid": "components-weightpicker-button", className: buttonClassNames, weight: this.props.activeWeight, colorDef: this.props.colorDef, readonly: this.props.readonly, disabled: this.props.disabled, hideLabel: this.props.hideLabel, "aria-haspopup": "listbox", "aria-expanded": this.state.showPopup, onClick: this._togglePopup })),
            React.createElement(ui_core_1.ElementResizeObserver, { watchedElement: this.state.targetElement, render: ({ width }) => (React.createElement(ui_core_1.Popup, { className: "components-weightpicker-popup", style: { width: `${width}px` }, isOpen: this.state.showPopup, position: ui_abstract_1.RelativePosition.Bottom, offset: 0, showShadow: false, onClose: this._closePopup, onOpen: this._onPopupOpened, focusTarget: `#${this.buildIdForWeight(this.props.activeWeight)}`, moveFocus: true, target: this.state.targetElement, closeOnNestedPopupOutsideClick: true }, this.renderPopup(this.props.dropDownTitle))) })));
    }
}
exports.WeightPickerButton = WeightPickerButton;
WeightPickerButton.defaultProps = {
    weights: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
};
//# sourceMappingURL=WeightPickerButton.js.map