"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module OIDC
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignIn = void 0;
require("./SignIn.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const UiComponents_1 = require("../UiComponents");
/**
 * SignIn React presentational component
 * @public
 */
class SignIn extends React.PureComponent {
    constructor(props) {
        super(props);
        this._onSignInClick = (e) => {
            e.preventDefault();
            this._onSigningIn();
        };
        this._onSigningIn = () => {
            this.setState({ isSigningIn: true });
            this.props.onSignIn();
        };
        this._handleKeyUp = (event, onActivate) => {
            const key = event.key;
            switch (key) {
                case ui_abstract_1.SpecialKey.Enter:
                case ui_abstract_1.SpecialKey.Space:
                    onActivate && onActivate();
                    break;
            }
        };
        this.state = {
            isSigningIn: false,
            prompt: UiComponents_1.UiComponents.translate("signIn.prompt"),
            signInButton: UiComponents_1.UiComponents.translate("signIn.signInButton"),
            profilePrompt: UiComponents_1.UiComponents.translate("signIn.profilePrompt"),
            registerAnchor: UiComponents_1.UiComponents.translate("signIn.register"),
            offlineButton: UiComponents_1.UiComponents.translate("signIn.offlineButton"),
        };
    }
    render() {
        const disableSignInOnClick = this.props.disableSignInOnClick === undefined ? true : this.props.disableSignInOnClick; // disableSignInOnClick defaults to true!
        return (React.createElement("div", { className: classnames_1.default("components-signin", this.props.className), style: this.props.style },
            React.createElement("div", { className: "components-signin-content" },
                React.createElement("span", { className: "icon icon-user" }),
                (this.state.isSigningIn && this.props.signingInMessage !== undefined) ?
                    React.createElement("span", { className: "components-signin-prompt" }, this.props.signingInMessage) :
                    React.createElement("span", { className: "components-signin-prompt" }, this.state.prompt),
                React.createElement("button", { className: "components-signin-button", disabled: this.state.isSigningIn && disableSignInOnClick, onClick: this._onSignInClick, onKeyUp: (e) => this._handleKeyUp(e, this._onSigningIn) }, this.state.signInButton),
                this.props.onRegister !== undefined &&
                    React.createElement("span", { className: "components-signin-register" },
                        this.state.profilePrompt,
                        React.createElement("a", { onClick: this.props.onRegister, onKeyUp: (e) => this._handleKeyUp(e, this.props.onRegister), role: "link", tabIndex: 0 }, this.state.registerAnchor)),
                this.props.onOffline !== undefined &&
                    // eslint-disable-next-line jsx-a11y/anchor-is-valid
                    React.createElement("a", { className: "components-signin-offline", onClick: this.props.onOffline, onKeyUp: (e) => this._handleKeyUp(e, this.props.onOffline), role: "link", tabIndex: 0 }, this.state.offlineButton))));
    }
}
exports.SignIn = SignIn;
//# sourceMappingURL=SignIn.js.map