/** @packageDocumentation
 * @module Properties
 */
import { CSSProperties } from "react";
/** Style properties for styled item like [[CellItem]] and [[TreeNodeItem]]
 * @public
 */
export interface ItemStyle {
    /** Is text bolded */
    isBold?: boolean;
    /** Is text italic */
    isItalic?: boolean;
    /** Color overrides for styled item */
    colorOverrides?: ItemColorOverrides;
}
/** Color overrides for styled item
 * @public
 */
export interface ItemColorOverrides {
    /** Text/foreground color */
    color?: number;
    /** Background color */
    backgroundColor?: number;
    /** Selected item text/foreground color */
    colorSelected?: number;
    /** Selected item background color */
    backgroundColorSelected?: number;
}
/**
 * Style provider for stylable items like [[CellItem]] and [[TreeNodeItem]]
 * @public
 */
export declare const ItemStyleProvider: {
    /**
     * Create CSS style from [[ItemStyle]]
     */
    createStyle: ({ colorOverrides, isBold, isItalic }: ItemStyle, isSelected?: boolean | undefined) => CSSProperties;
};
/**
 * Style provider for table rows
 * @public
 */
export declare const TableRowStyleProvider: {
    /**
     * Create CSS style from [[ItemStyle]]
     */
    createStyle: ({ color, backgroundColor }: ItemColorOverrides) => CSSProperties;
};
//# sourceMappingURL=ItemStyle.d.ts.map