"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Properties
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableRowStyleProvider = exports.ItemStyleProvider = void 0;
/** Converts a color value from a number to an HTML/CSS hex string */
const colorDecimalToHex = (decimal) => `#${decimal.toString(16).padStart(6, "0")}`;
function getBackgroundColor(isSelected, colorOverrides) {
    if (!colorOverrides)
        return undefined;
    if (isSelected)
        return colorOverrides.backgroundColorSelected !== undefined
            ? colorDecimalToHex(colorOverrides.backgroundColorSelected)
            : undefined;
    if (colorOverrides.backgroundColor)
        return colorDecimalToHex(colorOverrides.backgroundColor);
    return undefined;
}
function getForegroundColor(isSelected, colorOverrides) {
    if (!colorOverrides)
        return undefined;
    if (isSelected)
        return colorOverrides.colorSelected !== undefined
            ? colorDecimalToHex(colorOverrides.colorSelected)
            : undefined;
    if (colorOverrides.color)
        return colorDecimalToHex(colorOverrides.color);
    return undefined;
}
/**
 * Style provider for stylable items like [[CellItem]] and [[TreeNodeItem]]
 * @public
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
exports.ItemStyleProvider = {
    /**
     * Create CSS style from [[ItemStyle]]
     */
    createStyle: ({ colorOverrides, isBold, isItalic }, isSelected) => ({
        color: getForegroundColor(!!isSelected, colorOverrides),
        backgroundColor: getBackgroundColor(!!isSelected, colorOverrides),
        fontWeight: isBold ? "bold" : undefined,
        fontStyle: isItalic ? "italic" : undefined,
    }),
};
/**
 * Style provider for table rows
 * @public
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
exports.TableRowStyleProvider = {
    /**
     * Create CSS style from [[ItemStyle]]
     */
    createStyle: ({ color, backgroundColor }) => ({
        color: color ? colorDecimalToHex(color) : undefined,
        backgroundColor: backgroundColor ? colorDecimalToHex(backgroundColor) : undefined,
    }),
};
//# sourceMappingURL=ItemStyle.js.map