"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Properties
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LinksRenderer = exports.withLinks = exports.renderLinks = exports.hasLinks = void 0;
const React = __importStar(require("react"));
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const ui_core_1 = require("@bentley/ui-core");
/** Render a single anchor tag */
function renderTag(text, links, highlight) {
    return (React.createElement(ui_core_1.UnderlinedButton, { onClick: (e) => {
            e.preventDefault();
            e.stopPropagation();
            links.onClick(text);
        } }, highlight ? highlight(text) : text));
}
function matchComparison(matchA, matchB) {
    if (matchA.start > matchB.start)
        return 1;
    if (matchB.start > matchA.start)
        return -1;
    return 0;
}
function renderTextPart(text, highlight) {
    return highlight ? highlight(text) : text;
}
function renderText(text, links, highlight) {
    const { matcher } = links;
    if (!matcher)
        return renderTag(text, links, highlight);
    const matches = matcher(text);
    // Sort just to be sure
    matches.sort(matchComparison);
    const parts = [];
    let lastIndex = 0;
    for (const match of matches) {
        // If matches overlap there must be something wrong with the matcher
        if (lastIndex > match.start)
            throw new bentleyjs_core_1.BentleyError(bentleyjs_core_1.BentleyStatus.ERROR, "renderText: matcher returned overlapping matches");
        if (lastIndex < match.start)
            parts.push(renderTextPart(text.substring(lastIndex, match.start), highlight));
        const anchorText = text.substring(match.start, match.end);
        parts.push(renderTag(anchorText, links, highlight));
        lastIndex = match.end;
    }
    if (text.length > lastIndex)
        parts.push(renderTextPart(text.substring(lastIndex), highlight));
    // Need to map, because React complains about the lack of keys
    return parts.map((part, index) => React.createElement(React.Fragment, { key: index }, part));
}
function renderHighlighted(text, highlight) {
    return highlight(text);
}
/** Returns true if property record has an anchor tag
 * @public
 * @deprecated Should check if [[PropertyRecord]] has any links set instead.
 */
const hasLinks = (record) => !!record.links;
exports.hasLinks = hasLinks;
/** Renders anchor tag by wrapping or splitting provided text
 * @public
 */
const renderLinks = (text, links, highlight) => {
    return renderText(text, links, highlight);
};
exports.renderLinks = renderLinks;
/** If record has links, wraps stringValue in them, otherwise returns unchanged stringValue
 * Optionally it can highlight text
 * @public
 */
const withLinks = (stringValue, links, highlight) => {
    if (links)
        return exports.renderLinks(stringValue, links, highlight);
    if (highlight)
        return renderHighlighted(stringValue, highlight);
    return stringValue;
};
exports.withLinks = withLinks;
/**
 * React component for rendering string with links.
 * @alpha
 */
function LinksRenderer(props) {
    return React.createElement(React.Fragment, null, exports.withLinks(props.value, props.links, props.highlighter));
}
exports.LinksRenderer = LinksRenderer;
//# sourceMappingURL=LinkHandler.js.map