"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Properties
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommonPropertyRenderer = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const countMatchesInString_1 = require("../../common/countMatchesInString");
const HighlightedText_1 = require("../../common/HighlightedText");
const ValueRendererManager_1 = require("../ValueRendererManager");
/**
 * @internal
 */
class CommonPropertyRenderer {
    static getLabelOffset(indentation, orientation, width, columnRatio, minColumnLabelWidth) {
        if (!indentation)
            return 0;
        const maxIndent = 17;
        const minIndent = 6;
        if (orientation !== ui_core_1.Orientation.Horizontal || !width || !columnRatio || !minColumnLabelWidth)
            return indentation * maxIndent;
        const currentSize = Math.ceil(width * columnRatio);
        const shrinkThreshold = minColumnLabelWidth + (maxIndent * indentation);
        if (currentSize >= shrinkThreshold)
            return indentation * maxIndent;
        const minShrink = minColumnLabelWidth + minIndent + (maxIndent * (indentation - 1));
        if (currentSize <= minShrink)
            return minIndent + this.getLabelOffset(indentation - 1, orientation, width, columnRatio, minColumnLabelWidth);
        return currentSize - minColumnLabelWidth;
    }
    static createNewDisplayValue(orientation, propertyRecord, indentation, propertyValueRendererManager, isExpanded, onExpansionToggled, onHeightChanged, highlight) {
        const highlightCallback = (highlight === null || highlight === void 0 ? void 0 : highlight.applyOnValue) ? (CommonPropertyRenderer.createHighlightCallback(highlight, propertyRecord)) : undefined;
        const rendererContext = {
            orientation,
            containerType: ValueRendererManager_1.PropertyContainerType.PropertyPane,
            isExpanded,
            onExpansionToggled,
            onHeightChanged,
            textHighlighter: highlightCallback,
        };
        let displayValue;
        if (propertyValueRendererManager)
            displayValue = propertyValueRendererManager.render(propertyRecord, rendererContext);
        else
            displayValue = ValueRendererManager_1.PropertyValueRendererManager.defaultManager.render(propertyRecord, rendererContext);
        // Align value with label if orientation is vertical
        if (orientation === ui_core_1.Orientation.Vertical)
            displayValue = React.createElement("span", { style: { paddingLeft: CommonPropertyRenderer.getLabelOffset(indentation, orientation) } }, displayValue);
        return displayValue;
    }
    static createHighlightCallback(highlight, propertyRecord) {
        var _a;
        const activeMatch = highlight.activeHighlight;
        const propertyName = activeMatch === null || activeMatch === void 0 ? void 0 : activeMatch.highlightedItemIdentifier;
        const matchIndex = (_a = activeMatch === null || activeMatch === void 0 ? void 0 : activeMatch.highlightIndex) !== null && _a !== void 0 ? _a : 0;
        let labelMatches;
        if (highlight.applyOnLabel) {
            labelMatches = countMatchesInString_1.countMatchesInString(propertyRecord.property.displayLabel.toLowerCase(), highlight.highlightedText);
        }
        else {
            labelMatches = 0;
        }
        const activeMatchIndex = (propertyRecord.property.name === propertyName) && ((matchIndex - labelMatches) >= 0) ? (matchIndex - labelMatches) : undefined;
        const highlightCallback = (text) => (React.createElement(HighlightedText_1.HighlightedText, { text: text, activeMatchIndex: activeMatchIndex, searchText: highlight.highlightedText }));
        return highlightCallback;
    }
}
exports.CommonPropertyRenderer = CommonPropertyRenderer;
//# sourceMappingURL=CommonPropertyRenderer.js.map