"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Properties
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NonPrimitivePropertyRenderer = void 0;
require("./NonPrimitivePropertyRenderer.scss");
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const NonPrimitivePropertyLabelRenderer_1 = require("./label/NonPrimitivePropertyLabelRenderer");
const PropertyRenderer_1 = require("./PropertyRenderer");
const PropertyView_1 = require("./PropertyView");
const CommonPropertyRenderer_1 = require("./CommonPropertyRenderer");
/** React Component that renders struct and array properties
 * @public
 */
class NonPrimitivePropertyRenderer extends React.Component {
    constructor(props) {
        super(props);
        /** @internal */
        this.state = {
            /** If it's not collapsible, that means it's expanded by default and can't be collapsed */
            isExpanded: !this.props.isCollapsible || this.props.propertyRecord.autoExpand,
        };
        this._onExpanded = () => {
            this.setState({ isExpanded: true });
        };
        this._onCollapsed = () => {
            this.setState({ isExpanded: false });
        };
        this._renderPropertyForItem = (item) => {
            const prefix = this.props.uniqueKey ? this.props.uniqueKey : this.props.propertyRecord.property.name;
            const uniqueKey = `${prefix}_${item.property.name}`;
            return (React.createElement(PropertyRenderer_1.PropertyRenderer, { key: uniqueKey, uniqueKey: uniqueKey, propertyRecord: item, indentation: this.props.indentation ? this.props.indentation + 1 : 1, orientation: this.props.orientation, columnRatio: this.props.columnRatio, actionButtonRenderers: this.props.actionButtonRenderers, onColumnRatioChanged: this.props.onColumnRatioChanged, width: this.props.width, isResizeHandleHovered: this.props.isResizeHandleHovered, onResizeHandleHoverChanged: this.props.onResizeHandleHoverChanged, isResizeHandleBeingDragged: this.props.isResizeHandleBeingDragged, onResizeHandleDragChanged: this.props.onResizeHandleDragChanged, columnInfo: this.props.columnInfo }));
        };
    }
    getLabel(props, state) {
        const { orientation, indentation, width, columnRatio, columnInfo } = props;
        const offset = CommonPropertyRenderer_1.CommonPropertyRenderer.getLabelOffset(indentation, orientation, width, columnRatio, columnInfo === null || columnInfo === void 0 ? void 0 : columnInfo.minLabelWidth);
        let displayLabel = props.propertyRecord.property.displayLabel;
        if (this.props.propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Array)
            displayLabel = `${displayLabel} (${this.props.propertyRecord.value.items.length})`;
        return (React.createElement(NonPrimitivePropertyLabelRenderer_1.NonPrimitivePropertyLabelRenderer, { isExpanded: !!state.isExpanded, onExpand: this._onExpanded, onCollapse: this._onCollapsed, offset: offset, renderColon: false }, displayLabel));
    }
    overrideArrayChildrenNames(items) {
        const modifiedProperties = items.map((item, index) => {
            const newProperty = Object.assign({}, item.property);
            newProperty.displayLabel = `[${index + 1}]`;
            newProperty.name = `${newProperty.name}_${index}`;
            return new ui_abstract_1.PropertyRecord(item.value, newProperty);
        });
        return modifiedProperties;
    }
    /** @internal */
    render() {
        let items = this.props.propertyRecord.getChildrenRecords();
        if (this.props.propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Array)
            items = this.overrideArrayChildrenNames(items);
        const _a = this.props, { children, indentation } = _a, props = __rest(_a, ["children", "indentation"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        return (React.createElement(React.Fragment, null,
            this.props.isCollapsible
                ?
                    React.createElement(PropertyView_1.PropertyView, Object.assign({ labelElement: this.getLabel(this.props, this.state) }, props))
                : undefined,
            this.state.isExpanded ? items.map(this._renderPropertyForItem) : undefined));
    }
}
exports.NonPrimitivePropertyRenderer = NonPrimitivePropertyRenderer;
//# sourceMappingURL=NonPrimitivePropertyRenderer.js.map