"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Properties
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyRenderer = void 0;
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const EditorContainer_1 = require("../../editors/EditorContainer");
const UiComponents_1 = require("../../UiComponents");
const CommonPropertyRenderer_1 = require("./CommonPropertyRenderer");
const NonPrimitivePropertyRenderer_1 = require("./NonPrimitivePropertyRenderer");
const PrimitivePropertyRenderer_1 = require("./PrimitivePropertyRenderer");
/**  A React component that renders properties
 * @public
 */
class PropertyRenderer extends React.Component {
    constructor(props) {
        super(props);
        /** @internal */
        this.state = {
            displayValue: UiComponents_1.UiComponents.translate("general.loading"),
        };
        this._onEditCommit = (args) => {
            // istanbul ignore else
            if (this.props.onEditCommit)
                this.props.onEditCommit(args);
        };
        this._onEditCancel = () => {
            // istanbul ignore else
            if (this.props.onEditCancel)
                this.props.onEditCancel();
        };
    }
    static getLabelOffset(indentation, orientation, width, columnRatio, minColumnLabelWidth) {
        return CommonPropertyRenderer_1.CommonPropertyRenderer.getLabelOffset(indentation, orientation, width, columnRatio, minColumnLabelWidth);
    }
    updateDisplayValue(props) {
        if (props.isEditing) {
            this.updateDisplayValueAsEditor(props);
            return;
        }
        const displayValue = CommonPropertyRenderer_1.CommonPropertyRenderer.createNewDisplayValue(props.orientation, props.propertyRecord, props.indentation, props.propertyValueRendererManager);
        this.setState({ displayValue });
    }
    /** Display property record value in an editor */
    updateDisplayValueAsEditor(props) {
        this.setState({
            displayValue: React.createElement(EditorContainer_1.EditorContainer, { propertyRecord: props.propertyRecord, onCommit: this._onEditCommit, onCancel: this._onEditCancel, setFocus: true }),
        });
    }
    /** @internal */
    componentDidMount() {
        this.updateDisplayValue(this.props);
    }
    /** @internal */
    componentDidUpdate(prevProps) {
        if (prevProps.propertyRecord !== this.props.propertyRecord ||
            prevProps.isEditing !== this.props.isEditing ||
            prevProps.orientation !== this.props.orientation)
            this.updateDisplayValue(this.props);
    }
    /** @internal */
    render() {
        const _a = this.props, { children, propertyValueRendererManager, isEditing, onEditCommit, onEditCancel } = _a, props = __rest(_a, ["children", "propertyValueRendererManager", "isEditing", "onEditCommit", "onEditCancel"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        const primitiveRendererProps = Object.assign(Object.assign({}, props), { valueElement: this.state.displayValue, indentation: this.props.indentation });
        switch (this.props.propertyRecord.value.valueFormat) {
            case ui_abstract_1.PropertyValueFormat.Primitive:
                return (React.createElement(PrimitivePropertyRenderer_1.PrimitivePropertyRenderer, Object.assign({}, primitiveRendererProps)));
            case ui_abstract_1.PropertyValueFormat.Array:
                // If array is empty, render it as a primitive property
                if (this.props.propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Array
                    && this.props.propertyRecord.value.items.length === 0)
                    return (React.createElement(PrimitivePropertyRenderer_1.PrimitivePropertyRenderer, Object.assign({}, primitiveRendererProps)));
            // eslint-disable-next-line no-fallthrough
            case ui_abstract_1.PropertyValueFormat.Struct:
                return (React.createElement(NonPrimitivePropertyRenderer_1.NonPrimitivePropertyRenderer, Object.assign({ isCollapsible: true }, primitiveRendererProps)));
        }
    }
}
exports.PropertyRenderer = PropertyRenderer;
//# sourceMappingURL=PropertyRenderer.js.map