"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Properties
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyView = void 0;
require("./PropertyView.scss");
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const ActionButtonList_1 = require("./ActionButtonList");
const PropertyGridColumns_1 = require("./PropertyGridColumns");
/**
 * A React component that renders property as label/value pair
 * @public
 */
class PropertyView extends React.Component {
    constructor(props) {
        super(props);
        this._onClick = () => {
            if (this.props.onClick)
                this.props.onClick(this.props.propertyRecord, this.props.uniqueKey);
        };
        this._onMouseEnter = () => {
            if (this.props.isHoverable)
                this.setState({ isHovered: true });
        };
        this._onMouseLeave = () => {
            if (this.props.isHoverable)
                this.setState({ isHovered: false });
        };
        this._onContextMenu = (e) => {
            if (this.props.onContextMenu)
                this.props.onContextMenu(this.props.propertyRecord, e);
            if (this.props.onRightClick)
                this.props.onRightClick(this.props.propertyRecord, this.props.uniqueKey);
            e.preventDefault();
            return false;
        };
        this.state = {
            isHovered: false,
        };
    }
    getClassName(props) {
        let propertyRecordClassName = props.orientation === ui_core_1.Orientation.Horizontal
            ? "components-property-record--horizontal"
            : "components-property-record--vertical";
        if (props.isSelected)
            propertyRecordClassName += " components--selected";
        if (props.onClick)
            propertyRecordClassName += " components--clickable";
        if (props.isHoverable)
            propertyRecordClassName += " components--hoverable";
        return propertyRecordClassName;
    }
    /** @internal */
    render() {
        const ratio = this.props.columnRatio ? this.props.columnRatio : 0.25;
        // eslint-disable-next-line deprecation/deprecation
        const needElementSeparator = this.props.orientation === ui_core_1.Orientation.Horizontal && !!this.props.onColumnRatioChanged;
        const needActionButtons = !!this.props.actionButtonRenderers;
        const columnsStyleProvider = new PropertyGridColumns_1.PropertyGridColumnStyleProvider(this.props.columnInfo);
        return (React.createElement("div", { style: columnsStyleProvider.getStyle(this.props.orientation, needActionButtons, ratio, needElementSeparator), className: this.getClassName(this.props), onClick: this._onClick, onContextMenu: this._onContextMenu, onMouseEnter: this._onMouseEnter, onMouseLeave: this._onMouseLeave, role: "presentation" },
            React.createElement("div", { className: "components-property-record-label" }, this.props.labelElement),
            needElementSeparator
                ? React.createElement(ui_core_1.ElementSeparator, { movableArea: this.props.width, 
                    // eslint-disable-next-line deprecation/deprecation
                    onRatioChanged: this.props.onColumnRatioChanged, ratio: ratio, orientation: this.props.orientation, isResizeHandleHovered: this.props.isResizeHandleHovered, onResizeHandleHoverChanged: this.props.onResizeHandleHoverChanged, isResizeHandleBeingDragged: this.props.isResizeHandleBeingDragged, onResizeHandleDragChanged: this.props.onResizeHandleDragChanged })
                : undefined,
            this.props.propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive
                ? React.createElement("div", { className: "components-property-record-value" },
                    React.createElement("span", null, this.props.valueElementRenderer ? this.props.valueElementRenderer() : this.props.valueElement))
                : undefined,
            this.props.actionButtonRenderers
                ?
                    React.createElement(ActionButtonList_1.ActionButtonList, { orientation: this.props.orientation, property: this.props.propertyRecord, isPropertyHovered: this.state.isHovered, actionButtonRenderers: this.props.actionButtonRenderers })
                :
                    undefined));
    }
}
exports.PropertyView = PropertyView;
//# sourceMappingURL=PropertyView.js.map