"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/**
 * @packageDocumentation
 * @module Properties
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultilineTextRenderer = exports.MultilineTextPropertyValueRenderer = void 0;
const React = __importStar(require("react"));
// eslint-disable-next-line no-duplicate-imports
const react_1 = require("react");
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const ui_abstract_1 = require("@bentley/ui-abstract");
const UseRerender_1 = require("../../../common/UseRerender");
const TypeConverterManager_1 = require("../../../converters/TypeConverterManager");
const UiComponents_1 = require("../../../UiComponents");
const PrimitivePropertyValueRenderer_1 = require("./PrimitivePropertyValueRenderer");
/** @internal */
class MultilineTextPropertyValueRenderer {
    canRender(record) {
        var _a;
        return record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive
            && ((_a = record.property.renderer) === null || _a === void 0 ? void 0 : _a.name) === "multiline";
    }
    render(record, context) {
        return React.createElement(MultilineTextPropertyValueRendererImpl, { record: record, context: context });
    }
}
exports.MultilineTextPropertyValueRenderer = MultilineTextPropertyValueRenderer;
const MultilineTextPropertyValueRendererImpl = (props) => {
    var _a, _b, _c, _d;
    const { stringValue, element } = PrimitivePropertyValueRenderer_1.useRenderedStringValue(props.record, convertRecordToString, props.context);
    return (React.createElement(exports.MultilineTextRenderer, { style: (_a = props.context) === null || _a === void 0 ? void 0 : _a.style, stringValue: stringValue, isExpanded: (_b = props.context) === null || _b === void 0 ? void 0 : _b.isExpanded, onExpansionToggled: (_c = props.context) === null || _c === void 0 ? void 0 : _c.onExpansionToggled, onHeightChanged: (_d = props.context) === null || _d === void 0 ? void 0 : _d.onHeightChanged }, element));
};
/** @internal */
const MultilineTextRenderer = (props) => {
    const { rerenderContext, numRerenders, rerender } = UseRerender_1.useRerender({ contentOverflows: false });
    const spanRef = react_1.useRef(null);
    const divRef = react_1.useRef(null);
    const previousHeightRef = react_1.useRef(0);
    react_1.useLayoutEffect(() => {
        var _a;
        bentleyjs_core_1.assert(divRef.current !== null && spanRef.current !== null);
        const contentOverflows = spanRef.current.clientWidth < spanRef.current.scrollWidth;
        if (numRerenders === 0 && contentOverflows) {
            rerender({ contentOverflows });
        }
        if (numRerenders === 1 || !contentOverflows) {
            const currentHeight = Math.max(divRef.current.offsetHeight, 24) + 3;
            if (currentHeight !== previousHeightRef.current) {
                (_a = props.onHeightChanged) === null || _a === void 0 ? void 0 : _a.call(props, currentHeight);
                previousHeightRef.current = currentHeight;
            }
        }
    });
    const handleExpansionToggleClick = (event) => {
        var _a;
        (_a = props.onExpansionToggled) === null || _a === void 0 ? void 0 : _a.call(props);
        event.stopPropagation();
    };
    // In order to always trigger onMouseLeave event on PropertyView, collapse button must remain mounted at all times.
    // https://github.com/facebook/react/issues/6807
    return (React.createElement("div", { ref: divRef, className: "multiline" },
        React.createElement("span", { ref: spanRef, className: (numRerenders !== 0 && props.isExpanded) ? "expanded" : "", style: props.style, title: props.isExpanded ? undefined : props.stringValue },
            props.children,
            React.createElement("button", { className: "expand-toggle", style: { display: (rerenderContext.contentOverflows && props.isExpanded) ? "inline-block" : "none" }, onClick: handleExpansionToggleClick }, UiComponents_1.UiComponents.translate("property.collapse"))),
        rerenderContext.contentOverflows && !props.isExpanded &&
            React.createElement("button", { className: "expand-toggle", onClick: handleExpansionToggleClick }, UiComponents_1.UiComponents.translate("property.expand"))));
};
exports.MultilineTextRenderer = MultilineTextRenderer;
function convertRecordToString(record) {
    return TypeConverterManager_1.TypeConverterManager
        .getConverter(ui_abstract_1.StandardTypeNames.Text)
        .convertPropertyToString(record.property, record.value.value);
}
//# sourceMappingURL=MultilineTextPropertyValueRenderer.js.map