/** @packageDocumentation
 * @module Properties
 */
import * as React from "react";
import { IPropertyValueRenderer, PropertyValueRendererContext } from "../../ValueRendererManager";
import { LinkElementsInfo, PropertyRecord } from "@bentley/ui-abstract";
/** Default Primitive Property Renderer
 * @public
 */
export declare class PrimitivePropertyValueRenderer implements IPropertyValueRenderer {
    /** Checks if the renderer can handle given property */
    canRender(record: PropertyRecord): boolean;
    /** Method that returns a JSX representation of PropertyRecord */
    render(record: PropertyRecord, context?: PropertyValueRendererContext): React.ReactNode;
}
/**
 * Function that converts primitive [[PropertyRecord]] to string
 * @internal
 */
export declare function convertPrimitiveRecordToString(record: PropertyRecord): string | Promise<string>;
/** @internal */
interface PrimitivePropertyValueRendererImplProps {
    record: PropertyRecord;
    stringValueCalculator: (record: PropertyRecord) => string | Promise<string>;
    context?: PropertyValueRendererContext;
    linksHandler?: LinkElementsInfo;
}
/** @internal */
export declare function PrimitivePropertyValueRendererImpl(props: PrimitivePropertyValueRendererImplProps): JSX.Element;
/**
 * Default link handler used for handling records,
 * which did not have any specified LinkElementsInfo.
 *
 * Default matcher matches all URLs using regex.
 * Default onClick opens window or sets location.href with found URL.
 * @beta
 */
export declare const DEFAULT_LINKS_HANDLER: LinkElementsInfo;
/** @internal */
export declare function useRenderedStringValue(record: PropertyRecord, stringValueCalculator: (record: PropertyRecord) => string | Promise<string>, context?: PropertyValueRendererContext, linksHandler?: LinkElementsInfo): {
    stringValue?: string;
    element: React.ReactNode;
};
export {};
//# sourceMappingURL=PrimitivePropertyValueRenderer.d.ts.map