"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Properties
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRenderedStringValue = exports.DEFAULT_LINKS_HANDLER = exports.PrimitivePropertyValueRendererImpl = exports.convertPrimitiveRecordToString = exports.PrimitivePropertyValueRenderer = void 0;
const React = __importStar(require("react"));
const UseAsyncValue_1 = require("../../../common/UseAsyncValue");
const TypeConverterManager_1 = require("../../../converters/TypeConverterManager");
const LinkHandler_1 = require("../../LinkHandler");
const WithContextStyle_1 = require("./WithContextStyle");
const ui_abstract_1 = require("@bentley/ui-abstract");
const PropertyGridCommons_1 = require("../../../propertygrid/component/PropertyGridCommons");
/** Default Primitive Property Renderer
 * @public
 */
class PrimitivePropertyValueRenderer {
    /** Checks if the renderer can handle given property */
    canRender(record) {
        return record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive;
    }
    /** Method that returns a JSX representation of PropertyRecord */
    render(record, context) {
        if (context && context.decoratedTextElement) {
            // This is a deprecated code branch that's only needed to support the BeInspireTree-driven
            // tree - it's the only one using `decoratedTextElement` to pass an already rendered node.
            // The right way to do this is to supply enough information (either through `record` or `context`)
            // to render the node from here.
            return WithContextStyle_1.withContextStyle(context.decoratedTextElement, context);
        }
        return React.createElement(PrimitivePropertyValueRendererImpl, { record: record, context: context, stringValueCalculator: convertPrimitiveRecordToString });
    }
}
exports.PrimitivePropertyValueRenderer = PrimitivePropertyValueRenderer;
/**
 * Function that converts primitive [[PropertyRecord]] to string
 * @internal
 */
function convertPrimitiveRecordToString(record) {
    var _a;
    const primitive = record.value;
    return TypeConverterManager_1.TypeConverterManager.getConverter(record.property.typename, (_a = record.property.converter) === null || _a === void 0 ? void 0 : _a.name).convertPropertyToString(record.property, primitive.value);
}
exports.convertPrimitiveRecordToString = convertPrimitiveRecordToString;
/** @internal */
function PrimitivePropertyValueRendererImpl(props) {
    var _a;
    const { stringValue, element } = useRenderedStringValue(props.record, props.stringValueCalculator, props.context, props.linksHandler);
    return React.createElement("span", { style: (_a = props.context) === null || _a === void 0 ? void 0 : _a.style, title: stringValue }, element);
}
exports.PrimitivePropertyValueRendererImpl = PrimitivePropertyValueRendererImpl;
/**
 * Default link handler used for handling records,
 * which did not have any specified LinkElementsInfo.
 *
 * Default matcher matches all URLs using regex.
 * Default onClick opens window or sets location.href with found URL.
 * @beta
 */
exports.DEFAULT_LINKS_HANDLER = {
    matcher: PropertyGridCommons_1.PropertyGridCommons.getLinks,
    onClick: PropertyGridCommons_1.PropertyGridCommons.handleLinkClick,
};
/** @internal */
function useRenderedStringValue(record, stringValueCalculator, context, linksHandler) {
    var _a, _b;
    const stringValue = UseAsyncValue_1.useAsyncValue(stringValueCalculator(record));
    const el = (stringValue === undefined)
        ? context === null || context === void 0 ? void 0 : context.defaultValue
        : React.createElement(LinkHandler_1.LinksRenderer, { value: stringValue, links: (_b = (_a = record.links) !== null && _a !== void 0 ? _a : linksHandler) !== null && _b !== void 0 ? _b : exports.DEFAULT_LINKS_HANDLER, highlighter: context === null || context === void 0 ? void 0 : context.textHighlighter });
    return { stringValue, element: el };
}
exports.useRenderedStringValue = useRenderedStringValue;
//# sourceMappingURL=PrimitivePropertyValueRenderer.js.map