"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Properties
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UrlPropertyValueRenderer = void 0;
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const PrimitivePropertyValueRenderer_1 = require("./PrimitivePropertyValueRenderer");
/**
 * URL property value renderer that renders the whole value as a URL without matching it
 * against URL regex.
 *
 * @public
 */
class UrlPropertyValueRenderer {
    /** Checks if the renderer can handle given property */
    canRender(record) {
        return record.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive
            && record.property.typename === ui_abstract_1.StandardTypeNames.URL;
    }
    /** Method that returns a JSX representation of PropertyRecord */
    render(record, context) {
        return React.createElement(PrimitivePropertyValueRenderer_1.PrimitivePropertyValueRendererImpl, { record: record, context: context, stringValueCalculator: PrimitivePropertyValueRenderer_1.convertPrimitiveRecordToString, linksHandler: URI_PROPERTY_LINK_HANDLER });
    }
}
exports.UrlPropertyValueRenderer = UrlPropertyValueRenderer;
/**
 * Default URI onClick event, sets location.href to the whole URI value without matching it
 * against URL regex.
 */
function urlOnClick(text) {
    if (text.startsWith("mailto:") || text.startsWith("pw:"))
        location.href = text;
    else {
        const windowOpen = window.open(text, "_blank");
        if (windowOpen)
            windowOpen.focus();
    }
}
const URI_PROPERTY_LINK_HANDLER = {
    onClick: urlOnClick,
};
//# sourceMappingURL=UrlPropertyValueRenderer.js.map