/** @packageDocumentation
 * @module Properties
 */
import "./NonPrimitiveValueRenderer.scss";
import * as React from "react";
import { PropertyRecord } from "@bentley/ui-abstract";
import { Orientation } from "@bentley/ui-core";
import { PropertyDialogState } from "../../../ValueRendererManager";
/** Properties for [[TableArrayValueRenderer]] and [[TableStructValueRenderer]] React component
 * @public
 */
export interface TableSpecificValueRendererProps extends SharedTableNonPrimitiveValueRendererProps {
    /** Property record */
    propertyRecord: PropertyRecord;
    /** Orientation of the rendered property */
    orientation: Orientation;
}
/** Shared properties between table non-primitive value renderers
 * @public
 */
export interface SharedTableNonPrimitiveValueRendererProps {
    /** Callback to request for dialog to be opened. */
    onDialogOpen?: (dialogState: PropertyDialogState) => void;
}
/** Properties for [[TableNonPrimitiveValueRenderer]] React component
 * @public
 */
export interface TableNonPrimitiveValueRendererProps extends SharedTableNonPrimitiveValueRendererProps {
    /** Title of the dialog that shows property in more detail. */
    dialogTitle: string;
    /** Contents of the dialog. Should be the property record shown in more detail. */
    dialogContents: React.ReactNode;
    /** Text that will be rendered in the table cell, in other words - Property value */
    buttonLabel: string;
}
/**
 * A React component that renders non primitive values as a button with text.
 * When clicked, a dialog appears that shows the value in greater detail.
 * @public
 */
export declare class TableNonPrimitiveValueRenderer extends React.PureComponent<TableNonPrimitiveValueRendererProps> {
    private _onClick;
    /** @internal */
    render(): JSX.Element;
}
//# sourceMappingURL=NonPrimitiveValueRenderer.d.ts.map