/** @packageDocumentation
 * @module PropertyGrid
 */
import * as React from "react";
import { VirtualizedPropertyGridContext } from "./component/VirtualizedPropertyGrid";
import { GridCategoryItem } from "./internal/flat-items/FlatGridItem";
/**
 * Props that property category renderer receives.
 * @beta
 */
export interface PropertyCategoryRendererProps {
    /** The category being rendered. */
    categoryItem: GridCategoryItem;
    /** Context of the surrounding property grid. */
    gridContext: VirtualizedPropertyGridContext;
    /** Sets the allocated height for category contents. */
    onHeightChanged: (newHeight: number) => void;
}
/**
 * Factory function that produces custom property category components.
 *  @beta
 */
export declare type PropertyCategoryRenderer = (categoryItem: GridCategoryItem) => React.ComponentType<PropertyCategoryRendererProps> | undefined;
/**
 * Keeps a record of currently registered property category renderers and determines which renderers get invoked for
 * each category.
 * @beta
 */
export declare class PropertyCategoryRendererManager {
    private _categoryRenderers;
    static defaultManager: PropertyCategoryRendererManager;
    /** Retrieves a category rendering component based for the passed category item. */
    getCategoryComponent(categoryItem: GridCategoryItem): React.ComponentType<PropertyCategoryRendererProps> | undefined;
    /** Registers a renderer factory function to be invoked on categories with specific renderer name. */
    addRenderer(rendererName: string, categoryRenderer: PropertyCategoryRenderer, override?: boolean): void;
    /** Removes previous renderer factory registration. */
    removeRenderer(rendererName: string): void;
}
//# sourceMappingURL=PropertyCategoryRendererManager.d.ts.map