"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyCategoryRendererManager = void 0;
/**
 * Keeps a record of currently registered property category renderers and determines which renderers get invoked for
 * each category.
 * @beta
 */
class PropertyCategoryRendererManager {
    constructor() {
        this._categoryRenderers = new Map();
    }
    /** Retrieves a category rendering component based for the passed category item. */
    getCategoryComponent(categoryItem) {
        var _a;
        if (categoryItem.derivedCategory.renderer === undefined) {
            return undefined;
        }
        return (_a = this._categoryRenderers.get(categoryItem.derivedCategory.renderer.name)) === null || _a === void 0 ? void 0 : _a(categoryItem);
    }
    /** Registers a renderer factory function to be invoked on categories with specific renderer name. */
    addRenderer(rendererName, categoryRenderer, override = false) {
        if (this._categoryRenderers.has(rendererName) && !override) {
            const className = PropertyCategoryRendererManager.name;
            const methodName = PropertyCategoryRendererManager.prototype.addRenderer.name;
            throw new Error(`${className}.${methodName} error: renderer '${rendererName}' has already been added. Did you mean to override it?`);
        }
        this._categoryRenderers.set(rendererName, categoryRenderer);
    }
    /** Removes previous renderer factory registration. */
    removeRenderer(rendererName) {
        this._categoryRenderers.delete(rendererName);
    }
}
exports.PropertyCategoryRendererManager = PropertyCategoryRendererManager;
PropertyCategoryRendererManager.defaultManager = new PropertyCategoryRendererManager();
//# sourceMappingURL=PropertyCategoryRendererManager.js.map