"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SimplePropertyDataProvider = void 0;
const ui_abstract_1 = require("@bentley/ui-abstract");
const PropertyDataProvider_1 = require("./PropertyDataProvider");
/**
 * Implementation of [IPropertyDataProvider] that uses an associative array.
 * @public
 */
class SimplePropertyDataProvider {
    constructor() {
        this.label = ui_abstract_1.PropertyRecord.fromString("");
        this.categories = [];
        this.records = {};
        this.onDataChanged = new PropertyDataProvider_1.PropertyDataChangeEvent();
    }
    addCategory(category) {
        const categoryIdx = this.categories.push(category) - 1;
        this.records[this.categories[categoryIdx].name] = [];
        this.onDataChanged.raiseEvent();
        return categoryIdx;
    }
    findCategoryIndex(category) {
        const index = this.categories.findIndex((testCategory) => {
            return testCategory.name === category.name;
        });
        return index;
    }
    addProperty(propertyRecord, categoryIdx) {
        this.records[this.categories[categoryIdx].name].push(propertyRecord);
        this.onDataChanged.raiseEvent();
    }
    removeProperty(propertyRecord, categoryIdx) {
        const index = this.records[this.categories[categoryIdx].name].findIndex((record) => {
            return record === propertyRecord;
        });
        let result = false;
        // istanbul ignore else
        if (index >= 0) {
            this.records[this.categories[categoryIdx].name].splice(index, 1);
            this.onDataChanged.raiseEvent();
            result = true;
        }
        return result;
    }
    replaceProperty(propertyRecord, categoryIdx, newRecord) {
        const index = this.records[this.categories[categoryIdx].name].findIndex((record) => {
            return record === propertyRecord;
        });
        let result = false;
        // istanbul ignore else
        if (index >= 0) {
            this.records[this.categories[categoryIdx].name].splice(index, 1, newRecord);
            result = true;
        }
        return result;
    }
    async getData() {
        return this;
    }
}
exports.SimplePropertyDataProvider = SimplePropertyDataProvider;
//# sourceMappingURL=SimplePropertyDataProvider.js.map