"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColumnResizingPropertyListPropsSupplier = void 0;
const React = __importStar(require("react"));
const geometry_core_1 = require("@bentley/geometry-core");
const ui_core_1 = require("@bentley/ui-core");
/**
 * Wrapped PropertyCategoryBlock React component with list of properties and render optimization
 * @internal
 */
class ColumnResizingPropertyListPropsSupplier extends React.Component {
    constructor() {
        super(...arguments);
        this._initialRatio = 0.25;
        this._defaultMinRatio = 0.15;
        this._defaultMaxRatio = 0.6;
        this._minRatio = this._defaultMinRatio;
        this._maxRatio = this._defaultMaxRatio;
        this.state = {
            columnRatio: this._initialRatio,
            isResizeHandleHovered: false,
            isResizeHandleBeingDragged: false,
            isMinimumColumnSizeEnabled: false,
        };
        this._onColumnRatioChanged = (ratio) => {
            ratio = geometry_core_1.Geometry.clamp(ratio, this._minRatio, this._maxRatio);
            if (this.state.columnRatio === ratio)
                return { ratio };
            this.setState({ columnRatio: ratio });
            return { ratio };
        };
        // istanbul ignore next
        this._onResizeHandleHoverChanged = (isHovered) => {
            this.setState({ isResizeHandleHovered: isHovered });
        };
        this._onResizeHandleDragChanged = (isDragStarted) => {
            this.setState({ isResizeHandleBeingDragged: isDragStarted });
        };
        this._onListWidthChange = (width) => {
            if (this.props.orientation !== ui_core_1.Orientation.Horizontal)
                return;
            // Restore default behavior for screens that are too small to have minimum column widths
            if (width < this.props.minLabelWidth + 1 + this.props.minValueWidth + this.props.actionButtonWidth) {
                this._minRatio = this._defaultMinRatio;
                this._maxRatio = this._defaultMaxRatio;
                // istanbul ignore next
                if (this.state.isMinimumColumnSizeEnabled)
                    this.setState({ isMinimumColumnSizeEnabled: false });
                return;
            }
            this._minRatio = this.props.minLabelWidth / width;
            this._maxRatio = (width - this.props.actionButtonWidth - this.props.minValueWidth) / width;
            // istanbul ignore else
            if (!this.state.isMinimumColumnSizeEnabled)
                this.setState({ isMinimumColumnSizeEnabled: true });
        };
    }
    getValidColumnRatio() {
        return geometry_core_1.Geometry.clamp(this.state.columnRatio, this._minRatio, this._maxRatio);
    }
    render() {
        const listProps = {
            orientation: this.props.orientation,
            onColumnChanged: this._onColumnRatioChanged,
            columnRatio: this.getValidColumnRatio(),
            isResizeHandleHovered: this.state.isResizeHandleHovered,
            onResizeHandleHoverChanged: this._onResizeHandleHoverChanged,
            isResizeHandleBeingDragged: this.state.isResizeHandleBeingDragged,
            onResizeHandleDragChanged: this._onResizeHandleDragChanged,
            onListWidthChanged: this._onListWidthChange,
            columnInfo: {
                minLabelWidth: this.props.minLabelWidth,
                minValueWidth: this.props.minValueWidth,
                actionButtonWidth: this.props.actionButtonWidth,
                isMinimumColumnSizeEnabled: this.state.isMinimumColumnSizeEnabled,
            },
        };
        return this.props.children(listProps);
    }
}
exports.ColumnResizingPropertyListPropsSupplier = ColumnResizingPropertyListPropsSupplier;
ColumnResizingPropertyListPropsSupplier.defaultProps = {
    minLabelWidth: 100,
    minValueWidth: 100,
    actionButtonWidth: 90,
};
//# sourceMappingURL=ColumnResizingPropertyListPropsSupplier.js.map