"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyCategoryBlock = void 0;
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const HighlightedText_1 = require("../../common/HighlightedText");
/**
 * PropertyCategoryBlock React component
 * @public
 */
class PropertyCategoryBlock extends React.Component {
    constructor(props) {
        super(props);
        this._onClick = () => {
            this.toggleExpansion();
        };
        this._onKeyPress = (evt) => {
            // Prevent page from scrolling when clicking [Space]:
            if (evt.key === ui_abstract_1.SpecialKey.Space) {
                evt.preventDefault();
            }
            // [Space] and [Enter] toggle the block:
            if (evt.key === ui_abstract_1.SpecialKey.Space || evt.key === ui_abstract_1.SpecialKey.Enter) {
                this.toggleExpansion();
            }
        };
    }
    toggleExpansion() {
        if (this.props.onExpansionToggled)
            this.props.onExpansionToggled(this.props.category.name);
    }
    /** @internal */
    render() {
        var _a;
        const _b = this.props, { highlight, category, children } = _b, props = __rest(_b, ["highlight", "category", "children"]);
        const activeMatchIndex = this.props.category.name === ((_a = highlight === null || highlight === void 0 ? void 0 : highlight.activeHighlight) === null || _a === void 0 ? void 0 : _a.highlightedItemIdentifier) ? highlight.activeHighlight.highlightIndex : undefined;
        const label = highlight ?
            (React.createElement(HighlightedText_1.HighlightedText, { text: category.label, activeMatchIndex: activeMatchIndex, searchText: highlight.highlightedText })) :
            category.label;
        return (React.createElement(ui_core_1.ExpandableBlock, Object.assign({ isExpanded: category.expand, onClick: this._onClick, onKeyPress: this._onKeyPress, title: label, tooltip: category.label }, props), children));
    }
}
exports.PropertyCategoryBlock = PropertyCategoryBlock;
//# sourceMappingURL=PropertyCategoryBlock.js.map