"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyGrid = void 0;
/** @packageDocumentation
 * @module PropertyGrid
 */
require("./PropertyGrid.scss");
const classnames_1 = __importDefault(require("classnames"));
const immer_1 = require("immer");
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const DelayedSpinner_1 = require("../../common/DelayedSpinner");
const ColumnResizingPropertyListPropsSupplier_1 = require("./ColumnResizingPropertyListPropsSupplier");
const PropertyCategoryBlock_1 = require("./PropertyCategoryBlock");
const PropertyGridCommons_1 = require("./PropertyGridCommons");
const PropertyGridEventsRelatedPropsSupplier_1 = require("./PropertyGridEventsRelatedPropsSupplier");
const PropertyList_1 = require("./PropertyList");
/** PropertyGrid React component.
 * @public
 */
class PropertyGrid extends React.Component {
    /** @internal */
    constructor(props) {
        super(props);
        this._isMounted = false;
        this._isInDataRequest = false;
        this._hasPendingDataRequest = false;
        this._onPropertyDataChanged = () => {
            // eslint-disable-next-line @typescript-eslint/no-floating-promises
            this.gatherData();
        };
        this._onResize = (width) => {
            this.updateOrientation(width);
        };
        this._onCategoryExpansionToggled = (categoryName) => {
            this.setState((state) => {
                return immer_1.produce(state, (draft) => {
                    const records = findCategory(draft.categories, categoryName, true);
                    // istanbul ignore else
                    if (records) {
                        const category = records.category;
                        category.expand = !category.expand;
                    }
                });
            });
        };
        this.state = {
            categories: [],
            orientation: this.getPreferredOrientation(),
            width: 0,
        };
    }
    /** @internal */
    componentDidMount() {
        this._isMounted = true;
        this._dataChangesListenerDisposeFunc = this.props.dataProvider.onDataChanged.addListener(this._onPropertyDataChanged);
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        this.gatherData();
    }
    /** @internal */
    componentWillUnmount() {
        // istanbul ignore else
        if (this._dataChangesListenerDisposeFunc) {
            this._dataChangesListenerDisposeFunc();
            this._dataChangesListenerDisposeFunc = undefined;
        }
        this._isMounted = false;
    }
    componentDidUpdate(prevProps) {
        if (this.props.dataProvider !== prevProps.dataProvider) {
            // istanbul ignore else
            if (this._dataChangesListenerDisposeFunc)
                this._dataChangesListenerDisposeFunc();
            this._dataChangesListenerDisposeFunc = this.props.dataProvider.onDataChanged.addListener(this._onPropertyDataChanged);
            // eslint-disable-next-line @typescript-eslint/no-floating-promises
            this.gatherData();
        }
        if (this.props.orientation !== prevProps.orientation
            || this.props.isOrientationFixed !== prevProps.isOrientationFixed
            || this.props.horizontalOrientationMinWidth !== prevProps.horizontalOrientationMinWidth)
            this.updateOrientation(this.state.width);
    }
    async gatherData() {
        if (this._isInDataRequest) {
            this._hasPendingDataRequest = true;
            return;
        }
        this.setState((prev) => prev.loadStart ? null : { loadStart: new Date() });
        this._isInDataRequest = true;
        let propertyData;
        try {
            propertyData = await this.props.dataProvider.getData();
        }
        finally {
            this._isInDataRequest = false;
        }
        if (!this._isMounted)
            return;
        if (this._hasPendingDataRequest) {
            this._hasPendingDataRequest = false;
            return this.gatherData();
        }
        // Support for deprecated onPropertyLinkClick
        // eslint-disable-next-line deprecation/deprecation
        if (this.props.onPropertyLinkClick) {
            for (const categoryName in propertyData.records) {
                // istanbul ignore else
                if (propertyData.records.hasOwnProperty(categoryName))
                    // eslint-disable-next-line deprecation/deprecation
                    PropertyGridCommons_1.PropertyGridCommons.assignRecordClickHandlers(propertyData.records[categoryName], this.props.onPropertyLinkClick);
            }
        }
        this.setState((prevState) => {
            const buildCategoriesHierarchy = (newCategories, stateCategories) => newCategories.map((category) => {
                var _a, _b, _c, _d;
                const matchingStateCategory = findCategory(stateCategories !== null && stateCategories !== void 0 ? stateCategories : [], category.name, false);
                return {
                    category: Object.assign(Object.assign({}, category), { expand: (_b = (_a = matchingStateCategory === null || matchingStateCategory === void 0 ? void 0 : matchingStateCategory.category) === null || _a === void 0 ? void 0 : _a.expand) !== null && _b !== void 0 ? _b : category.expand }),
                    records: (_c = propertyData.records[category.name]) !== null && _c !== void 0 ? _c : [],
                    children: buildCategoriesHierarchy((_d = category.childCategories) !== null && _d !== void 0 ? _d : [], matchingStateCategory === null || matchingStateCategory === void 0 ? void 0 : matchingStateCategory.children),
                };
            });
            return {
                categories: buildCategoriesHierarchy(propertyData.categories, prevState.categories),
                loadStart: undefined,
            };
        });
    }
    getPreferredOrientation() {
        return (this.props.orientation !== undefined) ? this.props.orientation : ui_core_1.Orientation.Horizontal;
    }
    updateOrientation(width) {
        const { orientation, isOrientationFixed, horizontalOrientationMinWidth } = Object.assign({}, this.props);
        const currentOrientation = PropertyGridCommons_1.PropertyGridCommons.getCurrentOrientation(width, orientation, isOrientationFixed, horizontalOrientationMinWidth);
        if (currentOrientation !== this.state.orientation || width !== this.state.width)
            this.setState({ orientation: currentOrientation, width });
    }
    /** @internal */
    render() {
        var _a, _b;
        if (this.state.loadStart) {
            return (React.createElement("div", { className: "components-property-grid-loader" },
                React.createElement(DelayedSpinner_1.DelayedSpinner, { loadStart: this.state.loadStart, size: ui_core_1.SpinnerSize.Large })));
        }
        return (React.createElement(PropertyGridEventsRelatedPropsSupplier_1.PropertyGridEventsRelatedPropsSupplier, { isPropertySelectionEnabled: (_a = this.props.isPropertySelectionEnabled) !== null && _a !== void 0 ? _a : false, isPropertySelectionOnRightClickEnabled: this.props.isPropertySelectionOnRightClickEnabled, isPropertyEditingEnabled: this.props.isPropertyEditingEnabled, isPropertyHoverEnabled: (_b = this.props.isPropertyHoverEnabled) !== null && _b !== void 0 ? _b : false, onPropertyContextMenu: this.props.onPropertyContextMenu, onPropertyUpdated: this.props.onPropertyUpdated, onPropertySelectionChanged: this.props.onPropertySelectionChanged }, (selectionContext) => (React.createElement("div", { className: classnames_1.default("components-property-grid-wrapper", this.props.className), style: this.props.style },
            React.createElement("div", { className: "components-property-grid" },
                React.createElement("div", { className: "property-categories" }, this.state.categories.map((categorizedRecords) => (React.createElement(NestedCategoryBlock, Object.assign({}, selectionContext, { key: categorizedRecords.category.name, categorizedRecords: categorizedRecords, onCategoryExpansionToggled: this._onCategoryExpansionToggled, orientation: this.state.orientation, propertyValueRendererManager: this.props.propertyValueRendererManager, actionButtonRenderers: this.props.actionButtonRenderers })))))),
            React.createElement(ui_core_1.ResizableContainerObserver, { onResize: this._onResize })))));
    }
}
exports.PropertyGrid = PropertyGrid;
function findCategory(categories, lookupName, recurseIntoChildren) {
    for (const category of categories) {
        if (category.category.name === lookupName)
            return category;
        if (recurseIntoChildren) {
            const matchingChild = findCategory(category.children, lookupName, recurseIntoChildren);
            if (matchingChild)
                return matchingChild;
        }
    }
    return undefined;
}
function NestedCategoryBlock(props) {
    return (React.createElement(PropertyCategoryBlock_1.PropertyCategoryBlock, { category: props.categorizedRecords.category, onExpansionToggled: props.onCategoryExpansionToggled },
        props.categorizedRecords.records.length ? (React.createElement(ColumnResizingPropertyListPropsSupplier_1.ColumnResizingPropertyListPropsSupplier, { orientation: props.orientation }, (partialListProps) => (React.createElement(PropertyList_1.PropertyList, Object.assign({}, partialListProps, { orientation: props.orientation, category: props.categorizedRecords.category, properties: props.categorizedRecords.records, selectedPropertyKey: props.selectedPropertyKey, onPropertyClicked: props.onPropertyClicked, onPropertyRightClicked: props.onPropertyRightClicked, onPropertyContextMenu: props.onPropertyContextMenu, propertyValueRendererManager: props.propertyValueRendererManager, editingPropertyKey: props.editingPropertyKey, onEditCommit: props.onEditCommit, onEditCancel: props.onEditCancel, isPropertyHoverEnabled: props.isPropertyHoverEnabled, isPropertySelectionEnabled: props.isPropertySelectionEnabled, isPropertyRightClickSelectionEnabled: props.isPropertyRightClickSelectionEnabled, actionButtonRenderers: props.actionButtonRenderers }))))) : undefined,
        props.categorizedRecords.children.length ? (React.createElement("div", { className: "property-categories" }, props.categorizedRecords.children.map((categorizedChildRecords) => (React.createElement(NestedCategoryBlock, Object.assign({}, props, { key: categorizedChildRecords.category.name, categorizedRecords: categorizedChildRecords })))))) : undefined));
}
//# sourceMappingURL=PropertyGrid.js.map