"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyGridCommons = void 0;
const ui_core_1 = require("@bentley/ui-core");
const Links_1 = require("../../common/Links");
/** @internal */
class PropertyGridCommons {
    static getCurrentOrientation(width, preferredOrientation, isOrientationFixed, horizontalOrientationMinWidth) {
        const orientation = preferredOrientation !== null && preferredOrientation !== void 0 ? preferredOrientation : ui_core_1.Orientation.Horizontal;
        if (isOrientationFixed)
            return orientation;
        horizontalOrientationMinWidth = horizontalOrientationMinWidth !== null && horizontalOrientationMinWidth !== void 0 ? horizontalOrientationMinWidth : 300;
        // Switch to Vertical if width too small
        if (width < horizontalOrientationMinWidth)
            return ui_core_1.Orientation.Vertical;
        return orientation;
    }
    /**
     * Helper method to handle link clicks
     * @internal
     */
    static handleLinkClick(text) {
        const linksArray = Links_1.matchLinks(text);
        if (linksArray.length <= 0)
            return;
        const foundLink = linksArray[0];
        // istanbul ignore else
        if (foundLink && foundLink.url) {
            if (foundLink.schema === "mailto:" || foundLink.schema === "pw:")
                location.href = foundLink.url;
            else {
                const windowOpen = window.open(foundLink.url, "_blank");
                if (windowOpen)
                    windowOpen.focus();
            }
        }
    }
    static assignRecordClickHandlers(records, onPropertyLinkClick) {
        records.forEach((record) => {
            if (record.links)
                record.links.onClick = (text) => onPropertyLinkClick(record, text);
            this.assignRecordClickHandlers(record.getChildrenRecords(), onPropertyLinkClick);
        });
    }
}
exports.PropertyGridCommons = PropertyGridCommons;
/**
 * A helper method to get links from string.
 * @internal
 */
PropertyGridCommons.getLinks = (value) => {
    return Links_1.matchLinks(value).map((linkInfo) => {
        return { start: linkInfo.index, end: linkInfo.lastIndex };
    });
};
//# sourceMappingURL=PropertyGridCommons.js.map