"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyGridEventsRelatedPropsSupplier = void 0;
/** @packageDocumentation
 * @module PropertyGrid
 */
require("./PropertyGrid.scss");
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
/** PropertyGridEventsRelatedPropsSupplier React component.
 * @internal
 */
class PropertyGridEventsRelatedPropsSupplier extends React.Component {
    /** @internal */
    constructor(props) {
        super(props);
        this._onPropertyRightClicked = (property, key) => {
            // istanbul ignore else
            if (this._isRightClickSupported())
                this.onEnabledPropertyRightClicked(property, key);
        };
        this._onPropertyClicked = (property, key) => {
            // istanbul ignore else
            if (this._isClickSupported())
                this.onEnabledPropertyLeftClicked(property, key);
        };
        this._onPropertyContextMenu = (property, e) => {
            if (this.props.onPropertyContextMenu) {
                this.props.onPropertyContextMenu({ propertyRecord: property, event: e });
            }
        };
        this._onEditCommit = async (args, category) => {
            // istanbul ignore else
            if (this.props.onPropertyUpdated) {
                await this.props.onPropertyUpdated(args, category);
                this.setState({ editingPropertyKey: undefined });
            }
        };
        this._onEditCancel = () => {
            this.setState({ editingPropertyKey: undefined });
        };
        this.state = {};
    }
    _isClickSupported() {
        return this.props.isPropertySelectionEnabled || this.props.isPropertyEditingEnabled;
    }
    _isRightClickSupported() {
        return this.props.isPropertySelectionOnRightClickEnabled;
    }
    onEnabledPropertyRightClicked(property, key) {
        let selectedPropertyKey = this.state.selectedPropertyKey;
        let editingPropertyKey = this.state.editingPropertyKey;
        editingPropertyKey = undefined;
        if (selectedPropertyKey !== key)
            selectedPropertyKey = key;
        if (this.props.onPropertySelectionChanged)
            this.props.onPropertySelectionChanged(property);
        this.setState({ selectedPropertyKey, editingPropertyKey });
    }
    onEnabledPropertyLeftClicked(property, key) {
        let selectedPropertyKey = this.state.selectedPropertyKey;
        let editingPropertyKey = this.state.editingPropertyKey;
        const isValuePrimitive = property.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive;
        const isEditingEnabled = this.props.isPropertyEditingEnabled;
        const isSelectionEnabled = this.props.isPropertySelectionEnabled;
        if (isEditingEnabled && isValuePrimitive) {
            // Deselect editing key only if another selection was made
            editingPropertyKey = isSelectionEnabled && selectedPropertyKey !== key ? undefined : key;
        }
        if (editingPropertyKey === key) {
            this.setState({ editingPropertyKey });
            return;
        }
        // Select/Deselect
        selectedPropertyKey = selectedPropertyKey !== key ? key : undefined;
        if (this.props.onPropertySelectionChanged)
            this.props.onPropertySelectionChanged(property);
        this.setState({ selectedPropertyKey, editingPropertyKey });
    }
    /** @internal */
    render() {
        const renderContext = {
            isPropertyHoverEnabled: this.props.isPropertyHoverEnabled,
            isPropertySelectionEnabled: this.props.isPropertySelectionEnabled,
            isPropertySelectionOnRightClickEnabled: this.props.isPropertySelectionOnRightClickEnabled,
            isPropertyEditingEnabled: this.props.isPropertyEditingEnabled,
            selectedPropertyKey: this.state.selectedPropertyKey,
            editingPropertyKey: this.state.editingPropertyKey,
            onEditCommit: this._onEditCommit,
            onEditCancel: this._onEditCancel,
            onPropertyClicked: this._isClickSupported() ? this._onPropertyClicked : undefined,
            onPropertyRightClicked: this._isRightClickSupported() ? this._onPropertyRightClicked : undefined,
            onPropertyContextMenu: this._onPropertyContextMenu,
        };
        return (React.createElement(React.Fragment, null, this.props.children(renderContext)));
    }
}
exports.PropertyGridEventsRelatedPropsSupplier = PropertyGridEventsRelatedPropsSupplier;
//# sourceMappingURL=PropertyGridEventsRelatedPropsSupplier.js.map