"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyList = exports.getPropertyKey = void 0;
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PropertyRenderer_1 = require("../../properties/renderers/PropertyRenderer");
/**
 * Get unique key for property record
 * @internal
 */
function getPropertyKey(propertyCategory, propertyRecord) {
    return propertyCategory.name + propertyRecord.property.name;
}
exports.getPropertyKey = getPropertyKey;
/** A React component that renders multiple properties within a category as a list.
 * @public
 */
class PropertyList extends React.Component {
    constructor(props) {
        super(props);
        /** @internal */
        this.state = {};
        this._listRef = React.createRef();
        this._onEditCommit = (args) => {
            // istanbul ignore else
            if (this.props.onEditCommit && this.props.category)
                this.props.onEditCommit(args, this.props.category);
        };
    }
    afterRender() {
        if (this.props.orientation !== ui_core_1.Orientation.Horizontal || !this._listRef.current)
            return;
        const width = this._listRef.current.getBoundingClientRect().width;
        if (width !== this.state.width) {
            if (this.props.onListWidthChanged)
                this.props.onListWidthChanged(width);
            this.setState({ width });
        }
    }
    /** @internal */
    componentDidMount() {
        this.afterRender();
    }
    /** @internal */
    componentDidUpdate() {
        this.afterRender();
    }
    /** @internal */
    render() {
        const propertyListClassName = classnames_1.default((this.props.orientation === ui_core_1.Orientation.Horizontal) ? "components-property-list--horizontal" : "components-property-list--vertical", this.props.className);
        return (React.createElement("div", { className: propertyListClassName, style: this.props.style, ref: this._listRef }, this.props.properties.map((propertyRecord) => {
            const key = this.props.category ? getPropertyKey(this.props.category, propertyRecord) : propertyRecord.property.name;
            return (React.createElement(PropertyRenderer_1.PropertyRenderer, { key: key, uniqueKey: key, isHoverable: this.props.isPropertyHoverEnabled, isSelectable: this.props.isPropertySelectionEnabled, isSelected: key === this.props.selectedPropertyKey, propertyRecord: propertyRecord, orientation: this.props.orientation, onClick: propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive ? this.props.onPropertyClicked : undefined, onRightClick: propertyRecord.value.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive ? this.props.onPropertyRightClicked : undefined, onContextMenu: this.props.onPropertyContextMenu, columnRatio: this.props.columnRatio, 
                // eslint-disable-next-line deprecation/deprecation
                onColumnRatioChanged: this.props.onColumnChanged, propertyValueRendererManager: this.props.propertyValueRendererManager, isEditing: key === this.props.editingPropertyKey, onEditCommit: this._onEditCommit, onEditCancel: this.props.onEditCancel, width: this.state.width, actionButtonRenderers: this.props.actionButtonRenderers, isResizeHandleHovered: this.props.isResizeHandleHovered, onResizeHandleHoverChanged: this.props.onResizeHandleHoverChanged, isResizeHandleBeingDragged: this.props.isResizeHandleBeingDragged, onResizeHandleDragChanged: this.props.onResizeHandleDragChanged, columnInfo: this.props.columnInfo }));
        })));
    }
}
exports.PropertyList = PropertyList;
//# sourceMappingURL=PropertyList.js.map