"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VirtualizedPropertyGridWithDataProvider = void 0;
/** @packageDocumentation
 * @module PropertyGrid
 */
const react_1 = __importDefault(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const DelayedSpinner_1 = require("../../common/DelayedSpinner");
const PropertyGridHooks_1 = require("../internal/PropertyGridHooks");
const VirtualizedPropertyGrid_1 = require("./VirtualizedPropertyGrid");
/**
 * VirtualizedPropertyGrid React Component which takes dataProvider and
 * sets up default implementations for IPropertyGridModelSource nad IPropertyGridEventHandler
 * @beta
 */
function VirtualizedPropertyGridWithDataProvider(props) {
    // eslint-disable-next-line deprecation/deprecation
    const modelSource = PropertyGridHooks_1.usePropertyGridModelSource({ dataProvider: props.dataProvider, onPropertyLinkClick: props.onPropertyLinkClick });
    const model = PropertyGridHooks_1.usePropertyGridModel({ modelSource });
    const eventHandler = PropertyGridHooks_1.usePropertyGridEventHandler({ modelSource });
    if (!model) {
        return (react_1.default.createElement("div", { className: "components-virtualized-property-grid-loader" },
            react_1.default.createElement(DelayedSpinner_1.DelayedSpinner, { size: ui_core_1.SpinnerSize.Large })));
    }
    return (react_1.default.createElement(VirtualizedPropertyGrid_1.VirtualizedPropertyGrid, Object.assign({}, props, { model: model, eventHandler: eventHandler })));
}
exports.VirtualizedPropertyGridWithDataProvider = VirtualizedPropertyGridWithDataProvider;
//# sourceMappingURL=VirtualizedPropertyGridWithDataProvider.js.map