/** @packageDocumentation
 * @module PropertyGrid
 */
import { IDisposable } from "@bentley/bentleyjs-core";
import { HighlightInfo } from "../../common/HighlightingComponentProps";
import { IPropertyDataProvider, PropertyData, PropertyDataChangeEvent } from "../PropertyDataProvider";
import { FilteredType, IPropertyDataFilterer } from "./filterers/PropertyDataFiltererBase";
/**
 *  Data returned by [[FilteringPropertyDataProvider]]
 * @beta
 */
export interface FilteredPropertyData extends PropertyData {
    matchesCount?: number;
    getMatchByIndex?: (index: number) => HighlightInfo | undefined;
    filteredTypes?: FilteredType[];
}
/**
 * IPropertyDataProvider implementation which will filter wrapped provider PropertyData using passed IPropertyDataFilterer.
 * @beta
 */
export declare class FilteringPropertyDataProvider implements IPropertyDataProvider, IDisposable {
    private _dataProvider;
    private _filterer;
    onDataChanged: PropertyDataChangeEvent;
    private _filteredPropertyData;
    private _disposeFilterChangedListener;
    private _disposeDataChangedListener;
    constructor(_dataProvider: IPropertyDataProvider, _filterer: IPropertyDataFilterer);
    dispose(): void;
    getData(): Promise<FilteredPropertyData>;
    private filterPropertyData;
}
//# sourceMappingURL=FilteringDataProvider.d.ts.map