"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DisplayValuePropertyDataFilterer = void 0;
const ui_abstract_1 = require("@bentley/ui-abstract");
const countMatchesInString_1 = require("../../../common/countMatchesInString");
const PropertyDataFiltererBase_1 = require("./PropertyDataFiltererBase");
/**
 * Property data filterer which matches on Primitive Property Record display value text.
 * @beta
 */
class DisplayValuePropertyDataFilterer extends PropertyDataFiltererBase_1.PropertyRecordDataFiltererBase {
    constructor(filterText = "") {
        super();
        this._filterText = "";
        this._filterText = filterText;
    }
    get filterText() { return this._filterText; }
    set filterText(value) {
        const lowerValue = value.toLowerCase().trim();
        if (lowerValue !== this.filterText) {
            this._filterText = lowerValue;
            this.onFilterChanged.raiseEvent();
        }
    }
    get isActive() { return this.filterText !== ""; }
    async recordMatchesFilter(node) {
        var _a, _b;
        if (!this.isActive)
            return { matchesFilter: true };
        if (node.value.valueFormat !== ui_abstract_1.PropertyValueFormat.Primitive)
            return { matchesFilter: false };
        const displayValue = (_b = (_a = node.value.displayValue) === null || _a === void 0 ? void 0 : _a.toLowerCase()) !== null && _b !== void 0 ? _b : "";
        const matchesCount = countMatchesInString_1.countMatchesInString(displayValue, this.filterText);
        if (matchesCount === 0)
            return { matchesFilter: false };
        return {
            matchesFilter: true,
            shouldExpandNodeParents: true,
            matchesCount,
            filteredTypes: [PropertyDataFiltererBase_1.FilteredType.Value],
        };
    }
}
exports.DisplayValuePropertyDataFilterer = DisplayValuePropertyDataFilterer;
//# sourceMappingURL=DisplayValuePropertyDataFilterer.js.map