"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LabelPropertyDataFilterer = void 0;
const countMatchesInString_1 = require("../../../common/countMatchesInString");
const PropertyDataFiltererBase_1 = require("./PropertyDataFiltererBase");
/**
 * PropertyData filter which matches on any record type label and includes descendant nodes on match
 * @beta
 */
class LabelPropertyDataFilterer extends PropertyDataFiltererBase_1.PropertyRecordDataFiltererBase {
    constructor(filterText = "") {
        super();
        this._filterText = "";
        this._filterText = filterText;
    }
    get filterText() { return this._filterText; }
    set filterText(value) {
        const lowerValue = value.toLowerCase().trim();
        if (lowerValue !== this.filterText) {
            this._filterText = lowerValue;
            this.onFilterChanged.raiseEvent();
        }
    }
    get isActive() { return this.filterText !== ""; }
    async recordMatchesFilter(node) {
        if (!this.isActive)
            return { matchesFilter: true };
        const displayLabel = node.property.displayLabel.toLowerCase();
        const matchesCount = countMatchesInString_1.countMatchesInString(displayLabel, this.filterText);
        if (matchesCount === 0)
            return { matchesFilter: false };
        return {
            matchesFilter: true,
            shouldExpandNodeParents: true,
            shouldForceIncludeDescendants: true,
            matchesCount,
            filteredTypes: [PropertyDataFiltererBase_1.FilteredType.Label],
        };
    }
}
exports.LabelPropertyDataFilterer = LabelPropertyDataFilterer;
//# sourceMappingURL=LabelPropertyDataFilterer.js.map