"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyRecordDataFiltererBase = exports.PropertyCategoryDataFiltererBase = exports.PropertyDataFiltererBase = exports.PropertyFilterChangeEvent = exports.FilteredType = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
/**
 * Enumeration of possible component filtered types
 * @beta
 */
var FilteredType;
(function (FilteredType) {
    FilteredType[FilteredType["Category"] = 0] = "Category";
    FilteredType[FilteredType["Label"] = 1] = "Label";
    FilteredType[FilteredType["Value"] = 2] = "Value";
})(FilteredType = exports.FilteredType || (exports.FilteredType = {}));
/**
 * An event broadcasted when property filter changes
 * @beta
 */
class PropertyFilterChangeEvent extends bentleyjs_core_1.BeEvent {
}
exports.PropertyFilterChangeEvent = PropertyFilterChangeEvent;
/**
 * PropertyDataFilter base which helps implement common logic between all IPropertyDataFilterer
 * @beta
 */
class PropertyDataFiltererBase {
    constructor() {
        this.onFilterChanged = new PropertyFilterChangeEvent();
    }
}
exports.PropertyDataFiltererBase = PropertyDataFiltererBase;
/**
 * PropertyDataFilter base which is suited for only Category filtering
 * @beta
 */
class PropertyCategoryDataFiltererBase extends PropertyDataFiltererBase {
    async recordMatchesFilter() {
        return { matchesFilter: !this.isActive };
    }
}
exports.PropertyCategoryDataFiltererBase = PropertyCategoryDataFiltererBase;
/**
 * PropertyDataFilter base which is suited for only Record filtering
 * @beta
 */
class PropertyRecordDataFiltererBase extends PropertyDataFiltererBase {
    async categoryMatchesFilter() {
        return { matchesFilter: !this.isActive };
    }
}
exports.PropertyRecordDataFiltererBase = PropertyRecordDataFiltererBase;
//# sourceMappingURL=PropertyDataFiltererBase.js.map