/** @packageDocumentation
 * @module PropertyGrid
 */
import { PropertyRecord } from "@bentley/ui-abstract";
import { IPropertyDataProvider } from "../PropertyDataProvider";
import { PropertyGridEventHandler } from "./PropertyGridEventHandler";
import { IPropertyGridModel } from "./PropertyGridModel";
import { IPropertyGridModelSource, PropertyGridModelSource } from "./PropertyGridModelSource";
/**
 * Custom hook that gets propertyData from data provider and subscribes to further data changes.
 * Returned property data has links.onClick replaced by passed onPropertyLinkClick or default implementation
 * @beta
 */
export declare function usePropertyData(props: {
    dataProvider: IPropertyDataProvider;
    onPropertyLinkClick?: (property: PropertyRecord, text: string) => void;
}): {
    value: import("../PropertyDataProvider").PropertyData | undefined;
    inProgress: boolean;
};
/**
 * Custom hook that creates a PropertyGridModelSource and subscribes it to data updates from the data provider.
 * @beta
 */
export declare function usePropertyGridModelSource(props: {
    dataProvider: IPropertyDataProvider;
    onPropertyLinkClick?: (property: PropertyRecord, text: string) => void;
}): PropertyGridModelSource;
/**
 * Custom hook that creates memoized version of PropertyGridEventHandler that modifies given modelSource
 * @beta
 */
export declare function usePropertyGridEventHandler(props: {
    modelSource: IPropertyGridModelSource;
}): PropertyGridEventHandler;
/**
 * Custom hook that automatically listens and retrieves latest model from model source
 * @beta
 */
export declare function usePropertyGridModel(props: {
    modelSource: IPropertyGridModelSource;
}): IPropertyGridModel | undefined;
//# sourceMappingURL=PropertyGridHooks.d.ts.map