"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.MutableCategorizedArrayProperty = void 0;
const MutableFlatGridItem_1 = require("./MutableFlatGridItem");
/**
 * Mutable wrapper object for PropertyRecord with array valueFormat which provides methods for working with and managing record children hierarchies.
 * @beta
 */
class MutableCategorizedArrayProperty extends MutableFlatGridItem_1.MutableCategorizedProperty {
    constructor(record, parentSelectionKey, parentCategorySelectionKey, depth, gridItemFactory, overrideName, overrideDisplayLabel) {
        super(MutableFlatGridItem_1.FlatGridItemType.Array, record, parentSelectionKey, parentCategorySelectionKey, depth, overrideName, overrideDisplayLabel);
        this._renderLabel = !record.property.hideCompositePropertyLabel;
        const childrenDepth = depth + (this._renderLabel ? 1 : 0);
        this._children = record.getChildrenRecords().map((child, index) => {
            const newName = `${child.property.name}_${index}`;
            const newDisplayLabel = `[${index + 1}]`;
            return gridItemFactory.createCategorizedProperty(child, this.selectionKey, parentCategorySelectionKey, childrenDepth, newName, newDisplayLabel);
        });
    }
    get type() {
        return MutableFlatGridItem_1.FlatGridItemType.Array;
    }
    getChildren() {
        return this._children;
    }
    getDescendantsAndSelf() {
        return this._renderLabel ? super.getDescendantsAndSelf() : this.getDescendants();
    }
    getVisibleDescendants() {
        const descendants = [];
        if (this.isExpanded || !this._renderLabel) {
            // always render children if not rendering the label, otherwise there's no way to expand
            // this item to make children visible
            this.getChildren().forEach((child) => descendants.push(...child.getVisibleDescendantsAndSelf()));
        }
        return descendants;
    }
    getVisibleDescendantsAndSelf() {
        return this._renderLabel ? super.getVisibleDescendantsAndSelf() : this.getVisibleDescendants();
    }
}
exports.MutableCategorizedArrayProperty = MutableCategorizedArrayProperty;
//# sourceMappingURL=MutableCategorizedArrayProperty.js.map