"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MutableCustomGridCategory = void 0;
const MutableFlatGridItem_1 = require("./MutableFlatGridItem");
/** @internal */
class MutableCustomGridCategory extends MutableFlatGridItem_1.MutableFlatPropertyGridItem {
    constructor(category, recordsDict, gridItemFactory, parentSelectionKey, depth) {
        var _a;
        super(depth, parentSelectionKey, parentSelectionKey);
        this.type = MutableFlatGridItem_1.FlatGridItemType.Category;
        this.name = category.name;
        this.label = category.label;
        this.isExpanded = category.expand;
        this.selectionKey = parentSelectionKey === undefined ? this.name : `${parentSelectionKey}_${this.name}`;
        this._renderer = category.renderer;
        // Even though categories are nested and have their own depth, categorized properties depth is counted starting with
        // the parent category.
        const categoryRecords = (_a = recordsDict[category.name]) !== null && _a !== void 0 ? _a : [];
        this._children = categoryRecords.map((value) => gridItemFactory.createCategorizedProperty(value, this.selectionKey, this.selectionKey, 0));
        this.lastInNumberOfCategories = -1;
    }
    get derivedCategory() {
        return {
            name: this.name,
            label: this.label,
            expand: this.isExpanded,
            renderer: this._renderer,
        };
    }
    get isRootCategory() {
        return this.depth === 0;
    }
    get lastInNumberOfCategories() {
        return this._lastInNumberOfCategories;
    }
    set lastInNumberOfCategories(value) {
        this._lastInNumberOfCategories = value + 2;
    }
    getSelf() {
        return this;
    }
    getChildCategories() {
        return [];
    }
    getDescendantCategoriesAndSelf() {
        return [this];
    }
    getChildren() {
        return this._children;
    }
    getVisibleDescendantsAndSelf() {
        return [this];
    }
}
exports.MutableCustomGridCategory = MutableCustomGridCategory;
//# sourceMappingURL=MutableCustomGridCategory.js.map