/** @packageDocumentation
 * @module PropertyGrid
 */
import { PropertyRecord } from "@bentley/ui-abstract";
import { PropertyCategory } from "../../PropertyDataProvider";
import { FlatGridItemType, IMutableFlatGridItem, IMutableGridCategoryItem, MutableFlatPropertyGridItem } from "./MutableFlatGridItem";
import { IMutableGridItemFactory } from "./MutableGridItemFactory";
/**
 * Category name to PropertyRecord[] key pair interface used to describe which records belong to which category.
 * @beta
 */
export interface CategoryRecordsDict {
    [categoryName: string]: PropertyRecord[];
}
/**
 * Mutable wrapper object for PropertyCategory which provides methods for working with and managing category and record children hierarchies
 * @beta
 */
export declare class MutableGridCategory extends MutableFlatPropertyGridItem implements IMutableGridCategoryItem {
    private _children;
    private _childCategories;
    private _selectionKey;
    private _category;
    constructor(category: PropertyCategory, recordsDict: CategoryRecordsDict, gridItemFactory: IMutableGridItemFactory, parentSelectionKey?: string, depth?: number);
    /**
     * Category is considered to be root category if its depth is 0
     */
    get isRootCategory(): boolean;
    get selectionKey(): string;
    get type(): FlatGridItemType.Category;
    get name(): string;
    get label(): string;
    get derivedCategory(): PropertyCategory;
    getSelf(): this;
    getChildren(): IMutableFlatGridItem[];
    getChildCategories(): IMutableGridCategoryItem[];
    /**
     * Gets a flat list of all categories beneath this category and itself in depth first visiting order.
     */
    getDescendantCategoriesAndSelf(): IMutableGridCategoryItem[];
    /**
     * Gets and Sets lastInNumberOfCategories.
     * Setter increments set value by one to account self as category.
     * New value is sent down to this items last child
     * @internal
     */
    get lastInNumberOfCategories(): number;
    set lastInNumberOfCategories(value: number);
}
//# sourceMappingURL=MutableGridCategory.d.ts.map