/** @packageDocumentation
 * @module PropertyGrid
 */
import * as React from "react";
import { HighlightingComponentProps } from "../../../common/HighlightingComponentProps";
import { PropertyUpdatedArgs } from "../../../editors/EditorContainer";
import { SharedRendererProps } from "../../../properties/renderers/PropertyRenderer";
import { PropertyValueRendererManager } from "../../../properties/ValueRendererManager";
import { PropertyCategory } from "../../PropertyDataProvider";
/** Properties of [[FlatPropertyRenderer]] React component
 * @internal
 */
export interface FlatPropertyRendererProps extends SharedRendererProps {
    category?: PropertyCategory;
    /** Custom value renderer */
    propertyValueRendererManager?: PropertyValueRendererManager;
    /** Multiplier of how much the property is indented to the right */
    indentation?: number;
    /** Indicates property is being edited @beta */
    isEditing?: boolean;
    /** Called when property edit is committed. @beta */
    onEditCommit?: (args: PropertyUpdatedArgs, category: PropertyCategory) => void;
    /** Called when property edit is cancelled. @beta */
    onEditCancel?: () => void;
    /** Whether property value is displayed in expanded state. */
    isExpanded: boolean;
    /** Called when toggling between expanded and collapsed property value display state. */
    onExpansionToggled: () => void;
    /** Reports property height changes. */
    onHeightChanged?: (newHeight: number) => void;
    highlight?: HighlightingComponentProps & {
        applyOnLabel: boolean;
        applyOnValue: boolean;
    };
    children?: never;
}
/**  A React component that renders flat properties
 * @internal
 */
export declare const FlatPropertyRenderer: React.FC<FlatPropertyRendererProps>;
//# sourceMappingURL=FlatPropertyRenderer.d.ts.map