"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PropertyGrid
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FlatPropertyRenderer = void 0;
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const EditorContainer_1 = require("../../../editors/EditorContainer");
const CommonPropertyRenderer_1 = require("../../../properties/renderers/CommonPropertyRenderer");
const PrimitivePropertyRenderer_1 = require("../../../properties/renderers/PrimitivePropertyRenderer");
const FlatNonPrimitivePropertyRenderer_1 = require("./FlatNonPrimitivePropertyRenderer");
/**  A React component that renders flat properties
 * @internal
 */
const FlatPropertyRenderer = (props) => {
    const { category, propertyValueRendererManager, isEditing, onEditCommit, onEditCancel, onHeightChanged, highlight } = props, passthroughProps = __rest(props, ["category", "propertyValueRendererManager", "isEditing", "onEditCommit", "onEditCancel", "onHeightChanged", "highlight"]);
    const valueElementRenderer = () => (React.createElement(DisplayValue, { propertyRecord: passthroughProps.propertyRecord, orientation: passthroughProps.orientation, columnRatio: passthroughProps.columnRatio, width: passthroughProps.width, category: category, propertyValueRendererManager: propertyValueRendererManager, isEditing: isEditing, onEditCommit: onEditCommit, onEditCancel: onEditCancel, isExpanded: passthroughProps.isExpanded, onExpansionToggled: passthroughProps.onExpansionToggled, onHeightChanged: onHeightChanged, highlight: highlight }));
    const primitiveRendererProps = Object.assign(Object.assign({}, passthroughProps), { valueElementRenderer, indentation: props.indentation });
    switch (props.propertyRecord.value.valueFormat) {
        case ui_abstract_1.PropertyValueFormat.Primitive:
            return (React.createElement(PrimitivePropertyRenderer_1.PrimitivePropertyRenderer, Object.assign({ highlight: (highlight === null || highlight === void 0 ? void 0 : highlight.applyOnLabel) ? highlight : undefined }, primitiveRendererProps)));
        case ui_abstract_1.PropertyValueFormat.Array:
            // If array is empty, render it as a primitive property
            if (props.propertyRecord.value.items.length === 0)
                return (React.createElement(PrimitivePropertyRenderer_1.PrimitivePropertyRenderer, Object.assign({ highlight: (highlight === null || highlight === void 0 ? void 0 : highlight.applyOnLabel) ? highlight : undefined }, primitiveRendererProps)));
        // eslint-disable-next-line no-fallthrough
        case ui_abstract_1.PropertyValueFormat.Struct:
            return (React.createElement(FlatNonPrimitivePropertyRenderer_1.FlatNonPrimitivePropertyRenderer, Object.assign({ isExpanded: props.isExpanded, onExpandToggled: props.onExpansionToggled }, primitiveRendererProps)));
    }
};
exports.FlatPropertyRenderer = FlatPropertyRenderer;
const DisplayValue = (props) => {
    var _a;
    useResetHeightOnEdit(props.isEditing, props.onHeightChanged);
    if (props.isEditing) {
        const _onEditCommit = (args) => {
            var _a;
            /* istanbul ignore else */
            if (props.category)
                (_a = props.onEditCommit) === null || _a === void 0 ? void 0 : _a.call(props, args, props.category);
        };
        return (React.createElement(EditorContainer_1.EditorContainer, { propertyRecord: props.propertyRecord, onCommit: _onEditCommit, onCancel: (_a = props.onEditCancel) !== null && _a !== void 0 ? _a : ( /* istanbul ignore next */() => { }), setFocus: true }));
    }
    return (React.createElement(React.Fragment, null, CommonPropertyRenderer_1.CommonPropertyRenderer.createNewDisplayValue(props.orientation, props.propertyRecord, props.indentation, props.propertyValueRendererManager, props.isExpanded, props.onExpansionToggled, props.onHeightChanged, props.highlight)));
};
function useResetHeightOnEdit(isEditing, onHeightChanged) {
    const previousEditingStatusRef = React.useRef(isEditing);
    React.useEffect(() => {
        if (!previousEditingStatusRef.current && isEditing) {
            onHeightChanged === null || onHeightChanged === void 0 ? void 0 : onHeightChanged(27);
        }
        previousEditingStatusRef.current = isEditing;
    });
}
//# sourceMappingURL=FlatPropertyRenderer.js.map