"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormatPanel = void 0;
require("./FormatPanel.scss");
const React = __importStar(require("react"));
const imodeljs_quantity_1 = require("@bentley/imodeljs-quantity");
const FormatPrecision_1 = require("./FormatPrecision");
const FormatSample_1 = require("./FormatSample");
const FormatType_1 = require("./FormatType");
const FormatUnitLabel_1 = require("./FormatUnitLabel");
const FormatUnits_1 = require("./FormatUnits");
const MiscFormatOptions_1 = require("./MiscFormatOptions");
async function generateFormatSpec(formatProps, persistenceUnit, unitsProvider) {
    const actualFormat = await imodeljs_quantity_1.Format.createFromJSON("custom", unitsProvider, formatProps);
    return imodeljs_quantity_1.FormatterSpec.create(actualFormat.name, actualFormat, unitsProvider, persistenceUnit);
}
/** Component to show/edit Quantity Format.
 * @alpha
 */
function FormatPanel(props) {
    const [formatSpec, setFormatSpec] = React.useState();
    const { initialFormat, showSample, initialMagnitude, unitsProvider, persistenceUnit, onFormatChange, provideFormatSpec, enableMinimumProperties } = props;
    const [formatProps, setFormatProps] = React.useState(initialFormat);
    const [showOptions, setShowOptions] = React.useState(false);
    React.useEffect(() => {
        setFormatProps(initialFormat);
        setFormatSpec(undefined); // this will trigger the new spec to be created in the useEffect hook
    }, [initialFormat]);
    const handleUserFormatChanges = React.useCallback((newProps) => {
        setFormatProps(newProps);
        setFormatSpec(undefined); // this will trigger the new spec to be created in the useEffect hook
        onFormatChange && onFormatChange(newProps);
    }, [onFormatChange]);
    const isMounted = React.useRef(false);
    // runs returned function only when component is unmounted.
    React.useEffect(() => {
        isMounted.current = true;
        return (() => {
            isMounted.current = false;
        });
    }, []);
    React.useEffect(() => {
        async function fetchFormatSpec() {
            const pu = await persistenceUnit;
            let newFormatSpec;
            if (provideFormatSpec) {
                newFormatSpec = await provideFormatSpec(formatProps, pu, unitsProvider);
            }
            else {
                newFormatSpec = await generateFormatSpec(formatProps, pu, unitsProvider);
            }
            isMounted.current && setFormatSpec(newFormatSpec);
        }
        if (!formatSpec)
            fetchFormatSpec(); // eslint-disable-line @typescript-eslint/no-floating-promises
    }, [formatProps, formatSpec, persistenceUnit, provideFormatSpec, unitsProvider]);
    const handleFormatChange = React.useCallback((newFormatProps) => {
        handleUserFormatChanges(newFormatProps);
    }, [handleUserFormatChanges]);
    const handleShowOptions = React.useCallback((show) => {
        setShowOptions(show);
    }, []);
    return (React.createElement("div", { className: "components-quantityFormat-panel" },
        showSample &&
            React.createElement(FormatSample_1.FormatSample, { formatSpec: formatSpec, initialMagnitude: initialMagnitude }),
        React.createElement(FormatUnits_1.FormatUnits, { unitsProvider: unitsProvider, persistenceUnit: formatSpec === null || formatSpec === void 0 ? void 0 : formatSpec.persistenceUnit, initialFormat: formatProps, onUnitsChange: handleFormatChange }),
        React.createElement(FormatUnitLabel_1.FormatUnitLabel, { formatProps: formatProps, onUnitLabelChange: handleFormatChange }),
        React.createElement(FormatType_1.FormatTypeOption, { formatProps: formatProps, onChange: handleFormatChange }),
        React.createElement(FormatPrecision_1.FormatPrecision, { formatProps: formatProps, onChange: handleFormatChange }),
        props.providePrimaryChildren && props.providePrimaryChildren(formatProps, handleFormatChange),
        React.createElement(MiscFormatOptions_1.MiscFormatOptions, { formatProps: formatProps, onChange: handleFormatChange, enableMinimumProperties: enableMinimumProperties, showOptions: showOptions, onShowHideOptions: handleShowOptions }, props.provideSecondaryChildren && props.provideSecondaryChildren(formatProps, handleFormatChange))));
}
exports.FormatPanel = FormatPanel;
//# sourceMappingURL=FormatPanel.js.map