"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormatSample = void 0;
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../UiComponents");
/** Component to show the persistence value and formatted value given a FormatterSpec.
 * @alpha
 */
function FormatSample(props) {
    const { initialMagnitude, formatSpec, hideLabels } = props;
    const initialValue = initialMagnitude !== null && initialMagnitude !== void 0 ? initialMagnitude : 0;
    const [magnitude, setMagnitude] = React.useState(initialValue);
    const [sampleValue, setSampleValue] = React.useState(initialValue.toString());
    React.useEffect(() => {
        const value = initialMagnitude !== null && initialMagnitude !== void 0 ? initialMagnitude : 0;
        setMagnitude(value);
        setSampleValue(value.toString());
    }, [initialMagnitude]);
    const handleOnValueBlur = React.useCallback(() => {
        let newValue = Number.parseFloat(sampleValue);
        if (Number.isNaN(newValue))
            newValue = 0;
        setMagnitude(newValue);
        setSampleValue(newValue.toString());
    }, [sampleValue]);
    const handleOnValueChange = React.useCallback((event) => {
        setSampleValue(event.target.value);
    }, []);
    const handleKeyDown = React.useCallback((e) => {
        // istanbul ignore else
        if (e.key === ui_abstract_1.SpecialKey.Enter) {
            let newValue = Number.parseFloat(sampleValue);
            if (Number.isNaN(newValue))
                newValue = 0;
            setMagnitude(newValue);
            setSampleValue(newValue.toString());
            e.preventDefault();
        }
    }, [sampleValue]);
    const activePersistenceUnitLabel = formatSpec ? formatSpec.persistenceUnit.label : "";
    const formattedValue = formatSpec ? formatSpec.applyFormatting(magnitude) : "";
    const valueLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.value"));
    const formattedLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.formatted"));
    return (React.createElement(React.Fragment, null,
        !hideLabels && React.createElement("span", { className: "uicore-label" }, valueLabel.current),
        React.createElement("span", { className: "components-inline" },
            React.createElement(ui_core_1.Input, { "data-testid": "format-sample-input", className: "components-quantity-persistence-input", value: sampleValue, onChange: handleOnValueChange, onKeyDown: handleKeyDown, onBlur: handleOnValueBlur }),
            activePersistenceUnitLabel),
        !hideLabels && React.createElement("span", { className: "uicore-label" }, formattedLabel.current),
        React.createElement("span", null,
            hideLabels && (formattedValue.length > 0) && React.createElement(ui_core_1.WebFontIcon, { iconName: "icon-progress-forward-2" }),
            React.createElement("span", { "data-testid": "format-sample-formatted", className: "uicore-label components-quantity-formatted-sample" }, formattedValue))));
}
exports.FormatSample = FormatSample;
//# sourceMappingURL=FormatSample.js.map