"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormatTypeOption = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../UiComponents");
const imodeljs_quantity_1 = require("@bentley/imodeljs-quantity");
/** Component to select the format type.
 * @alpha
 */
function FormatTypeSelector(props) {
    const { type, onChange } = props, otherProps = __rest(props, ["type", "onChange"]);
    const formatOptions = React.useRef([
        { value: imodeljs_quantity_1.FormatType.Decimal, label: UiComponents_1.UiComponents.translate("QuantityFormat.decimal") },
        { value: imodeljs_quantity_1.FormatType.Scientific, label: UiComponents_1.UiComponents.translate("QuantityFormat.scientific") },
        { value: imodeljs_quantity_1.FormatType.Station, label: UiComponents_1.UiComponents.translate("QuantityFormat.station") },
        { value: imodeljs_quantity_1.FormatType.Fractional, label: UiComponents_1.UiComponents.translate("QuantityFormat.fractional") },
    ]);
    const handleOnChange = React.useCallback((e) => {
        e.preventDefault();
        const enumValue = parseInt(e.target.value, 10);
        onChange && onChange(enumValue);
    }, [onChange]);
    return (React.createElement(ui_core_1.Select, Object.assign({ options: formatOptions.current, value: type, onChange: handleOnChange }, otherProps)));
}
/** Component to set the Quantity Format type.
 * @alpha
 */
function FormatTypeOption(props) {
    const { formatProps, onChange } = props;
    const handleFormatTypeChange = React.useCallback((newType) => {
        var _a;
        const type = imodeljs_quantity_1.Format.formatTypeToString(newType);
        let precision;
        let stationOffsetSize;
        let scientificType;
        switch (newType) { // type must be decimal, fractional, scientific, or station
            case imodeljs_quantity_1.FormatType.Scientific:
                precision = imodeljs_quantity_1.DecimalPrecision.Six;
                scientificType = imodeljs_quantity_1.Format.scientificTypeToString(imodeljs_quantity_1.ScientificType.Normalized);
                break;
            case imodeljs_quantity_1.FormatType.Decimal:
                precision = imodeljs_quantity_1.DecimalPrecision.Four;
                break;
            case imodeljs_quantity_1.FormatType.Station:
                precision = imodeljs_quantity_1.DecimalPrecision.Two;
                stationOffsetSize = ((_a = formatProps.composite) === null || _a === void 0 ? void 0 : _a.units[0].name.toLocaleLowerCase().endsWith("m")) ? 3 : 2;
                break;
            case imodeljs_quantity_1.FormatType.Fractional:
                precision = imodeljs_quantity_1.FractionalPrecision.Eight;
                break;
        }
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { type, precision, scientificType, stationOffsetSize });
        onChange && onChange(newFormatProps);
    }, [formatProps, onChange]);
    const formatType = imodeljs_quantity_1.Format.parseFormatType(formatProps.type, "format");
    const label = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.type"));
    return (React.createElement(React.Fragment, null,
        React.createElement("span", { className: "uicore-label.current" }, label.current),
        React.createElement(FormatTypeSelector, { "data-testid": "format-type-selector", type: formatType, onChange: handleFormatTypeChange })));
}
exports.FormatTypeOption = FormatTypeOption;
//# sourceMappingURL=FormatType.js.map