"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormatUnitLabel = void 0;
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const imodeljs_quantity_1 = require("@bentley/imodeljs-quantity");
const UiComponents_1 = require("../UiComponents");
function UomSeparatorSelector(props) {
    const { separator, onChange } = props, otherProps = __rest(props, ["separator", "onChange"]);
    const uomDefaultEntries = React.useRef([
        { value: "", label: UiComponents_1.UiComponents.translate("QuantityFormat.none") },
        { value: " ", label: UiComponents_1.UiComponents.translate("QuantityFormat.space") },
        { value: "-", label: UiComponents_1.UiComponents.translate("QuantityFormat.dash") },
    ]);
    const handleOnChange = React.useCallback((e) => {
        e.preventDefault();
        onChange && onChange(e.target.value);
    }, [onChange]);
    const separatorOptions = React.useMemo(() => {
        const completeListOfEntries = [];
        // istanbul ignore next (only used if format already has a character that does not match standard options)
        if (undefined === uomDefaultEntries.current.find((option) => option.value === separator)) {
            completeListOfEntries.push({ value: separator, label: separator });
        }
        completeListOfEntries.push(...uomDefaultEntries.current);
        return completeListOfEntries;
    }, [separator]);
    return (React.createElement(ui_core_1.Select, Object.assign({ options: separatorOptions, value: separator, onChange: handleOnChange }, otherProps)));
}
/** Component to set the label separator definition in a Quantity Format and if it the label is to be displayed.
 * @alpha
 */
function FormatUnitLabel(props) {
    var _a;
    const { formatProps, onUnitLabelChange } = props;
    const handleSetFormatProps = React.useCallback((newProps) => {
        onUnitLabelChange && onUnitLabelChange(newProps);
    }, [onUnitLabelChange]);
    const isFormatTraitSet = React.useCallback((trait) => {
        return imodeljs_quantity_1.Format.isFormatTraitSetInProps(formatProps, trait);
    }, [formatProps]);
    const setFormatTrait = React.useCallback((trait, setActive) => {
        const traitStr = imodeljs_quantity_1.Format.getTraitString(trait);
        let formatTraits = [traitStr];
        if (setActive) { // setting trait
            // istanbul ignore else
            if (formatProps.formatTraits) {
                const traits = Array.isArray(formatProps.formatTraits) ? formatProps.formatTraits : /* istanbul ignore next */ formatProps.formatTraits.split(/,|;|\|/);
                // istanbul ignore else
                if (!traits.find((traitEntry) => traitStr === traitEntry)) {
                    formatTraits = [...traits, traitStr];
                }
            }
        }
        else { // clearing trait
            // istanbul ignore next
            if (!formatProps.formatTraits)
                return;
            const traits = Array.isArray(formatProps.formatTraits) ? formatProps.formatTraits : /* istanbul ignore next */ formatProps.formatTraits.split(/,|;|\|/);
            formatTraits = traits.filter((traitEntry) => traitEntry !== traitStr);
        }
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { formatTraits });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, handleSetFormatProps]);
    const handleUomSeparatorChange = React.useCallback((newSeparator) => {
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { uomSeparator: newSeparator });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, handleSetFormatProps]);
    const handleShowUnitLabelChange = React.useCallback((e) => {
        setFormatTrait(imodeljs_quantity_1.FormatTraits.ShowUnitLabel, e.target.checked);
    }, [setFormatTrait]);
    const appendUnitLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.appendUnitLabel"));
    const labelSeparator = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.labelSeparator"));
    return (React.createElement(React.Fragment, null,
        React.createElement("span", { className: "uicore-label" }, appendUnitLabel.current),
        React.createElement(ui_core_1.Checkbox, { "data-testid": "show-unit-label-checkbox", checked: isFormatTraitSet(imodeljs_quantity_1.FormatTraits.ShowUnitLabel), onChange: handleShowUnitLabelChange }),
        React.createElement("span", { className: classnames_1.default("uicore-label", !isFormatTraitSet(imodeljs_quantity_1.FormatTraits.ShowUnitLabel) && "uicore-disabled") }, labelSeparator.current),
        React.createElement(UomSeparatorSelector, { "data-testid": "uom-separator-select", separator: (_a = formatProps.uomSeparator) !== null && _a !== void 0 ? _a : "", onChange: handleUomSeparatorChange, disabled: !isFormatTraitSet(imodeljs_quantity_1.FormatTraits.ShowUnitLabel) })));
}
exports.FormatUnitLabel = FormatUnitLabel;
//# sourceMappingURL=FormatUnitLabel.js.map