"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormatUnits = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const UnitDescr_1 = require("./misc/UnitDescr");
const UiComponents_1 = require("../UiComponents");
/** Component to show/edit Units used for Quantity Formatting.
 * @alpha
 */
function FormatUnits(props) {
    var _a, _b, _c;
    const { initialFormat, persistenceUnit, unitsProvider, onUnitsChange } = props;
    const initialFormatRef = React.useRef(initialFormat);
    const [formatProps, setFormatProps] = React.useState(initialFormat);
    React.useEffect(() => {
        if (initialFormatRef.current !== initialFormat) {
            initialFormatRef.current = initialFormat;
            setFormatProps(initialFormat);
        }
    }, [initialFormat]);
    const handleSetFormatProps = React.useCallback((newProps) => {
        setFormatProps(newProps);
        onUnitsChange && onUnitsChange(newProps);
    }, [onUnitsChange]);
    const handleUnitLabelChange = React.useCallback((newLabel, index) => {
        // istanbul ignore else
        if (formatProps.composite && formatProps.composite.units.length > index && index >= 0) {
            const units = formatProps.composite.units.map((entry, ndx) => {
                // istanbul ignore else
                if (index === ndx)
                    return { name: entry.name, label: newLabel };
                else
                    return entry;
            });
            const composite = Object.assign(Object.assign({}, formatProps.composite), { units });
            const newFormatProps = Object.assign(Object.assign({}, formatProps), { composite });
            handleSetFormatProps(newFormatProps);
        }
    }, [formatProps, handleSetFormatProps]);
    const handleUnitChange = React.useCallback((newUnit, index) => {
        const unitParts = newUnit.split(/:/);
        if (unitParts[0] === "REMOVEUNIT") {
            // istanbul ignore else
            if (formatProps.composite && formatProps.composite.units.length > 1) {
                const units = [...formatProps.composite.units];
                units.pop();
                const composite = Object.assign(Object.assign({}, formatProps.composite), { units });
                const newFormatProps = Object.assign(Object.assign({}, formatProps), { composite });
                handleSetFormatProps(newFormatProps);
            }
        }
        else if (unitParts[0] === "ADDSUBUNIT") {
            const units = formatProps.composite && formatProps.composite.units.length ?
                [...formatProps.composite.units, { name: unitParts[1], label: unitParts[2] }] :
                /* istanbul ignore next*/ [{ name: unitParts[1], label: unitParts[2] }];
            const composite = Object.assign(Object.assign({}, formatProps.composite), { units });
            const newFormatProps = Object.assign(Object.assign({}, formatProps), { composite });
            handleSetFormatProps(newFormatProps);
        }
        else {
            // istanbul ignore else
            if (formatProps.composite && formatProps.composite.units.length > index && index >= 0) {
                const units = formatProps.composite.units.map((entry, ndx) => {
                    // istanbul ignore else
                    if (index === ndx)
                        return { name: unitParts[0], label: unitParts[1] };
                    else
                        return entry;
                });
                const composite = Object.assign(Object.assign({}, formatProps.composite), { units });
                const newFormatProps = Object.assign(Object.assign({}, formatProps), { composite });
                handleSetFormatProps(newFormatProps);
            }
            else if (!formatProps.composite) {
                const composite = { units: [{ name: unitParts[0], label: unitParts[1] }] };
                const newFormatProps = Object.assign(Object.assign({}, formatProps), { composite });
                handleSetFormatProps(newFormatProps);
            }
        }
    }, [formatProps, handleSetFormatProps]);
    const handleOnSpacerChange = React.useCallback((e) => {
        // istanbul ignore else
        if (formatProps.composite) {
            const spacerValue = e.target.value.length ? e.target.value[0] : /* istanbul ignore next */ ""; // spacer can only be empty or a single character
            const composite = Object.assign(Object.assign({}, formatProps.composite), { spacer: spacerValue });
            const newFormatProps = Object.assign(Object.assign({}, formatProps), { composite });
            handleSetFormatProps(newFormatProps);
        }
    }, [formatProps, handleSetFormatProps]);
    const compositeSpacer = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.compositeSpacer"));
    return (React.createElement(React.Fragment, null,
        ((_a = formatProps.composite) === null || _a === void 0 ? void 0 : _a.units)
            ?
                formatProps.composite.units.map((value, index) => {
                    var _a;
                    return React.createElement(UnitDescr_1.UnitDescr, { key: value.name, name: value.name, label: (_a = value.label) !== null && _a !== void 0 ? _a : "", parentUnitName: index > 0 ? formatProps.composite.units[index - 1].name :
                            undefined, unitsProvider: unitsProvider, index: index, onUnitChange: handleUnitChange, onLabelChange: handleUnitLabelChange, readonly: index < (formatProps.composite.units.length - 1) });
                })
            :
                persistenceUnit && React.createElement(UnitDescr_1.UnitDescr, { key: persistenceUnit.name, name: persistenceUnit.name, label: persistenceUnit.label, unitsProvider: unitsProvider, index: 0, onUnitChange: handleUnitChange, onLabelChange: handleUnitLabelChange }),
        (((_b = formatProps.composite) === null || _b === void 0 ? void 0 : _b.units) && formatProps.composite.units.length > 1) &&
            React.createElement(React.Fragment, null,
                React.createElement("span", { key: "composite-spacer-label", className: "uicore-label" }, compositeSpacer.current),
                React.createElement(ui_core_1.Input, { key: "composite-spacer", "data-testid": "composite-spacer", value: (_c = formatProps.composite.spacer) !== null && _c !== void 0 ? _c : "", onChange: handleOnSpacerChange }))));
}
exports.FormatUnits = FormatUnits;
//# sourceMappingURL=FormatUnits.js.map