"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MiscFormatOptions = void 0;
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const imodeljs_quantity_1 = require("@bentley/imodeljs-quantity");
const SignOption_1 = require("./misc/SignOption");
const ThousandsSeparator_1 = require("./misc/ThousandsSeparator");
const DecimalSeparator_1 = require("./misc/DecimalSeparator");
const ScientificType_1 = require("./misc/ScientificType");
const StationSeparatorSelector_1 = require("./misc/StationSeparatorSelector");
const StationSizeSelector_1 = require("./misc/StationSizeSelector");
const UiComponents_1 = require("../UiComponents");
/** Component use to set miscellaneous properties is a Formatted Quantity.
 * @alpha
 */
function MiscFormatOptions(props) {
    var _a, _b;
    const { formatProps, onChange, showOptions, onShowHideOptions, enableMinimumProperties } = props;
    const handleSetFormatProps = React.useCallback((newFormatProps) => {
        onChange && onChange(newFormatProps);
    }, [onChange]);
    const isFormatTraitSet = React.useCallback((trait) => {
        return imodeljs_quantity_1.Format.isFormatTraitSetInProps(formatProps, trait);
    }, [formatProps]);
    const handleShowSignChange = React.useCallback((option) => {
        const newShowSignOption = imodeljs_quantity_1.Format.showSignOptionToString(option);
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { showSignOption: newShowSignOption });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, handleSetFormatProps]);
    const setFormatTrait = React.useCallback((trait, setActive) => {
        const traitStr = imodeljs_quantity_1.Format.getTraitString(trait);
        let formatTraits = [traitStr];
        if (setActive) { // setting trait
            // istanbul ignore else
            if (formatProps.formatTraits) {
                const traits = Array.isArray(formatProps.formatTraits) ? formatProps.formatTraits : /* istanbul ignore next */ formatProps.formatTraits.split(/,|;|\|/);
                // istanbul ignore else
                if (!traits.find((traitEntry) => traitStr === traitEntry)) {
                    formatTraits = [...traits, traitStr];
                }
            }
        }
        else { // clearing trait
            // istanbul ignore next
            if (!formatProps.formatTraits)
                return;
            const traits = Array.isArray(formatProps.formatTraits) ? formatProps.formatTraits : /* istanbul ignore next */ formatProps.formatTraits.split(/,|;|\|/);
            formatTraits = traits.filter((traitEntry) => traitEntry !== traitStr);
        }
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { formatTraits });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, handleSetFormatProps]);
    const handleShowTrailingZeroesChange = React.useCallback((e) => {
        setFormatTrait(imodeljs_quantity_1.FormatTraits.TrailZeroes, e.target.checked);
    }, [setFormatTrait]);
    const handleKeepDecimalPointChange = React.useCallback((e) => {
        setFormatTrait(imodeljs_quantity_1.FormatTraits.KeepDecimalPoint, e.target.checked);
    }, [setFormatTrait]);
    const handleKeepSingleZeroChange = React.useCallback((e) => {
        setFormatTrait(imodeljs_quantity_1.FormatTraits.KeepSingleZero, e.target.checked);
    }, [setFormatTrait]);
    const handleZeroEmptyChange = React.useCallback((e) => {
        setFormatTrait(imodeljs_quantity_1.FormatTraits.ZeroEmpty, e.target.checked);
    }, [setFormatTrait]);
    const handleUseFractionDashChange = React.useCallback((e) => {
        setFormatTrait(imodeljs_quantity_1.FormatTraits.FractionDash, e.target.checked);
    }, [setFormatTrait]);
    const handleDecimalSeparatorChange = React.useCallback((decimalSeparator) => {
        let thousandSeparator = formatProps.thousandSeparator;
        // make sure 1000 and decimal separator do not match
        // istanbul ignore else
        if (isFormatTraitSet(imodeljs_quantity_1.FormatTraits.Use1000Separator)) {
            switch (decimalSeparator) {
                case ".":
                    thousandSeparator = ",";
                    break;
                case ",":
                    thousandSeparator = ".";
                    break;
            }
        }
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { thousandSeparator, decimalSeparator });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, isFormatTraitSet, handleSetFormatProps]);
    const handleScientificTypeChange = React.useCallback((type) => {
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { scientificType: imodeljs_quantity_1.Format.scientificTypeToString(type) });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, handleSetFormatProps]);
    const handleFormatChange = React.useCallback((newFormatProps) => {
        handleSetFormatProps(newFormatProps);
    }, [handleSetFormatProps]);
    const formatType = React.useMemo(() => imodeljs_quantity_1.Format.parseFormatType(formatProps.type, "format"), [formatProps.type]);
    const showSignOption = React.useMemo(() => { var _a; return imodeljs_quantity_1.Format.parseShowSignOption((_a = formatProps.showSignOption) !== null && _a !== void 0 ? _a : "onlyNegative", "format"); }, [formatProps.showSignOption]);
    const handleToggleButtonClick = React.useCallback(() => {
        onShowHideOptions(!showOptions);
    }, [onShowHideOptions, showOptions]);
    const handleKeyUpOnLink = React.useCallback((e) => {
        // istanbul ignore else
        if (e.key === ui_abstract_1.SpecialKey.Enter || e.key === ui_abstract_1.SpecialKey.Space) {
            onShowHideOptions(!showOptions);
            e.preventDefault();
        }
    }, [onShowHideOptions, showOptions]);
    const handleStationSeparatorChange = React.useCallback((value) => {
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { stationSeparator: value });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, handleSetFormatProps]);
    const handleStationOffsetChange = React.useCallback((value) => {
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { stationOffsetSize: value });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, handleSetFormatProps]);
    const signOptionLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.signOptionLabel"));
    const stationOffsetLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.stationOffsetLabel"));
    const stationSeparatorLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.stationSeparatorLabel"));
    const decimalSeparatorLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.decimalSeparatorLabel"));
    const showTrailZerosLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.showTrailZerosLabel"));
    const keepSingleZeroLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.keepSingleZeroLabel"));
    const zeroEmptyLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.zeroEmptyLabel"));
    const moreLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.moreLabel"));
    const lessLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.lessLabel"));
    const keepDecimalPointLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.keepDecimalPointLabel"));
    const fractionDashLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.fractionDashLabel"));
    const scientificTypeLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.scientificTypeLabel"));
    return (React.createElement(React.Fragment, null,
        enableMinimumProperties && !showOptions && React.createElement("a", { onClick: handleToggleButtonClick, onKeyUp: handleKeyUpOnLink, className: "components-quantityFormat-more-less", role: "link", "data-testid": "quantityFormat-more", tabIndex: 0 }, moreLabel.current),
        (!enableMinimumProperties || showOptions) &&
            React.createElement(React.Fragment, null,
                React.createElement("span", { className: "uicore-label" }, signOptionLabel.current),
                React.createElement(SignOption_1.SignOptionSelector, { "data-testid": "sign-option-selector", signOption: showSignOption, onChange: handleShowSignChange }),
                React.createElement("span", { className: classnames_1.default("uicore-label", formatType !== imodeljs_quantity_1.FormatType.Station && "uicore-disabled") }, stationOffsetLabel.current),
                React.createElement(StationSizeSelector_1.StationSizeSelector, { "data-testid": "station-size-selector", value: ((_a = formatProps.stationOffsetSize) !== null && _a !== void 0 ? _a : 2), disabled: formatType !== imodeljs_quantity_1.FormatType.Station, onChange: handleStationOffsetChange }),
                React.createElement("span", { className: classnames_1.default("uicore-label", formatType !== imodeljs_quantity_1.FormatType.Station && "uicore-disabled") }, stationSeparatorLabel.current),
                React.createElement(StationSeparatorSelector_1.StationSeparatorSelector, { "data-testid": "station-separator-selector", separator: (undefined !== formatProps.stationSeparator ? formatProps.stationSeparator : "+"), disabled: formatType !== imodeljs_quantity_1.FormatType.Station, onChange: handleStationSeparatorChange }),
                React.createElement(ThousandsSeparator_1.ThousandsSeparator, { formatProps: formatProps, onChange: handleFormatChange }),
                React.createElement("span", { className: classnames_1.default("uicore-label", formatType === imodeljs_quantity_1.FormatType.Fractional && "uicore-disabled") }, decimalSeparatorLabel.current),
                React.createElement(DecimalSeparator_1.DecimalSeparatorSelector, { "data-testid": "decimal-separator-selector", separator: (_b = formatProps.decimalSeparator) !== null && _b !== void 0 ? _b : ".", onChange: handleDecimalSeparatorChange, disabled: formatType === imodeljs_quantity_1.FormatType.Fractional }),
                React.createElement("span", { className: "uicore-label" }, showTrailZerosLabel.current),
                React.createElement(ui_core_1.Checkbox, { "data-testid": "show-trail-zeros", checked: isFormatTraitSet(imodeljs_quantity_1.FormatTraits.TrailZeroes), onChange: handleShowTrailingZeroesChange }),
                React.createElement("span", { className: classnames_1.default("uicore-label", formatType === imodeljs_quantity_1.FormatType.Fractional && "uicore-disabled") }, keepDecimalPointLabel.current),
                React.createElement(ui_core_1.Checkbox, { "data-testid": "keep-decimal-point", checked: isFormatTraitSet(imodeljs_quantity_1.FormatTraits.KeepDecimalPoint), onChange: handleKeepDecimalPointChange }),
                React.createElement("span", { className: "uicore-label" }, keepSingleZeroLabel.current),
                React.createElement(ui_core_1.Checkbox, { "data-testid": "keep-single-zero", checked: isFormatTraitSet(imodeljs_quantity_1.FormatTraits.KeepSingleZero), onChange: handleKeepSingleZeroChange }),
                React.createElement("span", { className: "uicore-label" }, zeroEmptyLabel.current),
                React.createElement(ui_core_1.Checkbox, { "data-testid": "zero-empty", checked: isFormatTraitSet(imodeljs_quantity_1.FormatTraits.ZeroEmpty), onChange: handleZeroEmptyChange }),
                React.createElement("span", { className: classnames_1.default("uicore-label", formatType !== imodeljs_quantity_1.FormatType.Fractional && "uicore-disabled") }, fractionDashLabel.current),
                React.createElement(ui_core_1.Checkbox, { "data-testid": "fraction-dash", checked: isFormatTraitSet(imodeljs_quantity_1.FormatTraits.FractionDash), onChange: handleUseFractionDashChange, disabled: formatType !== imodeljs_quantity_1.FormatType.Fractional }),
                React.createElement("span", { className: classnames_1.default("uicore-label", formatType !== imodeljs_quantity_1.FormatType.Scientific && "uicore-disabled") }, scientificTypeLabel.current),
                React.createElement(ScientificType_1.ScientificTypeSelector, { "data-testid": "scientific-type-selector", type: (formatProps.scientificType && formatProps.scientificType.length > 0) ? imodeljs_quantity_1.Format.parseScientificType(formatProps.scientificType, "custom") : imodeljs_quantity_1.ScientificType.Normalized, disabled: formatType !== imodeljs_quantity_1.FormatType.Scientific, onChange: handleScientificTypeChange }),
                props.children,
                enableMinimumProperties && showOptions && React.createElement("a", { onClick: handleToggleButtonClick, onKeyUp: handleKeyUpOnLink, className: "components-quantityFormat-more-less", role: "link", "data-testid": "quantityFormat-less", tabIndex: 0 }, lessLabel.current))));
}
exports.MiscFormatOptions = MiscFormatOptions;
//# sourceMappingURL=MiscFormatOptions.js.map