"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QuantityFormatPanel = void 0;
const React = __importStar(require("react"));
const imodeljs_frontend_1 = require("@bentley/imodeljs-frontend");
const ui_core_1 = require("@bentley/ui-core");
const FormatPanel_1 = require("./FormatPanel");
const geometry_core_1 = require("@bentley/geometry-core");
function createTextInputFormatPropEditor(key, label, inProps, getString, setString, fireFormatChange) {
    const value = getString(inProps);
    return (React.createElement(React.Fragment, { key: `${key}` },
        React.createElement("span", { key: `${key}-label`, className: "uicore-label" }, label),
        React.createElement(ui_core_1.Input, { "data-testid": `${key}-editor`, key: `${key}-editor`, value: value, onChange: (e) => {
                const newProps = setString(inProps, e.currentTarget.value);
                fireFormatChange(newProps);
            } })));
}
function createSelectFormatPropEditor(key, label, options, inProps, getString, setString, fireFormatChange) {
    const value = getString(inProps);
    return (React.createElement(React.Fragment, { key: `${key}` },
        React.createElement("span", { key: `${key}-label`, className: "uicore-label" }, label),
        React.createElement(ui_core_1.Select, { "data-testid": `${key}-editor`, key: `${key}-editor`, value: value, options: options, onChange: (e) => {
                const newProps = setString(inProps, e.currentTarget.value);
                fireFormatChange(newProps);
            } })));
}
function createCheckboxFormatPropEditor(key, label, inProps, getBool, setBool, fireFormatChange) {
    const isChecked = getBool(inProps);
    return (React.createElement(React.Fragment, { key: `${key}` },
        React.createElement("span", { key: `${key}-label`, className: "uicore-label" }, label),
        React.createElement(ui_core_1.Checkbox, { "data-testid": `${key}-editor`, key: `${key}-editor`, checked: isChecked, onChange: (e) => {
                const newProps = setBool(inProps, e.target.checked);
                fireFormatChange(newProps);
            } })));
}
function formatAreEqual(obj1, obj2) {
    const compare = new geometry_core_1.DeepCompare();
    return compare.compare(obj1, obj2);
}
/** Component to set properties that control Quantity Formatting.
 * @alpha
 */
function QuantityFormatPanel(props) {
    const { quantityType, onFormatChange } = props, otherProps = __rest(props, ["quantityType", "onFormatChange"]);
    const [formatProps, setFormatProps] = React.useState();
    const initialFormatProps = React.useRef();
    const [persistenceUnit, setPersistenceUnit] = React.useState(() => {
        const quantityTypeKey = imodeljs_frontend_1.getQuantityTypeKey(quantityType);
        const quantityTypeDefinition = imodeljs_frontend_1.IModelApp.quantityFormatter.quantityTypesRegistry.get(quantityTypeKey);
        // istanbul ignore else
        if (quantityTypeDefinition)
            return quantityTypeDefinition.persistenceUnit;
        else
            throw Error(`Unable to locate a quantity type with type ${quantityType}`);
    });
    React.useEffect(() => {
        const newFormatProps = imodeljs_frontend_1.IModelApp.quantityFormatter.getFormatPropsByQuantityType(quantityType);
        // istanbul ignore else
        if (!initialFormatProps.current)
            initialFormatProps.current = newFormatProps;
        setFormatProps(newFormatProps);
    }, [quantityType]); // no dependencies defined as we want this to run on every render
    // handle case where quantityType does not change but the formatProps for that quantity type has (ie after a Set or Clear)
    // eslint-disable-next-line react-hooks/exhaustive-deps
    React.useEffect(() => {
        const newFormatProps = imodeljs_frontend_1.IModelApp.quantityFormatter.getFormatPropsByQuantityType(quantityType);
        // istanbul ignore else
        if (initialFormatProps.current && newFormatProps) {
            if (!formatAreEqual(newFormatProps, initialFormatProps.current)) {
                initialFormatProps.current = newFormatProps;
                setFormatProps(newFormatProps);
            }
        }
    }); // no dependencies defined as we want this to run on every render
    React.useEffect(() => {
        const quantityTypeKey = imodeljs_frontend_1.getQuantityTypeKey(quantityType);
        const quantityTypeDefinition = imodeljs_frontend_1.IModelApp.quantityFormatter.quantityTypesRegistry.get(quantityTypeKey);
        // istanbul ignore else
        if (quantityTypeDefinition)
            setPersistenceUnit(quantityTypeDefinition.persistenceUnit);
    }, [quantityType]);
    const handleOnFormatChanged = React.useCallback(async (newProps) => {
        setFormatProps(newProps);
        onFormatChange && onFormatChange(newProps);
    }, [onFormatChange]);
    const createCustomPropEditors = React.useCallback((specs, inProps, fireFormatChange) => {
        return specs.map((spec, index) => {
            if (imodeljs_frontend_1.isCheckboxFormatPropEditorSpec(spec))
                return createCheckboxFormatPropEditor(`${spec.editorType}-${index}`, spec.label, inProps, spec.getBool, spec.setBool, fireFormatChange);
            if (imodeljs_frontend_1.isTextSelectFormatPropEditorSpec(spec))
                return createSelectFormatPropEditor(`${spec.editorType}-${index}`, spec.label, spec.selectOptions, inProps, spec.getString, spec.setString, fireFormatChange);
            /* istanbul ignore else */
            if (imodeljs_frontend_1.isTextInputFormatPropEditorSpec(spec))
                return createTextInputFormatPropEditor(`${spec.editorType}-${index}`, spec.label, inProps, spec.getString, spec.setString, fireFormatChange);
            /* istanbul ignore next */
            return React.createElement("div", { key: index });
        });
    }, []);
    const providePrimaryChildren = React.useCallback((inProps, fireFormatChange) => {
        const quantityTypeKey = imodeljs_frontend_1.getQuantityTypeKey(quantityType);
        const quantityTypeDefinition = imodeljs_frontend_1.IModelApp.quantityFormatter.quantityTypesRegistry.get(quantityTypeKey);
        if (quantityTypeDefinition && imodeljs_frontend_1.isCustomQuantityTypeDefinition(quantityTypeDefinition) &&
            quantityTypeDefinition.isCompatibleFormatProps(inProps)) {
            // istanbul ignore else
            if (quantityTypeDefinition.primaryPropEditorSpecs)
                return createCustomPropEditors(quantityTypeDefinition.primaryPropEditorSpecs, inProps, fireFormatChange);
        }
        return null;
    }, [createCustomPropEditors, quantityType]);
    const provideSecondaryChildren = React.useCallback((inProps, fireFormatChange) => {
        const quantityTypeKey = imodeljs_frontend_1.getQuantityTypeKey(quantityType);
        const quantityTypeDefinition = imodeljs_frontend_1.IModelApp.quantityFormatter.quantityTypesRegistry.get(quantityTypeKey);
        if (quantityTypeDefinition && imodeljs_frontend_1.isCustomQuantityTypeDefinition(quantityTypeDefinition) &&
            quantityTypeDefinition.isCompatibleFormatProps(inProps)) {
            // istanbul ignore else
            if (quantityTypeDefinition.secondaryPropEditorSpecs)
                return createCustomPropEditors(quantityTypeDefinition.secondaryPropEditorSpecs, inProps, fireFormatChange);
        }
        return null;
    }, [createCustomPropEditors, quantityType]);
    const provideFormatSpec = React.useCallback(async (inProps, _persistenceUnit, _unitsProvider) => {
        return imodeljs_frontend_1.IModelApp.quantityFormatter.generateFormatterSpecByType(quantityType, inProps);
    }, [quantityType]);
    return (React.createElement("div", { className: "components-quantityFormat-quantityPanel" }, persistenceUnit && formatProps &&
        React.createElement(FormatPanel_1.FormatPanel, Object.assign({ onFormatChange: handleOnFormatChanged }, otherProps, { initialFormat: formatProps, unitsProvider: imodeljs_frontend_1.IModelApp.quantityFormatter.unitsProvider, persistenceUnit: persistenceUnit, providePrimaryChildren: providePrimaryChildren, provideSecondaryChildren: provideSecondaryChildren, provideFormatSpec: provideFormatSpec }))));
}
exports.QuantityFormatPanel = QuantityFormatPanel;
//# sourceMappingURL=QuantityFormatPanel.js.map