"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StationSeparatorSelector = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../../UiComponents");
/** Component use to setStation separator.
 * @internal
 */
function StationSeparatorSelector(props) {
    const { separator, disabled, onChange } = props, otherProps = __rest(props, ["separator", "disabled", "onChange"]);
    const uomDefaultEntries = React.useRef([
        { value: "+", label: UiComponents_1.UiComponents.translate("QuantityFormat.station_separator.plus") },
        { value: "-", label: UiComponents_1.UiComponents.translate("QuantityFormat.station_separator.minus") },
        { value: " ", label: UiComponents_1.UiComponents.translate("QuantityFormat.station_separator.blank") },
        { value: "^", label: UiComponents_1.UiComponents.translate("QuantityFormat.station_separator.caret") },
    ]);
    const handleOnChange = React.useCallback((e) => {
        e.preventDefault();
        onChange && onChange(e.target.value);
    }, [onChange]);
    const separatorOptions = React.useMemo(() => {
        const completeListOfEntries = [];
        // istanbul ignore next (only used if format already has a character that does not match standard options)
        if (undefined === uomDefaultEntries.current.find((option) => option.value === separator)) {
            completeListOfEntries.push({ value: separator, label: separator });
        }
        completeListOfEntries.push(...uomDefaultEntries.current);
        return completeListOfEntries;
    }, [separator]);
    return (React.createElement(ui_core_1.Select, Object.assign({ options: separatorOptions, disabled: disabled, value: separator, onChange: handleOnChange }, otherProps)));
}
exports.StationSeparatorSelector = StationSeparatorSelector;
//# sourceMappingURL=StationSeparatorSelector.js.map