"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module QuantityFormat
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThousandsSeparator = void 0;
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const imodeljs_quantity_1 = require("@bentley/imodeljs-quantity");
const ThousandsSelector_1 = require("./ThousandsSelector");
const UiComponents_1 = require("../../UiComponents");
/** Component use to set Quantity Format thousand group separator.
 * @internal
 */
function ThousandsSeparator(props) {
    var _a;
    const { formatProps, onChange } = props;
    const handleSetFormatProps = React.useCallback((newProps) => {
        onChange && onChange(newProps);
    }, [onChange]);
    const setFormatTrait = React.useCallback((trait, setActive) => {
        const traitStr = imodeljs_quantity_1.Format.getTraitString(trait);
        let formatTraits = [traitStr];
        if (setActive) { // setting trait
            // istanbul ignore else
            if (formatProps.formatTraits) {
                const traits = Array.isArray(formatProps.formatTraits) ? formatProps.formatTraits : /* istanbul ignore next */ formatProps.formatTraits.split(/,|;|\|/);
                formatTraits = [...traits, traitStr];
            }
        }
        else { // clearing trait
            // istanbul ignore else
            if (formatProps.formatTraits) {
                const traits = Array.isArray(formatProps.formatTraits) ? formatProps.formatTraits : /* istanbul ignore next */ formatProps.formatTraits.split(/,|;|\|/);
                formatTraits = traits.filter((traitEntry) => traitEntry !== traitStr);
            }
        }
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { formatTraits });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, handleSetFormatProps]);
    const handleUseThousandsSeparatorChange = React.useCallback((e) => {
        setFormatTrait(imodeljs_quantity_1.FormatTraits.Use1000Separator, e.target.checked);
    }, [setFormatTrait]);
    const isFormatTraitSet = React.useCallback((trait) => {
        return imodeljs_quantity_1.Format.isFormatTraitSetInProps(formatProps, trait);
    }, [formatProps]);
    const handleThousandSeparatorChange = React.useCallback((thousandSeparator) => {
        let decimalSeparator = formatProps.decimalSeparator;
        // make sure 1000 and decimal separator do not match
        // istanbul ignore else
        if (isFormatTraitSet(imodeljs_quantity_1.FormatTraits.Use1000Separator)) {
            if (thousandSeparator === ".")
                decimalSeparator = ",";
            else // thousandSeparator === ","
                decimalSeparator = ".";
        }
        const newFormatProps = Object.assign(Object.assign({}, formatProps), { thousandSeparator, decimalSeparator });
        handleSetFormatProps(newFormatProps);
    }, [formatProps, isFormatTraitSet, handleSetFormatProps]);
    const useThousandSeparatorLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.useThousandSeparatorLabel"));
    const thousandSeparatorLabel = React.useRef(UiComponents_1.UiComponents.translate("QuantityFormat.labels.thousandSeparatorLabel"));
    return (React.createElement(React.Fragment, null,
        React.createElement("span", { className: "uicore-label" }, useThousandSeparatorLabel.current),
        React.createElement(ui_core_1.Checkbox, { "data-testid": "use-thousands-separator", checked: isFormatTraitSet(imodeljs_quantity_1.FormatTraits.Use1000Separator), onChange: handleUseThousandsSeparatorChange }),
        React.createElement("span", { className: classnames_1.default("uicore-label", !(isFormatTraitSet(imodeljs_quantity_1.FormatTraits.Use1000Separator)) && "uicore-disabled") }, thousandSeparatorLabel.current),
        React.createElement(ThousandsSelector_1.ThousandsSelector, { "data-testid": "thousands-separator-selector", separator: (_a = formatProps.thousandSeparator) !== null && _a !== void 0 ? _a : ",", disabled: !isFormatTraitSet(imodeljs_quantity_1.FormatTraits.Use1000Separator), onChange: handleThousandSeparatorChange })));
}
exports.ThousandsSeparator = ThousandsSeparator;
//# sourceMappingURL=ThousandsSeparator.js.map