/** @packageDocumentation
 * @module SelectableContent
 */
import "./SelectableContent.scss";
import * as React from "react";
/**
 * A definition for content displayed in [[ControlledSelectableContent]] and
 * [[SelectableContent]] components.
 * @beta
 */
export interface SelectableContentDefinition {
    id: string;
    label: string;
    render: () => React.ReactNode;
}
/**
 * [[ControlledSelectableContent]] component properties
 * @beta
 */
export interface ControlledSelectableContentProps {
    selectedContentId: string;
    onSelectedContentIdChanged?: (contentId: string) => void;
    children: SelectableContentDefinition[];
    selectAriaLabel?: string;
}
/**
 * A fully-controlled component that accepts a list of child components with ids and labels and
 * renders a select box at the top, allowing to choose which of the provided child components
 * should be rendered at the bottom.
 * @beta
 */
export declare function ControlledSelectableContent(props: ControlledSelectableContentProps): JSX.Element;
/**
 * [[SelectableContent]] component properties
 * @beta
 */
export interface SelectableContentProps {
    defaultSelectedContentId: string;
    children: SelectableContentDefinition[];
    selectAriaLabel?: string;
}
/**
 * An uncontrolled component that accepts a list of child components with ids and labels and
 * renders a select box at the top, allowing to choose which of the provided child components
 * should be rendered at the bottom.
 * @beta
 */
export declare function SelectableContent(props: SelectableContentProps): JSX.Element;
//# sourceMappingURL=SelectableContent.d.ts.map