"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module SelectableContent
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SelectableContent = exports.ControlledSelectableContent = void 0;
require("./SelectableContent.scss");
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
/**
 * A fully-controlled component that accepts a list of child components with ids and labels and
 * renders a select box at the top, allowing to choose which of the provided child components
 * should be rendered at the bottom.
 * @beta
 */
function ControlledSelectableContent(props) {
    var _a;
    const { onSelectedContentIdChanged } = props;
    const onContentIdSelected = React.useCallback((value, action) => {
        onSelectedContentIdChanged && action.action === "select-option" && value && onSelectedContentIdChanged(value.value);
    }, [onSelectedContentIdChanged]);
    const selectedContent = (_a = props.children.find((contentDef) => contentDef.id === props.selectedContentId)) !== null && _a !== void 0 ? _a : props.children[0];
    return (React.createElement("div", { className: "components-selectable-content" },
        React.createElement("div", { className: "components-selectable-content-header" },
            React.createElement(ui_core_1.ThemedSelect, { openMenuOnClick: true, openMenuOnFocus: true, isSearchable: false, onChange: onContentIdSelected, className: "components-selectable-content-selector", "aria-label": props.selectAriaLabel, value: { label: selectedContent === null || selectedContent === void 0 ? void 0 : selectedContent.label, value: selectedContent === null || selectedContent === void 0 ? void 0 : selectedContent.id }, options: props.children.map((componentDef) => ({
                    label: componentDef.label,
                    value: componentDef.id,
                })) })),
        React.createElement("div", { className: "components-selectable-content-wrapper" }, selectedContent === null || selectedContent === void 0 ? void 0 : selectedContent.render())));
}
exports.ControlledSelectableContent = ControlledSelectableContent;
/**
 * An uncontrolled component that accepts a list of child components with ids and labels and
 * renders a select box at the top, allowing to choose which of the provided child components
 * should be rendered at the bottom.
 * @beta
 */
function SelectableContent(props) {
    const [selectedContentId, setSelectedContentId] = React.useState(props.defaultSelectedContentId);
    const onSelectedContentIdChanged = React.useCallback((id) => {
        setSelectedContentId(id);
    }, []);
    return (React.createElement(ControlledSelectableContent, { selectedContentId: selectedContentId, onSelectedContentIdChanged: onSelectedContentIdChanged, selectAriaLabel: props.selectAriaLabel }, props.children));
}
exports.SelectableContent = SelectableContent;
//# sourceMappingURL=SelectableContent.js.map