/** @packageDocumentation
 * @module Table
 */
import { SortDirection } from "@bentley/ui-core";
import { CompositeFilterDescriptorCollection, DistinctValueCollection } from "./columnfiltering/ColumnFiltering";
import { ColumnDescription, MutableTableDataProvider, RowItem, TableDataChangeEvent } from "./TableDataProvider";
/**
 * A Table Data Provider using an array of items.
 * @public
 */
export declare class SimpleTableDataProvider implements MutableTableDataProvider {
    private _items;
    private _rowItemIndices;
    private _columns;
    private _secondarySortColumnStack?;
    private _sortDirection;
    private _sortColumnIndex;
    private _filterDescriptors?;
    /** Event emitted by the data provider when column data changes */
    onColumnsChanged: TableDataChangeEvent;
    /** Event emitted by the data provider when row data changes */
    onRowsChanged: TableDataChangeEvent;
    constructor(columns: ColumnDescription[]);
    /** Sets the row items based on an array */
    setItems(items: RowItem[]): void;
    private resetRowIndices;
    /** Retrieves the column descriptions */
    getColumns(): Promise<ColumnDescription[]>;
    /** Retrieves the row count */
    getRowsCount(): Promise<number>;
    /** Retrieves a specific row by index */
    getRow(rowIndex: number, unfiltered?: boolean): Promise<RowItem>;
    private getRowIndexFromFilteredRowIndex;
    /** Sorts the rows based on the value in a specific column */
    sort(columnIndex: number, sortDirection: SortDirection): Promise<void>;
    private sortDispatcher;
    private getPrimitiveValue;
    private sortRows;
    /** Gets distinct values in a column
     * @beta
     */
    getDistinctValues(columnKey: string, maximumValueCount?: number): Promise<DistinctValueCollection>;
    /** Apply a filter descriptor collection
     * @beta
     */
    applyFilterDescriptors(filterDescriptors: CompositeFilterDescriptorCollection): Promise<void>;
    /** Adds a row to the end */
    addRow(rowItem: RowItem): number;
    /** Inserts a row at a given row index */
    insertRow(rowItem: RowItem, index: number): number;
    /** Deletes a row */
    deleteRow(rowItem: RowItem, raiseRowsChangedEvent?: boolean): void;
    /** Moves a row to a new row index */
    moveRow(rowItem: RowItem, newIndex: number): number;
    private findRowIndex;
}
//# sourceMappingURL=SimpleTableDataProvider.d.ts.map