"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.OperatorValueFilterDescriptorCollection = exports.FilterDescriptorCollection = exports.FilterDescriptorCollectionBase = exports.DistinctValueCollection = exports.FilterCompositionLogicalOperator = exports.FilterOperator = void 0;
/** Operator used in FilterDescriptor
 * @public
 */
var FilterOperator;
(function (FilterOperator) {
    // All filterable types
    FilterOperator[FilterOperator["IsEqualTo"] = 0] = "IsEqualTo";
    FilterOperator[FilterOperator["IsNotEqualTo"] = 1] = "IsNotEqualTo";
    // Numeric types, Date, all types that implement these methods
    FilterOperator[FilterOperator["IsLessThan"] = 2] = "IsLessThan";
    FilterOperator[FilterOperator["IsLessThanOrEqualTo"] = 3] = "IsLessThanOrEqualTo";
    FilterOperator[FilterOperator["IsGreaterThan"] = 4] = "IsGreaterThan";
    FilterOperator[FilterOperator["IsGreaterThanOrEqualTo"] = 5] = "IsGreaterThanOrEqualTo";
    FilterOperator[FilterOperator["Range"] = 6] = "Range";
    // Strings
    FilterOperator[FilterOperator["StartsWith"] = 7] = "StartsWith";
    FilterOperator[FilterOperator["EndsWith"] = 8] = "EndsWith";
    FilterOperator[FilterOperator["Contains"] = 9] = "Contains";
    FilterOperator[FilterOperator["DoesNotContain"] = 10] = "DoesNotContain";
    FilterOperator[FilterOperator["IsContainedIn"] = 11] = "IsContainedIn";
    FilterOperator[FilterOperator["IsNotContainedIn"] = 12] = "IsNotContainedIn";
    FilterOperator[FilterOperator["IsEmpty"] = 13] = "IsEmpty";
    FilterOperator[FilterOperator["IsNotEmpty"] = 14] = "IsNotEmpty";
    // All filterable null-able types
    FilterOperator[FilterOperator["IsNull"] = 15] = "IsNull";
    FilterOperator[FilterOperator["IsNotNull"] = 16] = "IsNotNull";
})(FilterOperator = exports.FilterOperator || (exports.FilterOperator = {}));
/** Logical operator used for filter descriptor composition
 * @public
 */
var FilterCompositionLogicalOperator;
(function (FilterCompositionLogicalOperator) {
    FilterCompositionLogicalOperator[FilterCompositionLogicalOperator["And"] = 0] = "And";
    FilterCompositionLogicalOperator[FilterCompositionLogicalOperator["Or"] = 1] = "Or";
})(FilterCompositionLogicalOperator = exports.FilterCompositionLogicalOperator || (exports.FilterCompositionLogicalOperator = {}));
/** A set of distinct values for a column.
 * @public
 */
class DistinctValueCollection {
    constructor() {
        this._values = new Array();
    }
    get values() { return this._values; }
    set values(values) { this._values = values; }
}
exports.DistinctValueCollection = DistinctValueCollection;
/** Collection of filter descriptors.
 * @public
 */
class FilterDescriptorCollectionBase {
    constructor() {
        this._descriptors = new Array();
    }
    get descriptors() { return this._descriptors; }
    /** Adds an FilterDescriptor to the collection.
     * @param item  The FilterDescriptor to add.
     */
    add(item) {
        this.descriptors.push(item);
    }
    /** Removes a particular FilterDescriptor from the collection.
     * @param item  The FilterDescriptor to remove.
     */
    remove(item) {
        const index = this.descriptors.indexOf(item);
        if (index >= 0) {
            this.descriptors.splice(index, 1);
            return true;
        }
        return false;
    }
    /** Clears the collection.
     */
    clear() {
        this.descriptors.splice(0);
    }
    /** Determines if the collection is active.
     */
    get isActive() {
        return this.descriptors.some((fd) => fd.isActive);
    }
    /** Gets the count of items in the collection.
     */
    get count() {
        return this.descriptors.length;
    }
}
exports.FilterDescriptorCollectionBase = FilterDescriptorCollectionBase;
/** Collection of filter descriptors.
 * @public
 */
class FilterDescriptorCollection extends FilterDescriptorCollectionBase {
}
exports.FilterDescriptorCollection = FilterDescriptorCollection;
/** Collection of OperatorValue filter descriptors.
 * @public
 */
class OperatorValueFilterDescriptorCollection extends FilterDescriptorCollectionBase {
}
exports.OperatorValueFilterDescriptorCollection = OperatorValueFilterDescriptorCollection;
//# sourceMappingURL=ColumnFiltering.js.map