"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Table
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColumnFilteringUtilities = void 0;
const ui_abstract_1 = require("@bentley/ui-abstract");
/** Column Filtering utility methods
 * @internal
 */
class ColumnFilteringUtilities {
    static getCell(rowItem, columnKey) {
        return rowItem.cells.find((cellItem) => cellItem.key === columnKey);
    }
    static getValueFromCell(rowItem, columnKey) {
        const cellItem = ColumnFilteringUtilities.getCell(rowItem, columnKey);
        // istanbul ignore next
        if (cellItem === undefined || cellItem.record === undefined)
            return undefined;
        return ColumnFilteringUtilities.getPrimitiveValue(cellItem.record);
    }
    static getPrimitiveValue(record) {
        let primitiveValue;
        const recordValue = record.value;
        // istanbul ignore else
        if (recordValue.valueFormat === ui_abstract_1.PropertyValueFormat.Primitive)
            primitiveValue = recordValue.value;
        return primitiveValue;
    }
}
exports.ColumnFilteringUtilities = ColumnFilteringUtilities;
//# sourceMappingURL=ColumnFilteringUtilities.js.map