/** @packageDocumentation
 * @module Table
 */
import ReactDataGrid = require("react-data-grid");
import { TableColumn } from "../component/TableColumn";
import { ColumnDescription } from "../TableDataProvider";
import { ColumnFilterDescriptor, FilterCompositionLogicalOperator, FilterOperator, TableDistinctValue } from "./ColumnFiltering";
/** @internal */
export interface ReactDataGridFilter extends ReactDataGrid.Filter {
    column: TableColumn;
}
/** ReactDataGrid NumericFilter type
 * @internal
 */
export declare enum NumericFilterType {
    ExactMatch = 1,
    Range = 2,
    GreaterThan = 3,
    LessThan = 4
}
/** NumericFilter data
 * @internal
 */
export interface NumericFilterData {
    type: number;
}
/** Numeric Exact Match data
 * @internal
 */
export interface NumericExactMatchData {
    type: NumericFilterType.ExactMatch;
    value: number;
}
/** Numeric Range data
 * @internal
 */
export interface NumericRangeData {
    type: NumericFilterType.Range;
    begin: number;
    end: number;
}
/** Numeric Greater Than data
 * @internal
 */
export interface NumericGreaterThanData {
    type: NumericFilterType.GreaterThan;
    value: number;
}
/** Numeric Less Than data
 * @internal
 */
export interface NumericLessThanData {
    type: NumericFilterType.LessThan;
    value: number;
}
/** @internal */
export declare type NumericFilterRule = NumericExactMatchData | NumericRangeData | NumericGreaterThanData | NumericLessThanData;
/** @internal */
export interface FieldFilterData {
    fieldValue: any;
    operator: FilterOperator;
    isCaseSensitive?: boolean;
}
/** @internal */
export interface MultiValueFilterData {
    distinctValues: TableDistinctValue[];
    fieldValues: FieldFilterData[];
    fieldLogicalOperator: FilterCompositionLogicalOperator;
}
/** @internal */
export declare const FILTER_PARSER_TIMER_TIMEOUT = 250;
/** ReactDataGrid Filter Parser
 * @internal
 */
export declare class DataGridFilterParser {
    private static _timerTimeout;
    private static _textTimer;
    private static _numericTimer;
    static get timerTimeout(): number;
    static set timerTimeout(v: number);
    static handleFilterChange(filter: ReactDataGridFilter, filterDescriptor: ColumnFilterDescriptor, columnDescription: ColumnDescription, onApplyFilter: () => Promise<void>): Promise<void>;
    private static parseMultiSelect;
    private static parseMultiValue;
    private static parseSingleSelect;
    private static parseNumeric;
    private static parseText;
}
//# sourceMappingURL=DataGridFilterParser.d.ts.map