/** @packageDocumentation
 * @module Table
 */
import { ColumnDescription } from "../TableDataProvider";
import { ColumnFilterDescriptor, DistinctValueCollection, FilterableColumn, FilterableTable, FilterOperator } from "./ColumnFiltering";
import { TableFilterDescriptor } from "./TableFilterDescriptor";
/** Filterable Column base class.
 * @internal
 */
export declare abstract class FilterableColumnBase implements FilterableColumn {
    private _columnDescription;
    private _filterable;
    private _showFieldFilters;
    private _showDistinctValueFilters;
    private _filterCaseSensitive;
    private _filterableTable;
    constructor(filterableTable: FilterableTable, description: ColumnDescription);
    /** Indicates whether column is filterable.
     */
    get filterable(): boolean;
    /** Gets the owning filterable Table.
     */
    get filterableTable(): FilterableTable;
    /** Gets the Column Description.
     */
    get columnDescription(): ColumnDescription;
    /** Gets the column filter descriptor.
     * @return A class implementing IColumnFilterDescriptor.
     */
    get columnFilterDescriptor(): ColumnFilterDescriptor;
    /** Creates the column filter descriptor.
     * @return A new class implementing ColumnFilterDescriptor.
     */
    protected createColumnFilterDescriptor(): ColumnFilterDescriptor;
    /** Creates a basic filter descriptor for use .
     * @return A new FilterDescriptor.
     */
    createSimpleFilterDescriptor(value: any, filterOperator: FilterOperator): TableFilterDescriptor;
    /** Gets the filter member key.
     */
    get filterMemberKey(): string;
    /** Gets the filter member type.
     */
    get filterMemberType(): string;
    /** Determines if a filter is active. */
    get isFilterActive(): boolean;
    /** Determines if the filter should show distinct values as a filter option */
    get showDistinctValueFilters(): boolean;
    /** Determines if the filter should show field filter options */
    get showFieldFilters(): boolean;
    /** Determines if the filter is case-sensitive */
    get filterCaseSensitive(): boolean;
    /** Gets the distinct values for a column.
     * @return The distinct values.
     */
    abstract getDistinctValues(maximumValueCount: number): Promise<DistinctValueCollection>;
}
//# sourceMappingURL=FilterableColumnBase.d.ts.map