/** @packageDocumentation
 * @module Table
 */
import { RowItem } from "../TableDataProvider";
import { ColumnFilterDescriptor, DistinctValuesFilterDescriptor, FieldFilterDescriptor, FilterableColumn } from "./ColumnFiltering";
/** A ColumnFilterDescriptor for TableColumn.
 * @internal
 */
export declare class TableColumnFilterDescriptor implements ColumnFilterDescriptor {
    private _column;
    private _compositeFilter;
    private _distinctFilter;
    private _fieldFilter;
    private _memberKey;
    private _memberType;
    /** Initializes a new instance of the ColumnFilterDescriptor class.
     * @param  column      The column.
     * @param  memberKey   The member (key).
     * @param  memberType  The member type.
     */
    constructor(column: FilterableColumn, memberKey: string, memberType: string);
    /** Gets the distinct values filter descriptor.
     */
    get distinctFilter(): DistinctValuesFilterDescriptor;
    /** Gets the field filter descriptor.
     */
    get fieldFilter(): FieldFilterDescriptor;
    /** Determines if the filter descriptor is active.
     */
    get isActive(): boolean;
    /** Gets the column.
     */
    get column(): FilterableColumn;
    /** Clears the filter descriptor.
     */
    clear(): void;
    /** Evaluates a row for filtering
     */
    evaluateRow(row: RowItem): boolean;
    /** Determines if this filter is for a particular column.
     */
    isFilterForColumn(columnKey: string): boolean;
    getFilterExpression(): string;
    /** Gets the member (key).
     */
    get memberKey(): string;
    /** Sets the member (key).
     */
    set memberKey(value: string);
    /** Gets the member type.
     */
    get memberType(): string;
    /** Sets the member type.
     */
    set memberType(value: string);
}
//# sourceMappingURL=TableColumnFilterDescriptor.d.ts.map