/** @packageDocumentation
 * @module Table
 */
import { RowItem } from "../TableDataProvider";
import { FilterableTable, FilterOperator, OperatorValueFilterDescriptor } from "./ColumnFiltering";
/** Represents a filtering descriptor.
 * @internal
 */
export declare class TableFilterDescriptor implements OperatorValueFilterDescriptor {
    private _filterableTable;
    private _memberKey;
    private _memberType;
    private _typeConverterName?;
    private _operator;
    private _value;
    private _caseSensitive;
    static unsetValue: string;
    /** Initializes a new instance of the FilterDescriptor class.
     * @param filterableTable The owning Table.
     * @param memberKey       The member (key).
     * @param memberType      The Type of the member.
     * @param filterOperator  The filter operator.
     * @param filterValue     The filter value.
     * @param caseSensitive   Indicates that this filter descriptor will be case sensitive.
     * @param typeConverterName The Type of the member.
     *
     */
    constructor(filterableTable: FilterableTable, memberKey: string, memberType: string, filterOperator?: FilterOperator, filterValue?: any, caseSensitive?: boolean, typeConverterName?: string);
    /** Gets the member (key).
     */
    get memberKey(): string;
    /** Sets the member (key).
     */
    set memberKey(value: string);
    /** Gets the member type.
     */
    get memberType(): string;
    /** Sets the member type.
     */
    set memberType(value: string);
    /** Gets the type Converter Name.
     */
    get typeConverterName(): string | undefined;
    /** Sets the member type.
     */
    set typeConverterName(value: string | undefined);
    /** Gets the operator.
     */
    get operator(): FilterOperator;
    /** Sets the operator.
     */
    set operator(operator: FilterOperator);
    /** Gets the value.
     */
    get value(): any;
    /** Sets the value.
     */
    set value(value: any);
    /** Gets whether the filter is case sensitive.
     */
    get isCaseSensitive(): boolean;
    /** Sets whether the filter is case sensitive.
     */
    set isCaseSensitive(caseSensitive: boolean);
    /** Clears the filter descriptor.
     */
    clear(): void;
    /** Determines if the filter descriptor is active.
     */
    get isActive(): boolean;
    /** Evaluates a row for filtering
     */
    evaluateRow(row: RowItem): boolean;
    /** Determines if this filter is for a particular column.
     */
    isFilterForColumn(columnKey: string): boolean;
    private getJulianDaysFromValue;
    private constructComparisonFilterExpression;
    private constructRangeExpression;
    private getEqualsExpression;
    /** Returns filter as ECExpression */
    getFilterExpression(): string;
    private isOperatorUnary;
    private processFilterOperator;
}
//# sourceMappingURL=TableFilterDescriptor.d.ts.map