/** @packageDocumentation
 * @module Table
 */
import { RowItem } from "../TableDataProvider";
import { ColumnFilterDescriptor, CompositeFilterDescriptorCollection, FilterCompositionLogicalOperator, FilterDescriptorCollection } from "./ColumnFiltering";
/** Represents collection of FilterDescriptor objects composed together by a logical operator.
 * @internal
 */
export declare class TableFilterDescriptorCollection extends FilterDescriptorCollection implements CompositeFilterDescriptorCollection {
    private _logicalOperator;
    constructor();
    /** Gets the logical operator.
     */
    get logicalOperator(): FilterCompositionLogicalOperator;
    /** Sets the logical operator.
     */
    set logicalOperator(value: FilterCompositionLogicalOperator);
    /** Gets filter descriptors that will be used for composition.
     */
    get filterDescriptorCollection(): FilterDescriptorCollection;
    /** Evaluates a row for filtering
     */
    evaluateRow(row: RowItem): boolean;
    /** Determines if a filter is active for a particular column
     */
    isColumnFilterActive(columnKey: string): boolean;
    /** Gets the filter for a particular column
     */
    getColumnFilterDescriptor(columnKey: string): ColumnFilterDescriptor | undefined;
    getFilterExpression(): string;
}
//# sourceMappingURL=TableFilterDescriptorCollection.d.ts.map