"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumericFilter = void 0;
/*---------------------------------------------------------------------------------------------
* This code has been adapted from
* [react-data-grid-addons](https://github.com/adazzle/react-data-grid/tree/master/packages/react-data-grid-addons).
*--------------------------------------------------------------------------------------------*/
const react_1 = __importDefault(require("react"));
const UiComponents_1 = require("../../../UiComponents");
const DataGridFilterParser_1 = require("../DataGridFilterParser");
/* istanbul ignore next */
/** @internal */
class NumericFilter extends react_1.default.Component {
    constructor(props) {
        super(props);
        this._tooltipText = UiComponents_1.UiComponents.translate("table.filter.numericTooltip"); // "Input Methods: Range (x-y), Greater Then (>x), Less Then (<y)";
        this._placeholder = UiComponents_1.UiComponents.translate("table.filter.numericPlaceholder"); // "e.g. 3,10-15,>20"
        this._handleKeyPress = (e) => {
            const regex = ">|<|-|,|.|([0-9])";
            const result = RegExp(regex).test(e.key);
            if (result === false) {
                e.preventDefault();
            }
        };
        this._handleChange = (e) => {
            const value = e.target.value;
            const filters = this.getRules(value);
            this.props.onChange({ filterTerm: (filters.length > 0 ? filters : null), column: this.props.column });
        };
    }
    getRules(value) {
        const rules = [];
        if (value === "") {
            return rules;
        }
        // check comma
        const list = value.split(",");
        if (list.length > 0) {
            // handle each value with comma
            list.forEach((obj) => {
                if (obj.indexOf("-") > 0) { // handle dash
                    const begin = parseFloat(obj.split("-")[0]);
                    const end = parseFloat(obj.split("-")[1]);
                    rules.push({ type: DataGridFilterParser_1.NumericFilterType.Range, begin, end });
                }
                else if (obj.indexOf(">") > -1) { // handle greater then
                    const begin = parseFloat(obj.split(">")[1]);
                    rules.push({ type: DataGridFilterParser_1.NumericFilterType.GreaterThan, value: begin });
                }
                else if (obj.indexOf("<") > -1) { // handle less then
                    const end = parseFloat(obj.split("<")[1]);
                    rules.push({ type: DataGridFilterParser_1.NumericFilterType.LessThan, value: end });
                }
                else { // handle normal values
                    const numericValue = parseFloat(obj);
                    rules.push({ type: DataGridFilterParser_1.NumericFilterType.ExactMatch, value: numericValue });
                }
            });
        }
        return rules;
    }
    render() {
        const inputKey = `header-filter-${this.props.column.key}`;
        const columnStyle = {
            float: "left",
            marginRight: 5,
            maxWidth: "80%",
        };
        const badgeStyle = {
            cursor: "help",
        };
        return (react_1.default.createElement("div", null,
            react_1.default.createElement("div", { style: columnStyle },
                react_1.default.createElement("input", { key: inputKey, type: "text", placeholder: this.props.placeholder || this._placeholder, className: "form-control input-sm", onChange: this._handleChange, onKeyPress: this._handleKeyPress })),
            react_1.default.createElement("div", { className: "input-sm" },
                react_1.default.createElement("span", { className: "badge", style: badgeStyle, title: this._tooltipText }, "?"))));
    }
}
exports.NumericFilter = NumericFilter;
//# sourceMappingURL=NumericFilter.js.map