"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Table
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DragDropHeaderCell = exports.DragDropHeaderWrapper = void 0;
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const RDG = __importStar(require("react-data-grid"));
const withDragSource_1 = require("../../dragdrop/withDragSource");
const withDropTarget_1 = require("../../dragdrop/withDropTarget");
const ColumnDragLayer_1 = require("./ColumnDragLayer");
// eslint-disable-next-line @typescript-eslint/naming-convention
const HeaderCell = (RDG && RDG.HeaderCell); // react-data-grid @types does not support the HeaderCell export, but it is exported in the js-only library.
class HeaderWrapper extends React.Component {
    render() {
        const _a = this.props, { type, item, isOver, isDragging, canDrag, canDrop } = _a, props = __rest(_a, ["type", "item", "isOver", "isDragging", "canDrag", "canDrop"]); // eslint-disable-line @typescript-eslint/no-unused-vars
        let mode = 0;
        if (item && item.clientOffset && item.initialClientOffset) {
            // istanbul ignore next
            if (item.clientOffset.x > item.initialClientOffset.x)
                mode = 1;
            else
                mode = -1;
        }
        const classes = classnames_1.default("components-table-header-drag-drop", {
            left: canDrop && !isDragging && isOver && /* istanbul ignore next */ mode === -1,
            right: canDrop && !isDragging && isOver && /* istanbul ignore next */ mode === 1,
            dragging: isDragging,
        }, this.props.className);
        return (React.createElement("div", { className: classes, style: this.props.style },
            React.createElement(HeaderCell, Object.assign({}, props))));
    }
}
/** @internal */
exports.DragDropHeaderWrapper = withDragSource_1.withDragSource(withDropTarget_1.withDropTarget(HeaderWrapper)); // eslint-disable-line deprecation/deprecation
// Used only internally in ./Table.tsx
/** @internal */
class DragDropHeaderCell extends React.Component {
    render() {
        const { column } = this.props;
        /* istanbul ignore next */
        const dropTargetProps = {
            onDropTargetDrop: (args) => {
                const sourceKey = args.dataObject.key || "";
                const sourceXpos = args.dataObject.xpos || 0;
                const targetKey = (column && column.key) || "";
                const targetXpos = (column && column.left) || 0;
                args.dataObject = { sourceKey, targetKey, sourceXpos, targetXpos };
                return args;
            },
            objectTypes: ["Column"],
        };
        const dragSourceProps = {
            onDragSourceBegin: (args) => {
                args.dataObject = {
                    key: (column && column.key) || /* istanbul ignore next */ "",
                    xpos: (column && column.left) || /* istanbul ignore next */ "",
                    column,
                };
                return args;
            },
            onDragSourceEnd: (args) => {
                const { sourceKey, targetKey } = args.dataObject;
                this.props.onHeaderDrop && this.props.onHeaderDrop(sourceKey, targetKey);
            },
            objectType: () => {
                return "Column";
            },
            defaultDragLayer: ColumnDragLayer_1.ColumnDragLayer, // eslint-disable-line deprecation/deprecation
        };
        return (React.createElement(exports.DragDropHeaderWrapper, Object.assign({}, this.props, { dragProps: dragSourceProps, dropProps: dropTargetProps, shallow: false })));
    }
}
exports.DragDropHeaderCell = DragDropHeaderCell;
//# sourceMappingURL=DragDropHeaderCell.js.map