/** @packageDocumentation
 * @module Table
 */
import "./TableCell.scss";
import * as React from "react";
import { CommonProps, Omit } from "@bentley/ui-core";
import { EditorContainerProps } from "../../editors/EditorContainer";
import { PropertyDialogState, PropertyValueRendererManager } from "../../properties/ValueRendererManager";
import { CellItem } from "../TableDataProvider";
/**
 * Properties of the [[TableCell]] React component
 * @public
 */
export interface TableCellProps extends CommonProps {
    /** Additional class name for the cell container */
    className?: string;
    /** Title of the cell container */
    title: string;
    /** Cell content */
    children?: React.ReactNode;
    /** Click event callback */
    onClick?: (e: React.MouseEvent) => void;
    /** MouseMove event callback */
    onMouseMove?: (e: React.MouseEvent) => void;
    /** MouseDown event callback */
    onMouseDown?: (e: React.MouseEvent) => void;
    /** Properties for [[EditorContainer]]. Activates cell editing and provides properties to the container */
    cellEditingProps?: Omit<EditorContainerProps, "title">;
}
/**
 * A React component that renders a table cell
 * @public
 */
export declare class TableCell extends React.PureComponent<TableCellProps> {
    /** @internal */
    render(): JSX.Element;
}
/** Properties of the [[TableCellContent]] React component
 * @public
 */
export interface TableCellContentProps extends CommonProps {
    /** Indicates, whether container cell is selected or not */
    isSelected: boolean;
    /** Props for the item that will be rendered */
    cellItem: CellItem;
    /** Height of the component */
    height?: number;
    /** Callback to DialogOpen event */
    onDialogOpen?: (state: PropertyDialogState) => void;
    /** Property value renderer manager */
    propertyValueRendererManager: PropertyValueRendererManager;
}
/** State of the [[TableCellContent]] React component
 * @internal
 */
interface TableCellContentState {
    /** Rendered content */
    content: React.ReactNode;
}
/** A React component that renders table cell content
 * @public
 */
export declare class TableCellContent extends React.PureComponent<TableCellContentProps, TableCellContentState> {
    /** @internal */
    readonly state: TableCellContentState;
    private _isMounted;
    private getStyle;
    private renderContent;
    private doPropsDiffer;
    /** @internal */
    componentDidMount(): Promise<void>;
    /** @internal */
    componentWillUnmount(): void;
    /** @internal */
    componentDidUpdate(prevProps: TableCellContentProps): Promise<void>;
    /** @internal */
    render(): React.ReactNode;
}
/** Properties for the [[TableIconCellContent]] React component
 * @public
 */
export interface TableIconCellContentProps {
    /** Icon name */
    iconName: string;
}
/**
 * A React component that renders table cell content as a Bentley icon
 * @public
 */
export declare class TableIconCellContent extends React.PureComponent<TableIconCellContentProps> {
    /** @internal */
    render(): JSX.Element;
}
export {};
//# sourceMappingURL=TableCell.d.ts.map