"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Table
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableIconCellContent = exports.TableCellContent = exports.TableCell = void 0;
require("./TableCell.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const EditorContainer_1 = require("../../editors/EditorContainer");
const ItemStyle_1 = require("../../properties/ItemStyle");
const ValueRendererManager_1 = require("../../properties/ValueRendererManager");
/**
 * A React component that renders a table cell
 * @public
 */
class TableCell extends React.PureComponent {
    /** @internal */
    render() {
        if (this.props.cellEditingProps) {
            return (React.createElement("div", { className: classnames_1.default("components-table-cell", this.props.className), style: this.props.style },
                React.createElement(EditorContainer_1.EditorContainer, Object.assign({ title: this.props.title }, this.props.cellEditingProps))));
        }
        return (React.createElement("div", { className: classnames_1.default("components-table-cell", this.props.className), style: this.props.style, title: this.props.title, onClick: this.props.onClick, onMouseMove: this.props.onMouseMove, onMouseDown: this.props.onMouseDown, role: "presentation" }, this.props.children));
    }
}
exports.TableCell = TableCell;
/** A React component that renders table cell content
 * @public
 */
class TableCellContent extends React.PureComponent {
    constructor() {
        super(...arguments);
        /** @internal */
        this.state = {
            content: React.createElement("div", { className: this.props.className, style: this.getStyle(this.props.cellItem, this.props.isSelected, this.props.height) }),
        };
        this._isMounted = false;
    }
    getStyle(cellItem, isSelected, height) {
        return Object.assign(Object.assign(Object.assign({}, ItemStyle_1.ItemStyleProvider.createStyle(cellItem.style ? cellItem.style : {}, isSelected)), { textAlign: cellItem.alignment, height, lineHeight: `${height}px` }), this.props.style);
    }
    async renderContent(props) {
        const style = this.getStyle(props.cellItem, props.isSelected, props.height);
        if (!props.cellItem.record)
            return React.createElement("div", { className: this.props.className, style: style });
        const rendererContext = {
            containerType: ValueRendererManager_1.PropertyContainerType.Table,
            onDialogOpen: this.props.onDialogOpen,
            style,
            // TODO: Enable, when table gets refactored. Explanation in ./../table/NonPrimitiveValueRenderer
            // onPopupShow: this._onPopupShow,
            // onPopupHide: this._onPopupHide,
        };
        return this.props.propertyValueRendererManager.render(props.cellItem.record, rendererContext);
    }
    doPropsDiffer(props1, props2) {
        return props1.cellItem !== props2.cellItem
            || props1.isSelected !== props2.isSelected
            || props1.onDialogOpen !== props2.onDialogOpen
            || props1.propertyValueRendererManager !== props2.propertyValueRendererManager;
    }
    /** @internal */
    async componentDidMount() {
        this._isMounted = true;
        const content = await this.renderContent(this.props);
        // istanbul ignore else
        if (this._isMounted)
            this.setState({ content });
    }
    /** @internal */
    componentWillUnmount() {
        this._isMounted = false;
    }
    /** @internal */
    async componentDidUpdate(prevProps) {
        if (this.doPropsDiffer(prevProps, this.props)) {
            const content = await this.renderContent(this.props);
            if (this._isMounted)
                this.setState({ content });
        }
    }
    /** @internal */
    render() {
        return this.state.content;
    }
}
exports.TableCellContent = TableCellContent;
/**
 * A React component that renders table cell content as a Bentley icon
 * @public
 */
class TableIconCellContent extends React.PureComponent {
    /** @internal */
    render() {
        return React.createElement(ui_core_1.Icon, { iconSpec: this.props.iconName });
    }
}
exports.TableIconCellContent = TableIconCellContent;
//# sourceMappingURL=TableCell.js.map