"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Table
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DragDropRow = exports.DragDropRowWrapper = void 0;
require("./DragDropRow.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const withDragSource_1 = require("../../dragdrop/withDragSource");
const withDropTarget_1 = require("../../dragdrop/withDropTarget");
var HoverMode;
(function (HoverMode) {
    HoverMode[HoverMode["Above"] = 0] = "Above";
    HoverMode[HoverMode["On"] = 1] = "On";
    HoverMode[HoverMode["Below"] = 2] = "Below";
})(HoverMode || (HoverMode = {}));
/** @internal */
class DragDropRowWrapper extends React.Component {
    constructor() {
        super(...arguments);
        this._root = null;
        this.state = {
            hoverMode: HoverMode.Above,
        };
        this._handleDragOver = (event) => {
            if (this.props.isOver && this._root) {
                const rect = this._root.getBoundingClientRect();
                let relativeY = (event.clientY - rect.top) / rect.height;
                // istanbul ignore next
                if (this.props.style !== undefined &&
                    this.props.style.top !== undefined && typeof this.props.style.top === "number" &&
                    this.props.style.height !== undefined && typeof this.props.style.height === "number")
                    relativeY = (event.clientY - this.props.style.top) / this.props.style.height;
                if (this.props.canDropOn) {
                    if (relativeY < 1 / 3) {
                        if (this.state.hoverMode !== HoverMode.Above)
                            this.setState({ hoverMode: HoverMode.Above });
                    }
                    else if (relativeY < 2 / 3) {
                        if (this.state.hoverMode !== HoverMode.On)
                            this.setState({ hoverMode: HoverMode.On });
                    }
                    else {
                        if (this.state.hoverMode !== HoverMode.Below)
                            this.setState({ hoverMode: HoverMode.Below });
                    }
                }
                else {
                    if (relativeY < 1 / 2) {
                        if (this.state.hoverMode !== HoverMode.Above)
                            this.setState({ hoverMode: HoverMode.Above });
                    }
                    else {
                        if (this.state.hoverMode !== HoverMode.Below)
                            this.setState({ hoverMode: HoverMode.Below });
                    }
                }
            }
        };
    }
    render() {
        const { isDragging, isOver, canDrop, children } = this.props;
        const mode = this.state.hoverMode;
        const classes = classnames_1.default("components-table-drop-target", {
            above: canDrop && isOver && mode === HoverMode.Above,
            on: canDrop && isOver && mode === HoverMode.On,
            below: canDrop && isOver && mode === HoverMode.Below,
            dragging: isDragging,
        });
        return (React.createElement("div", { className: classes, "data-testid": "components-table-drop-target", ref: (el) => { this._root = el; }, onDragOver: this._handleDragOver }, children));
    }
    componentDidMount() {
        // istanbul ignore next
        if (this.props.onRender)
            this.props.onRender();
    }
    componentDidUpdate() {
        // istanbul ignore next
        if (this.props.onRender)
            this.props.onRender();
    }
}
exports.DragDropRowWrapper = DragDropRowWrapper;
/** @internal */
function DragDropRow() {
    // Used only internally in ./Table.tsx
    return class DragDropRowComponent extends React.Component {
        createDragProps(index) {
            if (!this.props.dragProps)
                return {};
            const { onDragSourceBegin, onDragSourceEnd, objectType } = this.props.dragProps;
            const dragProps = {
                onDragSourceBegin: (args) => {
                    return onDragSourceBegin ? onDragSourceBegin(args) : args; // Must return something for drag data.
                },
                onDragSourceEnd,
                objectType: () => {
                    // istanbul ignore else
                    if (objectType) {
                        if (typeof objectType === "function")
                            return objectType({ row: index });
                        else
                            return objectType;
                    }
                    else
                        return "";
                },
            };
            return dragProps;
        }
        createDropProps(index) {
            if (!this.props.dropProps)
                return {};
            // eslint-disable-next-line deprecation/deprecation
            const { onDropTargetDrop, onDropTargetOver, canDropTargetDrop, objectTypes, canDropOn } = this.props.dropProps;
            const dropProps = {
                onDropTargetDrop: (args) => {
                    if (index !== undefined) {
                        args.row = index;
                        if (args.dropRect) {
                            const relativeY = (args.clientOffset.y - args.dropRect.top) / args.dropRect.height;
                            if ((canDropOn && relativeY > 2 / 3) || (!canDropOn && relativeY > 1 / 2))
                                args.row = index + 1;
                        }
                    }
                    return onDropTargetDrop ? onDropTargetDrop(args) : args; // Must return something for pass-through to OnDragSourceEnd.
                }, onDropTargetOver: (args) => {
                    // istanbul ignore else
                    if (onDropTargetOver) {
                        if (index !== undefined) {
                            args.row = index;
                            if (args.dropRect) {
                                const relativeY = (args.clientOffset.y - args.dropRect.top) / args.dropRect.height;
                                if ((canDropOn && relativeY > 2 / 3) || (!canDropOn && relativeY > 1 / 2))
                                    args.row = index + 1;
                            }
                        }
                        onDropTargetOver(args);
                    }
                }, canDropTargetDrop: (args) => {
                    if (index !== undefined) {
                        args.row = index;
                    }
                    return canDropTargetDrop ? canDropTargetDrop(args) : true; // Must return something determining if item can drop.
                }, objectTypes,
            };
            return dropProps;
        }
        render() {
            // eslint-disable-next-line @typescript-eslint/naming-convention
            const DDRow = withDropTarget_1.withDropTarget(// eslint-disable-line deprecation/deprecation
            withDragSource_1.withDragSource(DragDropRowWrapper)); // eslint-disable-line deprecation/deprecation
            const _a = this.props, { dragProps, dropProps } = _a, props = __rest(_a, ["dragProps", "dropProps"]); // eslint-disable-line @typescript-eslint/no-unused-vars
            return (React.createElement(DDRow, Object.assign({ canDropOn: (this.props.dropProps && this.props.dropProps.canDropOn) || false }, props, { dropProps: this.createDropProps(this.props.idx), dragProps: this.createDragProps(this.props.idx), shallow: false }), this.props.children));
        }
    };
}
exports.DragDropRow = DragDropRow;
//# sourceMappingURL=DragDropRow.js.map