"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Table
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withTableDragDrop = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const withDropTarget_1 = require("../../dragdrop/withDropTarget");
const Table_1 = require("../component/Table");
const DragDropRow_1 = require("./DragDropRow");
const TableWrapper_1 = require("./TableWrapper");
/**
 * A HOC component that adds drag and drop functionality to the supplied table component.
 * @beta
 * @deprecated
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
function withTableDragDrop(TableComponent) {
    // eslint-disable-next-line @typescript-eslint/naming-convention
    return class WithDragAndDrop extends React.Component {
        constructor() {
            super(...arguments);
            this.renderRow = (item, props) => {
                const baseNode = this.props.renderRow ? /* istanbul ignore next */ this.props.renderRow(item, props) : React.createElement(Table_1.TableRow, Object.assign({ key: item.key }, props));
                const DDRow = DragDropRow_1.DragDropRow(); // eslint-disable-line @typescript-eslint/naming-convention
                return (React.createElement(DDRow, Object.assign({ key: item.key, dragProps: this.createDragProps(item), dropProps: this.createDropProps() }, props), baseNode));
            };
        }
        static get displayName() { return `WithDragAndDrop(${ui_core_1.getDisplayName(TableComponent)})`; }
        createDragProps(item) {
            if (!this.props.dragProps)
                return {};
            const { onDragSourceBegin, onDragSourceEnd, objectType } = this.props.dragProps; // eslint-disable-line deprecation/deprecation
            const dragProps = {
                onDragSourceBegin: (args) => {
                    args.dataObject = item.extendedData;
                    args.parentObject = this.props.dataProvider;
                    return onDragSourceBegin ? onDragSourceBegin(args) : args;
                },
                onDragSourceEnd: (args) => {
                    // istanbul ignore else
                    if (onDragSourceEnd) {
                        args.parentObject = this.props.dataProvider;
                        onDragSourceEnd(args);
                    }
                },
                objectType: () => {
                    // istanbul ignore else
                    if (objectType) {
                        if (typeof objectType === "function")
                            return objectType(item.extendedData);
                        else
                            return objectType;
                    }
                    else
                        return "";
                },
            };
            return dragProps;
        }
        createDropProps() {
            if (!this.props.dropProps)
                return {};
            const { canDropOn, onDropTargetOver, onDropTargetDrop, canDropTargetDrop, objectTypes } = this.props.dropProps; // eslint-disable-line deprecation/deprecation
            const dropProps = {
                canDropOn,
                onDropTargetOver: (args) => {
                    // populate table information while it's accessible
                    args.dropLocation = this.props.dataProvider;
                    // istanbul ignore else
                    if (onDropTargetOver)
                        onDropTargetOver(args);
                },
                onDropTargetDrop: (args) => {
                    // populate table information while it's accessible
                    args.dropLocation = this.props.dataProvider;
                    if (onDropTargetDrop)
                        return onDropTargetDrop(args);
                    return args;
                },
                canDropTargetDrop: (args) => {
                    // populate table information while it's accessible
                    args.dropLocation = this.props.dataProvider;
                    if (canDropTargetDrop)
                        return canDropTargetDrop(args);
                    return true;
                },
                objectTypes,
            };
            return dropProps;
        }
        render() {
            const _a = this.props, { dragProps, dropProps, renderNode } = _a, tableProps = __rest(_a, ["dragProps", "dropProps", "renderNode"]); // eslint-disable-line @typescript-eslint/no-unused-vars
            const DragDropWrapper = withDropTarget_1.withDropTarget(TableWrapper_1.TableWrapper); // eslint-disable-line deprecation/deprecation
            return (React.createElement(DragDropWrapper, { dropStyle: { height: "100%" }, dropProps: this.createDropProps() },
                React.createElement(TableComponent, Object.assign({}, tableProps, { renderRow: this.renderRow }))));
        }
    };
}
exports.withTableDragDrop = withTableDragDrop;
//# sourceMappingURL=withDragDrop.js.map