"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Timeline
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseTimelineDataProvider = void 0;
/** Base Timeline Data Provider
 * @alpha
 */
class BaseTimelineDataProvider {
    constructor(viewport) {
        this.id = "TestTimelineDataProvider";
        this.viewId = "";
        this.supportsTimelineAnimation = false; // set to true when provider determines animation data is available.
        this.animationFraction = 0; // value from 0.0 to 1.0 that specifies the percentage complete for the animation.
        this._settings = {
            duration: 20 * 1000,
            loop: true,
        };
        // istanbul ignore next
        this.onPlaybackSettingChanged = (_settings) => {
        };
        // istanbul ignore next
        this.onAnimationFractionChanged = (_animationFraction) => {
        };
        this._viewport = viewport;
        // istanbul ignore if - WIP
        if (viewport)
            this.viewId = viewport.view.id;
    }
    // istanbul ignore next
    async loadTimelineData() {
        return false;
    }
    /** Called to get the initial scrubber location */
    get initialDuration() {
        return this.duration * this.animationFraction;
    }
    /** Called to get playback duration  */
    get duration() {
        return (this.getSettings().duration) ? this.getSettings().duration : /* istanbul ignore next */ 20000;
    }
    // istanbul ignore next - WIP
    set viewport(viewport) {
        this._viewport = viewport;
        if (viewport)
            this.viewId = viewport.view.id;
        else
            this.viewId = "";
    }
    // istanbul ignore next - WIP
    get viewport() {
        return this._viewport;
    }
    get loop() {
        return (undefined === this.getSettings().loop) ? /* istanbul ignore next */ false : this.getSettings().loop;
    }
    getSettings() {
        return this._settings;
    }
    updateSettings(settings) {
        this._settings = Object.assign(Object.assign({}, this._settings), settings);
    }
}
exports.BaseTimelineDataProvider = BaseTimelineDataProvider;
//# sourceMappingURL=BaseTimelineDataProvider.js.map