"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayButton = exports.PlayerButton = void 0;
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
require("./PlayerButton.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const UiComponents_1 = require("../UiComponents");
/** Player button used by buttons on timeline control
 * @internal
 */
class PlayerButton extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._onClick = () => {
            // istanbul ignore else
            if (this.props.onClick)
                this.props.onClick();
        };
    }
    render() {
        const { icon, title } = this.props;
        return (React.createElement("button", { "data-testid": this.props.className, className: classnames_1.default("player-button", this.props.className), onClick: this._onClick, title: title },
            React.createElement("span", { className: classnames_1.default("icon", !!icon) })));
    }
}
exports.PlayerButton = PlayerButton;
/** Play/Pause button used on timeline control
 * @internal
 */
class PlayButton extends React.Component {
    constructor(props, context) {
        super(props, context);
        this._onClick = () => {
            const _isPlaying = !this.state.isPlaying;
            this.setState({ isPlaying: _isPlaying });
            if (_isPlaying) {
                // istanbul ignore else
                if (this.props.onPlay)
                    this.props.onPlay();
            }
            else {
                // istanbul ignore else
                if (this.props.onPause)
                    this.props.onPause();
            }
        };
        this.state = { isPlaying: this.props.isPlaying };
    }
    /** @internal */
    componentDidUpdate() {
        if (this.props.isPlaying !== this.state.isPlaying) {
            this.setState((_, props) => ({ isPlaying: props.isPlaying }));
        }
    }
    render() {
        const { tooltip } = this.props;
        const iconClassName = this.state.isPlaying ? "icon icon-media-controls-pause" : "icon icon-media-controls-play";
        let title = tooltip;
        if (!title)
            title = UiComponents_1.UiComponents.translate(this.state.isPlaying ? "timeline.pause" : "timeline.play");
        return (React.createElement("button", { "data-testid": this.props.className, title: title, className: classnames_1.default("player-button", this.props.className), onClick: this._onClick },
            React.createElement("span", { className: iconClassName })));
    }
}
exports.PlayButton = PlayButton;
//# sourceMappingURL=PlayerButton.js.map