"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Scrubber = void 0;
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
require("./Scrubber.scss");
const React = __importStar(require("react"));
const react_compound_slider_1 = require("react-compound-slider");
const DateUtils_1 = require("../common/DateUtils");
// istanbul ignore next - WIP
const formatDuration = (value) => {
    const addZero = (i) => {
        return (i < 10) ? `0${i}` : i;
    };
    const date = new Date(value);
    const minutes = date.getUTCMinutes();
    const seconds = date.getUTCSeconds();
    return `${addZero(minutes)}:${addZero(seconds)}`;
};
const formatDate = (startDate, endDate, fraction, timeZoneOffset) => {
    const delta = (endDate.getTime() - startDate.getTime()) * fraction;
    const date = new Date(startDate.getTime() + delta);
    return DateUtils_1.toDateString(date, timeZoneOffset);
};
// istanbul ignore next - WIP
const formatTime = (startDate, endDate, fraction, timeZoneOffset) => {
    const delta = (endDate.getTime() - startDate.getTime()) * fraction;
    const date = new Date(startDate.getTime() + delta);
    return DateUtils_1.toTimeString(date, timeZoneOffset);
};
class TooltipRail extends React.Component {
    constructor(props) {
        super(props);
        this._isMounted = false;
        // istanbul ignore next - WIP
        this._onMouseEnter = () => {
            document.addEventListener("mousemove", this._onMouseMove);
        };
        // istanbul ignore next - WIP
        this._onMouseLeave = () => {
            if (this._isMounted)
                this.setState({ value: null, percent: null });
            document.removeEventListener("mousemove", this._onMouseMove);
        };
        // istanbul ignore next - WIP
        this._onMouseMove = (e) => {
            const { activeHandleID, getEventData } = this.props;
            if (this._isMounted) {
                if (activeHandleID) {
                    this.setState({ value: null, percent: null });
                }
                else {
                    this.setState(getEventData(e));
                }
            }
        };
        this.state = { value: null, percent: null };
    }
    componentDidMount() {
        this._isMounted = true;
    }
    componentWillUnmount() {
        this._isMounted = false;
        document.removeEventListener("mousemove", this._onMouseMove);
    }
    // istanbul ignore next - WIP
    render() {
        const { value, percent } = this.state;
        const { activeHandleID, getRailProps, isPlaying, startDate, endDate, showTime, timeZoneOffset } = this.props;
        let toolTip = "";
        if (startDate && endDate && showTime)
            toolTip = `${formatDate(startDate, endDate, percent / 100, timeZoneOffset)} ${formatTime(startDate, endDate, percent / 100, timeZoneOffset)}`;
        else if (startDate && endDate)
            toolTip = formatDate(startDate, endDate, percent / 100, timeZoneOffset);
        else
            toolTip = formatDuration(value);
        return (React.createElement(React.Fragment, null,
            !activeHandleID && value && !isPlaying ? (React.createElement("div", { className: "tooltip-rail", style: { left: `${percent}%` } },
                React.createElement("div", { className: "tooltip" },
                    React.createElement("span", { className: "tooltip-text" }, toolTip)))) : null,
            React.createElement("div", Object.assign({ className: "rail" }, getRailProps({
                onMouseEnter: this._onMouseEnter,
                onMouseLeave: this._onMouseLeave,
            }))),
            React.createElement("div", { className: "rail-center" })));
    }
}
TooltipRail.defaultProps = {
    disabled: false,
};
class Handle extends React.Component {
    constructor(props) {
        super(props);
        // istanbul ignore next - WIP
        this._onMouseEnter = () => {
            this.setState({ mouseOver: true });
        };
        // istanbul ignore next - WIP
        this._onMouseLeave = () => {
            this.setState({ mouseOver: false });
        };
        this.state = { mouseOver: false };
    }
    // istanbul ignore next - WIP
    render() {
        const { domain: [min, max], handle: { id, value, percent }, showTooltipWhenPlaying, showTooltipOnMouseOver, showTime, startDate, endDate, timeZoneOffset, getHandleProps, } = this.props;
        const { mouseOver } = this.state;
        let toolTip = "";
        if (startDate && endDate && showTime)
            toolTip = `${formatDate(startDate, endDate, percent / 100, timeZoneOffset)} ${formatTime(startDate, endDate, percent / 100, timeZoneOffset)}`;
        else if (startDate && endDate)
            toolTip = formatDate(startDate, endDate, percent / 100, timeZoneOffset);
        else
            toolTip = formatDuration(value);
        return (React.createElement(React.Fragment, null,
            (showTooltipWhenPlaying || (mouseOver && showTooltipOnMouseOver)) &&
                React.createElement("div", { className: "tooltip-rail", style: { left: `${percent}%` } },
                    React.createElement("div", { className: "tooltip" },
                        React.createElement("span", { className: "tooltip-text" }, toolTip))),
            React.createElement("div", Object.assign({ role: "slider", "aria-valuemin": min, "aria-valuemax": max, "aria-valuenow": value, className: "scrubber-handle", style: { left: `${percent}%` } }, getHandleProps(id, {
                onMouseEnter: this._onMouseEnter,
                onMouseLeave: this._onMouseLeave,
            })),
                React.createElement("div", null),
                React.createElement("div", null),
                React.createElement("div", null))));
    }
}
Handle.defaultProps = {
    disabled: false,
};
function Track({ source, target, getTrackProps }) {
    return (React.createElement("div", Object.assign({ className: "scrubber-track", style: { left: `${source.percent}%`, width: `${target.percent - source.percent}%` } }, getTrackProps())));
}
/** Scrubber/Slider for timeline control
 * @internal
 */
class Scrubber extends React.Component {
    render() {
        const { currentDuration, totalDuration, onChange, onUpdate, onSlideStart, isPlaying, inMiniMode, startDate, endDate, showTime, timeZoneOffset } = this.props;
        const domain = [0, totalDuration];
        const showTooltip = isPlaying && inMiniMode;
        const showMouseTooltip = !isPlaying && inMiniMode;
        return (React.createElement(react_compound_slider_1.Slider, { className: this.props.className, mode: 1, step: 1, domain: domain, onUpdate: onUpdate, onChange: onChange, onSlideStart: onSlideStart, values: [currentDuration] },
            React.createElement(react_compound_slider_1.Rail, null, (railProps) => React.createElement(TooltipRail, Object.assign({}, railProps, { isPlaying: isPlaying, startDate: startDate, endDate: endDate, showTime: showTime, timeZoneOffset: timeZoneOffset }))),
            React.createElement(react_compound_slider_1.Handles, null, ({ handles, getHandleProps }) => (React.createElement("div", { className: "slider-handles" }, handles.map((handle) => (React.createElement(Handle, { key: handle.id, showTooltipWhenPlaying: showTooltip, showTooltipOnMouseOver: showMouseTooltip, startDate: startDate, endDate: endDate, handle: handle, domain: domain, showTime: showTime, getHandleProps: getHandleProps })))))),
            React.createElement(react_compound_slider_1.Tracks, { right: false }, ({ tracks, getTrackProps }) => (React.createElement("div", { className: "slider-tracks" }, tracks.map(({ id, source, target }) => (React.createElement(Track, { key: id, source: source, target: target, getTrackProps: getTrackProps }))))))));
    }
}
exports.Scrubber = Scrubber;
//# sourceMappingURL=Scrubber.js.map