/** @packageDocumentation
 * @module Timeline
 */
import "./SolarTimeline.scss";
import * as React from "react";
import { ColorDef } from "@bentley/imodeljs-common";
import { SolarDataProvider } from "./interfaces";
interface SolarTimelineComponentProps {
    dataProvider: SolarDataProvider;
    onPlayPause?: (playing: boolean) => void;
    duration?: number;
    speed?: number;
}
interface SolarTimelineComponentState {
    isPlaying: boolean;
    isDateOpened: boolean;
    isSettingsOpened: boolean;
    dayStartMs: number;
    sunRiseOffsetMs: number;
    sunSetOffsetMs: number;
    sunDeltaMs: number;
    currentTimeOffsetMs: number;
    speed: number;
    loop: boolean;
    isExpanded: boolean;
    shadowColor: ColorDef;
    duration: number;
    adjustedDuration: number;
}
/** Solar Timeline
 * @alpha
 */
export declare class SolarTimeline extends React.PureComponent<SolarTimelineComponentProps, SolarTimelineComponentState> {
    private _datePicker;
    private _settings;
    private _requestFrame;
    private _unmounted;
    private _timeLastCycle;
    private _totalPlayTime;
    private _settingsPopupTitle;
    private _playLabel;
    private _settingLabel;
    private _loopLabel;
    private _speedLabel;
    private _expandLabel;
    private _minimizeLabel;
    private _dateTimeLabel;
    private _months;
    private _timeLabel;
    private _amLabel;
    private _pmLabel;
    private readonly _presetColors;
    constructor(props: SolarTimelineComponentProps);
    componentWillUnmount(): void;
    private _updateAnimation;
    private _play;
    private _onPause;
    private _onPlay;
    private setPlaybackTimeBySunTime;
    /** note the day passed in is in the time of the current user not in project time because the date picker works in
     * local time  */
    private _onDayClick;
    private _onTimeChanged;
    private _onCloseDayPicker;
    private _onOpenDayPicker;
    private _onCloseSettingsPopup;
    private _onOpenSettingsPopup;
    private ensureRange;
    private processSunTimeChange;
    private _onUpdate;
    private _onChange;
    private _onSpeedChange;
    private _onToggleLoop;
    private _onToggleDisplay;
    private _formatTick;
    private _formatTime;
    private _onPresetColorPick;
    private _handleHueOrSaturationChange;
    getLocalTime(ticks: number): Date;
    render(): JSX.Element;
}
export {};
//# sourceMappingURL=SolarTimeline.d.ts.map