"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Timeline
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolarTimeline = void 0;
// component is in alpha state - it may change after usability testing - test coverage not complete
/* istanbul ignore file */
require("./SolarTimeline.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const react_compound_slider_1 = require("react-compound-slider");
const imodeljs_common_1 = require("@bentley/imodeljs-common");
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const UiComponents_1 = require("../../ui-components/UiComponents");
const HueSlider_1 = require("../color/HueSlider");
const SaturationPicker_1 = require("../color/SaturationPicker");
const Swatch_1 = require("../color/Swatch");
const PlayerButton_1 = require("./PlayerButton");
const SpeedTimeline_1 = require("./SpeedTimeline");
const DatePicker_1 = require("../datepicker/DatePicker");
const TimeField_1 = require("../datepicker/TimeField");
const DateUtils_1 = require("../common/DateUtils");
// cSpell:ignore millisec solarsettings showticks shadowcolor solartimeline
const millisecPerMinute = 1000 * 60;
const millisecPerHour = millisecPerMinute * 60;
const millisecPerDay = millisecPerHour * 24;
const scrubberIncrement = 1;
const defaultPlaybackDuration = 40 * 1000; // 40 seconds
const addZero = (i) => {
    return (i < 10) ? `0${i}` : i;
};
class Handle extends React.Component {
    render() {
        const { domain: [min, max], handle: { id, value, percent }, getHandleProps, } = this.props;
        return (React.createElement("div", Object.assign({ className: "solar-handle", role: "slider", "aria-valuemin": min, "aria-valuemax": max, "aria-valuenow": value, style: { left: `${percent}%` } }, getHandleProps(id)),
            React.createElement("div", null),
            React.createElement("div", null),
            React.createElement("div", null)));
    }
}
class TooltipRail extends React.Component {
    constructor(props) {
        super(props);
        this._onMouseEnter = () => {
            document.addEventListener("mousemove", this._onMouseMove);
        };
        this._onMouseLeave = () => {
            this.setState({ value: null, percent: null });
            document.removeEventListener("mousemove", this._onMouseMove);
        };
        this._onMouseMove = (e) => {
            const { activeHandleID, getEventData } = this.props;
            if (activeHandleID) {
                this.setState({ value: null, percent: null });
            }
            else {
                this.setState(getEventData(e));
            }
        };
        this._handleTooltipTarget = (element) => {
            this.setState({
                tooltipTarget: element || undefined,
            });
        };
        this.state = {
            value: null,
            percent: null,
            tooltipTarget: undefined,
        };
    }
    render() {
        const { value, percent } = this.state;
        const { formatTime, activeHandleID, getRailProps, dayStartMs, sunrise, sunset } = this.props;
        const leftOffset = (sunrise / millisecPerDay) * 100;
        const sunWidth = ((sunset - sunrise) / millisecPerDay) * 100;
        return (React.createElement(React.Fragment, null,
            !activeHandleID && value ? (React.createElement("div", { className: "rail-tooltip", ref: this._handleTooltipTarget, style: { left: `${percent}%` } },
                React.createElement(ui_core_1.Tooltip, { className: "components-rail-tooltip", target: this.state.tooltipTarget, visible: true }, formatTime(dayStartMs + value)))) : null,
            React.createElement("div", { className: "rail-inner" }),
            React.createElement("div", Object.assign({ className: "rail-outer" }, getRailProps({
                onMouseEnter: this._onMouseEnter,
                onMouseLeave: this._onMouseLeave,
            }))),
            React.createElement("div", { className: "rail-solar", style: { left: `${leftOffset}%`, width: `${sunWidth}%` } })));
    }
}
TooltipRail.defaultProps = {
    disabled: false,
};
function Tick({ tick, count, formatTick }) {
    return (React.createElement("div", null,
        React.createElement("div", { className: "tick-mark", style: { left: `${tick.percent}%` } }),
        React.createElement("div", { className: "tick-label", style: { marginLeft: `${-(100 / count) / 2}%`, width: `${100 / count}%`, left: `${tick.percent}%` } }, formatTick(tick.value))));
}
class Timeline extends React.PureComponent {
    constructor() {
        super(...arguments);
        this._timelineRef = React.createRef();
        this.state = {
            sunriseTooltipTarget: undefined,
            sunsetTooltipTarget: undefined,
            timelineElement: null,
        };
        this._getTickValues = (width) => {
            const tickValues = [];
            let tickIncrement = millisecPerHour;
            if (width > 600 && width < 900)
                tickIncrement = millisecPerHour * 2;
            else if (width <= 600)
                tickIncrement = millisecPerHour * 4;
            let tickValue = 0;
            while (tickValue <= millisecPerDay) {
                tickValues.push(tickValue);
                tickValue += tickIncrement;
            }
            return tickValues;
        };
        this._handleSunriseTooltipTarget = (element) => {
            this.setState({
                sunriseTooltipTarget: element || undefined,
            });
        };
        this._handleSunsetTooltipTarget = (element) => {
            this.setState({
                sunsetTooltipTarget: element || undefined,
            });
        };
    }
    /** @internal */
    componentDidMount() {
        this.setState({ timelineElement: this._timelineRef.current });
    }
    render() {
        const { formatTick, formatTime, onChange, onUpdate, dayStartMs, sunSetOffsetMs, sunRiseOffsetMs, currentTimeOffsetMs } = this.props;
        const domain = [0, millisecPerDay];
        const className = classnames_1.default("solar-slider", this.props.className, formatTick && "showticks");
        const sunRiseFormat = formatTime(dayStartMs + sunRiseOffsetMs);
        const sunSetFormat = formatTime(dayStartMs + sunSetOffsetMs);
        return (React.createElement("div", { className: className },
            React.createElement("span", { className: "sunrise", ref: this._handleSunriseTooltipTarget },
                "\u2600",
                React.createElement(ui_core_1.Tooltip, { target: this.state.sunriseTooltipTarget }, sunRiseFormat)),
            React.createElement("div", { ref: this._timelineRef, className: "ui-component-solar-slider-sizer" },
                React.createElement(ui_core_1.ElementResizeObserver, { watchedElement: this.state.timelineElement, render: ({ width }) => (React.createElement(react_compound_slider_1.Slider, { mode: (curr, next) => {
                            // hodgepodge way to get around type issue in react-compound-slider package
                            const nextValue = next[0].val;
                            if (nextValue > sunSetOffsetMs || nextValue < sunRiseOffsetMs) {
                                return curr;
                            }
                            return next;
                        }, step: scrubberIncrement, domain: domain, rootStyle: { position: "relative", height: "100%", flex: "1", margin: "0 10px" }, onChange: onChange, onUpdate: onUpdate, values: [currentTimeOffsetMs] },
                        React.createElement(react_compound_slider_1.Rail, null, (railProps) => React.createElement(TooltipRail, Object.assign({}, railProps, { dayStartMs: dayStartMs, sunset: sunSetOffsetMs, sunrise: sunRiseOffsetMs, formatTime: formatTime }))),
                        React.createElement(react_compound_slider_1.Handles, null, ({ handles, getHandleProps }) => (React.createElement("div", { className: "slider-handles" }, handles.map((handle) => (React.createElement(Handle, { key: handle.id, handle: handle, domain: [sunRiseOffsetMs, sunSetOffsetMs], getHandleProps: getHandleProps })))))),
                        formatTick && width &&
                            React.createElement(react_compound_slider_1.Ticks, { values: this._getTickValues(width) }, ({ ticks }) => (React.createElement("div", { className: "slider-ticks" }, ticks.map((tick, index) => (React.createElement(Tick, { key: tick.id, tick: tick, count: ticks.length, width: width, index: index, formatTick: formatTick })))))))) })),
            React.createElement("span", { className: "sunset", ref: this._handleSunsetTooltipTarget },
                "\u263D",
                React.createElement(ui_core_1.Tooltip, { target: this.state.sunsetTooltipTarget }, sunSetFormat))));
    }
}
/** Solar Timeline
 * @alpha
 */
class SolarTimeline extends React.PureComponent {
    constructor(props) {
        super(props);
        this._datePicker = null;
        this._settings = null;
        this._requestFrame = 0;
        this._unmounted = false;
        this._timeLastCycle = 0;
        this._totalPlayTime = 0;
        this._settingsPopupTitle = UiComponents_1.UiComponents.i18n.translate("UiComponents:solarsettings.shadowcolor");
        this._playLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:solartimeline.play");
        this._settingLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:solartimeline.settings");
        this._loopLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:timeline.repeat");
        this._speedLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:solartimeline.speed");
        this._expandLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:timeline.expand");
        this._minimizeLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:timeline.minimize");
        this._dateTimeLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:solartimeline.dateTime");
        this._months = [
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.january"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.february"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.march"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.april"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.may"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.june"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.july"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.august"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.september"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.october"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.november"),
            UiComponents_1.UiComponents.i18n.translate("UiComponents:month.short.december"),
        ];
        this._timeLabel = UiComponents_1.UiComponents.translate("datepicker.time");
        this._amLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:time.am");
        this._pmLabel = UiComponents_1.UiComponents.i18n.translate("UiComponents:time.pm");
        this._presetColors = [
            imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.grey),
            imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.lightGrey),
            imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.darkGrey),
            imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.lightBlue),
            imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.lightGreen),
            imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.darkGreen),
            imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.tan),
            imodeljs_common_1.ColorDef.create(imodeljs_common_1.ColorByName.darkBrown),
        ];
        // recursively update the animation until we hit the end or the pause button is clicked
        this._updateAnimation = (_timestamp) => {
            // istanbul ignore else
            if (!this.state.isPlaying || this._unmounted) {
                window.cancelAnimationFrame(this._requestFrame);
                return;
            }
            const currentTime = new Date().getTime();
            this._totalPlayTime += (currentTime - this._timeLastCycle);
            this._timeLastCycle = currentTime;
            let percentComplete = this._totalPlayTime / this.state.adjustedDuration;
            if (percentComplete > 1)
                percentComplete = 1;
            let newPlayingState = true;
            // calculate the next sun time base on the percentage playback complete - should be int value as that is step amount for slider
            let nextSunOffset = Math.floor(this.state.sunRiseOffsetMs + (percentComplete * this.state.sunDeltaMs));
            if (percentComplete > 0.99) {
                if (!this.state.loop) {
                    newPlayingState = false;
                    nextSunOffset = this.state.sunSetOffsetMs;
                    window.cancelAnimationFrame(this._requestFrame);
                }
                else {
                    nextSunOffset = this.state.sunRiseOffsetMs;
                    this._totalPlayTime = 0;
                }
            }
            if (this.props.dataProvider.onTimeChanged) {
                const currentSunTime = new Date(this.state.dayStartMs + nextSunOffset);
                this.props.dataProvider.onTimeChanged(currentSunTime);
            }
            this.setState({ isPlaying: newPlayingState, currentTimeOffsetMs: nextSunOffset }, () => {
                if (newPlayingState)
                    this._requestFrame = window.requestAnimationFrame(this._updateAnimation);
            });
        };
        // user clicked pause button
        this._onPause = () => {
            // istanbul ignore if
            if (!this.state.isPlaying)
                return;
            const currentTime = new Date().getTime();
            this._totalPlayTime += (currentTime - this._timeLastCycle);
            // stop requesting frames
            window.cancelAnimationFrame(this._requestFrame);
            // stop playing
            this.setState({ isPlaying: false });
            // istanbul ignore else
            if (this.props.onPlayPause)
                this.props.onPlayPause(false);
        };
        // user clicked play button
        this._onPlay = () => {
            // istanbul ignore if
            if (this.state.isPlaying)
                return;
            if (this.state.currentTimeOffsetMs >= this.state.sunSetOffsetMs || this.state.currentTimeOffsetMs <= this.state.sunRiseOffsetMs) {
                this._totalPlayTime = 0;
                this._play(this.state.sunRiseOffsetMs);
            }
            else {
                this._play(this.state.currentTimeOffsetMs);
            }
        };
        /** note the day passed in is in the time of the current user not in project time because the date picker works in
         * local time  */
        this._onDayClick = (day) => {
            const selectedDate = new Date(day.getTime() + this.state.currentTimeOffsetMs);
            this.props.dataProvider.setDateAndTime(selectedDate);
            const dayStartMs = this.props.dataProvider.dayStartMs;
            const sunRiseOffsetMs = this.props.dataProvider.sunrise.getTime() - dayStartMs;
            const sunSetOffsetMs = this.props.dataProvider.sunset.getTime() - dayStartMs;
            const sunDeltaMs = sunSetOffsetMs - sunRiseOffsetMs;
            const sunOffsetMs = this.ensureRange(this.state.currentTimeOffsetMs, sunRiseOffsetMs, sunSetOffsetMs);
            this.setPlaybackTimeBySunTime(sunOffsetMs, sunRiseOffsetMs, sunDeltaMs);
            /** call dataProvider to update display style */
            if (this.props.dataProvider.onTimeChanged)
                this.props.dataProvider.onTimeChanged(this.props.dataProvider.timeOfDay);
            this.setState({ dayStartMs, sunRiseOffsetMs, sunSetOffsetMs, currentTimeOffsetMs: sunOffsetMs, sunDeltaMs, isDateOpened: false }, () => {
                this._timeLastCycle = new Date().getTime();
            });
        };
        this._onTimeChanged = (time) => {
            // compute the current date (with time)
            const dayStartMs = this.props.dataProvider.dayStartMs;
            const sunTime = (time.hours * millisecPerHour) + (time.minutes * millisecPerMinute);
            const dateWithNewTime = new Date(dayStartMs + sunTime);
            this.props.dataProvider.setDateAndTime(dateWithNewTime, true);
            // notify the provider to update style
            if (this.props.dataProvider.onTimeChanged)
                this.props.dataProvider.onTimeChanged(dateWithNewTime);
            const currentTimeOffsetMs = this.ensureRange(sunTime, this.state.sunRiseOffsetMs, this.state.sunSetOffsetMs);
            this.setPlaybackTimeBySunTime(currentTimeOffsetMs, this.state.sunRiseOffsetMs, this.state.sunDeltaMs);
            this._timeLastCycle = new Date().getTime();
            // update the timeline
            this.setState({ currentTimeOffsetMs });
        };
        this._onCloseDayPicker = () => {
            this.setState({ isDateOpened: false });
        };
        this._onOpenDayPicker = () => {
            this.setState((prevState) => ({ isDateOpened: !prevState.isDateOpened }));
        };
        this._onCloseSettingsPopup = () => {
            this.setState({ isSettingsOpened: false });
        };
        this._onOpenSettingsPopup = () => {
            this.setState((prevState) => ({ isSettingsOpened: !prevState.isSettingsOpened }));
        };
        this._onUpdate = (values) => {
            if (!this.state.isPlaying)
                this.processSunTimeChange(values[0]);
        };
        this._onChange = (values) => {
            if (!this.state.isPlaying)
                this.processSunTimeChange(values[0]);
        };
        this._onSpeedChange = (value) => {
            const adjustedDuration = this.state.duration / value;
            this.setState({ speed: value, adjustedDuration });
        };
        this._onToggleLoop = () => {
            this.setState((prevState) => ({ loop: !prevState.loop }));
        };
        this._onToggleDisplay = () => {
            this.setState((prevState) => ({ isExpanded: !prevState.isExpanded }));
        };
        this._formatTick = (millisec) => {
            const hour = millisec / millisecPerHour;
            const abbrev = (hour < 12) ? this._amLabel : (hour === 24) ? this._amLabel : this._pmLabel;
            const newHour = (hour === 0) ? 12 : (hour <= 12) ? hour : hour - 12;
            return `${newHour}${abbrev}`;
        };
        this._formatTime = (millisec) => {
            const date = new Date(millisec);
            // convert project date to browser locale date
            const localTime = DateUtils_1.adjustDateToTimezone(date, this.props.dataProvider.timeZoneOffset * 60);
            let hours = localTime.getHours();
            const minutes = addZero(date.getMinutes());
            const abbrev = (hours < 12) ? this._amLabel : (hours === 24) ? this._amLabel : this._pmLabel;
            hours = (hours > 12) ? hours - 12 : hours;
            return `${hours}:${minutes} ${abbrev}`;
        };
        this._onPresetColorPick = (shadowColor) => {
            this.setState({ shadowColor }, () => this.props.dataProvider.shadowColor = shadowColor);
        };
        this._handleHueOrSaturationChange = (hueOrSaturation) => {
            if (hueOrSaturation.s === 0) // for a ColorDef to be created from hsv s can't be 0
                hueOrSaturation = hueOrSaturation.clone(undefined, 0.5);
            const shadowColor = hueOrSaturation.toColorDef();
            this.setState({ shadowColor }, () => this.props.dataProvider.shadowColor = shadowColor);
        };
        const dayStartMs = this.props.dataProvider.dayStartMs;
        const sunRiseOffsetMs = this.props.dataProvider.sunrise.getTime() - dayStartMs;
        const sunSetOffsetMs = this.props.dataProvider.sunset.getTime() - dayStartMs;
        const sunDeltaMs = sunSetOffsetMs - sunRiseOffsetMs;
        const sunOffsetMs = this.props.dataProvider.timeOfDay.getTime() - dayStartMs;
        const currentTimeOffsetMs = this.ensureRange(sunOffsetMs, sunRiseOffsetMs, sunSetOffsetMs);
        const shadowColor = this.props.dataProvider.shadowColor;
        const duration = this.props.duration ? this.props.duration : defaultPlaybackDuration;
        const speed = this.props.speed ? this.props.speed : 2;
        const adjustedDuration = duration / speed;
        this.setPlaybackTimeBySunTime(currentTimeOffsetMs, sunRiseOffsetMs, sunDeltaMs, adjustedDuration);
        this.state = {
            isDateOpened: false,
            isSettingsOpened: false,
            isPlaying: false,
            dayStartMs,
            sunRiseOffsetMs,
            sunSetOffsetMs,
            sunDeltaMs,
            currentTimeOffsetMs,
            speed,
            isExpanded: false,
            loop: false,
            shadowColor,
            duration,
            adjustedDuration,
        };
    }
    componentWillUnmount() {
        window.cancelAnimationFrame(this._requestFrame);
        this._unmounted = true;
    }
    _play(sunTimeMs) {
        this._timeLastCycle = new Date().getTime();
        // start playing
        this.setState({ isPlaying: true, currentTimeOffsetMs: sunTimeMs }, () => {
            this._requestFrame = window.requestAnimationFrame(this._updateAnimation);
            // istanbul ignore else
            if (this.props.onPlayPause)
                this.props.onPlayPause(true);
        });
    }
    setPlaybackTimeBySunTime(sunOffsetMs, sunRiseOffsetMs, sunDeltaMs, adjustedDuration) {
        this._totalPlayTime = ((sunOffsetMs - sunRiseOffsetMs) / (sunDeltaMs)) * ((adjustedDuration) ? adjustedDuration : this.state.adjustedDuration);
    }
    ensureRange(value, min, max) {
        return Math.max(Math.min(value, max), min);
    }
    processSunTimeChange(sunTime) {
        if (sunTime === this.state.currentTimeOffsetMs)
            return;
        const currentTimeOffsetMs = this.ensureRange(sunTime, this.state.sunRiseOffsetMs, this.state.sunSetOffsetMs);
        if (this.props.dataProvider.onTimeChanged) {
            const currentSunTime = new Date(this.state.dayStartMs + currentTimeOffsetMs);
            this.props.dataProvider.onTimeChanged(currentSunTime);
        }
        this.setState({ currentTimeOffsetMs }, () => {
            const currentTime = new Date().getTime();
            this._timeLastCycle = currentTime;
            const percentComplete = (currentTimeOffsetMs - this.state.sunRiseOffsetMs) / this.state.sunDeltaMs;
            this._totalPlayTime = percentComplete * this.state.adjustedDuration;
        });
    }
    getLocalTime(ticks) {
        const projectTime = new Date(ticks);
        // convert project date to browser locale date
        return DateUtils_1.adjustDateToTimezone(projectTime, this.props.dataProvider.timeZoneOffset * 60);
    }
    render() {
        const { dataProvider } = this.props;
        const { speed, loop, currentTimeOffsetMs, isExpanded, sunRiseOffsetMs, sunSetOffsetMs } = this.state;
        const localTime = this.getLocalTime(this.state.dayStartMs + this.state.currentTimeOffsetMs);
        const formattedTime = this._formatTime(dataProvider.dayStartMs + currentTimeOffsetMs);
        const formattedDate = `${this._months[localTime.getMonth()]}, ${localTime.getDate()}`;
        const colorSwatchStyle = {
            width: `100%`,
            height: `100%`,
        };
        const expandMinimizeLabel = isExpanded ? this._expandLabel : this._minimizeLabel;
        return (React.createElement("div", { className: classnames_1.default("solar-timeline-wrapper", isExpanded && "expanded") },
            React.createElement(Timeline, { className: "solar-timeline-expanded", dayStartMs: dataProvider.dayStartMs, sunSetOffsetMs: sunSetOffsetMs, sunRiseOffsetMs: sunRiseOffsetMs, currentTimeOffsetMs: currentTimeOffsetMs, onChange: this._onChange, onUpdate: this._onUpdate, formatTime: this._formatTime, formatTick: this._formatTick }),
            React.createElement("div", { className: "header" },
                React.createElement(PlayerButton_1.PlayButton, { tooltip: this._playLabel, className: "play-button", isPlaying: this.state.isPlaying, onPlay: this._onPlay, onPause: this._onPause }),
                React.createElement("button", { "data-testid": "solar-date-time-button", title: this._dateTimeLabel, className: "current-date", ref: (element) => this._datePicker = element, onClick: this._onOpenDayPicker },
                    React.createElement("span", null, formattedDate),
                    React.createElement("span", null, "/"),
                    React.createElement("span", null, formattedTime),
                    React.createElement("span", { className: "icon icon-calendar" })),
                React.createElement(ui_core_1.Popup, { style: { border: "none" }, offset: 11, target: this._datePicker, isOpen: this.state.isDateOpened, onClose: this._onCloseDayPicker, position: ui_abstract_1.RelativePosition.Top },
                    React.createElement("div", { className: "components-date-picker-calendar-popup-panel", "data-testid": "components-date-picker-calendar-popup-panel" },
                        React.createElement(DatePicker_1.DatePicker, { selected: localTime, onDateChange: this._onDayClick, showFocusOutline: false }),
                        React.createElement("div", { className: "time-container" },
                            React.createElement(ui_core_1.BodyText, { className: "time-label" }, this._timeLabel),
                            React.createElement(TimeField_1.TimeField, { time: { hours: localTime.getHours(), minutes: localTime.getMinutes(), seconds: 0 }, timeDisplay: ui_abstract_1.TimeDisplay.H12MC, onTimeChange: this._onTimeChanged })))),
                React.createElement(Timeline, { className: "solar-timeline", dayStartMs: dataProvider.dayStartMs, sunSetOffsetMs: sunSetOffsetMs, sunRiseOffsetMs: sunRiseOffsetMs, currentTimeOffsetMs: currentTimeOffsetMs, onChange: this._onChange, onUpdate: this._onUpdate, formatTime: this._formatTime }),
                React.createElement("div", { className: "speed-container" },
                    React.createElement("span", { title: this._speedLabel },
                        speed,
                        "x"),
                    React.createElement(SpeedTimeline_1.SpeedTimeline, { className: "speed", onChange: this._onSpeedChange, speed: this.state.speed })),
                React.createElement("span", { title: this._loopLabel, className: classnames_1.default("icon", "icon-media-controls-loop", !loop && "no-loop-playback", loop && "loop-playback"), onClick: this._onToggleLoop, role: "button", tabIndex: -1 }),
                React.createElement("button", { "data-testid": "shadow-settings-button", title: this._settingLabel, className: "shadow-settings-button", ref: (element) => this._settings = element, onClick: this._onOpenSettingsPopup },
                    React.createElement("span", { className: "icon icon-settings" })),
                React.createElement(ui_core_1.Popup, { className: "shadow-settings-popup", target: this._settings, offset: 11, isOpen: this.state.isSettingsOpened, onClose: this._onCloseSettingsPopup, position: ui_abstract_1.RelativePosition.Top },
                    React.createElement("div", { className: "shadow-settings-popup-container" },
                        React.createElement("div", { className: "shadow-settings-header" }, this._settingsPopupTitle),
                        React.createElement("div", { className: "shadow-settings-color" },
                            React.createElement("div", { className: "shadow-settings-color-top" },
                                React.createElement(SaturationPicker_1.SaturationPicker, { hsv: this.state.shadowColor.toHSV(), onSaturationChange: this._handleHueOrSaturationChange })),
                            React.createElement("div", { className: "shadow-settings-color-bottom" },
                                React.createElement("div", { className: "shadow-settings-color-bottom-left" },
                                    React.createElement(HueSlider_1.HueSlider, { hsv: this.state.shadowColor.toHSV(), onHueChange: this._handleHueOrSaturationChange, isHorizontal: true })),
                                React.createElement("div", { className: "shadow-settings-color-bottom-right" },
                                    React.createElement(Swatch_1.ColorSwatch, { style: colorSwatchStyle, colorDef: this.state.shadowColor, round: false })))),
                        React.createElement("div", { className: "shadow-settings-color-presets" },
                            React.createElement(Swatch_1.ColorSwatch, { colorDef: this._presetColors[0], round: false, onColorPick: this._onPresetColorPick }),
                            React.createElement(Swatch_1.ColorSwatch, { colorDef: this._presetColors[1], round: false, onColorPick: this._onPresetColorPick }),
                            React.createElement(Swatch_1.ColorSwatch, { colorDef: this._presetColors[2], round: false, onColorPick: this._onPresetColorPick }),
                            React.createElement(Swatch_1.ColorSwatch, { colorDef: this._presetColors[3], round: false, onColorPick: this._onPresetColorPick }),
                            React.createElement(Swatch_1.ColorSwatch, { colorDef: this._presetColors[4], round: false, onColorPick: this._onPresetColorPick }),
                            React.createElement(Swatch_1.ColorSwatch, { colorDef: this._presetColors[5], round: false, onColorPick: this._onPresetColorPick }),
                            React.createElement(Swatch_1.ColorSwatch, { colorDef: this._presetColors[6], round: false, onColorPick: this._onPresetColorPick }),
                            React.createElement(Swatch_1.ColorSwatch, { colorDef: this._presetColors[7], round: false, onColorPick: this._onPresetColorPick })))),
                React.createElement("span", { title: expandMinimizeLabel, "data-testid": "solar-timeline-toggle-expand", className: "expanded-icon icon icon-chevron-up", onClick: this._onToggleDisplay, role: "button", tabIndex: -1 }))));
    }
}
exports.SolarTimeline = SolarTimeline;
//# sourceMappingURL=SolarTimeline.js.map