"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module ToolSettings
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolbarOverflowPanel = void 0;
require("./OverflowPanel.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const ToolbarWithOverflow_1 = require("./ToolbarWithOverflow");
const Direction_1 = require("./utilities/Direction");
/** Displays overflown tool settings.
 * @internal
 */
// eslint-disable-next-line react/display-name
function ToolbarOverflowPanel(props) {
    const { toolbarOpacitySetting, openPopupCount, overflowDisplayActive, expandsTo, overflowExpandsTo, overflowDirection } = ToolbarWithOverflow_1.useToolbarWithOverflowDirectionContext();
    const { proximityScale } = ui_core_1.useWidgetOpacityContext();
    const useTransparentBackground = toolbarOpacitySetting === ToolbarWithOverflow_1.ToolbarOpacitySetting.Transparent;
    let toolbarOpacity = useTransparentBackground ? 0 : ui_core_1.TOOLBAR_OPACITY_DEFAULT;
    let boxShadowOpacity = useTransparentBackground ? 0 : ui_core_1.TOOLBAR_BOX_SHADOW_OPACITY_DEFAULT;
    let filterBlur = useTransparentBackground ? 0 : ui_core_1.TOOLBAR_BACKDROP_FILTER_BLUR_DEFAULT;
    let showSeparators = toolbarOpacitySetting === ToolbarWithOverflow_1.ToolbarOpacitySetting.Transparent ? false : true;
    // istanbul ignore next
    if (toolbarOpacitySetting === ToolbarWithOverflow_1.ToolbarOpacitySetting.Proximity && openPopupCount < 1 && !overflowDisplayActive) {
        toolbarOpacity = ui_core_1.calculateToolbarOpacity(proximityScale);
        boxShadowOpacity = ui_core_1.calculateBoxShadowOpacity(proximityScale);
        filterBlur = ui_core_1.calculateBackdropFilterBlur(proximityScale);
        if (proximityScale < .25)
            showSeparators = false;
    }
    const divStyle = Object.assign({ backgroundColor: ui_core_1.getToolbarBackgroundColor(toolbarOpacity), boxShadow: ui_core_1.getToolbarBoxShadow(boxShadowOpacity), backdropFilter: ui_core_1.getToolbarBackdropFilter(filterBlur) }, props.style);
    const className = classnames_1.default("components-toolbar-overflow-panel", "components-toolbar-items-container", Direction_1.OrthogonalDirectionHelpers.getCssClassName(overflowDirection), `${Direction_1.OrthogonalDirectionHelpers.getCssClassName(overflowDirection)}-${Direction_1.DirectionHelpers.getCssClassName(expandsTo)}`, showSeparators && "components-toolbar-show-decorators", Direction_1.DirectionHelpers.getCssClassName(overflowExpandsTo), props.className);
    return (React.createElement("div", { className: className, style: divStyle }, props.children));
}
exports.ToolbarOverflowPanel = ToolbarOverflowPanel;
//# sourceMappingURL=OverflowPanel.js.map