"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Toolbar
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PopupItemPopup = exports.PopupItem = exports.useToolbarPopupContext = exports.ToolbarPopupContext = void 0;
require("./PopupItem.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const ToolbarWithOverflow_1 = require("./ToolbarWithOverflow");
const PopupItemWithDrag_1 = require("./PopupItemWithDrag");
/**
 * Context used by Toolbar items in popups to close the popup panel.
 * @internal
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
exports.ToolbarPopupContext = React.createContext({
    closePanel: /* istanbul ignore next */ () => { },
    setSelectedItem: /* istanbul ignore next */ (_buttonItem) => { },
});
/** @internal */
function useToolbarPopupContext() {
    return React.useContext(exports.ToolbarPopupContext);
}
exports.useToolbarPopupContext = useToolbarPopupContext;
/** Popup toolbar item that displays a panel
 * @beta
 */
function PopupItem(props) {
    const [isPanelShown, setPanelShown] = React.useState(false);
    const { expandsTo, overflowExpandsTo, panelAlignment, onPopupPanelOpenClose } = ToolbarWithOverflow_1.useToolbarWithOverflowDirectionContext();
    const processPanelOpenClose = React.useCallback((isOpening) => {
        setPanelShown((prev) => {
            // istanbul ignore else
            if (prev !== isOpening)
                onPopupPanelOpenClose(isOpening);
            return isOpening;
        });
    }, [setPanelShown, onPopupPanelOpenClose]);
    // handle open and closing overflow panel
    const onButtonClick = React.useCallback(() => {
        processPanelOpenClose(!isPanelShown);
        // istanbul ignore next
        if (props.onClick)
            props.onClick();
    }, [props, isPanelShown, processPanelOpenClose]);
    const className = classnames_1.default("components-toolbar-button-item", "components-toolbar-expandable-button", props.isDisabled && "components-disabled", props.className);
    const [targetRef, target] = ui_core_1.useRefState();
    // istanbul ignore next
    const handleClose = React.useCallback(() => {
        processPanelOpenClose(false);
    }, [processPanelOpenClose]);
    const { hasOverflow } = ToolbarWithOverflow_1.useToolItemEntryContext();
    const expandsToDirection = hasOverflow ? overflowExpandsTo : expandsTo;
    const { hideIndicator, panel } = props;
    return (React.createElement(exports.ToolbarPopupContext.Provider, { value: {
            closePanel: () => processPanelOpenClose(false),
        } },
        React.createElement("button", { ref: targetRef, disabled: props.isDisabled, onClick: onButtonClick, onKeyDown: props.onKeyDown, className: className, style: props.style, title: props.title },
            React.createElement("div", { className: "components-icon" }, props.icon),
            props.badge &&
                React.createElement("div", { className: "components-badge" }, props.badge),
            hideIndicator ? /* istanbul ignore next */ undefined : React.createElement("div", { className: "components-triangle" })),
        React.createElement(PopupItemPopup, { isOpen: isPanelShown, onClose: handleClose, position: PopupItemWithDrag_1.toToolbarPopupRelativePosition(expandsToDirection, panelAlignment), target: target }, panel)));
}
exports.PopupItem = PopupItem;
/** @internal */
function PopupItemPopup(props) {
    return React.createElement(ui_core_1.Popup, Object.assign({ className: "components-toolbar-popupItem_popupItemPopup", offset: 0, showShadow: false }, props));
}
exports.PopupItemPopup = PopupItemPopup;
//# sourceMappingURL=PopupItem.js.map