"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Toolbar
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.toToolbarPopupRelativePosition = exports.PopupItemWithDrag = void 0;
require("./PopupItem.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const PopupItem_1 = require("./PopupItem");
const PopupItemsPanel_1 = require("./PopupItemsPanel");
const ToolbarWithOverflow_1 = require("./ToolbarWithOverflow");
const useDragInteraction_1 = require("./useDragInteraction");
const Direction_1 = require("./utilities/Direction");
function tryFindActiveAction(item) {
    for (const childItem of item.items) {
        // istanbul ignore else
        if (ui_abstract_1.ToolbarItemUtilities.isActionButton(childItem)) {
            if (childItem.isActive)
                return childItem;
        }
        else if (ui_abstract_1.ToolbarItemUtilities.isGroupButton(childItem)) {
            const nestedChild = tryFindActiveAction(childItem);
            if (nestedChild)
                return nestedChild;
        }
    }
    return undefined;
}
function getFirstAvailableChildActionItem(item) {
    for (const childItem of item.items) {
        if (ui_abstract_1.ToolbarItemUtilities.isActionButton(childItem)) {
            return childItem;
        }
        else {
            // istanbul ignore else
            if (ui_abstract_1.ToolbarItemUtilities.isGroupButton(childItem)) {
                const nestedChild = getFirstAvailableChildActionItem(childItem);
                // istanbul ignore else
                if (nestedChild)
                    return nestedChild;
            }
        }
    }
    return undefined;
}
function getActiveAction(item) {
    const activeItem = tryFindActiveAction(item);
    if (activeItem)
        return activeItem;
    // initially look only in root items
    for (const childItem of item.items) {
        // istanbul ignore else
        if (ui_abstract_1.ToolbarItemUtilities.isActionButton(childItem)) {
            return childItem;
        }
    }
    // if not found look inside groups
    return getFirstAvailableChildActionItem(item);
}
/** Expandable Group button Item
 * @beta
 */
function PopupItemWithDrag(props) {
    const [isPanelShown, setPanelShown] = React.useState(false);
    const [activeAction, setActiveAction] = React.useState(getActiveAction(props.groupItem));
    const { expandsTo, overflowExpandsTo, panelAlignment, onPopupPanelOpenClose } = ToolbarWithOverflow_1.useToolbarWithOverflowDirectionContext();
    React.useEffect(() => {
        const newActiveAction = getActiveAction(props.groupItem);
        // istanbul ignore else
        if (newActiveAction) {
            // istanbul ignore next
            if (newActiveAction.isActive) {
                setActiveAction(newActiveAction);
            }
            else {
                if (activeAction && activeAction.isActive) {
                    setActiveAction(Object.assign(Object.assign({}, activeAction), { isActive: false }));
                }
            }
        }
    }, [props.groupItem, activeAction]);
    const processPanelOpenClose = React.useCallback((isOpening) => {
        setPanelShown((prev) => {
            // istanbul ignore else
            if (prev !== isOpening)
                onPopupPanelOpenClose(isOpening);
            return isOpening;
        });
    }, [setPanelShown, onPopupPanelOpenClose]);
    // handle open and closing popup panel
    const onOpenPanel = React.useCallback(() => {
        processPanelOpenClose(!isPanelShown);
    }, [isPanelShown, processPanelOpenClose]);
    // handle open and closing popup panel
    const onGroupButtonClick = React.useCallback(() => {
        // only execute action if not disabled
        activeAction && !ui_abstract_1.ConditionalBooleanValue.getValue(activeAction.isDisabled) && activeAction.execute();
    }, [activeAction]);
    const badge = activeAction ? ui_core_1.BadgeUtilities.getComponentForBadgeType(activeAction.badgeType) : props.badge;
    const icon = activeAction ? ui_core_1.IconHelper.getIconReactNode(activeAction.icon, activeAction.internalData) : props.icon;
    const title = activeAction ? ui_abstract_1.ConditionalStringValue.getValue(activeAction.label) : props.title;
    const isActive = activeAction ? activeAction.isActive : props.isActive;
    const isDisabled = ui_abstract_1.ConditionalBooleanValue.getValue(activeAction ? activeAction.isDisabled : props.isDisabled);
    const { handlePointerDown, handleButtonClick } = useDragInteraction_1.useDragInteraction(onGroupButtonClick, onOpenPanel);
    const className = classnames_1.default("components-toolbar-button-item", "components-toolbar-expandable-button", isActive && "components-active", isDisabled && "components-disabled-drag", props.className);
    const [targetRef, target] = ui_core_1.useRefState();
    const handleClose = React.useCallback(() => {
        processPanelOpenClose(false);
    }, [processPanelOpenClose]);
    const { hasOverflow } = ToolbarWithOverflow_1.useToolItemEntryContext();
    const expandsToDirection = hasOverflow ? /* istanbul ignore next */ overflowExpandsTo : expandsTo;
    return (React.createElement(PopupItem_1.ToolbarPopupContext.Provider, { value: {
            closePanel: /* istanbul ignore next */ () => processPanelOpenClose(false),
            setSelectedItem: /* istanbul ignore next */ (buttonItem) => setActiveAction(buttonItem),
        } },
        React.createElement("button", { ref: targetRef, onPointerDown: handlePointerDown, onClick: handleButtonClick, onKeyDown: props.onKeyDown, className: className, style: props.style, title: title },
            React.createElement("div", { className: "components-icon" }, icon),
            props.badge &&
                React.createElement("div", { className: "components-badge" }, badge),
            React.createElement("div", { className: "components-triangle" })),
        React.createElement(PopupItem_1.PopupItemPopup, { isOpen: isPanelShown, onClose: handleClose, position: toToolbarPopupRelativePosition(expandsToDirection, panelAlignment), target: target },
            React.createElement(PopupItemsPanel_1.PopupItemsPanel, { groupItem: props.groupItem, activateOnPointerUp: true }))));
}
exports.PopupItemWithDrag = PopupItemWithDrag;
/** @internal */
function toToolbarPopupRelativePosition(expandsTo, alignment) {
    // istanbul ignore next
    switch (expandsTo) {
        case Direction_1.Direction.Bottom: {
            if (alignment === ToolbarWithOverflow_1.ToolbarPanelAlignment.End)
                return ui_abstract_1.RelativePosition.BottomRight;
            return ui_abstract_1.RelativePosition.BottomLeft;
        }
        case Direction_1.Direction.Left:
            return ui_abstract_1.RelativePosition.LeftTop;
        case Direction_1.Direction.Right:
            return ui_abstract_1.RelativePosition.RightTop;
        case Direction_1.Direction.Top:
            return ui_abstract_1.RelativePosition.Top;
    }
}
exports.toToolbarPopupRelativePosition = toToolbarPopupRelativePosition;
//# sourceMappingURL=PopupItemWithDrag.js.map