"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Toolbar
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PopupItemsPanel = void 0;
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const BackArrow_1 = require("./groupPanel/BackArrow");
const Column_1 = require("./groupPanel/Column");
const Columns_1 = require("./groupPanel/Columns");
const Panel_1 = require("./groupPanel/Panel");
const Title_1 = require("./groupPanel/Title");
const Expander_1 = require("./groupPanel/tool/Expander");
const Tool_1 = require("./groupPanel/tool/Tool");
const PopupItem_1 = require("./PopupItem");
const ToolbarWithOverflow_1 = require("./ToolbarWithOverflow");
function getNumItemsInColumn(numTotalItems) {
    if (numTotalItems <= 6)
        return numTotalItems;
    if (numTotalItems <= 24)
        return Math.ceil(numTotalItems / 2);
    if (numTotalItems <= 36)
        return Math.ceil(numTotalItems / 3);
    return Math.ceil(numTotalItems / 4);
}
/** Component that displays a list of tools in a panel.
 * @internal future
 */
function PopupItemsPanel(props) {
    const [groupArray, setGroupArray] = React.useState([props.groupItem]);
    const activeGroup = React.useMemo(() => groupArray[0], [groupArray]);
    const items = React.useMemo(() => activeGroup.items, [activeGroup]);
    const preferredNumItemsInColumn = getNumItemsInColumn(items.length);
    // Divide items equally between columns.
    const numberOfColumns = Math.ceil(items.length / preferredNumItemsInColumn);
    const numItemsPerColumn = Math.ceil(items.length / numberOfColumns);
    const columnToItems = React.useMemo(() => items.reduce((acc, item, index) => {
        const columnIndex = Math.floor(index / numItemsPerColumn);
        if (columnIndex >= acc.length) {
            return [
                ...acc,
                [item],
            ];
        }
        return [
            ...acc.slice(0, columnIndex),
            [
                ...acc[columnIndex],
                item,
            ],
            ...acc.slice(columnIndex + 1),
        ];
    }, []), [items, numItemsPerColumn]);
    const handleGroupItemClick = React.useCallback((item) => {
        // istanbul ignore else
        if (ui_abstract_1.ToolbarItemUtilities.isGroupButton(item)) {
            // push group to front of array
            setGroupArray([item, ...groupArray]);
        }
    }, [groupArray]);
    const handleBackArrowClick = React.useCallback(() => {
        // istanbul ignore else
        if (groupArray.length > 1) {
            setGroupArray(groupArray.slice(1));
        }
    }, [groupArray]);
    const { closePanel, setSelectedItem } = PopupItem_1.useToolbarPopupContext();
    const { onItemExecuted, onKeyDown } = ToolbarWithOverflow_1.useToolbarWithOverflowDirectionContext();
    const handleOnPointerUp = React.useCallback(/* istanbul ignore next */ (panelItem) => {
        // istanbul ignore else
        if (ui_abstract_1.ToolbarItemUtilities.isActionButton(panelItem)) {
            props.activateOnPointerUp && setSelectedItem && setSelectedItem(panelItem);
            props.activateOnPointerUp && panelItem.execute();
            onItemExecuted(panelItem);
            props.activateOnPointerUp && closePanel();
        }
    }, [props.activateOnPointerUp, setSelectedItem, closePanel, onItemExecuted]);
    const handleActionItemClick = React.useCallback((panelItem) => {
        // istanbul ignore else
        if (ui_abstract_1.ToolbarItemUtilities.isActionButton(panelItem)) {
            setSelectedItem && setSelectedItem(panelItem);
            panelItem.execute();
            onItemExecuted(panelItem);
            closePanel();
        }
    }, [setSelectedItem, closePanel, onItemExecuted]);
    // istanbul ignore next - NEEDSWORK add complete tests
    const handleOnKeyDown = React.useCallback((e) => {
        onKeyDown(e);
    }, [onKeyDown]);
    // build n-number of columns
    const columns = React.useMemo(() => columnToItems.map((columnItems, columnIndex) => React.createElement(Column_1.GroupColumn, { key: columnIndex }, columnItems.map((panelItem) => {
        const badge = ui_core_1.BadgeUtilities.getComponentForBadgeType(panelItem.badgeType);
        const icon = ui_core_1.IconHelper.getIconReactNode(panelItem.icon, panelItem.internalData);
        const label = ui_abstract_1.ConditionalStringValue.getValue(panelItem.label);
        if (ui_abstract_1.ToolbarItemUtilities.isGroupButton(panelItem)) {
            return (React.createElement(Expander_1.GroupToolExpander, { isDisabled: ui_abstract_1.ConditionalBooleanValue.getValue(panelItem.isDisabled), key: panelItem.id, label: label, icon: icon, badge: badge, item: panelItem, onClick: handleGroupItemClick }));
        }
        return (React.createElement(Tool_1.GroupTool, { isDisabled: ui_abstract_1.ConditionalBooleanValue.getValue(panelItem.isDisabled), isActive: !!panelItem.isActive, key: panelItem.id, label: label, icon: icon, item: panelItem, onClick: handleActionItemClick, onPointerUp: handleOnPointerUp, badge: badge }));
    }))), [columnToItems, handleActionItemClick, handleGroupItemClick, handleOnPointerUp]);
    // ensure we have a panel title for nested groups
    const titleString = activeGroup.panelLabel ? activeGroup.panelLabel : activeGroup.label;
    const panelTitle = React.useMemo(() => ui_abstract_1.ConditionalStringValue.getValue(titleString), [titleString]);
    const className = classnames_1.default(1 === groupArray.length && "components-toolbar-item-expandable-group-group", groupArray.length > 1 && "components-toolbar-item-expandable-group-nested");
    return (React.createElement(Panel_1.Panel, { className: className, onKeyDown: handleOnKeyDown },
        groupArray.length > 1 &&
            React.createElement(BackArrow_1.BackArrow, { className: "components-back", onClick: handleBackArrowClick }),
        panelTitle &&
            React.createElement(Title_1.Title, null, panelTitle),
        columns &&
            React.createElement(Columns_1.Columns, null, columns)));
}
exports.PopupItemsPanel = PopupItemsPanel;
//# sourceMappingURL=PopupItemsPanel.js.map