/** @packageDocumentation
 * @module Toolbar
 */
import "./Toolbar.scss";
import * as React from "react";
import { CommonToolbarItem, OnItemExecutedFunc } from "@bentley/ui-abstract";
import { CommonProps, NoChildrenProps } from "@bentley/ui-core";
import { Direction } from "./utilities/Direction";
import { ToolbarOpacitySetting, ToolbarPanelAlignment } from "./ToolbarWithOverflow";
/** Properties of [[Toolbar]] component.
 * @beta
 */
export interface ToolbarProps extends CommonProps, NoChildrenProps {
    /** Describes to which direction the popup panels are expanded. Defaults to: [[Direction.Bottom]] */
    expandsTo?: Direction;
    /** definitions for items of the toolbar. i.e. [[CommonToolbarItem]]. Items are expected to be already sorted by group and item. */
    items: CommonToolbarItem[];
    /** Describes how expanded panels are aligned. Defaults to: [[ToolbarPanelAlignment.Start]] */
    panelAlignment?: ToolbarPanelAlignment;
    /** Use Drag Interaction to open popups with nest action buttons */
    useDragInteraction?: boolean;
    /** Determines whether to use mouse proximity to alter the opacity of the toolbar */
    toolbarOpacitySetting?: ToolbarOpacitySetting;
    /** Optional function to call on any item execution */
    onItemExecuted?: OnItemExecutedFunc;
    /** Optional function to call on any KeyDown events processed by toolbar */
    onKeyDown?: (e: React.KeyboardEvent) => void;
}
/** Component that displays tool settings as a bar across the top of the content view.
 * @beta
 */
export declare function Toolbar(props: ToolbarProps): JSX.Element;
//# sourceMappingURL=Toolbar.d.ts.map