"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Toolbar
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Toolbar = void 0;
require("./Toolbar.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const Items_1 = require("./Items");
const Direction_1 = require("./utilities/Direction");
const ToolbarWithOverflow_1 = require("./ToolbarWithOverflow");
function getItemWrapperClass(child) {
    // istanbul ignore else
    if (React.isValidElement(child)) {
        if (child.props && child.props.addGroupSeparator)
            return "components-toolbar-button-add-gap-before";
    }
    return "";
}
/** Component that displays tool settings as a bar across the top of the content view.
 * @beta
 */
function Toolbar(props) {
    const expandsTo = props.expandsTo ? props.expandsTo : Direction_1.Direction.Bottom;
    const useDragInteraction = !!props.useDragInteraction;
    const panelAlignment = props.panelAlignment ? props.panelAlignment : ToolbarWithOverflow_1.ToolbarPanelAlignment.Start;
    const [popupPanelCount, setPopupPanelCount] = React.useState(0);
    const handlePopupPanelOpenClose = React.useCallback((isOpening) => {
        // use setImmediate to avoid warning about setting state in Toolbar from render method of PopupItem/PopupItemWithDrag
        setImmediate(() => {
            setPopupPanelCount((prev) => {
                const nextCount = isOpening ? (prev + 1) : (prev - 1);
                // eslint-disable-next-line no-console
                // console.log(`new popup count = ${nextCount}`);
                return nextCount < 0 ? /* istanbul ignore next */ 0 : nextCount;
            });
        });
    }, []);
    const availableNodes = React.useMemo(() => {
        return props.items.map((item, index) => {
            let addGroupSeparator = false;
            if (index > 0)
                addGroupSeparator = item.groupPriority !== props.items[index - 1].groupPriority;
            return (React.createElement(ToolbarWithOverflow_1.ToolbarItemComponent, { key: item.id, item: item, addGroupSeparator: !!addGroupSeparator }));
        });
    }, [props.items]);
    const direction = ToolbarWithOverflow_1.getToolbarDirection(expandsTo);
    const className = classnames_1.default("components-toolbar-overflow-sizer", Direction_1.OrthogonalDirectionHelpers.getCssClassName(direction), props.className);
    // needed to construct DOM structure identical to ToolbarWithOverflow so same css can be applied.
    const wrapperClassName = classnames_1.default("components-toolbar-item-container", Direction_1.OrthogonalDirectionHelpers.getCssClassName(direction));
    return (React.createElement(ToolbarWithOverflow_1.ToolbarWithOverflowDirectionContext.Provider, { value: {
            expandsTo, direction, overflowExpandsTo: Direction_1.Direction.Right, panelAlignment, useDragInteraction,
            toolbarOpacitySetting: props.toolbarOpacitySetting ? props.toolbarOpacitySetting : ToolbarWithOverflow_1.ToolbarOpacitySetting.Proximity,
            overflowDirection: Direction_1.OrthogonalDirection.Horizontal,
            openPopupCount: popupPanelCount, onPopupPanelOpenClose: handlePopupPanelOpenClose, overflowDisplayActive: false,
            onItemExecuted: props.onItemExecuted ? props.onItemExecuted : /* istanbul ignore next */ () => { },
            onKeyDown: props.onKeyDown ? props.onKeyDown : /* istanbul ignore next */ (_e) => { },
        } },
        React.createElement(ToolbarWithOverflow_1.ToolbarItemContext.Provider, { value: {
                hasOverflow: false,
                useHeight: false,
                onResize: /* istanbul ignore next */ () => { },
            } }, (availableNodes.length > 0) &&
            React.createElement("div", { className: className, style: props.style, onKeyDown: props.onKeyDown, role: "presentation" },
                React.createElement(Items_1.ToolbarItems, { className: "components-items", direction: direction }, availableNodes.map((child, index) => React.createElement("div", { key: index, className: `${wrapperClassName} ${getItemWrapperClass(child)}` }, child)))))));
}
exports.Toolbar = Toolbar;
//# sourceMappingURL=Toolbar.js.map