"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Toolbar
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrthogonalDirectionHelpers = exports.OrthogonalDirection = exports.DirectionHelpers = exports.Direction = void 0;
/** Available directions.
 * @beta
 */
var Direction;
(function (Direction) {
    Direction[Direction["Left"] = 1] = "Left";
    Direction[Direction["Top"] = 2] = "Top";
    Direction[Direction["Right"] = 3] = "Right";
    Direction[Direction["Bottom"] = 4] = "Bottom";
})(Direction = exports.Direction || (exports.Direction = {}));
/** Helpers for [[Direction]].
 * @internal
 */
class DirectionHelpers {
    /** @returns Class name of specified [[Direction]] */
    static getCssClassName(direction) {
        switch (direction) {
            case Direction.Left:
                return DirectionHelpers.LEFT_CLASS_NAME;
            case Direction.Top:
                return DirectionHelpers.TOP_CLASS_NAME;
            case Direction.Right:
                return DirectionHelpers.RIGHT_CLASS_NAME;
            case Direction.Bottom:
                return DirectionHelpers.BOTTOM_CLASS_NAME;
        }
    }
    /** @returns Orthogonal direction of specified [[Direction]] */
    static getOrthogonalDirection(direction) {
        switch (direction) {
            case Direction.Left:
            case Direction.Right:
                return OrthogonalDirection.Horizontal;
            case Direction.Top:
            case Direction.Bottom:
                return OrthogonalDirection.Vertical;
        }
    }
}
exports.DirectionHelpers = DirectionHelpers;
/** Class name of [[Direction.Left]] */
DirectionHelpers.LEFT_CLASS_NAME = "components-direction-left";
/** Class name of [[Direction.Top]] */
DirectionHelpers.TOP_CLASS_NAME = "components-direction-top";
/** Class name of [[Direction.Right]] */
DirectionHelpers.RIGHT_CLASS_NAME = "components-direction-right";
/** Class name of [[Direction.Bottom]] */
DirectionHelpers.BOTTOM_CLASS_NAME = "components-direction-bottom";
/** Available orthogonal directions.
 * @alpha
 */
var OrthogonalDirection;
(function (OrthogonalDirection) {
    OrthogonalDirection[OrthogonalDirection["Vertical"] = 0] = "Vertical";
    OrthogonalDirection[OrthogonalDirection["Horizontal"] = 1] = "Horizontal";
})(OrthogonalDirection = exports.OrthogonalDirection || (exports.OrthogonalDirection = {}));
/** Helpers for [[OrthogonalDirection]].
 * @internal
 */
class OrthogonalDirectionHelpers {
    /** @returns Class name of specified [[OrthogonalDirection]] */
    static getCssClassName(direction) {
        switch (direction) {
            case OrthogonalDirection.Vertical:
                return OrthogonalDirectionHelpers.VERTICAL_CLASS_NAME;
            case OrthogonalDirection.Horizontal:
                return OrthogonalDirectionHelpers.HORIZONTAL_CLASS_NAME;
        }
    }
    /** @returns Opposite of specified [[OrthogonalDirection]] */
    static inverse(direction) {
        switch (direction) {
            case OrthogonalDirection.Vertical:
                return OrthogonalDirection.Horizontal;
            case OrthogonalDirection.Horizontal:
                return OrthogonalDirection.Vertical;
        }
    }
}
exports.OrthogonalDirectionHelpers = OrthogonalDirectionHelpers;
/** Class name of [[OrthogonalDirection.Vertical]] */
OrthogonalDirectionHelpers.VERTICAL_CLASS_NAME = "components-vertical";
/** Class name of [[OrthogonalDirection.Horizontal]] */
OrthogonalDirectionHelpers.HORIZONTAL_CLASS_NAME = "components-horizontal";
//# sourceMappingURL=Direction.js.map