/** @packageDocumentation
 * @module Tree
 */
import "./HighlightingEngine.scss";
import * as React from "react";
/**
 * Properties for identifying an active highlight on a node in a tree.
 * @see [[HighlightableTreeProps.activeMatch]]
 * @public
 */
export interface ActiveMatchInfo {
    nodeId: string;
    matchIndex: number;
}
/**
 * Properties for highlighting nodes in a tree.
 * @see [[ControlledTreeProps.nodeHighlightingProps]]
 * @public
 */
export interface HighlightableTreeProps {
    searchText: string;
    activeMatch?: ActiveMatchInfo;
}
/**
 * Properties for a highlightable [[TreeNode]]
 * @public
 */
export interface HighlightableTreeNodeProps {
    searchText: string;
    activeMatchIndex?: number;
}
/**
 * Tree highlighting engine
 * @beta
 */
export declare class HighlightingEngine {
    private _searchText;
    private _activeMatch?;
    static readonly ACTIVE_CLASS_NAME = "components-activehighlight";
    constructor(props: HighlightableTreeProps);
    isNodeActive(node: {
        id?: string;
    }): boolean | undefined;
    getActiveMatchIndex(node: {
        id?: string;
    }): number | undefined;
    createRenderProps(node: {
        id?: string;
    }): HighlightableTreeNodeProps;
    static renderNodeLabel(text: string, props: HighlightableTreeNodeProps): React.ReactNode;
}
//# sourceMappingURL=HighlightingEngine.d.ts.map