"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SimpleTreeDataProvider = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
/**
 * A tree data provider using [[SimpleTreeDataProviderHierarchy]].
 * @public
 */
class SimpleTreeDataProvider {
    constructor(hierarchy) {
        this.onTreeNodeChanged = new bentleyjs_core_1.BeEvent();
        this._hierarchy = hierarchy;
    }
    getNodesByParentId(parentId, pageOptions) {
        const nodes = this._hierarchy.get(parentId);
        if (!nodes)
            return [];
        if (!pageOptions)
            return [...nodes];
        let pageEndIndex;
        if (pageOptions.size !== undefined && pageOptions.size !== 0) {
            pageEndIndex = pageOptions.size;
            pageEndIndex += pageOptions.start ? pageOptions.start : 0;
        }
        return nodes.slice(pageOptions.start, pageEndIndex);
    }
    async getNodes(parent, pageOptions) {
        return this.getNodesByParentId(parent ? parent.id : undefined, pageOptions);
    }
    async getNodesCount(parent) {
        return this.getNodesByParentId(parent ? parent.id : undefined).length;
    }
}
exports.SimpleTreeDataProvider = SimpleTreeDataProvider;
//# sourceMappingURL=SimpleTreeDataProvider.js.map