"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasChildren = exports.isTreeDataProviderInterface = exports.isTreeDataProviderMethod = exports.isTreeDataProviderPromise = exports.isTreeDataProviderRaw = void 0;
/** Checks if [[TreeDataProvider]] is a [[TreeDataProviderRaw]]
 * @public
 */
const isTreeDataProviderRaw = (provider) => {
    return Array.isArray(provider);
};
exports.isTreeDataProviderRaw = isTreeDataProviderRaw;
/** Checks if [[TreeDataProvider]] is a [[TreeDataProviderPromise]]
 * @public
 */
const isTreeDataProviderPromise = (provider) => {
    return (undefined !== provider.then);
};
exports.isTreeDataProviderPromise = isTreeDataProviderPromise;
/** Checks if [[TreeDataProvider]] is a [[TreeDataProviderMethod]]
 * @public
 */
const isTreeDataProviderMethod = (provider) => {
    return (typeof provider === "function");
};
exports.isTreeDataProviderMethod = isTreeDataProviderMethod;
/** Checks if [[TreeDataProvider]] is an [[ITreeDataProvider]]
 * @public
 */
const isTreeDataProviderInterface = (provider) => {
    const candidate = provider;
    return undefined !== candidate.getNodes && undefined !== candidate.getNodesCount;
};
exports.isTreeDataProviderInterface = isTreeDataProviderInterface;
/**
 * Determines whether node has children
 * @param node node to check
 * @returns whether node has children
 * @public
 */
const hasChildren = (node) => {
    const nodeAsImmediate = node;
    if ("children" in nodeAsImmediate && nodeAsImmediate.children && nodeAsImmediate.children.length > 0)
        return true;
    const nodeAsDelayed = node;
    if ("hasChildren" in nodeAsDelayed && nodeAsDelayed.hasChildren)
        return true;
    return false;
};
exports.hasChildren = hasChildren;
//# sourceMappingURL=TreeDataProvider.js.map