/** @packageDocumentation
 * @module Tree
 */
/// <reference types="react" />
import { CheckBoxState } from "@bentley/ui-core";
import { SelectionMode } from "../../common/selection/SelectionModes";
import { TreeActions } from "./TreeActions";
import { TreeEvents } from "./TreeEvents";
import { VisibleTreeNodes } from "./TreeModel";
import { ITreeNodeLoader } from "./TreeNodeLoader";
/**
 * Default event dispatcher that emits tree events according performed actions.
 * It converts low level tree events into TreeEvents.
 * @internal
 */
export declare class TreeEventDispatcher implements TreeActions {
    private _treeEvents;
    private _nodeLoader;
    private _getVisibleNodes;
    private _selectionManager;
    private _activeSelections;
    constructor(treeEvents: TreeEvents, nodeLoader: ITreeNodeLoader, selectionMode: SelectionMode, getVisibleNodes?: () => VisibleTreeNodes);
    setVisibleNodes(visibleNodes: () => VisibleTreeNodes): void;
    onNodeCheckboxClicked(nodeId: string, newState: CheckBoxState): void;
    onNodeExpanded(nodeId: string): void;
    onNodeCollapsed(nodeId: string): void;
    onNodeClicked(nodeId: string, event: React.MouseEvent<Element, MouseEvent>): void;
    onNodeMouseDown(nodeId: string): void;
    onNodeMouseMove(nodeId: string): void;
    onNodeEditorActivated(nodeId: string): void;
    onTreeKeyDown(event: React.KeyboardEvent): void;
    onTreeKeyUp(event: React.KeyboardEvent): void;
    private collectSelectionChanges;
    private collectNodesBetween;
    private iterateNodesBetween;
    private collectNodeItems;
    private static groupNodesByLoadingState;
}
//# sourceMappingURL=TreeEventDispatcher.d.ts.map