"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TreeNodeContent = void 0;
require("./NodeContent.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const ItemStyle_1 = require("../../../properties/ItemStyle");
const ValueRendererManager_1 = require("../../../properties/ValueRendererManager");
const HighlightingEngine_1 = require("../../HighlightingEngine");
const TreeNodeEditor_1 = require("./TreeNodeEditor");
/** React component for displaying [[TreeNode]] label
 * @internal
 */
function TreeNodeContent(props) {
    const { node, valueRendererManager, onLabelRendered, highlightProps } = props;
    const label = React.useMemo(() => getLabel(node, valueRendererManager, highlightProps), [node, valueRendererManager, highlightProps]);
    React.useEffect(() => {
        onLabelRendered && onLabelRendered(node);
    }, [label, node, onLabelRendered]);
    // handle cell editing
    let editor;
    if (props.node.editingInfo) {
        // if cell editing is enabled, return editor instead of the label
        const style = getStyle(props.node.item.style, props.node.isSelected);
        const editorProps = {
            node: props.node,
            onCancel: props.node.editingInfo.onCancel,
            onCommit: props.node.editingInfo.onCommit,
            style,
        };
        editor = props.nodeEditorRenderer ? props.nodeEditorRenderer(editorProps) : React.createElement(TreeNodeEditor_1.TreeNodeEditor, Object.assign({}, editorProps));
    }
    const isDescriptionEnabled = props.node.item.description && props.showDescription;
    const containerClassName = classnames_1.default("components-controlledTree-node-content", isDescriptionEnabled ? "with-description" : undefined, props.className);
    const descriptionClassName = classnames_1.default("components-controlledTree-node-description", editor ? "with-editor" : undefined);
    return (React.createElement("div", { className: containerClassName, style: props.style },
        editor ? editor : label,
        isDescriptionEnabled ?
            React.createElement("div", { className: descriptionClassName }, props.node.item.description)
            : undefined));
}
exports.TreeNodeContent = TreeNodeContent;
function getLabel(node, valueRendererManager, highlightProps) {
    // handle filtered matches' highlighting
    const highlightCallback = highlightProps
        ? (text) => HighlightingEngine_1.HighlightingEngine.renderNodeLabel(text, highlightProps)
        : undefined;
    // handle custom cell rendering
    const context = {
        containerType: ValueRendererManager_1.PropertyContainerType.Tree,
        style: getStyle(node.item.style, node.isSelected),
        textHighlighter: highlightCallback,
        defaultValue: React.createElement(ui_core_1.TreeNodePlaceholder, { level: 0, "data-testid": "node-label-placeholder" }),
    };
    return valueRendererManager.render(node.item.label, context);
}
function getStyle(style, isSelected) {
    return ItemStyle_1.ItemStyleProvider.createStyle(style ? style : {}, isSelected);
}
//# sourceMappingURL=NodeContent.js.map