/** @packageDocumentation
 * @module Tree
 */
import * as React from "react";
import { CommonProps, NodeCheckboxRenderer } from "@bentley/ui-core";
import { HighlightableTreeNodeProps } from "../../HighlightingEngine";
import { ITreeImageLoader } from "../../ImageLoader";
import { TreeActions } from "../TreeActions";
import { TreeModelNode } from "../TreeModel";
import { TreeNodeEditorRenderer } from "./TreeNodeEditor";
/**
 * Properties for [[TreeNodeRenderer]].
 * @public
 */
export interface TreeNodeRendererProps extends CommonProps {
    node: TreeModelNode;
    treeActions: TreeActions;
    /** Properties used to highlight matches when tree is filtered. */
    nodeHighlightProps?: HighlightableTreeNodeProps;
    /**
     * Callback used to detect when label is rendered. It is used by TreeRenderer for scrolling to active match.
     * @internal
     */
    onLabelRendered?: (node: TreeModelNode) => void;
}
/**
 * Extended properties for [[TreeNodeRenderer]].
 * @beta
 */
export interface ExtendedTreeNodeRendererProps extends TreeNodeRendererProps {
    /** Callback to render custom checkbox. */
    checkboxRenderer?: NodeCheckboxRenderer;
    /** Callback to render custom node editor when node is in editing mode. */
    nodeEditorRenderer?: TreeNodeEditorRenderer;
    /** Specifies whether to show descriptions or not. */
    descriptionEnabled?: boolean;
    /** Image loader used to load icon. */
    imageLoader?: ITreeImageLoader;
}
/**
 * Default component for rendering tree node.
 * @beta
 */
export declare const TreeNodeRenderer: React.MemoExoticComponent<(props: ExtendedTreeNodeRendererProps) => JSX.Element>;
//# sourceMappingURL=TreeNodeRenderer.d.ts.map