"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TreeNodeRenderer = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const ImageRenderer_1 = require("../../../common/ImageRenderer");
const ValueRendererManager_1 = require("../../../properties/ValueRendererManager");
const TreeComponentTestId_1 = require("../../TreeComponentTestId");
const NodeContent_1 = require("./NodeContent");
/**
 * Default component for rendering tree node.
 * @beta
 */
exports.TreeNodeRenderer = React.memo((props) => {
    const label = (React.createElement(NodeContent_1.TreeNodeContent, { key: props.node.id, node: props.node, showDescription: props.descriptionEnabled, valueRendererManager: ValueRendererManager_1.PropertyValueRendererManager.defaultManager, highlightProps: props.nodeHighlightProps, onLabelRendered: props.onLabelRendered, nodeEditorRenderer: props.nodeEditorRenderer }));
    function onExpansionToggle() {
        if (props.node.isExpanded)
            props.treeActions.onNodeCollapsed(props.node.id);
        else
            props.treeActions.onNodeExpanded(props.node.id);
    }
    const createCheckboxProps = (checkboxInfo) => ({
        state: checkboxInfo.state,
        tooltip: checkboxInfo.tooltip,
        isDisabled: checkboxInfo.isDisabled,
        onClick: (newState) => props.treeActions.onNodeCheckboxClicked(props.node.id, newState),
    });
    return (React.createElement(ui_core_1.TreeNode, { "data-testid": TreeComponentTestId_1.TreeComponentTestId.Node, className: props.className, checkboxProps: props.node.checkbox.isVisible ? createCheckboxProps(props.node.checkbox) : undefined, style: props.style, isExpanded: props.node.isExpanded, isSelected: props.node.isSelected, isLoading: props.node.isLoading, isLeaf: props.node.numChildren === 0, icon: props.imageLoader ? React.createElement(TreeNodeIcon, { node: props.node, imageLoader: props.imageLoader }) : undefined, label: label, level: props.node.depth, onClick: (event) => props.treeActions.onNodeClicked(props.node.id, event), onMouseDown: () => props.treeActions.onNodeMouseDown(props.node.id), onMouseMove: () => props.treeActions.onNodeMouseMove(props.node.id), onClickExpansionToggle: onExpansionToggle, renderOverrides: { renderCheckbox: props.checkboxRenderer } }));
});
function TreeNodeIcon(props) {
    const { imageLoader, node } = props;
    const image = imageLoader.load(node.item);
    if (!image)
        return null;
    const renderer = new ImageRenderer_1.ImageRenderer();
    return React.createElement(React.Fragment, null, renderer.render(image));
}
//# sourceMappingURL=TreeNodeRenderer.js.map