/** @packageDocumentation
 * @module Tree
 */
import { TreeNodeItem } from "../../TreeDataProvider";
import { Observable } from "../Observable";
import { CheckboxStateChange } from "../TreeEvents";
import { TreeModelNode } from "../TreeModel";
import { TreeModelSource } from "../TreeModelSource";
import { ITreeNodeLoader, TreeNodeLoadResult } from "../TreeNodeLoader";
/**
 * Provides basic tree manipulation implementation for various cases like
 * expand/collapse node, modify/replace/clear selection. It is used by default
 * tree event handler to modify model when events occur.
 * @internal
 */
export declare class TreeModelMutator {
    private _modelSource;
    private _nodeLoader;
    private _collapsedChildrenDisposalEnabled;
    constructor(modelSource: TreeModelSource, nodeLoader: ITreeNodeLoader, collapsedChildrenDisposalEnabled: boolean);
    get modelSource(): TreeModelSource;
    expandNode(nodeId: string): Observable<TreeNodeLoadResult>;
    collapseNode(nodeId: string): void;
    modifySelection(nodesToSelect: TreeNodeItem[], nodesToDeselect: TreeNodeItem[]): void;
    replaceSelection(nodesToSelect: TreeNodeItem[]): void;
    clearNodeSelection(): void;
    setCheckboxStates(stateChanges: CheckboxStateChange[]): void;
    activateEditing(nodeId: string, onCommit: (node: TreeModelNode, newValue: string) => void): void;
    private createNodeEditingInfo;
}
//# sourceMappingURL=TreeModelMutator.d.ts.map