"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CellEditingEngine = void 0;
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const EditorContainer_1 = require("../../editors/EditorContainer");
/** Tree Cell editing information
 * @beta
 * @deprecated Use [ControlledTree]($ui-components) instead. Will be removed in iModel.js 3.0.
 */
class CellEditingEngine {
    /**
     * @param props Cell editing properties
     */
    constructor(props) {
        this._onCommit = async (args) => {
            // istanbul ignore next
            if (!this._getCurrentlyEditedNode || !this._setCurrentlyEditedNode)
                return;
            // istanbul ignore else
            if (this._getCurrentlyEditedNode()) {
                const newValue = args.newValue.value;
                const cellUpdatedArgs = {
                    node: this._getCurrentlyEditedNode(),
                    newValue,
                };
                const allowed = await this._props.onCellUpdated(cellUpdatedArgs);
                // istanbul ignore else
                if (allowed)
                    this._getCurrentlyEditedNode().setDirty(true);
            }
            this.deactivateEditor();
        };
        this.deactivateEditor = () => {
            if (!this._setCurrentlyEditedNode || !this._getCurrentlyEditedNode)
                return;
            const node = this._getCurrentlyEditedNode();
            if (!node)
                return;
            node.setDirty(true);
            this._setCurrentlyEditedNode(undefined);
        };
        this.checkStatus = (node, isPressedItemSelected) => {
            if (node.selected() && isPressedItemSelected && node.payload && node.payload.isEditable)
                this.activateEditor(node);
            else
                this.deactivateEditor();
        };
        this.activateEditor = (node) => {
            if (!this._setCurrentlyEditedNode || !this._getCurrentlyEditedNode)
                return;
            const currentNode = this._getCurrentlyEditedNode();
            if (currentNode === node)
                return;
            if (currentNode)
                currentNode.setDirty(true);
            this._setCurrentlyEditedNode(node);
            this._props.onCellEditing(node);
        };
        this._props = props;
    }
    /**
     * @param getCurrentNode Function, that returns currently edited node
     * @param setCurrentNode Function, that sets currently edited node
     */
    subscribe(getCurrentNode, setCurrentNode) {
        this._getCurrentlyEditedNode = getCurrentNode;
        this._setCurrentlyEditedNode = setCurrentNode;
    }
    get hasSubscriptions() {
        return !!(this._getCurrentlyEditedNode && this._setCurrentlyEditedNode);
    }
    unsubscribe() {
        this._getCurrentlyEditedNode = undefined;
        this._setCurrentlyEditedNode = undefined;
    }
    static createPropertyRecord(value, typename = "text", editor) {
        const v = {
            valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
            value,
            displayValue: value,
        };
        const p = {
            name: "tree-cell-editor",
            displayLabel: "Tree Cell Editor",
            typename,
        };
        // istanbul ignore next
        if (editor)
            p.editor = { name: editor, params: [] };
        const record = new ui_abstract_1.PropertyRecord(v, p);
        record.description = "";
        record.isReadonly = false;
        return record;
    }
    isEditingEnabled(node) {
        return this._props && this._getCurrentlyEditedNode && node === this._getCurrentlyEditedNode();
    }
    renderEditor(node, style) {
        const record = CellEditingEngine.createPropertyRecord(node.text);
        return (React.createElement("span", { style: style },
            React.createElement(EditorContainer_1.EditorContainer, { propertyRecord: record, title: record.description, onCommit: this._onCommit, onCancel: this.deactivateEditor, ignoreEditorBlur: this._props.ignoreEditorBlur, setFocus: true })));
    }
}
exports.CellEditingEngine = CellEditingEngine;
//# sourceMappingURL=CellEditingEngine.js.map