"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeEventManager = void 0;
const concat_1 = require("rxjs/internal/observable/concat");
const NodeLoadingOrchestrator_1 = require("./NodeLoadingOrchestrator");
/** @internal @deprecated */
class NodeEventManager {
    constructor(loadingOrchestrator, bulkCheckboxActionsEnabled, callbacks) {
        this._loadingOrchestrator = loadingOrchestrator;
        this._bulkCheckboxActionsEnabled = bulkCheckboxActionsEnabled;
        this._callbacks = callbacks;
    }
    modifySelection(selectedNodes, deselectedNodes) {
        const deselectedNodesSet = new NodeLoadingOrchestrator_1.NodeSet(deselectedNodes.map((node) => NodeLoadingOrchestrator_1.NodeKey.for(node)));
        this._loadingOrchestrator.prepareNodes(selectedNodes.concat(deselectedNodes))
            .subscribe((preparedNodes) => {
            if (preparedNodes.length === 0) {
                return;
            }
            const preparedSelectedNodes = [];
            const preparedDeselectedNodes = [];
            for (const node of preparedNodes) {
                if (deselectedNodesSet.has(NodeLoadingOrchestrator_1.NodeKey.for(node))) {
                    preparedDeselectedNodes.push(node);
                }
                else {
                    preparedSelectedNodes.push(node);
                }
            }
            this._callbacks.onSelectionModified(preparedSelectedNodes, preparedDeselectedNodes);
        });
    }
    replaceSelection(selectedNodes) {
        this._loadingOrchestrator.cancelLoading();
        let selectionReplaced = false;
        this._loadingOrchestrator.prepareNodes(selectedNodes)
            .subscribe((preparedNodes) => {
            if (selectionReplaced) {
                this._callbacks.onSelectionModified(preparedNodes, []);
            }
            else {
                this._callbacks.onSelectionReplaced(preparedNodes);
                selectionReplaced = true;
            }
        });
    }
    /**
     * Selects all visible nodes that are between node1 and node2. Both nodes
     * must be loaded and can be supplied in any order.
     */
    selectNodesBetween(replace, node1, node2) {
        if (replace) {
            this._loadingOrchestrator.cancelLoading();
        }
        this._loadingOrchestrator.prepareNodesBetween(node1, node2)
            .subscribe((preparedNodes) => {
            if (replace) {
                this._callbacks.onSelectionReplaced(preparedNodes);
                replace = false;
            }
            else {
                this._callbacks.onSelectionModified(preparedNodes, []);
            }
        });
    }
    setCheckboxState(node, state) {
        if (!node.selected() || !this._bulkCheckboxActionsEnabled) {
            this._callbacks.onCheckboxStateChanged([{ node, newState: state }]);
            return;
        }
        concat_1.concat(this._loadingOrchestrator.prepareLoadedNodes(), this._loadingOrchestrator.preparePendingNodes())
            .subscribe((loadedNodes) => {
            const affectedNodes = loadedNodes.filter((loadedNode) => {
                if (!loadedNode.selected()) {
                    return false;
                }
                if (loadedNode.payload.isCheckboxDisabled) {
                    return false;
                }
                return node.payload.checkBoxState !== state;
            });
            this._callbacks.onCheckboxStateChanged(affectedNodes.map((affectedNode) => ({ node: affectedNode, newState: state })));
        });
    }
}
exports.NodeEventManager = NodeEventManager;
//# sourceMappingURL=NodeEventManager.js.map