"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TreeNodeIcon = exports.TreeNode = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const ImageRenderer_1 = require("../../../common/ImageRenderer");
const TreeComponentTestId_1 = require("../../TreeComponentTestId");
const NodeContent_1 = require("./NodeContent");
/**
 * Default component for rendering a node for the [DEPRECATED_Tree]($ui-components)
 * @public
 * @deprecated Use [ControlledTree]($ui-components) instead
 */
class TreeNode extends React.Component {
    constructor(props) {
        super(props);
        this._onCheckboxClick = (newValue) => {
            // istanbul ignore else
            if (this.props.checkboxProps && this.props.checkboxProps.onClick)
                this.props.checkboxProps.onClick(this.props.node, newValue);
        };
    }
    shouldComponentUpdate(nextProps) {
        if (nextProps.node.isDirty() || doPropsDiffer(this.props, nextProps))
            return true;
        // This is an anti-pattern, but it's main purpose is for testing.
        // We need to know when all of the nodes have finished rendering
        // and asynchronous updates make it very difficult.
        // If it should not render, let the parent know that it's
        // already fully rendered
        // istanbul ignore else
        if (nextProps.renderId && nextProps.onFinalRenderComplete)
            nextProps.onFinalRenderComplete(nextProps.renderId);
        return false;
    }
    componentDidUpdate(_prevProps) {
        // istanbul ignore else
        if (this.props.node.isDirty())
            this.props.node.setDirty(false);
    }
    render() {
        const checkboxProps = this.props.checkboxProps ? Object.assign(Object.assign({}, this.props.checkboxProps), { onClick: this._onCheckboxClick }) : undefined;
        const label = (React.createElement(NodeContent_1.TreeNodeContent, { node: this.props.node, cellEditing: this.props.cellEditing, highlightProps: this.props.highlightProps, showDescription: this.props.showDescription, valueRendererManager: this.props.valueRendererManager, onFinalRenderComplete: this.props.onFinalRenderComplete, renderId: this.props.renderId }));
        return (React.createElement(ui_core_1.TreeNode, { "data-testid": TreeComponentTestId_1.TreeComponentTestId.Node, className: this.props.className, style: this.props.style, isExpanded: this.props.node.expanded(), isSelected: this.props.node.selected(), isLoading: this.props.node.loading(), isLeaf: !this.props.node.hasOrWillHaveChildren(), label: label, icon: this.props.imageLoader ? React.createElement(TreeNodeIcon, { node: this.props.node, imageLoader: this.props.imageLoader }) : undefined, checkboxProps: checkboxProps, level: this.props.node.getParents().length, renderOverrides: { renderCheckbox: this.props.renderOverrides ? this.props.renderOverrides.renderCheckbox : undefined }, onClick: this.props.onClick, onMouseMove: this.props.onMouseMove, onMouseDown: this.props.onMouseDown, onClickExpansionToggle: () => this.props.node.toggleCollapse() }));
    }
}
exports.TreeNode = TreeNode;
function doPropsDiffer(props1, props2) {
    return ui_core_1.shallowDiffers(props1.highlightProps, props2.highlightProps)
        || ui_core_1.shallowDiffers(props1.renderOverrides, props2.renderOverrides)
        || props1.valueRendererManager !== props2.valueRendererManager
        || props1.cellEditing !== props2.cellEditing
        || props1.showDescription !== props2.showDescription
        || ui_core_1.shallowDiffers(props1.checkboxProps, props2.checkboxProps)
        || props1.imageLoader !== props2.imageLoader;
}
/** React component that renders tree node icons
 * @public
 * @deprecated Use [ControlledTree]($ui-components) instead. Will be removed in iModel.js 3.0.
 */
function TreeNodeIcon(props) {
    const { imageLoader, node } = props;
    let image;
    if (node.itree && node.itree.icon)
        image = imageLoader.load(node.itree);
    else if (node.payload && node.payload.icon)
        image = imageLoader.load(node.payload);
    if (!image)
        return null;
    const renderer = new ImageRenderer_1.ImageRenderer();
    return React.createElement(React.Fragment, null, renderer.render(image));
}
exports.TreeNodeIcon = TreeNodeIcon;
//# sourceMappingURL=Node.js.map