"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TreeNodeContent = void 0;
require("./NodeContent.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const ui_abstract_1 = require("@bentley/ui-abstract");
const ui_core_1 = require("@bentley/ui-core");
const ItemStyle_1 = require("../../../properties/ItemStyle");
const ValueRendererManager_1 = require("../../../properties/ValueRendererManager");
const UiComponents_1 = require("../../../UiComponents");
const HighlightingEngine_1 = require("../../HighlightingEngine");
/** React component for displaying [[TreeNode]] label
 * @internal @deprecated
 */
class TreeNodeContent extends React.Component {
    constructor(props) {
        super(props);
        this._onLabelStateChanged = () => {
            if (this.props.renderId && this.props.onFinalRenderComplete)
                this.props.onFinalRenderComplete(this.props.renderId);
        };
        this.state = {
            label: React.createElement(ui_core_1.TreeNodePlaceholder, { level: 0, "data-testid": "node-label-placeholder" }),
        };
    }
    getStyle(style, isSelected) {
        return ItemStyle_1.ItemStyleProvider.createStyle(style ? /* istanbul ignore next */ style : {}, isSelected);
    }
    nodeToPropertyRecord(node) {
        const value = {
            displayValue: node.text,
            value: node.text,
            valueFormat: ui_abstract_1.PropertyValueFormat.Primitive,
        };
        const property = {
            displayLabel: UiComponents_1.UiComponents.translate("general.label"),
            typename: "string",
            name: "node_label",
        };
        return new ui_abstract_1.PropertyRecord(value, property);
    }
    getLabel(props) {
        // handle filtered matches' highlighting
        let labelElement = props.node.text;
        if (props.highlightProps)
            labelElement = HighlightingEngine_1.HighlightingEngine.renderNodeLabel(props.node.text, props.highlightProps);
        // handle custom cell rendering
        const context = {
            containerType: ValueRendererManager_1.PropertyContainerType.Tree,
            decoratedTextElement: labelElement,
            style: props.node.payload ? this.getStyle(props.node.payload.style, props.node.selected()) : /* istanbul ignore next */ undefined,
        };
        const nodeRecord = this.nodeToPropertyRecord(props.node);
        return props.valueRendererManager.render(nodeRecord, context);
    }
    updateLabel(props) {
        const label = this.getLabel(props);
        this.setState({ label }, this._onLabelStateChanged);
    }
    componentDidMount() {
        this.updateLabel(this.props);
        this.setState((_, props) => ({ renderInfo: createRenderInfo(props.node) }));
    }
    static doPropsDiffer(props1, props2) {
        return ui_core_1.shallowDiffers(props1.highlightProps, props2.highlightProps)
            || props1.valueRendererManager !== props2.valueRendererManager
            || props1.cellEditing !== props2.cellEditing
            || props1.showDescription !== props2.showDescription;
    }
    static needsLabelUpdate(state, prevProps, nextProps) {
        if (this.doPropsDiffer(prevProps, nextProps)) {
            return true;
        }
        if (nextProps.node.itree.dirtyTimestamp && (!state.renderInfo || state.renderInfo.timestamp < nextProps.node.itree.dirtyTimestamp || state.renderInfo.counter < nextProps.node.itree.dirtyCounter)) {
            return true;
        }
        return false;
    }
    componentDidUpdate(prevProps) {
        if (TreeNodeContent.needsLabelUpdate(this.state, prevProps, this.props)) {
            this.updateLabel(this.props);
        }
        const renderInfo = createRenderInfo(this.props.node);
        // istanbul ignore else
        if (renderInfo !== this.state.renderInfo)
            this.setState({ renderInfo });
    }
    shouldComponentUpdate(nextProps, nextState) {
        if (this.state.label !== nextState.label || TreeNodeContent.needsLabelUpdate(nextState, this.props, nextProps))
            return true;
        // istanbul ignore else
        if (nextState.label) {
            // This is an anti-pattern, but it's main purpose is for testing.
            // We need to know when all of the nodes have finished rendering
            // and asynchronous updates make it very difficult.
            // If it should not render, let the parent know that it's
            // already fully rendered
            if (nextProps.renderId && nextProps.onFinalRenderComplete)
                nextProps.onFinalRenderComplete(nextProps.renderId);
        }
        return false;
    }
    render() {
        // handle cell editing
        let editor;
        if (this.props.cellEditing && this.props.cellEditing.isEditingEnabled(this.props.node)) {
            // if cell editing is enabled, return editor instead of the label
            const style = this.props.node.payload ? this.getStyle(this.props.node.payload.style, this.props.node.selected()) : /* istanbul ignore next */ undefined;
            editor = this.props.cellEditing.renderEditor(this.props.node, style);
        }
        const isDescriptionEnabled = this.props.node.payload && this.props.node.payload.description && this.props.showDescription;
        const containerClassName = classnames_1.default("components-tree-node-content", isDescriptionEnabled ? "with-description" : undefined, this.props.className);
        const descriptionClassName = classnames_1.default("components-tree-node-description", editor ? "with-editor" : undefined);
        return (React.createElement("div", { className: containerClassName, style: this.props.style },
            editor ? editor : this.state.label,
            isDescriptionEnabled ?
                React.createElement("div", { className: descriptionClassName }, this.props.node.payload.description)
                : undefined));
    }
}
exports.TreeNodeContent = TreeNodeContent;
const createRenderInfo = (node) => ({
    timestamp: node.itree.dirtyTimestamp || 0,
    counter: node.itree.dirtyCounter || 0,
});
//# sourceMappingURL=NodeContent.js.map