"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEPRECATED_Tree = void 0;
// css
require("./Tree.scss");
const classnames_1 = __importDefault(require("classnames"));
const React = __importStar(require("react"));
const react_virtualized_1 = require("react-virtualized");
// bentley imports
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const ui_core_1 = require("@bentley/ui-core");
const getPropertyRecordAsString_1 = require("../../../common/getPropertyRecordAsString");
const SelectionHandler_1 = require("../../../common/selection/SelectionHandler");
// selection-related imports
const SelectionModes_1 = require("../../../common/selection/SelectionModes");
const ValueRendererManager_1 = require("../../../properties/ValueRendererManager");
// misc
const UiComponents_1 = require("../../../UiComponents");
// node highlighting
const HighlightingEngine_1 = require("../../HighlightingEngine");
const ImageLoader_1 = require("../../ImageLoader");
const TreeDataProvider_1 = require("../../TreeDataProvider");
const CellEditingEngine_1 = require("../CellEditingEngine");
const NodeEventManager_1 = require("../NodeEventManager");
const NodeLoadingOrchestrator_1 = require("../NodeLoadingOrchestrator");
// tree-related imports
const BeInspireTree_1 = require("./BeInspireTree");
const Node_1 = require("./Node");
/**
 * A Tree React component that uses the core of BeInspireTree but renders with TreeBase and TreeNodeBase from ui-core.
 * @public
 * @deprecated Use [ControlledTree]($ui-components) instead. Will be removed in iModel.js 3.0.
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
class DEPRECATED_Tree extends React.Component {
    /** @internal */
    constructor(props) {
        super(props);
        this._mounted = false;
        this._treeRef = React.createRef();
        this._scrollableContainerRef = React.createRef();
        this._pressedItemSelected = false;
        /** Used to delay the automatic scrolling when stepping through highlighted text */
        this._shouldScrollToActiveNode = false;
        this._defaultImageLoader = new ImageLoader_1.TreeImageLoader();
        this._setCellEditorState = (state) => this.setState({ currentlyEditedNode: state });
        this._getCellEditorState = () => this.state.currentlyEditedNode;
        this._onModelChanged = () => {
            // just re-set the model to initiate update
            this.setState((prev) => ({ model: prev.model }));
        };
        this._onModelReady = async () => {
            // istanbul ignore else
            if (this._mounted) {
                await this.handleCheckboxes(this.state.prev, this.props, true);
                this.setState({ modelReady: true });
            }
        };
        this._onNodesSelected = (selectedNodes, replace) => {
            // We don't know whether range or regular selection is happening.
            // Assume that if there are nodes without payload then shift-click action
            // happened and we are selecting a node range.
            const rangeSelection = selectedNodes.some((node) => node.payload === undefined);
            if (rangeSelection) {
                this.state.nodeEventManager.selectNodesBetween(replace, selectedNodes[0], selectedNodes[selectedNodes.length - 1]);
            }
            else {
                if (replace) {
                    this.state.nodeEventManager.replaceSelection(selectedNodes);
                }
                else {
                    this.state.nodeEventManager.modifySelection(selectedNodes, []);
                }
            }
        };
        this._onNodesDeselected = (deselectedNodes) => {
            this.state.nodeEventManager.modifySelection([], deselectedNodes);
        };
        this._onNodeExpanded = (node) => {
            if (this.props.onNodeExpanded)
                this.props.onNodeExpanded(node.payload);
            // note: we get here when parent node is expanded. if data provider loads
            // children immediately, then node has children here. if data provider
            // delay loads children, then `node.getChildren()` returns empty array and
            // the `_onChildrenLoaded` callback is called where we do the same thing as here
            const children = node.getChildren();
            if (children.length > 0) {
                this.state.model.updateNodesSelection(BeInspireTree_1.toNodes(children), this.props.selectedNodes);
                if (this.props.checkboxInfo) {
                    // eslint-disable-next-line @typescript-eslint/no-floating-promises
                    this.state.model.updateNodesCheckboxes(BeInspireTree_1.toNodes(children), this.props.checkboxInfo);
                }
            }
            this._nodesSelectionHandlers = undefined;
        };
        this._onNodeCollapsed = (node) => {
            if (this.props.onNodeCollapsed)
                this.props.onNodeCollapsed(node.payload);
            this._nodesSelectionHandlers = undefined;
        };
        this._onModelLoaded = (rootNodes) => {
            // note: if pagination is enabled, this callback is called for every
            // root nodes' page
            if (this.props.onRootNodesLoaded) {
                // we call the `onRootNodesLoaded` callback only with the nodes that have payload
                const nodesWithPayload = rootNodes.filter((n) => undefined !== n.payload);
                this.props.onRootNodesLoaded(nodesWithPayload.map((n) => n.payload));
            }
            this.onNodesLoaded(rootNodes);
        };
        this._onChildrenLoaded = (parentNode) => {
            // note: we get here when parent node is expanded and data provider
            // finishes delay-loading its child nodes. If pagination is enabled, this callback
            // is called for every page of children
            const children = parentNode.getChildren();
            if (this.props.onChildrenLoaded) {
                // we call the `onChildrenLoaded` callback only with the nodes that have payload
                const nodesWithPayload = BeInspireTree_1.toNodes(children).filter((n) => undefined !== n.payload);
                this.props.onChildrenLoaded(parentNode.payload, nodesWithPayload.map((n) => n.payload));
            }
            this.onNodesLoaded(BeInspireTree_1.toNodes(children));
        };
        this._onTreeNodeChanged = (items) => {
            bentleyjs_core_1.using(this.state.model.pauseRendering(), async () => {
                for (const item of items) {
                    if (item) {
                        // specific node needs to be reloaded
                        const node = this.state.model.node(item.id);
                        // istanbul ignore else
                        if (node) {
                            const wasExpanded = node.expanded();
                            // eslint-disable-next-line @typescript-eslint/naming-convention
                            node.assign(DEPRECATED_Tree.inspireNodeFromTreeNodeItem(item, DEPRECATED_Tree.inspireNodeFromTreeNodeItem, node));
                            if (wasExpanded)
                                await node.loadChildren();
                        }
                    }
                    else {
                        // all root nodes need to be reloaded
                        await this.state.model.reload();
                    }
                }
            });
        };
        this._onMouseDown = () => {
            document.addEventListener("mouseup", this._onMouseUp, { capture: true, once: true });
        };
        this._onMouseUp = () => {
            this._selectionHandler.completeDragAction();
        };
        this._getNodeHeight = (node) => {
            const contentHeight = (this.props.showDescriptions && node && node.description) ? 43 : 24;
            const borderSize = 1;
            // Not counting node's border size twice because we want neighboring borders to overlap
            return contentHeight + borderSize;
        };
        this._createItemSelectionHandler = (node) => {
            return {
                preselect: () => {
                    this._pressedItemSelected = node.selected();
                },
                select: () => node.select(),
                deselect: () => node.deselect(),
                isSelected: () => node.selected(),
                item: () => node,
            };
        };
        this._multiSelectionHandler = {
            selectBetween: (node1, node2) => this.state.model.selectBetween(node1, node2),
            deselectAll: () => {
                this.state.model.deselectAll();
                if (!this._pressedItemSelected) {
                    if (this.state.cellEditingEngine)
                        this.state.cellEditingEngine.deactivateEditor();
                    this.forceUpdate();
                }
            },
            updateSelection: (selections, deselections) => {
                selections.forEach((x) => x.select());
                deselections.forEach((x) => x.deselect());
            },
            areEqual: (item1, item2) => item1 === item2,
        };
        this._onCheckboxClick = (node, newState) => {
            this.state.nodeEventManager.setCheckboxState(node, newState);
        };
        // eslint-disable-next-line @typescript-eslint/naming-convention
        this.defaultRenderNode = (node, props) => {
            return (React.createElement(Node_1.TreeNode, Object.assign({ key: node.id }, props)));
        };
        this._onNodeFullyRendered = (renderId) => {
            if (!this._nodesRenderInfo || this._nodesRenderInfo.renderId !== renderId)
                return;
            if (++this._nodesRenderInfo.rendered < this._nodesRenderInfo.total)
                return;
            // istanbul ignore else
            if (this.props.onNodesRender)
                this.props.onNodesRender();
            if (this._shouldScrollToActiveNode) {
                this.scrollToActiveNode();
                this._shouldScrollToActiveNode = false;
            }
            this._nodesRenderInfo = undefined;
        };
        this._selectionHandler = new SelectionHandler_1.SelectionHandler(props.selectionMode, this._onNodesSelected, this._onNodesDeselected);
        this._selectionHandler.onItemsSelectedCallback = this._onNodesSelected;
        this._selectionHandler.onItemsDeselectedCallback = this._onNodesDeselected;
        const model = DEPRECATED_Tree.createModel(props); // eslint-disable-line @typescript-eslint/naming-convention
        const nodeLoadingOrchestrator = DEPRECATED_Tree.createNodeLoadingOrchestrator(model, props); // eslint-disable-line @typescript-eslint/naming-convention
        const nodeEventManager = DEPRECATED_Tree.createNodeEventManager(nodeLoadingOrchestrator, model, props); // eslint-disable-line @typescript-eslint/naming-convention
        this.state = {
            prev: {
                dataProvider: props.dataProvider,
                selectedNodes: props.selectedNodes,
                checkboxInfo: props.checkboxInfo,
                bulkCheckboxActionsDisabled: props.bulkCheckboxActionsDisabled,
                modelReady: false,
            },
            model,
            modelReady: false,
            nodeLoadingOrchestrator,
            nodeEventManager,
        };
    }
    static createModel(props) {
        return new BeInspireTree_1.BeInspireTree({
            dataProvider: props.dataProvider,
            mapPayloadToInspireNodeConfig: DEPRECATED_Tree.inspireNodeFromTreeNodeItem,
            pageSize: props.pageSize,
            disposeChildrenOnCollapse: props.disposeChildrenOnCollapse,
        });
    }
    static createNodeLoadingOrchestrator(model, props) {
        return new NodeLoadingOrchestrator_1.NodeLoadingOrchestrator(model, {
            onLoadProgress: (loaded, total, cancel) => {
                // istanbul ignore else
                if (props.onSelectionLoadProgress) {
                    props.onSelectionLoadProgress(loaded, total, cancel);
                }
            },
            onLoadCanceled: () => {
                // istanbul ignore else
                if (props.onSelectionLoadCanceled) {
                    props.onSelectionLoadCanceled();
                }
            },
            onLoadFinished: () => {
                // istanbul ignore else
                if (props.onSelectionLoadFinished) {
                    props.onSelectionLoadFinished();
                }
            },
        });
    }
    static createNodeEventManager(nodeManager, model, props) {
        function selectNodes(nodesToSelect) {
            bentleyjs_core_1.using(model.mute([BeInspireTree_1.BeInspireTreeEvent.NodeSelected]), (_r) => {
                nodesToSelect.forEach((node) => node.select());
            });
        }
        return new NodeEventManager_1.NodeEventManager(nodeManager, !props.bulkCheckboxActionsDisabled, {
            onSelectionModified: (selectedNodes, deselectedNodes) => {
                selectNodes(selectedNodes);
                if (props.onNodesSelected && selectedNodes.length > 0)
                    props.onNodesSelected(selectedNodes.map(({ payload }) => payload), false);
                if (props.onNodesDeselected && deselectedNodes.length > 0)
                    props.onNodesDeselected(deselectedNodes.map(({ payload }) => payload));
            },
            onSelectionReplaced: (selectedNodes) => {
                selectNodes(selectedNodes);
                if (props.onNodesSelected && selectedNodes.length > 0)
                    props.onNodesSelected(selectedNodes.map(({ payload }) => payload), true);
            },
            onCheckboxStateChanged: (stateChanges) => {
                for (const { node, newState } of stateChanges) {
                    if (newState === ui_core_1.CheckBoxState.Off) {
                        node.uncheck();
                    }
                    else {
                        node.check();
                    }
                }
                // istanbul ignore else
                if (props.onCheckboxClick) {
                    props.onCheckboxClick(stateChanges.map(({ node, newState }) => ({ node: node.payload, newState })));
                }
            },
        });
    }
    /** @internal */
    static getDerivedStateFromProps(props, state) {
        const providerChanged = (props.dataProvider !== state.prev.dataProvider);
        const selectedNodesChanged = (props.selectedNodes !== state.prev.selectedNodes);
        const modelReadyChanged = (state.modelReady !== state.prev.modelReady);
        // create derived state that just updates `prev` values
        const derivedState = Object.assign(Object.assign({}, state), { prev: Object.assign(Object.assign({}, state.prev), { dataProvider: props.dataProvider, modelReady: state.modelReady, selectedNodes: props.selectedNodes, checkboxInfo: props.checkboxInfo, bulkCheckboxActionsDisabled: props.bulkCheckboxActionsDisabled, nodeHighlightingProps: props.nodeHighlightingProps, cellEditing: props.cellEditing }) });
        // update highlighting engine if related props changed
        if (props.nodeHighlightingProps !== state.prev.nodeHighlightingProps) {
            derivedState.highlightingEngine = props.nodeHighlightingProps ? new HighlightingEngine_1.HighlightingEngine(props.nodeHighlightingProps) : undefined;
        }
        // update cell editing engine if related props changed
        if (ui_core_1.shallowDiffers(props.cellEditing, state.prev.cellEditing)) {
            derivedState.cellEditingEngine = props.cellEditing ? new CellEditingEngine_1.CellEditingEngine(props.cellEditing) : /* istanbul ignore next */ undefined;
        }
        if (selectedNodesChanged || providerChanged) {
            state.nodeLoadingOrchestrator.cancelLoading();
        }
        // in case provider changed, have to re-create `model` and reset `modelReady`
        if (providerChanged) {
            derivedState.model = DEPRECATED_Tree.createModel(props); // eslint-disable-line @typescript-eslint/naming-convention
            derivedState.modelReady = false;
            derivedState.nodeLoadingOrchestrator = DEPRECATED_Tree.createNodeLoadingOrchestrator(derivedState.model, props); // eslint-disable-line @typescript-eslint/naming-convention
            derivedState.nodeEventManager = DEPRECATED_Tree.createNodeEventManager(derivedState.nodeLoadingOrchestrator, derivedState.model, props); // eslint-disable-line @typescript-eslint/naming-convention
        }
        else {
            const modelBecameReady = (modelReadyChanged && state.modelReady);
            if (modelBecameReady || selectedNodesChanged) {
                // note: not using `pauseRendering()` here to avoid firing `ChangesApplied`
                // when the EventsMuteContext is disposed - the component is going to be
                // rendered anyway if we got here
                bentleyjs_core_1.using((state.model.mute([BeInspireTree_1.BeInspireTreeEvent.ChangesApplied])), (_r) => {
                    // note: calling this may mutate `model` in state
                    state.model.updateTreeSelection(props.selectedNodes);
                });
            }
            if (props.bulkCheckboxActionsDisabled !== state.prev.bulkCheckboxActionsDisabled) {
                derivedState.nodeEventManager = DEPRECATED_Tree.createNodeEventManager(derivedState.nodeLoadingOrchestrator, derivedState.model, props); // eslint-disable-line @typescript-eslint/naming-convention
            }
        }
        return derivedState;
    }
    /** @internal */
    componentDidMount() {
        this._mounted = true;
        this.assignModelListeners(this.state.model);
        this.assignDataProviderListeners(this.props.dataProvider);
        if (this.state.cellEditingEngine && !this.state.cellEditingEngine.hasSubscriptions)
            this.state.cellEditingEngine.subscribe(this._getCellEditorState, this._setCellEditorState);
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        this.handleCheckboxes(this.state.prev, this.props);
        /* istanbul ignore next */
        if (this.props.onRender)
            this.props.onRender();
    }
    /** @internal */
    componentWillUnmount() {
        this.state.nodeLoadingOrchestrator.cancelLoading();
        this.dropModelListeners(this.state.model);
        this.dropDataProviderListeners(this.props.dataProvider);
        if (this.state.cellEditingEngine)
            this.state.cellEditingEngine.unsubscribe();
        this._mounted = false;
    }
    shouldComponentUpdate(nextProps, nextState) {
        if (this.state.modelReady !== nextState.modelReady || this.state.model !== nextState.model) {
            // always render when modelReady or model changes
            return true;
        }
        if (!nextState.modelReady) {
            // if we got here and model is not ready - don't render
            return false;
        }
        // otherwise, render when any of the following props / state change
        return this.props.selectedNodes !== nextProps.selectedNodes
            || this.props.checkboxInfo !== nextProps.checkboxInfo
            || ui_core_1.shallowDiffers(this.props.renderOverrides, nextProps.renderOverrides)
            || this.props.dataProvider !== nextProps.dataProvider
            || this.props.nodeHighlightingProps !== nextProps.nodeHighlightingProps
            || this.state.currentlyEditedNode !== nextState.currentlyEditedNode
            || this.state.model.visible().some((n) => n.isDirty());
    }
    /** @internal */
    componentDidUpdate(prevProps, prevState) {
        this._selectionHandler.selectionMode = this.props.selectionMode;
        if (this.props.selectedNodes !== prevProps.selectedNodes) {
            this.state.nodeLoadingOrchestrator.cancelLoading();
        }
        if (this.props.nodeHighlightingProps && ui_core_1.shallowDiffers(this.props.nodeHighlightingProps, prevProps.nodeHighlightingProps)) {
            // istanbul ignore else
            if (this._nodesRenderInfo)
                this._shouldScrollToActiveNode = true;
            else
                this.scrollToActiveNode();
        }
        if (this.state.model !== prevState.model) {
            this.dropModelListeners(prevState.model);
            this.assignModelListeners(this.state.model);
        }
        if (this.props.dataProvider !== prevProps.dataProvider) {
            this.dropDataProviderListeners(prevProps.dataProvider);
            this.assignDataProviderListeners(this.props.dataProvider);
        }
        // istanbul ignore next
        if (this.state.cellEditingEngine && !this.state.cellEditingEngine.hasSubscriptions) {
            this.state.cellEditingEngine.subscribe(this._getCellEditorState, this._setCellEditorState);
        }
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        this.handleCheckboxes(prevProps, this.props);
        /* istanbul ignore next */
        if (this.props.onRender)
            this.props.onRender();
    }
    async handleCheckboxes(prevProps, newProps, force) {
        const checkboxInfoChanged = (prevProps.checkboxInfo !== newProps.checkboxInfo);
        if ((force || checkboxInfoChanged) && newProps.checkboxInfo) {
            // note: using `pauseRendering()` here - need it to fire `ChangesApplied`
            // event after checkboxes are asynchronously updated
            await bentleyjs_core_1.using((this.state.model.pauseRendering()), async (_r) => {
                // note: calling this may actually mutate `model` in state - in
                // that case a `ChangesApplied` event will be emitted and the
                // `_onModelChanged` callback will be called
                await this.state.model.updateTreeCheckboxes(newProps.checkboxInfo);
            });
        }
    }
    assignModelListeners(model) {
        model.on(BeInspireTree_1.BeInspireTreeEvent.ChangesApplied, this._onModelChanged);
        model.on(BeInspireTree_1.BeInspireTreeEvent.NodeExpanded, this._onNodeExpanded);
        model.on(BeInspireTree_1.BeInspireTreeEvent.NodeCollapsed, this._onNodeCollapsed);
        model.on(BeInspireTree_1.BeInspireTreeEvent.ModelLoaded, this._onModelLoaded);
        model.on(BeInspireTree_1.BeInspireTreeEvent.ChildrenLoaded, this._onChildrenLoaded);
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        model.ready.then(async () => {
            // istanbul ignore else
            if (model === this.state.model)
                await this._onModelReady();
        });
    }
    dropModelListeners(model) {
        model.removeAllListeners();
    }
    assignDataProviderListeners(provider) {
        if (TreeDataProvider_1.isTreeDataProviderInterface(provider) && provider.onTreeNodeChanged) {
            provider.onTreeNodeChanged.addListener(this._onTreeNodeChanged);
        }
    }
    dropDataProviderListeners(provider) {
        if (TreeDataProvider_1.isTreeDataProviderInterface(provider) && provider.onTreeNodeChanged) {
            provider.onTreeNodeChanged.removeListener(this._onTreeNodeChanged);
        }
    }
    scrollToActiveNode() {
        if (!this._scrollableContainerRef.current || !this._treeRef.current
            || !this.props.nodeHighlightingProps || !this.props.nodeHighlightingProps.activeMatch) {
            return;
        }
        // scroll to active node
        const activeNodeId = this.props.nodeHighlightingProps.activeMatch.nodeId;
        const index = this.state.model.visible().findIndex((n) => n.id === activeNodeId);
        this._scrollableContainerRef.current.scrollToRow(index);
        // now make sure the active match is also visible
        const scrollTo = [...this._treeRef.current.getElementsByClassName(HighlightingEngine_1.HighlightingEngine.ACTIVE_CLASS_NAME)];
        if (scrollTo.length > 0)
            this._treeRef.current.scrollToElement(scrollTo[0]);
    }
    onNodesLoaded(nodes) {
        // clear node selection handlers' cache
        this._nodesSelectionHandlers = undefined;
        // update the selection state of already loaded nodes
        this.state.model.updateNodesSelection(nodes, this.props.selectedNodes);
        if (this.props.checkboxInfo) {
            // eslint-disable-next-line @typescript-eslint/no-floating-promises
            this.state.model.updateNodesCheckboxes(nodes, this.props.checkboxInfo);
        }
    }
    // eslint-disable-next-line @typescript-eslint/naming-convention
    get nodesSelectionHandlers() {
        if (!this._nodesSelectionHandlers) {
            this._nodesSelectionHandlers = [];
            const nodes = this.state.model.visible();
            for (const node of nodes) {
                this._nodesSelectionHandlers.push(this._createItemSelectionHandler(node));
            }
        }
        return this._nodesSelectionHandlers;
    }
    /** map TreeNodeItem into an InspireNode
     * @internal
     */
    static inspireNodeFromTreeNodeItem(item, remapper, base) {
        base = base || { text: "" };
        const node = Object.assign(Object.assign({}, base), { id: item.id, text: getPropertyRecordAsString_1.getPropertyRecordAsString(item.label), itree: Object.assign(Object.assign({}, base.itree), { state: Object.assign({}, (base.itree ? base.itree.state : undefined)) }) });
        if (item.isCheckboxVisible)
            node.itree.state.checkboxVisible = true;
        else
            delete node.itree.state.checkboxVisible;
        if (item.isCheckboxDisabled)
            node.itree.state.checkboxDisabled = true;
        else
            delete node.itree.state.checkboxDisabled;
        if (item.checkBoxState === ui_core_1.CheckBoxState.Partial) {
            node.itree.state.indeterminate = true;
            delete node.itree.state.checked;
        }
        else if (item.checkBoxState === ui_core_1.CheckBoxState.On) {
            node.itree.state.checked = true;
            delete node.itree.state.indeterminate;
        }
        else {
            delete node.itree.state.checked;
            delete node.itree.state.indeterminate;
        }
        if (item.icon)
            node.itree.icon = item.icon;
        if (item.autoExpand)
            node.itree.state.collapsed = false;
        if (item.hasChildren)
            node.children = true;
        else if (item.children)
            node.children = item.children.map((p) => remapper(p, remapper));
        return node;
    }
    createTreeNodeProps(node) {
        const onNodeSelectionChanged = this._selectionHandler.createSelectionFunction(this._multiSelectionHandler, this._createItemSelectionHandler(node));
        return {
            node,
            checkboxProps: node.itree.state.checkboxVisible ? {
                isDisabled: node.itree.state.checkboxDisabled,
                state: node.itree.state.checked ? ui_core_1.CheckBoxState.On : ui_core_1.CheckBoxState.Off,
                onClick: this._onCheckboxClick,
                tooltip: node.itree.checkboxTooltip,
            } : undefined,
            cellEditing: this.state.cellEditingEngine,
            showDescription: this.props.showDescriptions,
            renderOverrides: {
                renderCheckbox: this.props.renderOverrides ? this.props.renderOverrides.renderCheckbox : undefined,
            },
            renderId: this._nodesRenderInfo ? this._nodesRenderInfo.renderId : /* istanbul ignore next */ undefined,
            onFinalRenderComplete: this._onNodeFullyRendered,
            highlightProps: this.state.highlightingEngine
                ? this.state.highlightingEngine.createRenderProps(node)
                : undefined,
            valueRendererManager: this.props.propertyValueRendererManager
                ? this.props.propertyValueRendererManager
                : ValueRendererManager_1.PropertyValueRendererManager.defaultManager,
            imageLoader: this.props.showIcons ? (this.props.imageLoader ? this.props.imageLoader : this._defaultImageLoader) : undefined,
            onClick: (e) => {
                onNodeSelectionChanged(e.shiftKey, e.ctrlKey);
                if (this.state.cellEditingEngine)
                    this.state.cellEditingEngine.checkStatus(node, this._pressedItemSelected);
            },
            onMouseDown: () => this._selectionHandler.createDragAction(this._multiSelectionHandler, [this.nodesSelectionHandlers], node),
            onMouseMove: (e) => { if (e.buttons === 1)
                this._selectionHandler.updateDragAction(node); },
        };
    }
    /** Get loaded node by its ID */
    // istanbul ignore next
    getLoadedNode(id) {
        const node = this.state.model.node(id);
        return node ? node.payload : undefined;
    }
    /** @internal */
    render() {
        if (!this.state.modelReady) {
            return (React.createElement("div", { className: "components-tree-loader" },
                React.createElement(ui_core_1.Spinner, { size: ui_core_1.SpinnerSize.Large })));
        }
        const nodes = this.state.model.visible();
        if (nodes.length === 0) {
            return (React.createElement("p", { className: "components-tree-errormessage" }, this.props.nodeHighlightingProps ?
                UiComponents_1.UiComponents.i18n.translateWithNamespace(UiComponents_1.UiComponents.i18nNamespace, "tree.noResultsForFilter", { searchText: this.props.nodeHighlightingProps.searchText }) :
                UiComponents_1.UiComponents.translate("general.noData")));
        }
        // This is a hack (since it doesn't have a proper public method) to force Virtualized List to clear cell cache.
        // There is recomputeRowHeights, but it forces an update
        if (this._scrollableContainerRef.current && this._scrollableContainerRef.current.Grid)
            this._scrollableContainerRef.current.Grid.state.instanceProps.rowSizeAndPositionManager.resetCell(0);
        const getNodesRenderInfo = () => {
            if (!this._nodesRenderInfo)
                this._nodesRenderInfo = { total: 0, rendered: 0, renderId: bentleyjs_core_1.Guid.createValue() };
            return this._nodesRenderInfo;
        };
        this._nodesRenderInfo = undefined;
        const baseRenderNode = this.props.renderOverrides && this.props.renderOverrides.renderNode ? this.props.renderOverrides.renderNode : this.defaultRenderNode;
        const renderNode = ({ index, style, isScrolling }) => {
            const node = nodes[index];
            const key = node.id ? node.id : /* istanbul ignore next */ node.text;
            // Mark selected node's wrapper to make detecting consecutively selected nodes with css selectors possible
            const className = classnames_1.default("node-wrapper", { "is-selected": node.selected() });
            if (!node.payload) {
                // istanbul ignore else
                if (!isScrolling) {
                    // eslint-disable-next-line @typescript-eslint/no-floating-promises
                    this.state.model.requestNodeLoad(BeInspireTree_1.toNode(node.getParent()), node.placeholderIndex);
                }
                return (React.createElement("div", { key: key, className: className, style: style },
                    React.createElement(PlaceholderNode, { key: node.id, node: node })));
            }
            getNodesRenderInfo().total++;
            const props = this.createTreeNodeProps(node);
            return (React.createElement("div", { key: key, className: className, style: style }, baseRenderNode(node, props)));
        };
        const getRowHeight = ({ index }) => {
            if (this.props.rowHeight && typeof (this.props.rowHeight) === "number")
                return this.props.rowHeight;
            const getHeight = this.props.rowHeight && typeof (this.props.rowHeight) === "function" ? this.props.rowHeight : this._getNodeHeight;
            return getHeight(nodes[index].payload, index);
        };
        return (React.createElement(ui_core_1.Tree, { ref: this._treeRef, onMouseDown: this._onMouseDown, className: classnames_1.default("components-tree", this.props.className), style: this.props.style },
            React.createElement(react_virtualized_1.AutoSizer, null, ({ width, height }) => (React.createElement(react_virtualized_1.List, { ref: this._scrollableContainerRef, width: width, height: height, rowCount: nodes.length, overscanRowCount: 10, rowHeight: getRowHeight, rowRenderer: renderNode, autoContainerWidth: false })))));
    }
}
exports.DEPRECATED_Tree = DEPRECATED_Tree;
DEPRECATED_Tree.defaultProps = {
    selectionMode: SelectionModes_1.SelectionMode.Single,
};
/**
 * Default component for rendering a node for the [[DEPRECATED_Tree]]
 */
class PlaceholderNode extends React.Component {
    shouldComponentUpdate(nextProps) {
        return nextProps.node.isDirty() || this.props.node.id !== nextProps.node.id;
    }
    render() {
        // note: props get mutated here
        this.props.node.setDirty(false);
        const level = this.props.node.getParents().length + 1;
        return React.createElement(ui_core_1.TreeNodePlaceholder, { level: level });
    }
}
//# sourceMappingURL=Tree.js.map