"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tree
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEPRECATED_withTreeDragDrop = void 0;
const React = __importStar(require("react"));
const ui_core_1 = require("@bentley/ui-core");
const withDropTarget_1 = require("../../../dragdrop/withDropTarget");
const Node_1 = require("../component/Node");
const DragDropTreeNode_1 = require("./DragDropTreeNode");
/**
 * A HOC component that adds drag and drop functionality to the supplied tree component.
 * @beta
 * @deprecated
 */
// eslint-disable-next-line @typescript-eslint/naming-convention
function DEPRECATED_withTreeDragDrop(TreeComponent) {
    // eslint-disable-next-line @typescript-eslint/naming-convention
    const DropTree = withDropTarget_1.withDropTarget(TreeComponent);
    return class WithDragAndDrop extends React.Component {
        constructor() {
            super(...arguments);
            this.renderNode = (item, props) => {
                // istanbul ignore next
                const baseNode = this.props.renderOverrides && this.props.renderOverrides.renderNode ? this.props.renderOverrides.renderNode(item, props) : React.createElement(Node_1.TreeNode, Object.assign({}, props));
                const DDTreeNode = DragDropTreeNode_1.DragDropTreeNode(); // eslint-disable-line @typescript-eslint/naming-convention
                return (React.createElement(DDTreeNode, { key: item.id, dragProps: this.createNodeDragProps(item), dropProps: this.createNodeDropProps(item), shallow: true }, baseNode));
            };
        }
        static get displayName() { return `WithDragAndDrop(${ui_core_1.getDisplayName(TreeComponent)})`; }
        createTreeDropProps() {
            if (!this.props.dropProps)
                return {};
            const { onDropTargetOver, onDropTargetDrop, canDropTargetDrop, objectTypes } = this.props.dropProps;
            const dropProps = {
                onDropTargetOver: (args) => {
                    // istanbul ignore else
                    if (onDropTargetOver) {
                        args.dropLocation = this.props.dataProvider;
                        onDropTargetOver(args);
                    }
                },
                onDropTargetDrop: (args) => {
                    args.dropLocation = this.props.dataProvider;
                    return onDropTargetDrop ? onDropTargetDrop(args) : args;
                },
                canDropTargetDrop: (args) => {
                    args.dropLocation = this.props.dataProvider;
                    return canDropTargetDrop ? canDropTargetDrop(args) : true;
                },
                objectTypes,
            };
            return dropProps;
        }
        createNodeDragProps(item) {
            if (!this.props.dragProps)
                return {};
            const parent = item.getParent();
            const { onDragSourceBegin, onDragSourceEnd, objectType } = this.props.dragProps;
            const dragProps = {
                onDragSourceBegin: (args) => {
                    args.dataObject = (item.payload && item.payload.extendedData);
                    args.parentObject = ((parent && parent.payload) || this.props.dataProvider);
                    return onDragSourceBegin ? onDragSourceBegin(args) : args;
                },
                onDragSourceEnd: (args) => {
                    // istanbul ignore else
                    if (onDragSourceEnd) {
                        args.parentObject = ((parent && parent.payload) || this.props.dataProvider);
                        onDragSourceEnd(args);
                    }
                },
                objectType: () => {
                    // istanbul ignore else
                    if (objectType) {
                        if (typeof objectType === "function")
                            return objectType(item.payload.extendedData);
                        else
                            return objectType;
                    }
                    else
                        return "";
                },
            };
            return dragProps;
        }
        createNodeDropProps(item) {
            if (!this.props.dropProps)
                return {};
            const parent = item.getParent();
            let index = 0;
            if (parent !== undefined)
                index = parent.getChildren().indexOf(item);
            const { onDropTargetOver, onDropTargetDrop, canDropTargetDrop, objectTypes } = this.props.dropProps;
            const dropProps = {
                onDropTargetOver: (args) => {
                    // istanbul ignore else
                    if (onDropTargetOver) {
                        // populate tree information while it's accessible
                        args.dropLocation = item.payload;
                        if (args.dropRect) {
                            const relativeY = (args.clientOffset.y - args.dropRect.top) / args.dropRect.height;
                            if ((relativeY < 1 / 3 || relativeY > 2 / 3) && index !== undefined) {
                                args.dropLocation = (parent && parent.payload) || this.props.dataProvider;
                                args.row = index;
                                if (relativeY > 2 / 3) {
                                    args.row = index + 1;
                                }
                            }
                        }
                        onDropTargetOver(args);
                    }
                },
                onDropTargetDrop: (args) => {
                    // populate tree information while it's accessible
                    args.dropLocation = item.payload;
                    if (args.dropRect) {
                        const relativeY = (args.clientOffset.y - args.dropRect.top) / args.dropRect.height;
                        if ((relativeY < 1 / 3 || relativeY > 2 / 3) && index !== undefined) {
                            args.dropLocation = (parent && parent.payload) || this.props.dataProvider;
                            args.row = index;
                            if (relativeY > 2 / 3) {
                                args.row = index + 1;
                            }
                        }
                    }
                    if (onDropTargetDrop)
                        return onDropTargetDrop(args);
                    return args;
                },
                canDropTargetDrop: (args) => {
                    // populate tree information while it's accessible
                    args.dropLocation = item.payload;
                    if (canDropTargetDrop)
                        return canDropTargetDrop(args);
                    return true;
                },
                objectTypes,
            };
            return dropProps;
        }
        render() {
            const _a = this.props, { dragProps, dropProps, renderNode } = _a, treeProps = __rest(_a, ["dragProps", "dropProps", "renderNode"]); // eslint-disable-line @typescript-eslint/no-unused-vars
            return (React.createElement(DropTree, Object.assign({}, treeProps, { renderNode: this.renderNode, dropStyle: { height: "100%" }, dropProps: this.createTreeDropProps(), shallow: true })));
        }
    };
}
exports.DEPRECATED_withTreeDragDrop = DEPRECATED_withTreeDragDrop;
//# sourceMappingURL=withDragDrop.js.map