/** @packageDocumentation
 * @module Viewport
 */
import { Matrix3d, Point3d, Vector3d } from "@bentley/geometry-core";
import { StandardViewId, Viewport } from "@bentley/imodeljs-frontend";
import { Face, UiEvent } from "@bentley/ui-core";
/** Arguments for [[DrawingViewportChangeEvent]]
 * @public
 */
export interface DrawingViewportChangeEventArgs {
    rotation: Matrix3d;
    origin: Point3d;
    complete: boolean;
}
/** Drawing View Change event
 * @public
 */
export declare class DrawingViewportChangeEvent extends UiEvent<DrawingViewportChangeEventArgs> {
}
/** Arguments for [[CubeRotationChangeEvent]]
 * @public
 */
export interface CubeRotationChangeEventArgs {
    rotMatrix: Matrix3d;
    face: Face;
    complete?: boolean;
}
/** 3d Cube Rotation Change event
 * @public
 */
export declare class CubeRotationChangeEvent extends UiEvent<CubeRotationChangeEventArgs> {
}
/** Arguments for [[StandardRotationChangeEvent]]
 * @public
 */
export interface StandardRotationChangeEventArgs {
    standardRotation: StandardViewId;
}
/** Standard Rotation Change event
 * @public
 */
export declare class StandardRotationChangeEvent extends UiEvent<StandardRotationChangeEventArgs> {
}
/** Arguments for [[ViewRotationChangeEvent]]
 * @public
 */
export interface ViewRotationChangeEventArgs {
    viewport: Viewport;
    animationTime?: number;
}
/** View Rotation Change event
 * @public
 */
export declare class ViewRotationChangeEvent extends UiEvent<ViewRotationChangeEventArgs> {
}
/** Arguments for [[ViewClassFullNameChangedEvent]]
 * @public
 */
export interface ViewClassFullNameChangedEventArgs {
    viewport: Viewport;
    oldName: string;
    newName: string;
}
/** View Class Full Name Change event
 * @public
 */
export declare class ViewClassFullNameChangedEvent extends UiEvent<ViewClassFullNameChangedEventArgs> {
}
/** Arguments for [[ViewIdChangedEvent]]
 * @public
 */
export interface ViewIdChangedEventArgs {
    viewport: Viewport;
    oldId: string;
    newId: string;
}
/** View Id Change event
 * @public
 */
export declare class ViewIdChangedEvent extends UiEvent<ViewIdChangedEventArgs> {
}
/** Viewport Rotation events and methods
 * @public
 */
export declare class ViewportComponentEvents {
    private static _removeListener?;
    static initialize(): void;
    /** @internal - for unit testing */
    static terminate(): void;
    static face: Face;
    static readonly origin: Point3d;
    static readonly extents: Vector3d;
    static readonly rotationMatrix: Matrix3d;
    static readonly onDrawingViewportChangeEvent: DrawingViewportChangeEvent;
    static readonly onCubeRotationChangeEvent: CubeRotationChangeEvent;
    static readonly onStandardRotationChangeEvent: StandardRotationChangeEvent;
    static readonly onViewRotationChangeEvent: ViewRotationChangeEvent;
    static readonly onViewClassFullNameChangedEvent: ViewClassFullNameChangedEvent;
    static readonly onViewIdChangedEvent: ViewIdChangedEvent;
    private static handleSelectedViewportChanged;
    static setCubeMatrix(rotMatrix: Matrix3d, face?: Face, complete?: boolean): void;
    static setDrawingViewportState(origin: Point3d, rotation: Matrix3d, complete?: boolean): void;
    static setStandardRotation(standardRotation: StandardViewId): void;
    static setViewMatrix(viewport: Viewport, animationTime?: number): void;
}
//# sourceMappingURL=ViewportComponentEvents.d.ts.map